@@ -25,7 +25,6 @@ __docformat__ = 'restructuredtext'
 
 import os
 import posixpath
-from copy import copy
 import logging
 import transaction
 
@@ -37,13 +36,11 @@ if HAS_LINGUA_PLONE:
     from Products.LinguaPlone.public import BaseBTreeFolder
     from Products.LinguaPlone.public import registerType
 else:
-    from Products.Archetypes.public import BaseContent
-    from Products.Archetypes.public import BaseFolder
-    from Products.Archetypes.public import OrderedBaseFolder
-    from Products.Archetypes.public import BaseBTreeFolder
-    from Products.Archetypes.public import registerType
-
-from Products.ATContentTypes.config import HAS_PLONE2
+    from Products.Archetypes.atapi import BaseContent
+    from Products.Archetypes.atapi import BaseFolder
+    from Products.Archetypes.atapi import OrderedBaseFolder
+    from Products.Archetypes.atapi import BaseBTreeFolder
+    from Products.Archetypes.atapi import registerType
 
 from AccessControl import ClassSecurityInfo, Permissions
 from ComputedAttribute import ComputedAttribute
@@ -62,36 +59,20 @@ from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from Products.CMFCore.permissions import ManageProperties
 from Products.CMFCore.utils import getToolByName
-
 from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin
-from Products.ATContentTypes import permission as ATCTPermissions
+from Products.CMFPlone.PloneFolder import ReplaceableWrapper
 
-from Products.ATContentTypes.config import CHAR_MAPPING
-from Products.ATContentTypes.config import GOOD_CHARS
+from Products.ATContentTypes import permission as ATCTPermissions
 from Products.ATContentTypes.config import MIME_ALIAS
 from Products.ATContentTypes.lib.constraintypes import ConstrainTypesMixin
 from Products.ATContentTypes.interfaces import IATContentType
 from Products.ATContentTypes.content.schemata import ATContentTypeSchema
 
+from plone.i18n.normalizer.interfaces import IUserPreferredFileNameNormalizer
+
 DEBUG = True
 LOG = logging.getLogger('ATCT')
 
-if HAS_PLONE2:
-    # the browser default checks for isinstance()
-    from Products.CMFPlone.PloneFolder import ReplaceableWrapper
-else:
-    class ReplaceableWrapper:
-        """A wrapper around an object to make it replaceable
-        """
-        def __init__(self, ob):
-            self.__ob = ob
-
-        def __getattr__(self, name):
-            if name == '__replaceable__':
-                return REPLACEABLE
-            return getattr(self.__ob, name)
-
-
 def registerATCT(class_, project):
     """Registers an ATContentTypes based type
 
@@ -100,49 +81,14 @@ def registerATCT(class_, project):
     assert IATContentType.isImplementedByInstancesOf(class_)
     registerType(class_, project)
 
-def updateActions(klass, actions):
-    """Merge the actions from a class with a list of actions
-    """
-    kactions = copy(klass.actions)
-    aids  = [action.get('id') for action in actions ]
-    actions = list(actions)
-
-    for kaction in kactions:
-        kaid = kaction.get('id')
-        if kaid not in aids:
-            actions.append(kaction)
-
-    return tuple(actions)
-
-def updateAliases(klass, aliases):
-    """Merge the method aliases from a class with a dict of aliases
-    """
-    oldAliases = copy(klass.aliases)
-
-    for aliasId, aliasTarget in oldAliases.items():
-        if aliasId not in aliases:
-            aliases[aliasId] = aliasTarget
-
-    return aliases
-
-def cleanupFilename(filename, context=None, encoding='utf-8'):
+def cleanupFilename(filename, request=None):
     """Removes bad chars from file names to make them a good id
     """
     if not filename:
         return
-    if context is not None:
-        plone_utils = getToolByName(context, 'plone_utils', None)
-        if plone_utils is not None:
-            return plone_utils.normalizeString(filename, relaxed=True)
-
-    # no context or plone_utils
-    result = u''
-    for s in str(filename).decode(encoding):
-        s = CHAR_MAPPING.get(s, s)
-        for c in s:
-            if c in GOOD_CHARS:
-                result += c
-    return result.encode(encoding)
+    if request is not None:
+        return IUserPreferredFileNameNormalizer(request).normalize(filename)
+    return None
 
 def translateMimetypeAlias(alias):
     """Maps old CMF content types to real mime types
@@ -157,16 +103,11 @@ def translateMimetypeAlias(alias):
 
 class ATCTMixin(BrowserDefaultMixin):
     """Mixin class for AT Content Types"""
+
     schema         =  ATContentTypeSchema
 
-    # content_icon   = 'document_icon.gif'
-    meta_type      = 'ATContentType'
     archetype_name = 'AT Content Type'
-    immediate_view = 'base_view'
-    suppl_views    = ()
     _atct_newTypeFor = {'portal_type' : None, 'meta_type' : None}
-    typeDescription= ''
-    typeDescMsgId  = ''
     assocMimetypes = ()
     assocFileExt   = ()
     cmf_edit_kws   = ()
@@ -179,37 +120,6 @@ class ATCTMixin(BrowserDefaultMixin):
 
     security       = ClassSecurityInfo()
 
-    actions = ({
-        'id'          : 'view',
-        'name'        : 'View',
-        'action'      : 'string:${object_url}',
-        'permissions' : (View,)
-         },
-        {
-        'id'          : 'edit',
-        'name'        : 'Edit',
-        'action'      : 'string:${object_url}/edit',
-        'permissions' : (ModifyPortalContent,),
-         },
-        {
-        'id'          : 'metadata',
-        'name'        : 'Properties',
-        'action'      : 'string:${object_url}/properties',
-        'permissions' : (ModifyPortalContent,),
-         },
-        )
-
-    aliases = {
-        '(Default)'  : '(dynamic view)',
-        'view'       : '(selected layout)',
-        'index.html' : '(dynamic view)',
-        'edit'       : 'atct_edit',
-        'properties' : 'base_metadata',
-        'sharing'    : 'folder_localrole_form',
-        'gethtml'    : '',
-        'mkdir'      : '',
-        }
-
     security.declareProtected(ModifyPortalContent,
                               'initializeArchetype')
     def initializeArchetype(self, **kwargs):
@@ -234,7 +144,6 @@ class ATCTMixin(BrowserDefaultMixin):
             if DEBUG and str(msg) not in ('SESSION',):
                 # debug code
                 raise
-                #_default_logger.log_exc()
 
     security.declarePrivate('copyLayoutFromParent')
     def copyLayoutFromParent(self):
@@ -303,23 +212,6 @@ class ATCTContent(ATCTMixin, BaseContent):
                       ATCTMixin.__implements__)
 
     security       = ClassSecurityInfo()
-    actions = updateActions(ATCTMixin,
-        ({
-          'id'          : 'external_edit',
-          'name'        : 'External Edit',
-          'action'      : 'string:${object_url}/external_edit',
-          'condition'   : 'object/externalEditorEnabled',
-          'permissions' : (ModifyPortalContent,),
-          'visible'     : 0,
-         },
-        {
-        'id'          : 'local_roles',
-        'name'        : 'Sharing',
-        'action'      : 'string:${object_url}/sharing',
-        'permissions' : (ManageProperties,),
-         },
-        )
-    )
 
     security.declarePrivate('manage_afterPUT')
     def manage_afterPUT(self, data, marshall_data, file, context, mimetype,
@@ -354,30 +246,12 @@ class ATCTFileContent(ATCTContent):
     # (not yet) supported.
     precondition = ''
 
-    security = ClassSecurityInfo()
-    actions = updateActions(ATCTContent,
-        ({
-        'id'          : 'view',
-        'name'        : 'View',
-        'action'      : 'string:${object_url}/view',
-        'permissions' : (View,)
-         },
-         {
-        'id'          : 'download',
-        'name'        : 'Download',
-        'action'      : 'string:${object_url}/download',
-        'permissions' : (View,),
-        'condition'   : 'member', # don't show border for anon user
-        'visible'     :  False,
-         },
+    manage_options = (
+        ATCTContent.manage_options[0:1] +
+        ATCTContent.manage_options[2:]
         )
-    )
 
-    aliases = updateAliases(ATCTMixin,
-        {
-        '(Default)' : 'index_html',
-        'view'      : '(selected layout)',
-        })
+    security = ClassSecurityInfo()
 
     security.declareProtected(View, 'download')
     def download(self, REQUEST=None, RESPONSE=None):
@@ -435,12 +309,8 @@ class ATCTFileContent(ATCTContent):
             kwargs['mimetype'] = content_type
         mutator = self.getPrimaryField().getMutator(self)
         mutator(data, **kwargs)
-        ##self.ZCacheable_invalidate()
-        ##self.ZCacheable_set(None)
-        ##self.http__refreshEtag()
 
-    security.declareProtected(ModifyPortalContent,
-                              'manage_edit')
+    security.declareProtected(ModifyPortalContent, 'manage_edit')
     def manage_edit(self, title, content_type, precondition='',
                     filedata=None, REQUEST=None):
         """
@@ -456,12 +326,15 @@ class ATCTFileContent(ATCTContent):
             message="Saved changes."
             return self.manage_main(self,REQUEST,manage_tabs_message=message)
 
-    def _cleanupFilename(self, filename, encoding=None):
+    def _cleanupFilename(self, filename, request=None):
         """Cleans the filename from unwanted or evil chars
         """
-        if encoding is None:
+        if filename and not isinstance(filename, unicode):
             encoding = self.getCharset()
-        return cleanupFilename(filename, context=self, encoding=encoding)
+            filename = unicode(filename, encoding)
+
+        filename = cleanupFilename(filename, request=request)
+        return filename and filename.encode(encoding) or None
 
     def _setATCTFileContent(self, value, **kwargs):
         """Set id to uploaded id
@@ -471,8 +344,9 @@ class ATCTFileContent(ATCTContent):
         field.set(self, value, **kwargs) # set is ok
         if self._isIDAutoGenerated(self.getId()):
             filename = field.getFilename(self, fromBaseUnit=False)
-            clean_filename = self._cleanupFilename(filename)
-            request_id = self.REQUEST.form.get('id')
+            request = self.REQUEST
+            clean_filename = self._cleanupFilename(filename, request=request)
+            request_id = request.form.get('id')
             if request_id and not self._isIDAutoGenerated(request_id):
                 # request contains an id
                 # skip renaming when then request id is not autogenerated which
@@ -501,7 +375,7 @@ class ATCTFileContent(ATCTContent):
         if isinstance(filename, basestring):
             filename = os.path.basename(filename)
             filename = filename.split("\\")[-1]
-        clean_filename = self._cleanupFilename(filename)
+        clean_filename = self._cleanupFilename(filename, request=REQUEST)
         used_id = (id and not self._isIDAutoGenerated(id)) and id or clean_filename
 
         if upload:
@@ -564,22 +438,6 @@ class ATCTFolder(ATCTMixin, BaseFolder):
 
     security       = ClassSecurityInfo()
 
-    actions = updateActions(ATCTMixin,
-        ({
-        'id'          : 'local_roles',
-        'name'        : 'Sharing',
-        'action'      : 'string:${object_url}/sharing',
-        'permissions' : (ManageProperties,),
-         },
-        {
-        'id'          : 'view',
-        'name'        : 'View',
-        'action'      : 'string:${folder_url}/',
-        'permissions' : (View,),
-         },
-        )
-    )
-
     security.declareProtected(View, 'get_size')
     def get_size(self):
         """Returns 1 as folders have no size."""
@@ -599,10 +457,7 @@ class ATCTFolderMixin(ConstrainTypesMixin, ATCTMixin):
     def __browser_default__(self, request):
         """ Set default so we can return whatever we want instead
         of index_html """
-        if HAS_PLONE2:
-            return getToolByName(self, 'plone_utils').browserDefault(self)
-        else:
-            return self, [self.getLayout(),]
+        return getToolByName(self, 'plone_utils').browserDefault(self)
 
     security.declareProtected(View, 'get_size')
     def get_size(self):
@@ -660,22 +515,6 @@ class ATCTOrderedFolder(ATCTFolderMixin, OrderedBaseFolder):
 
     security       = ClassSecurityInfo()
 
-    actions = updateActions(ATCTMixin,
-        ({
-        'id'          : 'local_roles',
-        'name'        : 'Sharing',
-        'action'      : 'string:${object_url}/sharing',
-        'permissions' : (ManageProperties,),
-         },
-        {
-        'id'          : 'view',
-        'name'        : 'View',
-        'action'      : 'string:${folder_url}/',
-        'permissions' : (View,),
-         },
-        )
-    )
-
     security.declareProtected(View, 'index_html')
     def index_html(self, REQUEST=None, RESPONSE=None):
         """Special case index_html"""
@@ -710,22 +549,6 @@ class ATCTBTreeFolder(ATCTFolderMixin, BaseBTreeFolder):
 
     security       = ClassSecurityInfo()
 
-    actions = updateActions(ATCTMixin,
-        ({
-        'id'          : 'local_roles',
-        'name'        : 'Sharing',
-        'action'      : 'string:${object_url}/sharing',
-        'permissions' : (ManageProperties,),
-         },
-        {
-        'id'          : 'view',
-        'name'        : 'View',
-        'action'      : 'string:${folder_url}/',
-        'permissions' : (View,),
-         },
-        )
-    )
-
     security.declareProtected(View, 'index_html')
     def index_html(self, REQUEST=None, RESPONSE=None):
         """
@@ -748,4 +571,4 @@ InitializeClass(ATCTBTreeFolder)
 
 
 __all__ = ('ATCTContent', 'ATCTFolder', 'ATCTOrderedFolder',
-           'ATCTBTreeFolder', 'updateActions' )
+           'ATCTBTreeFolder' )
