@@ -34,79 +34,85 @@ from Products.CMFCore.utils import getToolByName
 from AccessControl import ClassSecurityInfo
 from ComputedAttribute import ComputedAttribute
 
-from Products.CMFDefault.utils import html_headcheck
 from Products.CMFDefault.utils import SimpleHTMLParser
 
-from Products.Archetypes.public import Schema
-from Products.Archetypes.public import TextField
-from Products.Archetypes.public import RichWidget
-from Products.Archetypes.public import RFC822Marshaller
-from Products.Archetypes.public import AnnotationStorage
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import TextField
+from Products.Archetypes.atapi import BooleanField
+from Products.Archetypes.atapi import RichWidget
+from Products.Archetypes.atapi import BooleanWidget
+from Products.Archetypes.atapi import RFC822Marshaller
+from Products.Archetypes.atapi import AnnotationStorage
 
 from Products.ATContentTypes.configuration import zconf
 from Products.ATContentTypes.config import PROJECTNAME
-from Products.ATContentTypes.config import HAS_PLONE2
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.base import ATCTContent
-from Products.ATContentTypes.content.base import updateActions
 from Products.ATContentTypes.content.base import translateMimetypeAlias
 from Products.ATContentTypes.content.schemata import ATContentTypeSchema
 from Products.ATContentTypes.content.schemata import finalizeATCTSchema
 from Products.ATContentTypes.lib.historyaware import HistoryAwareMixin
 from Products.ATContentTypes.interfaces import IATDocument
 
+from Products.ATContentTypes import ATCTMessageFactory as _
+
 ATDocumentSchema = ATContentTypeSchema.copy() + Schema((
     TextField('text',
-              required=True,
+              required=False,
               searchable=True,
               primary=True,
               storage = AnnotationStorage(migrate=True),
               validators = ('isTidyHtmlWithCleanup',),
               #validators = ('isTidyHtml',),
-              default_content_type = zconf.ATDocument.default_content_type,
               default_output_type = 'text/x-html-safe',
-              allowable_content_types = zconf.ATDocument.allowed_content_types,
               widget = RichWidget(
-                        description = "",
-                        description_msgid = "help_body_text",
-                        label = "Body Text",
-                        label_msgid = "label_body_text",
+                        description = '',
+                        label = _(u'label_body_text', default=u'Body Text'),
                         rows = 25,
-                        i18n_domain = "plone",
-                        allow_file_upload = zconf.ATDocument.allow_document_upload)),
-    ), marshall=RFC822Marshaller()
+                        allow_file_upload = zconf.ATDocument.allow_document_upload),
+    ),
+    BooleanField('presentation',
+        required = False,
+        languageIndependent = True,
+        widget = BooleanWidget(
+            label= _(
+                u'help_enable_presentation', 
+                default=u'Presentation mode'),
+            description = _(
+                u'help_enable_presentation_description', 
+                default=u'If selected, this will give users the ability to view the contents as presentation slides.')
+            ),
+    ),
+    BooleanField('tableContents',
+        required = False,
+        languageIndependent = True,
+        widget = BooleanWidget(
+            label= _(
+                u'help_enable_table_of_contents', 
+                default=u'Table of contents'),
+            description = _(
+                u'help_enable_table_of_contents_description', 
+                default=u'If selected, this will show a table of contents at the top of the page.')
+            ),
+    )),
+    marshall=RFC822Marshaller()
     )
-finalizeATCTSchema(ATDocumentSchema)
 
-class ATDocument(ATCTContent, HistoryAwareMixin):
+finalizeATCTSchema(ATDocumentSchema)
+# moved schema setting after finalizeATCTSchema, so the order of the fieldsets
+# is preserved
+ATDocumentSchema.changeSchemataForField('presentation', 'settings')
+ATDocumentSchema.changeSchemataForField('tableContents', 'settings')
+
+class ATDocumentBase(ATCTContent, HistoryAwareMixin):
     """A page in the site. Can contain rich text."""
 
-    schema         =  ATDocumentSchema
-
-    content_icon   = 'document_icon.gif'
-    meta_type      = 'ATDocument'
-    portal_type    = 'Document'
-    archetype_name = 'Page'
-    default_view   = 'document_view'
-    immediate_view = 'document_view'
-    suppl_views    = ()
-    _atct_newTypeFor = {'portal_type' : 'CMF Document', 'meta_type' : 'Document'}
-    typeDescription= 'A page in the site. Can contain rich text.'
-    typeDescMsgId  = 'description_edit_document'
-    assocMimetypes = ('application/xhtml+xml', 'message/rfc822', 'text/*',)
-    assocFileExt   = ('txt', 'stx', 'rst', 'rest', 'py',)
-    cmf_edit_kws   = ('text_format',)
-
     __implements__ = (ATCTContent.__implements__,
-                      IATDocument,
                       HistoryAwareMixin.__implements__,
                      )
 
     security       = ClassSecurityInfo()
-
-    actions = updateActions(ATCTContent,
-                            HistoryAwareMixin.actions
-                           )
+    cmf_edit_kws   = ('text_format',)
 
     security.declareProtected(View, 'CookedBody')
     def CookedBody(self, stx_level='ignored'):
@@ -199,9 +205,9 @@ class ATDocument(ATCTContent, HistoryAwareMixin):
         """Get the tidied output for a specific field from the request
         if available
         """
-        request = self.REQUEST
-        tidyAttribute = '%s_tidier_data' % field.getName()
-        if isinstance(request, HTTPRequest):
+        request = getattr(self, 'REQUEST', None)
+        if request is not None and isinstance(request, HTTPRequest):
+            tidyAttribute = '%s_tidier_data' % field.getName()
             return request.get(tidyAttribute, None)
 
     def _notifyOfCopyTo(self, container, op=0):
@@ -239,13 +245,6 @@ class ATDocument(ATCTContent, HistoryAwareMixin):
         self.setText(text, mimetype=translateMimetypeAlias(text_format))
         self.update(**kwargs)
 
-    def deferring(self):
-        """
-        """
-        t = time.time()
-        time.sleep(10)
-        return str(time.time(), t)
-
     security.declarePrivate('manage_afterPUT')
     def manage_afterPUT(self, data, marshall_data, file, context, mimetype,
                         filename, REQUEST, RESPONSE):
@@ -260,7 +259,7 @@ class ATDocument(ATCTContent, HistoryAwareMixin):
         else:
             content = data
 
-        if -1 != content.lower().find("<html>"):
+        if -1 != content.lower().find("<html"):
             parser = SimpleHTMLParser()
             parser.feed(content)
             if parser.title:
@@ -271,4 +270,17 @@ class ATDocument(ATCTContent, HistoryAwareMixin):
                                     context, mimetype, filename, REQUEST,
                                     RESPONSE)
 
+class ATDocument(ATDocumentBase):
+    """A page in the site. Can contain rich text."""
+
+    schema         =  ATDocumentSchema
+
+    portal_type    = 'Document'
+    archetype_name = 'Page'
+    _atct_newTypeFor = {'portal_type' : 'CMF Document', 'meta_type' : 'Document'}
+    assocMimetypes = ('application/xhtml+xml', 'message/rfc822', 'text/*',)
+    assocFileExt   = ('txt', 'stx', 'rst', 'rest', 'py',)
+
+    __implements__ = ATDocumentBase.__implements__, IATDocument
+
 registerATCT(ATDocument, PROJECTNAME)
