@@ -27,30 +27,27 @@ __old_name__ = 'Products.ATContentTypes.types.ATEvent'
 from types import StringType
 
 from Products.CMFCore.permissions import ModifyPortalContent, View
-from Products.CMFCore.utils import getToolByName
 from AccessControl import ClassSecurityInfo
 from DateTime import DateTime
 from ComputedAttribute import ComputedAttribute
 
-from Products.Archetypes.public import Schema
-from Products.Archetypes.public import DateTimeField
-from Products.Archetypes.public import LinesField
-from Products.Archetypes.public import StringField
-from Products.Archetypes.public import TextField
-from Products.Archetypes.public import CalendarWidget
-from Products.Archetypes.public import LinesWidget
-from Products.Archetypes.public import KeywordWidget
-from Products.Archetypes.public import RichWidget
-from Products.Archetypes.public import StringWidget
-from Products.Archetypes.public import RFC822Marshaller
-from Products.Archetypes.public import AnnotationStorage
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import DateTimeField
+from Products.Archetypes.atapi import LinesField
+from Products.Archetypes.atapi import StringField
+from Products.Archetypes.atapi import TextField
+from Products.Archetypes.atapi import CalendarWidget
+from Products.Archetypes.atapi import LinesWidget
+from Products.Archetypes.atapi import KeywordWidget
+from Products.Archetypes.atapi import RichWidget
+from Products.Archetypes.atapi import StringWidget
+from Products.Archetypes.atapi import RFC822Marshaller
+from Products.Archetypes.atapi import AnnotationStorage
 
 from Products.ATContentTypes.configuration import zconf
 from Products.ATContentTypes.config import PROJECTNAME
-from Products.ATContentTypes.config import HAS_PLONE2
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.base import ATCTContent
-from Products.ATContentTypes.content.base import updateActions
 from Products.ATContentTypes.interfaces import IATEvent
 from Products.ATContentTypes.content.schemata import ATContentTypeSchema
 from Products.ATContentTypes.content.schemata import finalizeATCTSchema
@@ -59,7 +56,16 @@ from Products.ATContentTypes.lib.historyaware import HistoryAwareMixin
 from Products.ATContentTypes.permission import ChangeEvents
 from Products.ATContentTypes.utils import DT2dt
 
+from Products.ATContentTypes import ATCTMessageFactory as _
+
 ATEventSchema = ATContentTypeSchema.copy() + Schema((
+    StringField('location',
+                searchable=True,
+                write_permission = ChangeEvents,
+                widget = StringWidget(
+                    description = '',
+                    label = _(u'label_event_location', default=u'Event Location')
+                    )),
     DateTimeField('startDate',
                   required=True,
                   searchable=False,
@@ -68,11 +74,9 @@ ATEventSchema = ATContentTypeSchema.copy() + Schema((
                   default_method=DateTime,
                   languageIndependent=True,
                   widget = CalendarWidget(
-                        description= "",
-                        description_msgid = "help_event_start",
-                        label="Event Starts",
-                        label_msgid = "label_event_start",
-                        i18n_domain = "plone")),
+                        description= '',
+                        label=_(u'label_event_start', default=u'Event Starts')
+                        )),
 
     DateTimeField('endDate',
                   required=True,
@@ -82,48 +86,30 @@ ATEventSchema = ATContentTypeSchema.copy() + Schema((
                   default_method=DateTime,
                   languageIndependent=True,
                   widget = CalendarWidget(
-                        description = "",
-                        description_msgid = "help_event_end",
-                        label = "Event Ends",
-                        label_msgid = "label_event_end",
-                        i18n_domain = "plone")),
-    StringField('location',
-                searchable=True,
-                write_permission = ChangeEvents,
-                widget = StringWidget(
-                    description = "",
-                    description_msgid = "help_event_location",
-                    label = "Event Location",
-                    label_msgid = "label_event_location",
-                    i18n_domain = "plone")),
-
+                        description = '',
+                        label = _(u'label_event_end', default=u'Event Ends')
+                        )),
     TextField('text',
               required=False,
               searchable=True,
               primary=True,
               storage = AnnotationStorage(migrate=True),
               validators = ('isTidyHtmlWithCleanup',),
-              default_content_type = zconf.ATEvent.default_content_type,
               default_output_type = 'text/x-html-safe',
-              allowable_content_types = zconf.ATEvent.allowed_content_types,
               widget = RichWidget(
-                        description = "",
-                        description_msgid = "help_event_announcement",
-                        label = "Event body text",
-                        label_msgid = "label_event_announcement",
+                        description = '',
+                        label = _(u'label_event_announcement', default=u'Event body text'),
                         rows = 25,
-                        i18n_domain = "plone",
                         allow_file_upload = zconf.ATDocument.allow_document_upload)),
 
     LinesField('attendees',
                languageIndependent=True,
                searchable=True,
                write_permission=ChangeEvents,
-               widget=LinesWidget(label="Attendees",
-                                  label_msgid="label_event_attendees",
-                                  description=(" "),
-                                  description_msgid="help_event_attendees",
-                                  i18n_domain="plone")),
+               widget=LinesWidget(
+                      description='',
+                      label=_(u'label_event_attendees', default=u'Attendees')
+                      )),
 
     LinesField('eventType',
                required=False,
@@ -132,25 +118,22 @@ ATEventSchema = ATContentTypeSchema.copy() + Schema((
                languageIndependent=True,
                widget = KeywordWidget(
                         size = 6,
-                        description="",
-                        description_msgid = "help_event_type",
-                        label = "Event Type(s)",
-                        label_msgid = "label_event_type",
-                        i18n_domain = "plone")),
+                        description='',
+                        label = _(u'label_event_type', default=u'Event Type(s)')
+                        )),
 
     StringField('eventUrl',
                 required=False,
                 searchable=True,
                 accessor='event_url',
                 write_permission = ChangeEvents,
+                validators=('isURL',),
                 widget = StringWidget(
-                        description = ("Web address with more info about the event. "
-                                       "Add http:// for external links."),
-                        description_msgid = "help_url",
-                        label = "Event URL",
-                        label_msgid = "label_url",
-                        i18n_domain = "plone")),
-
+                        description = _(u'help_url',
+                                        default=u"Web address with more info about the event. "
+                                                 "Add http:// for external links."),
+                        label = _(u'label_url', default=u'Event URL')
+                        )),
 
     StringField('contactName',
                 required=False,
@@ -158,11 +141,9 @@ ATEventSchema = ATContentTypeSchema.copy() + Schema((
                 accessor='contact_name',
                 write_permission = ChangeEvents,
                 widget = StringWidget(
-                        description = "",
-                        description_msgid = "help_contact_name",
-                        label = "Contact Name",
-                        label_msgid = "label_contact_name",
-                        i18n_domain = "plone")),
+                        description = '',
+                        label = _(u'label_contact_name', default=u'Contact Name')
+                        )),
 
     StringField('contactEmail',
                 required=False,
@@ -171,11 +152,9 @@ ATEventSchema = ATContentTypeSchema.copy() + Schema((
                 write_permission = ChangeEvents,
                 validators = ('isEmail',),
                 widget = StringWidget(
-                        description = "",
-                        description_msgid = "help_contact_email",
-                        label = "Contact E-mail",
-                        label_msgid = "label_contact_email",
-                        i18n_domain = "plone")),
+                        description = '',
+                        label = _(u'label_contact_email', default=u'Contact E-mail')
+                        )),
     StringField('contactPhone',
                 required=False,
                 searchable=True,
@@ -183,30 +162,29 @@ ATEventSchema = ATContentTypeSchema.copy() + Schema((
                 write_permission = ChangeEvents,
                 validators= (),
                 widget = StringWidget(
-                        description = "",
-                        description_msgid = "help_contact_phone",
-                        label = "Contact Phone",
-                        label_msgid = "label_contact_phone",
-                        i18n_domain = "plone")),
+                        description = '',
+                        label = _(u'label_contact_phone', default=u'Contact Phone')
+                        )),
     ), marshall = RFC822Marshaller()
     )
+
+# Remove the subject field because the eventType field is a proxy for this
+ATEventSchema['subject'].widget.visible = {'edit': 'invisible'}
+ATEventSchema['subject'].mode = 'r'
+
 finalizeATCTSchema(ATEventSchema)
+# finalizeATCTSchema moves 'location' into 'categories', we move it back:
+ATEventSchema.changeSchemataForField('location', 'default')
+ATEventSchema.moveField('location', before='startDate')
 
 class ATEvent(ATCTContent, CalendarSupportMixin, HistoryAwareMixin):
     """Information about an upcoming event, which can be displayed in the calendar."""
 
     schema         =  ATEventSchema
 
-    content_icon   = 'event_icon.gif'
-    meta_type      = 'ATEvent'
     portal_type    = 'Event'
     archetype_name = 'Event'
-    default_view   = 'event_view'
-    immediate_view = 'event_view'
-    suppl_views    = ()
     _atct_newTypeFor = {'portal_type' : 'CMF Event', 'meta_type' : 'CMF Event'}
-    typeDescription= 'Information about an upcoming event, which can be displayed in the calendar.'
-    typeDescMsgId  = 'description_edit_event'
     assocMimetypes = ()
     assocFileExt   = ('event', )
     cmf_edit_kws   = ('effectiveDay', 'effectiveMo', 'effectiveYear',
@@ -221,9 +199,6 @@ class ATEvent(ATCTContent, CalendarSupportMixin, HistoryAwareMixin):
 
     security       = ClassSecurityInfo()
 
-    actions = updateActions(ATCTContent, CalendarSupportMixin.actions +
-                            HistoryAwareMixin.actions)
-
     security.declareProtected(ChangeEvents, 'setEventType')
     def setEventType(self, value, alreadySet=False, **kw):
         """CMF compatibility method
@@ -323,16 +298,29 @@ class ATEvent(ATCTContent, CalendarSupportMixin, HistoryAwareMixin):
         rendDate = REQUEST.get('endDate', None)
 
         if rendDate:
-            end = DateTime(rendDate)
+            try:
+                end = DateTime(rendDate)
+            except:
+                errors['endDate'] = _(u'error_invalid_end_date',
+                                      default=u'End date is not valid.')
         else:
             end = self.end()
         if rstartDate:
-            start = DateTime(rstartDate)
+            try:
+                start = DateTime(rstartDate)
+            except:
+                errors['startDate'] = _(u'error_invalid_start_date',
+                                        default=u'Start date is not valid.')
         else:
             start = self.start()
 
+        if 'startDate' in errors or 'endDate' in errors:
+            # No point in validating bad input
+            return
+        
         if start > end:
-            errors['endDate'] = "End date must be after start date"
+            errors['endDate'] = _(u'error_end_must_be_after_start_date',
+                                  default=u'End date must be after start date.')
 
     def _start_date(self):
         value = self['startDate']
@@ -366,16 +354,20 @@ class ATEvent(ATCTContent, CalendarSupportMixin, HistoryAwareMixin):
         If other is a DateTime instance, compare start date with date
         In all other cases there is no specific order
         """
+        # Please note that we can not use self.Title() here: the generated
+        # edit accessor uses getToolByName, which ends up in
+        # five.localsitemanager looking for a parent using a comparison
+        # on this object -> infinite recursion.
         if IATEvent.isImplementedBy(other):
-            return cmp((self.start_date, self.duration, self.Title()),
-                       (other.start_date, other.duration, other.Title()))
+            return cmp((self.start_date, self.duration, self.title),
+                       (other.start_date, other.duration, other.title))
         #elif isinstance(other, (int, long, float)):
         #    return cmp(self.duration, other)
         elif isinstance(other, DateTime):
             return cmp(self.start(), other)
         else:
             # TODO come up with a nice cmp for types
-            return cmp(self.Title(), other)
+            return cmp(self.title, other)
 
     def __hash__(self):
         return hash((self.start_date, self.duration, self.title))
