@@ -27,19 +27,23 @@ __old_name__ = 'Products.ATContentTypes.types.ATFolder'
 from AccessControl import ClassSecurityInfo
 
 from Products.ATContentTypes.config import PROJECTNAME
-from Products.ATContentTypes.config import HAS_PLONE2
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.base import ATCTOrderedFolder
 from Products.ATContentTypes.content.base import ATCTBTreeFolder
 from Products.ATContentTypes.interfaces import IATFolder
 from Products.ATContentTypes.interfaces import IATBTreeFolder
 from Products.ATContentTypes.content.schemata import ATContentTypeSchema
+from Products.ATContentTypes.content.schemata import NextPreviousAwareSchema
 from Products.ATContentTypes.content.schemata import finalizeATCTSchema
 from Products.ATContentTypes.lib.constraintypes import ConstrainTypesMixinSchema
 from Products.ATContentTypes.lib.autosort import AutoSortSupport
 from Products.ATContentTypes.lib.autosort import AutoOrderSupport
 
-ATFolderSchema      = ATContentTypeSchema.copy() + ConstrainTypesMixinSchema
+from Products.ATContentTypes import ATCTMessageFactory as _
+
+from Products.CMFCore.permissions import View
+
+ATFolderSchema      = ATContentTypeSchema.copy() + ConstrainTypesMixinSchema + NextPreviousAwareSchema
 ATBTreeFolderSchema = ATContentTypeSchema.copy() + ConstrainTypesMixinSchema
 
 finalizeATCTSchema(ATFolderSchema, folderish=True, moveDiscussion=False)
@@ -51,16 +55,9 @@ class ATFolder(AutoOrderSupport, ATCTOrderedFolder):
 
     schema         =  ATFolderSchema
 
-    content_icon   = 'folder_icon.gif'
-    meta_type      = 'ATFolder'
     portal_type    = 'Folder'
     archetype_name = 'Folder'
-    immediate_view = 'folder_listing'
-    default_view   = 'folder_listing'
-    suppl_views    = ('folder_summary_view', 'folder_tabular_view', 'atct_album_view')
     _atct_newTypeFor = {'portal_type' : 'CMF Folder', 'meta_type' : 'Plone Folder'}
-    typeDescription= 'A folder which can contain other items.'
-    typeDescMsgId  = 'description_edit_folder'
     assocMimetypes = ()
     assocFileExt   = ()
     cmf_edit_kws   = ()
@@ -73,6 +70,19 @@ class ATFolder(AutoOrderSupport, ATCTOrderedFolder):
 
     security       = ClassSecurityInfo()
 
+    security.declareProtected(View, 'getNextPreviousParentValue')
+    def getNextPreviousParentValue(self):
+        """If the parent node is also an IATFolder and has next/previous
+        navigation enabled, then let this folder have it enabled by
+        default as well.
+        """
+        parent = self.getParentNode()
+        from Products.ATContentTypes.interface.folder import IATFolder as IATFolder_
+        if IATFolder_.providedBy(parent):
+            return parent.getNextPreviousEnabled()
+        else:
+            return False
+
     def manage_afterAdd(self, item, container):
         ATCTOrderedFolder.manage_afterAdd(self, item, container)
         AutoOrderSupport.manage_afterAdd(self, item, container)
@@ -83,18 +93,11 @@ class ATBTreeFolder(AutoSortSupport, ATCTBTreeFolder):
     """A folder suitable for holding a very large number of items"""
     schema         =  ATBTreeFolderSchema
 
-    content_icon   = 'folder_icon.gif'
-    meta_type      = 'ATBTreeFolder'
+
     portal_type    = 'Large Plone Folder'
     archetype_name = 'Large Folder'
-    immediate_view = 'folder_listing'
-    default_view   = 'folder_listing'
-    suppl_views    = ('folder_summary_view', 'folder_tabular_view', 'atct_album_view')
-    global_allow   = False
     _atct_newTypeFor = {'portal_type' : 'CMF Large Plone Folder',
                         'meta_type' : 'Large Plone Folder'}
-    typeDescription= 'A folder suitable for holding a very large number of items'
-    typeDescMsgId  = 'description_edit_large_folder'
     assocMimetypes = ()
     assocFileExt   = ()
     cmf_edit_kws   = ()
