@@ -31,18 +31,19 @@ from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from AccessControl import ClassSecurityInfo
 
-from Products.Archetypes.public import Schema
-from Products.Archetypes.public import StringField
-from Products.Archetypes.public import StringWidget
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import StringField
+from Products.Archetypes.atapi import StringWidget
 
 from Products.ATContentTypes.config import PROJECTNAME
-from Products.ATContentTypes.config import HAS_PLONE2
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.base import ATCTContent
 from Products.ATContentTypes.interfaces import IATLink
 from Products.ATContentTypes.content.schemata import ATContentTypeSchema
 from Products.ATContentTypes.content.schemata import finalizeATCTSchema
 
+from Products.ATContentTypes import ATCTMessageFactory as _
+
 ATLinkSchema = ATContentTypeSchema.copy() + Schema((
     StringField('remoteUrl',
         required=True,
@@ -52,11 +53,9 @@ ATLinkSchema = ATContentTypeSchema.copy() + Schema((
         # either mailto, absolute url or relative url
         validators = (),
         widget = StringWidget(
-            description = "",
-            description_msgid = "help_url",
-            label = "URL",
-            label_msgid = "label_url",
-            i18n_domain = "plone")),
+            description = '',
+            label = _(u'label_url', default=u'URL')
+            )),
     ))
 finalizeATCTSchema(ATLinkSchema)
 
@@ -65,16 +64,9 @@ class ATLink(ATCTContent):
 
     schema         =  ATLinkSchema
 
-    content_icon   = 'link_icon.gif'
-    meta_type      = 'ATLink'
     portal_type    = 'Link'
     archetype_name = 'Link'
-    immediate_view = 'link_view'
-    default_view   = 'link_view'
-    suppl_views    = ()
     _atct_newTypeFor = {'portal_type' : 'CMF Link', 'meta_type' : 'Link'}
-    typeDescription= 'A link to an internal or external resource.'
-    typeDescMsgId  = 'description_edit_link_item'
     assocMimetypes = ()
     assocFileExt   = ('link', 'url', )
     cmf_edit_kws   = ('remote_url', )
@@ -88,7 +80,7 @@ class ATLink(ATCTContent):
         """remute url mutator
 
         Use urlparse to sanify the url
-        Also see http://plone.org/collector/3296
+        Also see http://dev.plone.org/plone/ticket/3296
         """
         if value:
             value = urlparse.urlunparse(urlparse.urlparse(value))
@@ -112,6 +104,6 @@ class ATLink(ATCTContent):
         """
         value = self.Schema()['remoteUrl'].get(self)
         if not value: value = '' # ensure we have a string
-        return quote(value, safe='?$#@/:=+;$,')
+        return quote(value, safe='?$#@/:=+;$,&')
 
 registerATCT(ATLink, PROJECTNAME)
