@@ -26,27 +26,28 @@ __old_name__ = 'Products.ATContentTypes.types.ATNewsItem'
 
 from AccessControl import ClassSecurityInfo
 
-from Products.Archetypes.public import Schema
-from Products.Archetypes.public import ImageField
-from Products.Archetypes.public import StringField
-from Products.Archetypes.public import TextField
-from Products.Archetypes.public import ImageWidget
-from Products.Archetypes.public import RichWidget
-from Products.Archetypes.public import StringWidget
-from Products.Archetypes.public import RFC822Marshaller
-from Products.Archetypes.public import AnnotationStorage
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import ImageField
+from Products.Archetypes.atapi import StringField
+from Products.Archetypes.atapi import TextField
+from Products.Archetypes.atapi import ImageWidget
+from Products.Archetypes.atapi import RichWidget
+from Products.Archetypes.atapi import StringWidget
+from Products.Archetypes.atapi import RFC822Marshaller
+from Products.Archetypes.atapi import AnnotationStorage
 
 from Products.ATContentTypes.config import PROJECTNAME
-from Products.ATContentTypes.config import HAS_PLONE2
 from Products.ATContentTypes.configuration import zconf
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.base import translateMimetypeAlias
-from Products.ATContentTypes.content.document import ATDocument
+from Products.ATContentTypes.content.document import ATDocumentBase
 from Products.ATContentTypes.content.image import ATCTImageTransform
 from Products.ATContentTypes.interfaces import IATNewsItem
 from Products.ATContentTypes.content.schemata import ATContentTypeSchema
 from Products.ATContentTypes.content.schemata import finalizeATCTSchema
 
+from Products.ATContentTypes import ATCTMessageFactory as _
+
 from Products.CMFCore.permissions import View
 
 from Products.validation.config import validation
@@ -56,7 +57,6 @@ from Products.validation import V_REQUIRED
 validation.register(MaxSizeValidator('checkNewsImageMaxSize',
                                      maxsize=zconf.ATNewsItem.max_file_size))
 
-from Products.validation.validators.SupplValidators import MaxSizeValidator
 
 ATNewsItemSchema = ATContentTypeSchema.copy() + Schema((
     TextField('text',
@@ -66,16 +66,11 @@ ATNewsItemSchema = ATContentTypeSchema.copy() + Schema((
         storage = AnnotationStorage(migrate=True),
         validators = ('isTidyHtmlWithCleanup',),
         #validators = ('isTidyHtml',),
-        default_content_type = zconf.ATNewsItem.default_content_type,
         default_output_type = 'text/x-html-safe',
-        allowable_content_types = zconf.ATNewsItem.allowed_content_types,
         widget = RichWidget(
-            description = "",
-            description_msgid = "help_body_text",
-            label = "Body Text",
-            label_msgid = "label_body_text",
+            description = '',
+            label = _(u'label_body_text', u'Body Text'),
             rows = 25,
-            i18n_domain = "plone",
             allow_file_upload = zconf.ATDocument.allow_document_upload)
         ),
     ImageField('image',
@@ -94,48 +89,35 @@ ATNewsItemSchema = ATContentTypeSchema.copy() + Schema((
         validators = (('isNonEmptyFile', V_REQUIRED),
                              ('checkNewsImageMaxSize', V_REQUIRED)),
         widget = ImageWidget(
-            description = "Will be shown in the news listing, and in the news item itself. Image will be scaled to a sensible size.",
-            description_msgid = "help_news_image",
-            label= "Image",
-            label_msgid = "label_news_image",
-            i18n_domain = "plone",
+            description = _(u'help_news_image', default=u'Will be shown in the news listing, and in the news item itself. Image will be scaled to a sensible size.'),
+            label= _(u'label_news_image', default=u'Image'),
             show_content_type = False)
         ),
     StringField('imageCaption',
         required = False,
         searchable = True,
         widget = StringWidget(
-            description = "",
-            description_msgid = "help_image_caption",
-            label = "Image Caption",
-            label_msgid = "label_image_caption",
-            size = 40,
-            i18n_domain = "plone")
+            description = '',
+            label = _(u'label_image_caption', default=u'Image Caption'),
+            size = 40)
         ),
     ), marshall=RFC822Marshaller()
     )
 finalizeATCTSchema(ATNewsItemSchema)
 
-class ATNewsItem(ATDocument, ATCTImageTransform):
+class ATNewsItem(ATDocumentBase, ATCTImageTransform):
     """An announcement that will show up on the news portlet and in the news listing."""
 
     schema         =  ATNewsItemSchema
 
-    content_icon   = 'newsitem_icon.gif'
-    meta_type      = 'ATNewsItem'
     portal_type    = 'News Item'
     archetype_name = 'News Item'
-    immediate_view = 'newsitem_view'
-    default_view   = 'newsitem_view'
-    suppl_views    = ()
     _atct_newTypeFor = {'portal_type' : 'CMF News Item', 'meta_type' : 'News Item'}
-    typeDescription = 'An announcement that will show up on the news portlet and in the news listing.'
-    typeDescMsgId  = 'description_edit_news_item'
     assocMimetypes = ()
     assocFileExt   = ('news', )
-    cmf_edit_kws   = ATDocument.cmf_edit_kws
+    cmf_edit_kws   = ATDocumentBase.cmf_edit_kws
 
-    __implements__ = ATDocument.__implements__, IATNewsItem
+    __implements__ = ATDocumentBase.__implements__, IATNewsItem
 
     security = ClassSecurityInfo()
 
@@ -170,6 +152,6 @@ class ATNewsItem(ATDocument, ATCTImageTransform):
                 # image might be None or '' for empty images
                 return image
 
-        return ATDocument.__bobo_traverse__(self, REQUEST, name)
+        return ATDocumentBase.__bobo_traverse__(self, REQUEST, name)
 
 registerATCT(ATNewsItem, PROJECTNAME)
