@@ -23,17 +23,16 @@
 __author__  = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
-from Products.Archetypes.public import BaseSchema
-from Products.Archetypes.public import MetadataSchema
-from Products.Archetypes.public import ReferenceField
-from Products.Archetypes.public import BooleanField
-from Products.Archetypes.public import BooleanWidget
-
+from Products.Archetypes.atapi import BaseSchema
+from Products.Archetypes.atapi import MetadataSchema
+from Products.Archetypes.atapi import ReferenceField
+from Products.Archetypes.atapi import BooleanField
+from Products.Archetypes.atapi import BooleanWidget
+from Products.ATContentTypes import ATCTMessageFactory as _
 from Products.CMFCore.permissions import ModifyPortalContent
 
 from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import ReferenceBrowserWidget
 
-
 # for ATContentTypes we want to have the description in the edit view
 # just like CMF
 ATContentTypeSchema = BaseSchema.copy() + MetadataSchema((
@@ -42,19 +41,20 @@ ATContentTypeSchema = BaseSchema.copy() + MetadataSchema((
         languageIndependent = True,
         schemata = 'metadata', # moved to 'default' for folders
         widget = BooleanWidget(
-            description="If selected, this item will not appear in the navigation tree",
-            description_msgid = "help_exclude_from_nav",
-            label = "Exclude from navigation",
-            label_msgid = "label_exclude_from_nav",
-            i18n_domain = "plone",
+            description=_(u'help_exclude_from_nav', default=u'If selected, this item will not appear in the navigation tree'),
+            label = _(u'label_exclude_from_nav', default=u'Exclude from navigation'),
             visible={'view' : 'hidden',
                      'edit' : 'visible'},
             ),
         ),
     ),)
 
-ATContentTypeSchema['id'].validators = ('isValidId',)
 ATContentTypeSchema['id'].searchable = True
+ATContentTypeSchema['id'].validators = ('isValidId',)
+
+# Update the validation layer after change the validator in runtime
+ATContentTypeSchema['id']._validationLayer()
+
 ATContentTypeSchema['description'].schemata = 'default'
 
 # BBB
@@ -73,16 +73,33 @@ relatedItemsField = ReferenceField('relatedItems',
             show_indexes = False,
             force_close_on_insert = True,
 
-            label = "Related Item(s)",
-            label_msgid = "label_related_items",
-            description = "",
-            description_msgid = "help_related_items",
-            i18n_domain = "plone",
+            label = _(u'label_related_items', default=u'Related Items'),
+            description = '',
             visible = {'edit' : 'visible', 'view' : 'invisible' }
             )
         )
 ATContentTypeSchema.addField(relatedItemsField.copy())
 
+#Enabling next / previous navigation
+
+NextPreviousAwareSchema = MetadataSchema((
+    BooleanField('nextPreviousEnabled',
+        #required = False,
+        languageIndependent = True,
+        schemata = 'metadata',
+        widget = BooleanWidget(
+            description="This enables next/previous widget on content items contained in this folder",
+            description_msgid = "help_nextprevious",
+            label = "Enable next previous navigation",
+            label_msgid = "label_nextprevious",
+            i18n_domain = "plone",
+            visible={'view' : 'hidden',
+                     'edit' : 'visible'},
+            ),
+        default_method="getNextPreviousParentValue"
+        ),
+    ),)
+
 def marshall_register(schema):
     try:
         # It's a soft dependency, if not available ignore it.
@@ -114,8 +131,47 @@ def finalizeATCTSchema(schema, folderish=False, moveDiscussion=True):
     schema.moveField('excludeFromNav', after='allowDiscussion')
     if moveDiscussion:
         schema.moveField('allowDiscussion', after='relatedItems')
+
+    # Categorization
+    if schema.has_key('subject'):
+        schema.changeSchemataForField('subject', 'categorization')
+    if schema.has_key('relatedItems'):
+        schema.changeSchemataForField('relatedItems', 'categorization')
+    if schema.has_key('location'):
+        schema.changeSchemataForField('location', 'categorization')
+    if schema.has_key('language'):
+        schema.changeSchemataForField('language', 'categorization')
+
+    # Dates
+    if schema.has_key('effectiveDate'):
+        schema.changeSchemataForField('effectiveDate', 'dates')
+    if schema.has_key('expirationDate'):
+        schema.changeSchemataForField('expirationDate', 'dates')    
+    if schema.has_key('creation_date'):
+        schema.changeSchemataForField('creation_date', 'dates')    
+    if schema.has_key('modification_date'):
+        schema.changeSchemataForField('modification_date', 'dates')    
+
+    # Ownership
+    if schema.has_key('creators'):
+        schema.changeSchemataForField('creators', 'ownership')
+    if schema.has_key('contributors'):
+        schema.changeSchemataForField('contributors', 'ownership')
+    if schema.has_key('rights'):
+        schema.changeSchemataForField('rights', 'ownership')
+
+    # Settings
+    if schema.has_key('allowDiscussion'):
+        schema.changeSchemataForField('allowDiscussion', 'settings')
+    if schema.has_key('excludeFromNav'):
+        schema.changeSchemataForField('excludeFromNav', 'settings')
+    if schema.has_key('nextPreviousEnabled'):
+        schema.changeSchemataForField('nextPreviousEnabled', 'settings')
+
     marshall_register(schema)
     return schema
 
+# Make sure the base ATCT schema is correctly finalized
+finalizeATCTSchema(ATContentTypeSchema)
 
 __all__ = ('ATContentTypeSchema', 'relatedItemsField',)
