@@ -24,7 +24,7 @@ __docformat__ = 'restructuredtext'
 __old_name__ = 'Products.ATContentTypes.types.criteria'
 
 from UserDict import UserDict
-from Products.Archetypes.public import registerType
+from Products.Archetypes.atapi import registerType
 from Products.Archetypes.ClassGen import generateClass
 from Products.ATContentTypes.config import PROJECTNAME
 from types import StringType
@@ -77,7 +77,6 @@ class _CriterionRegistry(UserDict):
             indices = ALL_INDICES
 
         assert IATTopicCriterion.isImplementedByInstancesOf(criterion)
-        #generateClass(criterion)
         registerType(criterion, PROJECTNAME)
 
         crit_id = criterion.meta_type
