@@ -28,9 +28,9 @@ from Missing import MV
 from Products.CMFCore.permissions import View
 from AccessControl import ClassSecurityInfo
 
-from Products.Archetypes.public import Schema
-from Products.Archetypes.public import BooleanField
-from Products.Archetypes.public import BooleanWidget
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import BooleanField
+from Products.Archetypes.atapi import BooleanWidget
 
 from Products.ATContentTypes.criteria import registerCriterion
 from Products.ATContentTypes.criteria import FIELD_INDICES
@@ -39,6 +39,8 @@ from Products.ATContentTypes.permission import ChangeTopics
 from Products.ATContentTypes.criteria.base import ATBaseCriterion
 from Products.ATContentTypes.criteria.schemata import ATBaseCriterionSchema
 
+from Products.ATContentTypes import ATCTMessageFactory as _
+
 ATBooleanCriterionSchema = ATBaseCriterionSchema + Schema((
     BooleanField('bool',
                 required=1,
@@ -46,11 +48,10 @@ ATBooleanCriterionSchema = ATBaseCriterionSchema + Schema((
                 write_permission=ChangeTopics,
                 default=None,
                 widget=BooleanWidget(
-                    label="Value",
-                    label_msgid="label_boolean_criteria_bool",
-                    description="True or false",
-                    description_msgid="help_boolean_criteria_bool",
-                    i18n_domain="plone"),
+                    label=_(u'label_boolean_criteria_bool', default=u'Value'),
+                    description=_(u'help_boolean_criteria_bool',
+                                  default=u'True or false')
+                    ),
                 ),
     ))
 
@@ -62,9 +63,6 @@ class ATBooleanCriterion(ATBaseCriterion):
     schema         = ATBooleanCriterionSchema
     meta_type      = 'ATBooleanCriterion'
     archetype_name = 'Boolean Criterion'
-    typeDescription= ''
-    typeDescMsgId  = ''
-
     shortDesc      = 'Boolean (True/False)'
 
     security.declareProtected(View, 'getCriteriaItems')
