@@ -28,12 +28,12 @@ from Products.CMFCore.permissions import View
 from Products.CMFCore.utils import getToolByName
 from AccessControl import ClassSecurityInfo
 
-from Products.Archetypes.public import Schema
-from Products.Archetypes.public import LinesField
-from Products.Archetypes.public import MultiSelectionWidget
-from Products.Archetypes.public import StringField
-from Products.Archetypes.public import SelectionWidget
-from Products.Archetypes.public import DisplayList
+from Products.Archetypes.atapi import Schema
+from Products.Archetypes.atapi import LinesField
+from Products.Archetypes.atapi import MultiSelectionWidget
+from Products.Archetypes.atapi import StringField
+from Products.Archetypes.atapi import SelectionWidget
+from Products.Archetypes.atapi import DisplayList
 
 from Products.ATContentTypes.criteria import registerCriterion
 from Products.ATContentTypes.criteria import LIST_INDICES
@@ -42,9 +42,11 @@ from Products.ATContentTypes.permission import ChangeTopics
 from Products.ATContentTypes.criteria.base import ATBaseCriterion
 from Products.ATContentTypes.criteria.schemata import ATBaseCriterionSchema
 
+from Products.ATContentTypes import ATCTMessageFactory as _
+
 CompareOperators = DisplayList((
-                    ('and', 'and')
-                  , ('or', 'or')
+                    ('and', _(u'and'))
+                  , ('or', _(u'or'))
     ))
 
 ATSelectionCriterionSchema = ATBaseCriterionSchema + Schema((
@@ -57,11 +59,9 @@ ATSelectionCriterionSchema = ATBaseCriterionSchema + Schema((
                 default=[],
                 vocabulary="getCurrentValues",
                 widget=MultiSelectionWidget(
-                    label="Value",
-                    label_msgid="label_selection_criteria_value",
-                    description="Existing values.",
-                    description_msgid="help_selection_criteria_value",
-                    i18n_domain="plone"),
+                    label=_(u'label_criteria_values', default=u'Values'),
+                    description=_(u'help_criteria_values', default=u'Existing values.')
+                    ),
                 ),
     StringField('operator',
                 required=1,
@@ -70,12 +70,10 @@ ATSelectionCriterionSchema = ATBaseCriterionSchema + Schema((
                 default='or',
                 vocabulary=CompareOperators,
                 widget=SelectionWidget(
-                    label="operator name",
-                    label_msgid="label_list_criteria_operator",
-                    description="Operator used to join the tests "
-                    "on each value.",
-                    description_msgid="help_list_criteria_operator",
-                    i18n_domain="atcontenttypes"),
+                    label=_(u'label_list_criteria_operator', default=u'operator name'),
+                    description=_(u'help_list_criteria_operator',
+                                  default=u'Operator used to join the tests on each value.')
+                    ),
                 ),
     ))
 
@@ -87,12 +85,8 @@ class ATSelectionCriterion(ATBaseCriterion):
     schema         = ATSelectionCriterionSchema
     meta_type      = 'ATSelectionCriterion'
     archetype_name = 'Selection Criterion'
-    typeDescription= ''
-    typeDescMsgId  = ''
-
     shortDesc      = 'Select values from list'
 
-
     def getCurrentValues(self):
         catalog = getToolByName(self, 'portal_catalog')
         options = catalog.uniqueValuesFor(self.Field())
