@@ -22,10 +22,6 @@
 __author__ = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Testing import ZopeTestCase # side effect import. leave it here.
 from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 
@@ -33,14 +29,13 @@ import transaction
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from Products.Archetypes.interfaces.layer import ILayerContainer
-from Products.Archetypes.public import *
+from Products.Archetypes.atapi import *
 from Products.ATContentTypes.tests.utils import dcEdit
 
 from Products.ATContentTypes.content.event import ATEvent
-from Products.ATContentTypes.migration.atctmigrator import EventMigrator
-from Products.CMFCalendar.Event import Event
 from Products.ATContentTypes.tests.utils import EmptyValidator
 from Products.ATContentTypes.tests.utils import EmailValidator
+from Products.ATContentTypes.tests.utils import URLValidator
 from Products.ATContentTypes.tests.utils import NotRequiredTidyHTMLValidator
 from Products.ATContentTypes.permission import ChangeEvents
 from Products.ATContentTypes.utils import DT2dt
@@ -68,17 +63,6 @@ EV_ATTENDEES = ('john@doe.com',
                 'john@example.org')
 TEXT = "lorem ipsum"
 
-def editCMF(obj):
-    dcEdit(obj)
-    obj.setStartDate(S_DATE)
-    obj.setEndDate(E_DATE)
-    obj.location=LOCATION
-    obj.contact_name=C_NAME
-    obj.contact_email=C_EMAIL
-    obj.contact_phone=C_PHONE
-    obj.event_url=EV_URL
-    obj.setSubject((EV_TYPE,))
-
 def editATCT(obj):
     dcEdit(obj)
     obj.setLocation(LOCATION)
@@ -99,8 +83,6 @@ class TestSiteATEvent(atcttestcase.ATCTTypeTestCase):
 
     klass = ATEvent
     portal_type = 'Event'
-    cmf_portal_type = 'CMF Event'
-    cmf_klass = Event
     title = 'Event'
     meta_type = 'ATEvent'
     icon = 'event_icon.gif'
@@ -123,95 +105,14 @@ class TestSiteATEvent(atcttestcase.ATCTTypeTestCase):
         self.failUnless(Z3verifyObject(iface, self._ATCT))
 
     def test_edit(self):
-        old = self._cmf
         new = self._ATCT
-        editCMF(old)
         editATCT(new)
-        self.failUnless(old.Title() == new.Title(), 'Title mismatch: %s / %s' \
-                        % (old.Title(), new.Title()))
-        self.failUnless(old.Description() == new.Description(), 'Description mismatch: %s / %s' \
-                        % (old.Description(), new.Description()))
-
-        self.failUnless(old.location == new.getLocation(), 'Location mismatch: %s / %s' \
-                        % (old.location, new.getLocation()))
-        self.failUnless(old.Subject() == new.getEventType(), 'EventType mismatch: %s / %s' \
-                        % (old.Subject(), new.getEventType()))
-        self.failUnless(old.event_url == new.event_url(), 'EventUrl mismatch: %s / %s' \
-                        % (old.event_url, new.event_url()))
-        self.failUnless(old.start() == new.start(), 'Start mismatch: %s / %s' \
-                        % (old.start(), new.start()))
-        self.failUnless(old.end() == new.end(), 'End mismatch: %s / %s' \
-                        % (old.end(), new.end()))
-        self.failUnless(old.contact_name == new.contact_name(), 'contact_name mismatch: %s / %s' \
-                        % (old.contact_name, new.contact_name()))
-        self.failUnless(old.contact_phone == new.contact_phone(), 'contact_phone mismatch: %s / %s' \
-                        % (old.contact_phone, new.contact_phone()))
-        self.failUnless(old.contact_email == new.contact_email(), 'contact_email mismatch: %s / %s' \
-                        % (old.contact_email, new.contact_email()))
         self.assertEquals(new.start_date, DT2dt(new.start()))
         self.assertEquals(new.end_date, DT2dt(new.end()))
         self.assertEquals(new.start_date, DT2dt(S_DATE))
         self.assertEquals(new.end_date, DT2dt(E_DATE))
         self.assertEquals(new.duration, new.end_date - new.start_date)
 
-    def test_migration(self):
-        old = self._cmf
-        id  = old.getId()
-
-        # edit
-        editCMF(old)
-        title       = old.Title()
-        description = old.Description()
-        mod         = old.ModificationDate()
-        created     = old.CreationDate()
-
-        start = old.start()
-        end   = old.end()
-        location = old.location
-        c_name = old.contact_name
-        c_email = old.contact_email
-        c_phone = old.contact_phone
-        ev_url = old.event_url
-        ev_type = old.Subject()
-
-        # migrated (needs subtransaction to work)
-        transaction.savepoint(optimistic=True)
-        m = EventMigrator(old)
-        m(unittest=1)
-
-        self.failUnless(id in self.folder.objectIds(), self.folder.objectIds())
-        migrated = getattr(self.folder, id)
-
-        self.compareAfterMigration(migrated, mod=mod, created=created)
-        self.compareDC(migrated, title=title, description=description)
-
-        self.failUnless(migrated.location == location,
-                        'Location mismatch: %s / %s' %
-                        (migrated.location, location))
-        self.failUnless(migrated.Subject() == ev_type,
-                        'EventType mismatch: %s / %s' %
-                        (migrated.Subject(), ev_type))
-        self.failUnless(migrated.event_url() == ev_url,
-                        'EventUrl mismatch: %s / %s' %
-                        (migrated.event_url(), ev_url))
-        self.failUnless(migrated.start() == start,
-                        'Start mismatch: %s / %s' %
-                        (migrated.start(), start))
-        self.failUnless(migrated.end() == end,
-                        'End mismatch: %s / %s' % (migrated.end(), end))
-        self.failUnless(migrated.contact_name() == c_name,
-                        'contact_name mismatch: %s / %s' %
-                        (migrated.contact_name(), c_name))
-        self.failUnless(migrated.contact_phone() == c_phone,
-                        'contact_phone mismatch: %s / %s' %
-                        (migrated.contact_phone(), c_phone))
-        self.failUnless(migrated.contact_email() == c_email,
-                        'contact_email mismatch: %s / %s' %
-                        (migrated.contact_email(), c_email))
-        self.failUnless(migrated.getAttendees() == (),
-                        'attendees mismatch: %s / %s' %
-                        (migrated.getAttendees(), ()))
-
     def test_cmp(self):
         e1 = self._ATCT
         e2 = self._createType(self.folder, self.portal_type, 'e2')
@@ -394,7 +295,7 @@ class TestATEventFields(atcttestcase.ATCTFieldTestCase):
         self.failUnless(field.getLayerImpl('storage') == AttributeStorage(),
                         'Value is %s' % field.getLayerImpl('storage'))
         self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnlessEqual(field.validators, EmptyValidator)
+        self.failUnlessEqual(field.validators, URLValidator)
         self.failUnless(isinstance(field.widget, StringWidget),
                         'Value is %s' % id(field.widget))
         vocab = field.Vocabulary(dummy)
@@ -697,12 +598,11 @@ class TestATEventFields(atcttestcase.ATCTFieldTestCase):
         self.failUnless(tuple(vocab) == (), 'Value is %s' % str(tuple(vocab)))
 
         self.failUnless(field.primary == 1, 'Value is %s' % field.primary)
-        self.failUnless(field.default_content_type == 'text/html',
+        self.failUnless(field.default_content_type is None,
                         'Value is %s' % field.default_content_type)
         self.failUnless(field.default_output_type == 'text/x-html-safe',
                         'Value is %s' % field.default_output_type)
-        self.failUnless('text/html' in field.allowable_content_types)
-        self.failUnless('text/structured'  in field.allowable_content_types)
+        self.failUnless('text/html' in field.getAllowedContentTypes(dummy))
 
     def beforeTearDown(self):
         # more
@@ -717,15 +617,9 @@ class TestATEventFunctional(atctftestcase.ATCTIntegrationTestCase):
 
 tests.append(TestATEventFunctional)
 
-
-if __name__ == '__main__':
-    framework()
-else:
-    # While framework.py provides its own test_suite()
-    # method the testrunner utility does not.
-    import unittest
-    def test_suite():
-        suite = unittest.TestSuite()
-        for test in tests:
-            suite.addTest(unittest.makeSuite(test))
-        return suite
+import unittest
+def test_suite():
+    suite = unittest.TestSuite()
+    for test in tests:
+        suite.addTest(unittest.makeSuite(test))
+    return suite
