@@ -36,15 +36,13 @@ from OFS.Image import Image as OFSImage
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from Products.Archetypes.interfaces.layer import ILayerContainer
-from Products.Archetypes.public import *
+from Products.Archetypes.atapi import *
 from Products.ATContentTypes.tests.utils import dcEdit, PACKAGE_HOME
 
 from Products.ATContentTypes.content.image import ATImage
-from Products.ATContentTypes.migration.atctmigrator import ImageMigrator
 from Products.ATContentTypes.interfaces import IImageContent
 from Products.ATContentTypes.interfaces import IATImage
 
-from Products.CMFDefault.Image import Image
 from Interface.Verify import verifyObject
 
 # z3 imports
@@ -74,10 +72,6 @@ TEST_JPEG_FILE = open(os.path.join(PACKAGE_HOME, 'input', 'canoneye.jpg'), 'rb')
 TEST_JPEG = loadImage('canoneye.jpg')
 TEST_JPEG_LEN = len(TEST_JPEG)
 
-def editCMF(obj):
-    obj.update_data(TEST_GIF, content_type="image/gif")
-    dcEdit(obj)
-
 def editATCT(obj):
     obj.setImage(TEST_GIF, content_type="image/gif")
     dcEdit(obj)
@@ -88,8 +82,6 @@ class TestSiteATImage(atcttestcase.ATCTTypeTestCase):
 
     klass = ATImage
     portal_type = 'Image'
-    cmf_portal_type = 'CMF Image'
-    cmf_klass = Image
     title = 'Image'
     meta_type = 'ATImage'
     icon = 'image_icon.gif'
@@ -113,36 +105,8 @@ class TestSiteATImage(atcttestcase.ATCTTypeTestCase):
         self.failUnless(Z3verifyObject(iface, self._ATCT))
 
     def test_edit(self):
-        old = self._cmf
         new = self._ATCT
-        editCMF(old)
         editATCT(new)
-        self.failUnless(old.Title() == new.Title(), 'Title mismatch: %s / %s' \
-                        % (old.Title(), new.Title()))
-        self.failUnless(old.Description() == new.Description(), 'Description mismatch: %s / %s' \
-                        % (old.Description(), new.Description()))
-
-    def test_migration(self):
-        old = self._cmf
-        id  = old.getId()
-
-        # edit
-        editCMF(old)
-        title       = old.Title()
-        description = old.Description()
-        mod         = old.ModificationDate()
-        created     = old.CreationDate()
-
-        # migrated (needs subtransaction to work)
-        transaction.savepoint(optimistic=True)
-        m = ImageMigrator(old)
-        m(unittest=1)
-
-        self.failUnless(id in self.folder.objectIds(), self.folder.objectIds())
-        migrated = getattr(self.folder, id)
-
-        self.compareAfterMigration(migrated, mod=mod, created=created)
-        self.compareDC(migrated, title=title, description=description)
 
     def test_getEXIF(self):
         # NOTE: not a real test
@@ -217,31 +181,11 @@ class TestSiteATImage(atcttestcase.ATCTTypeTestCase):
         self.failUnless(isinstance(marshall, tuple(marshallers)), marshall)
 
     def test_dcEdit(self):
-        #if not hasattr(self, '_cmf') or not hasattr(self, '_ATCT'):
-        #    return
-        old = self._cmf
         new = self._ATCT
         new.setImage(TEST_GIF, content_type="image/gif")
-        dcEdit(old)
         dcEdit(new)
-        self.compareDC(old, new)
 
     def test_broken_exif(self):
-        #EXIF data in images from Canon digicams breaks EXIF of 2005.05.12 with following exception
-        #
-        #2005-05-01T19:21:16 ERROR(200) Archetypes None
-        #Traceback (most recent call last):
-        #  File "/home/russ/cb/var/zope/Products/ATContentTypes/content/image.py", line 207, in getEXIF
-        #    exif_data = exif.process_file(img, debug=False, noclose=True)
-        #  File "/home/russ/cb/var/zope/Products/ATContentTypes/lib/exif.py", line 1013, in process_file
-        #    hdr.decode_maker_note()
-        #  File "/home/russ/cb/var/zope/Products/ATContentTypes/lib/exif.py", line 919, in decode_maker_note
-        #    dict=MAKERNOTE_CANON_TAGS)
-        #  File "/home/russ/cb/var/zope/Products/ATContentTypes/lib/exif.py", line 753, in dump_IFD
-        #    raise ValueError, \
-        #ValueError: unknown type 768 in tag 0x0100
-        #
-
         # This test fails even with the 2005.05.12 exif version from
         #    http://home.cfl.rr.com/genecash/
         f = StringIO(TEST_EXIF_ERROR)
@@ -280,6 +224,11 @@ tests.append(TestSiteATImage)
 
 class TestATImageFields(atcttestcase.ATCTFieldTestCase):
 
+    # Title is not a required field, since we don't require them 
+    # on File/Image - they are taken from the filename if not present.
+    # "Add the comment 'damn stupid fucking test'" -- optilude ;)
+    def test_title(self):
+        pass
 
     def afterSetUp(self):
         atcttestcase.ATCTFieldTestCase.afterSetUp(self)
@@ -354,20 +303,15 @@ class TestATImageFunctional(atctftestcase.ATCTIntegrationTestCase):
         # Should be allowed for member
         self.assertStatusEqual(response2.getStatus(), 200) # OK
         # Should fail for anonymous
+        self.error_log._ignored_exceptions = ('Unauthorized', )
         response3 = self.publish(self.obj_path+'/image')
         self.assertStatusEqual(response3.getStatus(), 401)
 
 tests.append(TestATImageFunctional)
 
-
-if __name__ == '__main__':
-    framework()
-else:
-    # While framework.py provides its own test_suite()
-    # method the testrunner utility does not.
-    import unittest
-    def test_suite():
-        suite = unittest.TestSuite()
-        for test in tests:
-            suite.addTest(unittest.makeSuite(test))
-        return suite
+import unittest
+def test_suite():
+    suite = unittest.TestSuite()
+    for test in tests:
+        suite.addTest(unittest.makeSuite(test))
+    return suite
