@@ -21,17 +21,13 @@
 
 __author__ = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
-
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
 from DateTime import DateTime
 
 from Testing import ZopeTestCase # side effect import. leave it here.
 from Products.ATContentTypes.tests import atcttestcase
 from Missing import MV
 
-from Products.Archetypes.public import *
+from Products.Archetypes.atapi import *
 
 from Interface.Verify import verifyObject
 from Products.Archetypes.interfaces.base import IBaseContent
@@ -112,7 +108,7 @@ class CriteriaTest(atcttestcase.ATCTSiteTestCase):
             dummy = klass(field=field, oid=id)
             self.failUnless(dummy.getId(), id)
             self.failUnless(dummy.Field(), field)
-    
+
     def test_typeInfo(self):
         if self.dummy is not None:
             ti = self.dummy.getTypeInfo()
@@ -528,30 +524,49 @@ class TestATPortalTypeCriterion(CriteriaTest):
     def test_vocabulary(self):
         #Should return standard types, but not blacklisted types
         self.dummy.Schema()['field'].set(self.dummy,'portal_types')
-        self.failUnless('Document' in self.dummy.getCurrentValues())
-        self.failUnless('ATSimpleStringCriterion' not in self.dummy.getCurrentValues())
+        self.failUnless('Document' in self.dummy.getCurrentValues().keys())
+        self.failUnless('ATSimpleStringCriterion' not in self.dummy.getCurrentValues().keys())
 
     def test_vocabulary_sorts_by_type(self):
         #Should return standard types, but not blacklisted types
         self.dummy.Schema()['field'].set(self.dummy,'Type')
-        vocab = list(self.dummy.getCurrentValues())
-        self.failUnless(vocab.index('Page') > vocab.index('Event'))
+        type_ids, type_names = self.dummy.getCurrentValues().keys(), self.dummy.getCurrentValues().values()
+        self.failUnless(type_names.index('Page') > type_names.index('Event'))
         self.dummy.Schema()['field'].set(self.dummy,'portal_types')
-        vocab = list(self.dummy.getCurrentValues())
-        self.failUnless(vocab.index('Document')< vocab.index('Event'))
+        type_ids, type_names = self.dummy.getCurrentValues().keys(), self.dummy.getCurrentValues().values()
+        self.failUnless(type_names.index('Document')< type_names.index('Event'))
 
     def test_types_v_portaltypes(self):
         #Using the Types index as field should cause the vocabulary to use the
         #type Title rather than the type name
         self.dummy.Schema()['field'].set(self.dummy,'portal_type')
-        self.failUnless('Large Plone Folder' in self.dummy.getCurrentValues())
-        self.failUnless('Large Folder' not in self.dummy.getCurrentValues())
+        type_ids, type_names = self.dummy.getCurrentValues().keys(), self.dummy.getCurrentValues().values()
+        self.failUnless('Large Plone Folder' in type_names)
+        self.failUnless('Large Folder' not in type_names)
         self.dummy.Schema()['field'].set(self.dummy,'Type')
-        self.failUnless('Large Plone Folder' not in self.dummy.getCurrentValues())
-        self.failUnless('Large Folder' in self.dummy.getCurrentValues())
+        type_ids, type_names = self.dummy.getCurrentValues().keys(), self.dummy.getCurrentValues().values()
+        self.failUnless('Large Plone Folder' not in type_names)
+        self.failUnless('Large Folder' in type_names)
         #ensure that blacklisted types aren't here either
-        self.failUnless('Simple String Criterion' not in self.dummy.getCurrentValues())
+        self.failUnless('Simple String Criterion' not in type_names)
 
+    def test_type_ids_names(self):
+        # test introduced when fixing Plone bug #6981
+        self.dummy.Schema()['field'].set(self.dummy,'Type')
+        type_ids, type_names = self.dummy.getCurrentValues().keys(), self.dummy.getCurrentValues().values()
+        self.failUnless('Page' in type_ids)
+        self.failUnless('Page' in type_names)
+        self.failIf('Document' in type_ids)
+        self.failIf('Document' in type_names)
+        # use type id everytime
+        self.dummy.Schema()['field'].set(self.dummy,'portal_type')
+        type_ids, type_names = self.dummy.getCurrentValues().keys(), self.dummy.getCurrentValues().values()
+        self.failUnless('Document' in type_ids)
+        self.failUnless('Document' in type_names)
+        self.failIf('Page' in type_ids)
+        self.failIf('Page' in type_names)
+        
+        
 tests.append(TestATPortalTypeCriterion)
 
 
@@ -722,14 +737,9 @@ class TestCriterionRegistry(atcttestcase.ATCTSiteTestCase):
 
 tests.append(TestCriterionRegistry)
 
-if __name__ == '__main__':
-    framework()
-else:
-    # While framework.py provides its own test_suite()
-    # method the testrunner utility does not.
-    import unittest
-    def test_suite():
-        suite = unittest.TestSuite()
-        for test in tests:
-            suite.addTest(unittest.makeSuite(test))
-        return suite
+import unittest
+def test_suite():
+    suite = unittest.TestSuite()
+    for test in tests:
+        suite.addTest(unittest.makeSuite(test))
+    return suite
