@@ -22,10 +22,6 @@
 __author__ = 'Alec Mitchell <apm13@columbia.edu>'
 __docformat__ = 'restructuredtext'
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Testing import ZopeTestCase # side effect import. leave it here.
 from Products.ATContentTypes.tests import atcttestcase
 from DateTime import DateTime
@@ -56,6 +52,9 @@ class TestFormatCatalogMetadata(atcttestcase.ATCTSiteTestCase):
     def testFormatList(self):
         self.assertEqual(self.script(('a','b',1,2,3,4)), 'a, b, 1, 2, 3, 4')
         self.assertEqual(self.script(['a','b',1,2,3,4]), 'a, b, 1, 2, 3, 4')
+        # this also needs to be able to handle unicode that won't encode to ascii
+        ustr = 'i\xc3\xadacute'.decode('utf8')
+        self.assertEqual(self.script(['a','b',ustr]), 'a, b, i\xc3\xadacute'.decode('utf8'))
 
     def testFormatString(self):
         self.assertEqual(self.script('fkj dsh ekjhsdf kjer'), 'fkj dsh ekjhsdf kjer')
@@ -69,17 +68,17 @@ class TestFormatCatalogMetadata(atcttestcase.ATCTSiteTestCase):
         self.assertEqual(self.script(None), '')
         self.assertEqual(self.script(Missing.Value()), '')
 
+    def testUnicodeValue(self):
+        """ Make sure non-ascii encodable unicode is acceptable """
+        
+        ustr = 'i\xc3\xadacute'.decode('utf8')
+        self.assertEqual(self.script(ustr), ustr)
+
 tests.append(TestFormatCatalogMetadata)
 
-
-if __name__ == '__main__':
-    framework()
-else:
-    # While framework.py provides its own test_suite()
-    # method the testrunner utility does not.
-    import unittest
-    def test_suite():
-        suite = unittest.TestSuite()
-        for test in tests:
-            suite.addTest(unittest.makeSuite(test))
-        return suite
+import unittest
+def test_suite():
+    suite = unittest.TestSuite()
+    for test in tests:
+        suite.addTest(unittest.makeSuite(test))
+    return suite
