@@ -1,9 +1,6 @@
 """ demonstrates the use of ATReferenceBrowserWidget """
 
-try:
-    from Products.Archetypes.atapi import *
-except ImportError:
-    from Products.Archetypes.public import *
+from Products.Archetypes.atapi import *
 
 from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import *
 from DateTime import DateTime
