@@ -12,7 +12,7 @@ class ReferenceBrowserWidget(ReferenceWidget):
     _properties.update({
         'macro' : "referencebrowser",
         'size' : '',
-        'helper_js': ('referencebrowser.js', 'select_lists.js'),
+        'helper_js': ('referencebrowser.js',),
         'default_search_index':'SearchableText',
         'show_indexes':0,
         'available_indexes':{},
@@ -30,6 +30,7 @@ class ReferenceBrowserWidget(ReferenceWidget):
         'image_method' : None,
         'history_length' : 0,
         'restrict_browsing_to_startup_directory' : 0,
+        'show_results_without_query': 0,
         })
 
     # default_search_index: when a user searches in the popup, this index is used by default
