@@ -1,39 +1,42 @@
 import sys
 from Globals import InitializeClass
 
-from Products.Archetypes.debug import log
+from Products.Archetypes import PloneMessageFactory as _
 from Products.Archetypes.debug import log_exc
-from Products.Archetypes.debug import _default_logger
 from Products.Archetypes.utils import DisplayList
 from Products.Archetypes.utils import mapply
 from Products.Archetypes.utils import fixSchema
-from Products.Archetypes.utils import getRelURL
-from Products.Archetypes.utils import getRelPath
 from Products.Archetypes.utils import shasattr
 from Products.Archetypes.Field import StringField
 from Products.Archetypes.Field import TextField
-from Products.Archetypes.Field import STRING_TYPES
 from Products.Archetypes.Renderer import renderer
 from Products.Archetypes.Schema import Schema
 from Products.Archetypes.Schema import getSchemata
-from Products.Archetypes.Storage import AttributeStorage
 from Products.Archetypes.Widget import IdWidget
 from Products.Archetypes.Widget import StringWidget
 from Products.Archetypes.Marshall import RFC822Marshaller
+from Products.Archetypes.interfaces import IBaseObject
+from Products.Archetypes.interfaces import IReferenceable
+from Products.Archetypes.interfaces import ISchema
 from Products.Archetypes.interfaces.base import IBaseObject as z2IBaseObject
-from Products.Archetypes.interfaces.base import IBaseUnit as z2IBaseUnit
 from Products.Archetypes.interfaces.field import IFileField
+from Products.Archetypes.validator import AttributeValidator
 from Products.Archetypes.config import ATTRIBUTE_SECURITY
 from Products.Archetypes.config import RENAME_AFTER_CREATION_ATTEMPTS
 from Products.Archetypes.ArchetypeTool import getType
 from Products.Archetypes.ArchetypeTool import _guessPackage
 
+from Products.Archetypes.event import ObjectInitializedEvent
+from Products.Archetypes.event import ObjectEditedEvent
+
+from Products.Archetypes.interfaces import IMultiPageSchema
+from Products.Archetypes.interfaces import IObjectPreValidation
+from Products.Archetypes.interfaces import IObjectPostValidation
+
 from AccessControl import ClassSecurityInfo
 from AccessControl import Unauthorized
 from AccessControl.Permissions import copy_or_move as permission_copy_or_move
-from Acquisition import Implicit
 from Acquisition import aq_base
-from Acquisition import aq_acquire
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from Acquisition import ImplicitAcquisitionWrapper
@@ -41,63 +44,39 @@ from Acquisition import ExplicitAcquisitionWrapper
 from Acquisition import Explicit
 
 from ComputedAttribute import ComputedAttribute
-from OFS.ObjectManager import ObjectManager
 from ZODB.POSException import ConflictError
 import transaction
 
 from Products.CMFCore import permissions
 from Products.CMFCore.utils import getToolByName
-from Products.CMFCore.utils import _checkPermission as checkPerm
 
 from Referenceable import Referenceable
-from types import TupleType, ListType, UnicodeType
 
 from ZPublisher import xmlrpc
 from webdav.NullResource import NullResource
 
-from Products.Archetypes.interfaces import IBaseObject
-from zope.interface import implements, Interface
 from zope import event
-from zope.app.event import objectevent
+from zope.interface import implements, Interface
+from zope.component import subscribers
 from zope.component import queryMultiAdapter
+from zope.component import queryUtility
+
+# Import conditionally, so we don't introduce a hard depdendency
+try:
+    from plone.i18n.normalizer.interfaces import IUserPreferredURLNormalizer
+    from plone.i18n.normalizer.interfaces import IURLNormalizer
+    URL_NORMALIZER = True
+except ImportError:
+    URL_NORMALIZER = False
+
+try:
+    from plone.locking.interfaces import ILockable
+    HAS_LOCKING = True
+except ImportError:
+    HAS_LOCKING = False
 
 _marker = []
 
-class AttributeValidator(Implicit):
-    """(Ab)Use the security policy implementation.
-
-    This class will be used to protect attributes managed by
-    AttributeStorage with the same permission as the accessor method.
-
-    It does so by abusing a feature of the security policy
-    implementation that the
-    '__allow_access_to_unprotected_subobjects__' attribute can be (0,
-    1) or a dictionary of {name: 0|1} or a callable instance taking
-    'name' and 'value' arguments.
-
-    The said attribute is accessed through getattr(), so by
-    subclassing from Implicit we get the accessed object as our
-    aq_parent.
-
-    Next step is to check if the name is indeed a field name, and if
-    so, if it's using AttributeStorage, and if so, check the
-    read_permission against the object being accessed. All other cases
-    return '1' which means allow.
-    """
-
-    def __call__(self, name, value):
-        context = aq_parent(self)
-        schema = context.Schema()
-        if not schema.has_key(name):
-            return 1
-        field = schema[name]
-        if not isinstance(field.getStorage(), AttributeStorage):
-            return 1
-        perm = field.read_permission
-        if checkPerm(perm, context):
-            return 1
-        return 0
-
 content_type = Schema((
 
     StringField(
@@ -110,13 +89,11 @@ content_type = Schema((
         mutator='setId',
         default=None,
         widget=IdWidget(
-            label='Short Name',
-            label_msgid='label_short_name',
-            description='Should not contain spaces, underscores or mixed case. '\
-                        'Short Name is part of the item\'s web address.',
-            description_msgid='help_shortname',
-            visible={'view' : 'invisible'},
-            i18n_domain='plone',
+            label=_(u'label_short_name', default=u'Short Name'),
+            description=_(u'help_shortname',
+                          default=u'Should not contain spaces, underscores or mixed case. '
+                                   'Short Name is part of the item\'s web address.'),
+            visible={'view' : 'invisible'}
         ),
     ),
 
@@ -153,13 +130,10 @@ class BaseObject(Referenceable):
 
     installMode = ['type', 'actions', 'indexes']
 
-    typeDescMsgId = ''
-    typeDescription = ''
     _at_rename_after_creation = False # rename object according to title?
 
     __implements__ = (z2IBaseObject, ) + Referenceable.__implements__
-
-    implements(IBaseObject)
+    implements(IBaseObject, IReferenceable)
 
     def __init__(self, oid, **kwargs):
         self.id = oid
@@ -167,7 +141,7 @@ class BaseObject(Referenceable):
     security.declareProtected(permissions.ModifyPortalContent,
                               'initializeArchetype')
     def initializeArchetype(self, **kwargs):
-        """Called by the generated addXXX factory in types tool.
+        """Called by the generated add* factory in types tool.
         """
         try:
             self.initializeLayers()
@@ -181,8 +155,6 @@ class BaseObject(Referenceable):
             raise
         except:
             log_exc()
-            #_default_logger.log_exc()
-            #raise
 
     security.declarePrivate('manage_afterAdd')
     def manage_afterAdd(self, item, container):
@@ -234,7 +206,18 @@ class BaseObject(Referenceable):
             if parent is not None:
                 # See Referenceable, keep refs on what is a move/rename
                 self._v_cp_refs = 1
-                parent.manage_renameObject(self.id, value)
+                # We can't rename if the object is locked
+                if HAS_LOCKING:
+                    lockable = ILockable(self)
+                    was_locked = False
+                    if lockable.locked():
+                        was_locked = True
+                        lockable.unlock()
+                    parent.manage_renameObject(self.id, value)
+                    if was_locked:
+                        lockable.lock()
+                else:
+                    parent.manage_renameObject(self.id, value)
             self._setId(value)
 
     security.declareProtected(permissions.View, 'Type')
@@ -337,7 +320,7 @@ class BaseObject(Referenceable):
         return value
 
     # Backward compatibility
-    # Note: ComputedAttribute should never be protected by a security 
+    # Note: ComputedAttribute should never be protected by a security
     # declaration! See http://dev.plone.org/archetypes/ticket/712
     content_type = ComputedAttribute(getContentType, 1)
 
@@ -359,8 +342,7 @@ class BaseObject(Referenceable):
         if field and IFileField.isImplementedBy(field):
             field.setContentType(self, value)
 
-    security.declareProtected(permissions.ModifyPortalContent,
-                              'setFilename')
+    security.declareProtected(permissions.ModifyPortalContent, 'setFilename')
     def setFilename(self, value, key=None):
         """Sets the filename of a field.
         """
@@ -389,15 +371,14 @@ class BaseObject(Referenceable):
         pmt = getToolByName(self, 'portal_metadata')
         policy = None
         try:
-            spec = pmt.getElementSpec(field.accessor)
+            schema = getattr(pmt, 'DCMI', None)
+            spec = schema.getElementSpec(field.accessor)
             policy = spec.getPolicy(self.portal_type)
-
-
         except (ConflictError, KeyboardInterrupt):
             raise
         except:
             log_exc()
-            return None, 0
+            return None, False
 
         if not policy:
             policy = spec.getPolicy(None)
@@ -511,12 +492,34 @@ class BaseObject(Referenceable):
         """
         if errors is None:
             errors = {}
+
         self.pre_validate(REQUEST, errors)
+
+        for pre_validator in subscribers((self,), IObjectPreValidation):
+            pre_errors = pre_validator(REQUEST)
+            if pre_errors is not None:
+                for field_name, error_message in pre_errors.items():
+                    if field_name in errors:
+                        errors[field_name] += " %s" % error_message
+                    else:
+                        errors[field_name] = error_message
+
         if errors:
             return errors
         self.Schema().validate(instance=self, REQUEST=REQUEST,
                                errors=errors, data=data, metadata=metadata)
+
         self.post_validate(REQUEST, errors)
+
+        for post_validator in subscribers((self,), IObjectPostValidation):
+            post_errors = post_validator(REQUEST)
+            if post_errors is not None:
+                for field_name, error_message in post_errors.items():
+                    if field_name in errors:
+                        errors[field_name] += " %s" % error_message
+                    else:
+                        errors[field_name] = error_message
+
         return errors
 
     security.declareProtected(permissions.View, 'SearchableText')
@@ -537,8 +540,6 @@ class BaseObject(Referenceable):
                 # handle the mimetype argument
                 try:
                     datum =  method()
-
-
                 except (ConflictError, KeyboardInterrupt):
                     raise
                 except:
@@ -546,20 +547,21 @@ class BaseObject(Referenceable):
             if datum:
                 type_datum = type(datum)
                 vocab = field.Vocabulary(self)
-                if type_datum is ListType or type_datum is TupleType:
+                if isinstance(datum, list) or isinstance(datum, tuple):
                     # Unmangle vocabulary: we index key AND value
                     vocab_values = map(lambda value, vocab=vocab: vocab.getValue(value, ''), datum)
                     datum = list(datum)
                     datum.extend(vocab_values)
                     datum = ' '.join(datum)
-                elif type_datum in STRING_TYPES:
-                    if type_datum is UnicodeType:
+                elif isinstance(datum, basestring):
+                    if isinstance(datum, unicode):
                         datum = datum.encode(charset)
-                    datum = "%s %s" % (datum, vocab.getValue(datum, ''), )
+                    value = vocab.getValue(datum, '')
+                    if isinstance(value, unicode):
+                        value = value.encode(charset)
+                    datum = "%s %s" % (datum, value, )
 
-                # XXX: We really need an unicode policy !
-                type_datum = type(datum)
-                if type_datum is UnicodeType:
+                if isinstance(datum, unicode):
                     datum = datum.encode(charset)
                 data.append(str(datum))
 
@@ -598,7 +600,9 @@ class BaseObject(Referenceable):
         schemata = self.Schemata()
         fields = []
 
-        if fieldset is not None:
+        if not IMultiPageSchema.providedBy(self):
+            fields = schema.fields()
+        elif fieldset is not None:
             fields = schemata[fieldset].fields()
         else:
             if data: fields += schema.filterFields(isMetadata=0)
@@ -625,10 +629,20 @@ class BaseObject(Referenceable):
                 # exist just bail out.
                 continue
 
-            widget = field.widget
-            result = widget.process_form(self, field, form,
-                                         empty_marker=_marker)
-            if result is _marker or result is None: continue
+            try:
+                # Pass validating=False to inform the widget that we
+                # aren't in the validation phase, IOW, the returned
+                # data will be forwarded to the storage
+                result = field.widget.process_form(self, field, form,
+                                                   empty_marker=_marker,
+                                                   validating=False)
+            except TypeError:
+                # Support for old-style process_form methods
+                result = field.widget.process_form(self, field, form,
+                                                   empty_marker=_marker)
+
+            if result is _marker or result is None:
+                continue
 
             # Set things by calling the mutator
             mutator = field.getMutator(self)
@@ -638,8 +652,7 @@ class BaseObject(Referenceable):
 
         self.reindexObject()
 
-    security.declareProtected(permissions.ModifyPortalContent,
-                              'processForm')
+    security.declareProtected(permissions.ModifyPortalContent, 'processForm')
     def processForm(self, data=1, metadata=0, REQUEST=None, values=None):
         """Processes the schema looking for data in the form.
         """
@@ -652,12 +665,12 @@ class BaseObject(Referenceable):
 
         # Post create/edit hooks
         if is_new_object:
+            event.notify(ObjectInitializedEvent(self))
             self.at_post_create_script()
         else:
+            event.notify(ObjectEditedEvent(self))
             self.at_post_edit_script()
 
-        event.notify(objectevent.ObjectModifiedEvent(self))
-
     # This method is only called once after object creation.
     security.declarePrivate('at_post_create_script')
     def at_post_create_script(self):
@@ -707,18 +720,24 @@ class BaseObject(Referenceable):
         """Suggest an id for this object.
         This id is used when automatically renaming an object after creation.
         """
-        plone_tool = getToolByName(self, 'plone_utils', None)
-        if plone_tool is None or not shasattr(plone_tool, 'normalizeString'):
-            # Plone tool is not available or too old
-            # XXX log?
-            return None
-
         title = self.Title()
+        # Can't work w/o a title
         if not title:
-            # Can't work w/o a title
             return None
 
-        return plone_tool.normalizeString(title)
+        # Don't do anything without the plone.i18n package
+        if not URL_NORMALIZER:
+            return None
+
+        if not isinstance(title, unicode):
+            charset = self.getCharset()
+            title = unicode(title, charset)
+
+        request = getattr(self, 'REQUEST', None)
+        if request is not None:
+            return IUserPreferredURLNormalizer(request).normalize(title)
+
+        return queryUtility(IURLNormalizer).normalize(title)
 
     security.declarePrivate('_renameAfterCreation')
     def _renameAfterCreation(self, check_auto_id=False):
@@ -804,20 +823,20 @@ class BaseObject(Referenceable):
         return getSchemata(self)
 
     def Schema(self):
-        """Return a (wrapped) schema instance for
-        this object instance.
+        """Return a (wrapped) schema instance for this object instance.
         """
-        schema = self.schema
+        schema = ISchema(self)
         return ImplicitAcquisitionWrapper(schema, self)
 
     security.declarePrivate('_isSchemaCurrent')
     def _isSchemaCurrent(self):
-        """Determines whether the current object's schema is up to date."""
-        package = _guessPackage(self.__module__)
-        return getType(self.meta_type, package)['signature'] == self._signature
+        """Determines whether the current object's schema is up to date.
+        """
+        return self._signature == self.Schema().signature()
 
     security.declarePrivate('_updateSchema')
-    def _updateSchema(self, excluded_fields=[], out=None):
+    def _updateSchema(self, excluded_fields=[], out=None,
+                      remove_instance_schemas=False):
         """Updates an object's schema when the class schema changes.
 
         For each field we use the existing accessor to get its value,
@@ -830,11 +849,14 @@ class BaseObject(Referenceable):
         at the same time -- you really should restart zope after doing
         a schema update).
         """
-        if out:
+        if out is not None:
             print >> out, 'Updating %s' % (self.getId())
 
-        package = _guessPackage(self.__module__)
-        new_schema = getType(self.meta_type, package)['schema']
+        if remove_instance_schemas and 'schema' in self.__dict__:
+            if out is not None:
+                print >> out, 'Removing schema from instance dict.'
+            del self.schema
+        new_schema = self.Schema()
 
         # Read all the old values into a dict
         values = {}
@@ -846,7 +868,7 @@ class BaseObject(Referenceable):
             try:
                 values[name] = self._migrateGetValue(name, new_schema)
             except ValueError:
-                if out != None:
+                if out is not None:
                     print >> out, ('Unable to get %s.%s'
                                    % (str(self.getId()), name))
             else:
@@ -865,8 +887,6 @@ class BaseObject(Referenceable):
             for k in current_class.__dict__.keys():
                 obj_class.__dict__[k] = current_class.__dict__[k]
 
-        # Replace the schema
-        self.schema = new_schema.copy()
         # Set a request variable to avoid resetting the newly created flag
         req = getattr(self, 'REQUEST', None)
         if req is not None:
@@ -882,13 +902,13 @@ class BaseObject(Referenceable):
                 try:
                     self._migrateSetValue(name, values[name], **kw)
                 except ValueError:
-                    if out != None:
+                    if out is not None:
                         print >> out, ('Unable to set %s.%s to '
                                        '%s' % (str(self.getId()),
                                                name, str(values[name])))
         # Make sure the changes are persisted
         self._p_changed = 1
-        if out:
+        if out is not None:
             return out
 
     security.declarePrivate('_migrateGetValue')
@@ -905,7 +925,6 @@ class BaseObject(Referenceable):
                 if IFileField.isImplementedBy(field):
                     return field.getBaseUnit(self)
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -917,7 +936,6 @@ class BaseObject(Referenceable):
                 if editAccessor:
                     return editAccessor()
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -929,7 +947,6 @@ class BaseObject(Referenceable):
                 if accessor:
                     return accessor()
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -946,7 +963,6 @@ class BaseObject(Referenceable):
             try:
                 return self[field.getName()]
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -962,7 +978,6 @@ class BaseObject(Referenceable):
                 if editAccessor:
                     return editAccessor()
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -974,7 +989,6 @@ class BaseObject(Referenceable):
                 if accessor:
                     return accessor()
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -984,7 +998,6 @@ class BaseObject(Referenceable):
             try:
                 return self[new_field.getName()]
 
-
             except (ConflictError, KeyboardInterrupt):
                 raise
             except:
@@ -1014,7 +1027,6 @@ class BaseObject(Referenceable):
                     mapply(mutator, *args, **kw)
                     return
 
-
                 except (ConflictError, KeyboardInterrupt):
                     raise
                 except:
@@ -1035,8 +1047,7 @@ class BaseObject(Referenceable):
         return shasattr(parent, 'meta_type') and \
                parent.meta_type == 'TempFolder'
 
-    security.declareProtected(permissions.View,
-                              'getFolderWhenPortalFactory')
+    security.declareProtected(permissions.View, 'getFolderWhenPortalFactory')
     def getFolderWhenPortalFactory(self):
         """Returns the folder where this object was created temporarily.
         """
@@ -1141,7 +1152,6 @@ class BaseObject(Referenceable):
 
 InitializeClass(BaseObject)
 
-
 class Wrapper(Explicit):
     """Wrapper object for access to sub objects."""
     __allow_access_to_unprotected_subobjects__ = 1
