@@ -1,167 +1,25 @@
-import traceback, os
+import os
 from os.path import isdir, join
-from types import *
 
 from Globals import package_home
-from Globals import PersistentMapping
 from OFS.ObjectManager import BadRequestException
-from Acquisition import aq_base, aq_parent
-from Products.CMFCore.TypesTool import  FactoryTypeInformation
+from Products.CMFCore.ActionInformation import ActionInformation
 from Products.CMFCore.DirectoryView import addDirectoryViews, \
      registerDirectory, manage_listAvailableDirectories
-from Products.CMFCore.utils import getToolByName, minimalpath
+from Products.CMFCore.utils import getToolByName, getPackageName
+from Products.Archetypes.config import REFERENCE_CATALOG
 from Products.Archetypes.ArchetypeTool import fixActionsForType
+from Products.Archetypes.ArchetypeTool import listTypes
+from Products.Archetypes.ArchetypeTool import process_types
+from Products.Archetypes.ArchetypeTool import base_factory_type_information
 from Products.Archetypes import types_globals
 from Products.Archetypes.interfaces.base import IBaseObject
 from Products.Archetypes.interfaces.ITemplateMixin import ITemplateMixin
-from Products.Archetypes.config import *
 
-from Products.CMFFormController.Extensions.Install \
-     import install as install_formcontroller
-from Products.MimetypesRegistry.Extensions.Install \
-     import install as install_mimetypes_registry
-from Products.PortalTransforms.Extensions.Install \
-     import install as install_portal_transforms
-
-
-from Products.Archetypes.ReferenceEngine import manage_addReferenceCatalog
-from Products.Archetypes.UIDCatalog import manage_addUIDCatalog
-from Products.Archetypes.interfaces.referenceengine import \
-     IReferenceCatalog, IUIDCatalog
 
 class Extra:
     """indexes extra properties holder"""
 
-def install_dependencies(self, out, required=1):
-    qi=getToolByName(self, 'portal_quickinstaller', None)
-    if qi is None:
-        if required:
-            raise RuntimeError, (
-                'portal_quickinstaller tool could not be found, and it is '
-                'required to install Archetypes dependencies')
-        else:
-            print >>out, install_formcontroller(self)
-            print >>out, install_mimetypes_registry(self)
-            print >>out, install_portal_transforms(self)
-
-    if not qi.isProductInstalled('CMFFormController'):
-        qi.installProduct('CMFFormController',locked=1)
-        print >>out, 'Installing CMFFormController'
-    if not qi.isProductInstalled('MimetypesRegistry'):
-        qi.installProduct('MimetypesRegistry')
-        print >>out, 'Installing MimetypesRegistry'
-    if not qi.isProductInstalled('PortalTransforms'):
-        qi.installProduct('PortalTransforms')
-        print >>out, 'Installing PortalTransforms'
-
-def install_archetypetool(self, out):
-    at = getToolByName(self, 'archetype_tool', None)
-    if at is None:
-        addTool = self.manage_addProduct['Archetypes'].manage_addTool
-        addTool('Archetype Tool')
-        print >>out, 'Installing Archetype Tool'
-    else:
-        # Migration from 1.0
-        if not hasattr(aq_base(at), '_registeredTemplates'):
-            at._registeredTemplates = PersistentMapping()
-        if not hasattr(aq_base(at), 'catalog_map'):
-            at.catalog_map = PersistentMapping()
-
-def install_tools(self, out):
-    # Backwards compat. People (eg: me!) may depend on that
-    install_archetypetool(self, out)
-    install_uidcatalog(self, out)
-
-def install_uidcatalog(self, out, rebuild=False):
-
-    index_defs=( ('UID', 'FieldIndex'),
-                 ('Type', 'FieldIndex'),
-                 ('id', 'FieldIndex'),
-                 ('Title', 'FieldIndex'), # used for sorting
-                 ('portal_type', 'FieldIndex'),
-               )
-    metadata_defs = ('UID', 'Type', 'id', 'Title', 'portal_type', 'meta_type')
-    reindex = False
-    catalog = getToolByName(self, UID_CATALOG, None)
-    
-    if catalog is not None and not IUIDCatalog.isImplementedBy(catalog):
-        # got a catalog but it's doesn't implement IUIDCatalog
-        parent = getToolByName(self, "portal_url").getPortalObject()
-        parent.manage_delObjects([UID_CATALOG,])
-        catalog = None
-        rebuild = True
-
-    if catalog is None:
-        #Add a zcatalog for uids
-        addCatalog = manage_addUIDCatalog
-        addCatalog(self, UID_CATALOG, 'Archetypes UID Catalog')
-        catalog = getToolByName(self, UID_CATALOG)
-        print >>out, 'Installing uid catalog'
-
-    for indexName, indexType in index_defs:
-        try: #ugly try catch XXX FIXME
-            if indexName not in catalog.indexes():
-                catalog.addIndex(indexName, indexType, extra=None)
-                reindex = True
-        except:
-            pass
-
-    for metadata in metadata_defs:
-        if not indexName in catalog.schema():
-            catalog.addColumn(metadata)
-            reindex = True
-    if reindex:
-        catalog.manage_reindexIndex()
-    elif rebuild:
-        catalog.manage_rebuildCatalog()
-
-def install_referenceCatalog(self, out, rebuild=False):
-    catalog = getToolByName(self, REFERENCE_CATALOG, None)
-    if catalog and not IReferenceCatalog.isImplementedBy(catalog):
-        # got a catalog but it's doesn't implement IUIDCatalog
-        aq_parent(catalog).manage_delObjects([REFERENCE_CATALOG,])
-        catalog = None
-        rebuild = 1
-
-    if not catalog:
-        #Add a zcatalog for uids
-        addCatalog = manage_addReferenceCatalog
-        addCatalog(self, REFERENCE_CATALOG, 'Archetypes Reference Catalog')
-        catalog = getToolByName(self, REFERENCE_CATALOG)
-        print >>out, 'Installing reference catalog'
-        schema = catalog.schema()
-        for indexName, indexType in (
-                                      ('UID', 'FieldIndex'),
-                                      ('sourceUID', 'FieldIndex'),
-                                      ('targetUID', 'FieldIndex'),
-                                      ('relationship', 'FieldIndex'),
-                                      ('targetId', 'FieldIndex'),
-                                      ):
-            try:
-                catalog.addIndex(indexName, indexType, extra=None)
-            except:
-                pass
-            try:
-                if not indexName in schema:
-                    catalog.addColumn(indexName)
-            except:
-                pass
-
-        catalog.manage_reindexIndex()
-
-    if rebuild:
-        catalog = getToolByName(self, REFERENCE_CATALOG)
-        catalog.manage_rebuildCatalog()
-
-def install_templates(self, out):
-    at = getToolByName(self, 'archetype_tool')
-    at.registerTemplate('base_view', 'Base View')
-    
-    # fix name of base_view
-    #rt = at._registeredTemplates
-    #if 'base_view' not in rt.keys() or rt['base_view'] == 'base_view':
-    #    at.registerTemplate(base_view)
-
 def install_additional_templates(self, out, types):
     """Registers additionals templates for TemplateMixin classes.
     """
@@ -190,10 +48,10 @@ def install_additional_templates(self, out, types):
 def install_subskin(self, out, globals=types_globals, product_skins_dir='skins'):
     skinstool=getToolByName(self, 'portal_skins')
 
-    fullProductSkinsPath = os.path.join(package_home(globals), product_skins_dir)
-    productSkinsPath = minimalpath(fullProductSkinsPath)
+    product = getPackageName(globals)
+    registry_key = "%s:%s" % (product, product_skins_dir)
     registered_directories = manage_listAvailableDirectories()
-    if productSkinsPath not in registered_directories:
+    if registry_key not in registered_directories:
         try:
             registerDirectory(product_skins_dir, globals)
         except OSError, ex:
@@ -203,7 +61,7 @@ def install_subskin(self, out, globals=types_globals, product_skins_dir='skins')
     try:
         addDirectoryViews(skinstool, product_skins_dir, globals)
     except BadRequestException, e:
-        # XXX: find a better way to do this, but that seems not feasible
+        # TODO: find a better way to do this, but that seems not feasible
         #      until Zope stops using string exceptions
         if str(e).endswith(' is reserved.'):
             # trying to use a reserved identifier, let the user know
@@ -214,11 +72,12 @@ def install_subskin(self, out, globals=types_globals, product_skins_dir='skins')
         # directory view has already been added
         pass
 
+    fullProductSkinsPath = os.path.join(package_home(globals), product_skins_dir)
     files = os.listdir(fullProductSkinsPath)
     for productSkinName in files:
         # skip directories with a dot or special dirs
         # or maybe just startswith('.')?
-        if productSkinName.find('.') != -1 or productSkinName in ('CVS', '{arch}'):
+        if '.' in productSkinName or productSkinName in ('CVS', '_svn', '{arch}'):
             continue
         if isdir(join(fullProductSkinsPath, productSkinName)):
             for skinName in skinstool.getSkinSelections():
@@ -248,21 +107,35 @@ def install_types(self, out, types, package_name):
         # get the meta type of the FTI from the class, use the
         # default FTI as default
         fti_meta_type = getattr(klass, '_at_fti_meta_type', None)
-        if not fti_meta_type:
-            fti_meta_type = FactoryTypeInformation.meta_type
-
-        typesTool.manage_addTypeInformation(fti_meta_type,
-                                            id=klass.portal_type,
-                                            typeinfo_name=typeinfo_name)
+        if not fti_meta_type or fti_meta_type == 'simple item':
+            ## rr: explicitly catching 'simple item' because
+            ## CMF 2.0 removed the meta_type from the basic TIs :-(
+            ## seems to me, 'manage_addTypeInformation' is just broken
+            fti_meta_type = 'Factory-based Type Information'
+        try:
+            typesTool.manage_addTypeInformation(fti_meta_type,
+                                                id=klass.portal_type,
+                                                typeinfo_name=typeinfo_name)
+        except ValueError:
+            print "failed to add '%s'" %  klass.portal_type
+            print "fti_meta_type = %s" % fti_meta_type
+        ## rr: from CMF-2.0 onward typeinfo_name from the call above
+        ## is ignored and we have to do some more work
+        t, fti = _getFtiAndDataFor(typesTool, klass.portal_type, klass.__name__, package_name)
+        if t and fti:
+            t.manage_changeProperties(**fti)
+            if fti.has_key('aliases'):
+                t.setMethodAliases(fti['aliases'])
+        
         # Set the human readable title explicitly
-        t = getattr(typesTool, klass.portal_type, None)
         if t:
             t.title = klass.archetype_name
 
         # If the class appears folderish and the 'use_folder_tabs' is
         # not set to a false value, then we add the portal_type to
         # Plone's 'use_folder_tabs' property
-        use_folder_tabs = klass.isPrincipiaFolderish and getattr(klass, 'use_folder_tabs', 1)
+        use_folder_tabs = klass.isPrincipiaFolderish and \
+                          getattr(klass, 'use_folder_tabs', 1)
         if use_folder_tabs:
             folderish.append(klass.portal_type)
     if folderish:
@@ -282,10 +155,28 @@ def install_types(self, out, types, package_name):
             folders = tuple(dict(zip(folders, folders)).keys())
             sp._updateProperty(prop, folders)
 
+def _getFtiAndDataFor(tool, typename, klassname, package_name):
+    """helper method for type info setting
+       returns fti object from the types tool and the data created
+       by process_types for the fti
+    """
+    t = getattr(tool, typename, None)
+    if t is None:
+        return None, None
+    all_ftis = process_types(listTypes(package_name),
+                             package_name)[2]
+    for fti in all_ftis:
+        if fti['id'] == klassname:
+            fti['content_meta_type'] = fti['meta_type']
+            return t, fti
+    return t, None
+    
 
 def install_actions(self, out, types):
     typesTool = getToolByName(self, 'portal_types')
     for portal_type in types:
+        ## rr: XXX TODO somehow the following doesn't do anymore what
+        ## it used to do :-(
         fixActionsForType(portal_type, typesTool)
 
 def install_indexes(self, out, types):
@@ -298,9 +189,9 @@ def install_indexes(self, out, types):
             if not field.index:
                 continue
 
-            if type(field.index) is StringType:
+            if isinstance(field.index, basestring):
                 index = (field.index,)
-            elif isinstance(field.index, (TupleType, ListType) ):
+            elif isinstance(field.index, (tuple, list)):
                 index = field.index
             else:
                 raise SyntaxError("Invalid Index Specification %r"
@@ -407,23 +298,6 @@ def filterTypes(self, out, types, package_name):
         name = rti['name']
         meta_type = rti['meta_type']
 
-        # CMF 1.4 name: (product_id, metatype)
-        typeinfo_name="%s: %s" % (package_name, meta_type)
-        # CMF 1.5 name: (product_id, id, metatype)
-        typeinfo_name2="%s: %s (%s)" % (package_name, name, meta_type)
-        info = typesTool.listDefaultTypeInformation()
-        found = 0
-        for (name, ft) in info:
-            #if name.startswith(typeinfo_name):
-            if name in (typeinfo_name, typeinfo_name2):
-                found = 1
-                break
-
-        if not found:
-            print >> out, ('%s is not a registered Type '
-                           'Information' % typeinfo_name)
-            continue
-
         isBaseObject = 0
         if IBaseObject.isImplementedByInstancesOf(t):
             isBaseObject = 1
@@ -444,19 +318,6 @@ def filterTypes(self, out, types, package_name):
 
     return filtered_types
 
-def setupArchetypes(self, out, require_dependencies=True):
-    # installing dependency products
-    install_dependencies(self, out, require_dependencies)
-
-    # install archetype tools and templates
-    install_archetypetool(self, out)
-    install_uidcatalog(self, out, rebuild=False)
-    install_referenceCatalog(self, out, rebuild=False)
-
-    # install skins and register templates
-    install_subskin(self, out, types_globals)
-    install_templates(self, out)
-
 def setupEnvironment(self, out, types,
                      package_name,
                      globals=types_globals,
@@ -466,9 +327,16 @@ def setupEnvironment(self, out, types,
 
     if install_deps:
         qi=getToolByName(self, 'portal_quickinstaller', None)
-        if qi is None:
-            setupArchetypes(self, out, require_dependencies=require_dependencies)
-        else:
+        if require_dependencies:
+            if not qi.isProductInstalled('CMFFormController'):
+                qi.installProduct('CMFFormController',locked=1)
+                print >>out, 'Installing CMFFormController'
+            if not qi.isProductInstalled('MimetypesRegistry'):
+                qi.installProduct('MimetypesRegistry')
+                print >>out, 'Installing MimetypesRegistry'
+            if not qi.isProductInstalled('PortalTransforms'):
+                qi.installProduct('PortalTransforms')
+                print >>out, 'Installing PortalTransforms'
             if not qi.isProductInstalled('Archetypes'):
                 qi.installProduct('Archetypes')
                 print >>out, 'Installing Archetypes'
@@ -482,6 +350,30 @@ def setupEnvironment(self, out, types,
     install_indexes(self, out, ftypes)
     install_actions(self, out, ftypes)
 
+def doubleCheckDefaultTypeActions(self, ftypes):
+    # rr: for some reason, AT's magic wrt adding the default type actions
+    # stopped working when moving to CMF-2.0
+    # Instead of trying to resurect the old way (which I tried but couldn't)
+    # I make it brute force here
+
+    typesTool = getToolByName(self, 'portal_types')
+    defaultTypeActions = [ActionInformation(**action) for action in
+                          base_factory_type_information[0]['actions']]
+
+    for ftype in ftypes:
+        portal_type = ftype.portal_type
+        fti = typesTool.get(portal_type, None)
+        if fti is None:
+            continue
+        actions = list(fti._actions)
+        action_ids = [a.id for a in actions]
+        prepend = []
+        for a in defaultTypeActions:
+            if a.id not in action_ids:
+                prepend.append(a.clone())
+        if prepend:
+            fti._actions = tuple(prepend + actions)
+    
 
 ## The master installer
 def installTypes(self, out, types, package_name,
@@ -495,6 +387,8 @@ def installTypes(self, out, types, package_name,
     setupEnvironment(self, out, types, package_name,
                      globals, product_skins_dir, require_dependencies,
                      install_deps)
+    ## rr: sometimes the default actions are still missing
+    doubleCheckDefaultTypeActions(self, ftypes)
     if refresh_references and ftypes:
         rc = getToolByName(self, REFERENCE_CATALOG)
         rc.manage_rebuildCatalog()
