@@ -1,5 +1,6 @@
 from copy import deepcopy
 from types import DictType, FileType, ListType, StringTypes
+from DateTime import DateTime
 
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.Expression import Expression
@@ -8,7 +9,7 @@ from Products.CMFCore.Expression import createExprContext
 from Products.Archetypes.utils import className
 from Products.Archetypes.utils import unique
 from Products.Archetypes.utils import capitalize
-from Products.generator.widget import macrowidget
+from Products.Archetypes.generator import macrowidget
 from Products.Archetypes.debug import log
 from Products.Archetypes.Registry import registerPropertyType
 from Products.Archetypes.Registry import registerWidget
@@ -17,7 +18,6 @@ from ExtensionClass import Base
 from AccessControl import ClassSecurityInfo
 from Globals import InitializeClass
 from Acquisition import aq_base
-from Acquisition import Implicit
 
 _marker = []
 
@@ -31,6 +31,7 @@ class TypesWidget(macrowidget, Base):
         'show_content_type' : False,
         'helper_js': (),
         'helper_css': (),
+        'blurrable': False,
         })
 
     security = ClassSecurityInfo()
@@ -89,12 +90,8 @@ class TypesWidget(macrowidget, Base):
             state = 'invisible'
         elif vis_dic < 0:
             state = 'hidden'
-        #assert(state in ('visible', 'hidden', 'invisible',),
-        #      'Invalid view state %s' % state
-        #      )
         return state
 
-    # XXX
     security.declarePublic('setCondition')
     def setCondition(self, condition):
         """Set the widget expression condition."""
@@ -118,10 +115,9 @@ class TypesWidget(macrowidget, Base):
         except AttributeError:
             return True
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """Basic impl for form processing in a widget"""
         value = form.get(field.getName(), empty_marker)
         if value is empty_marker:
@@ -148,6 +144,7 @@ class StringWidget(TypesWidget):
         'macro' : "widgets/string",
         'size' : '30',
         'maxlength' : '255',
+        'blurrable' : True,
         })
 
     security = ClassSecurityInfo()
@@ -161,6 +158,7 @@ class DecimalWidget(TypesWidget):
         'dollars_and_cents' : False,
         'whole_dollars' : False,
         'thousands_commas' : False,
+        'blurrable' : True,
         })
 
     security = ClassSecurityInfo()
@@ -171,6 +169,7 @@ class IntegerWidget(TypesWidget):
         'macro' : "widgets/integer",
         'size' : '5',
         'maxlength' : '255',
+        'blurrable' : True,
         })
 
     security = ClassSecurityInfo()
@@ -301,7 +300,7 @@ class ReferenceWidget(TypesWidget):
                     if isinstance(place, ListType):
                         value['destinations'] = place + value['destinations']
                     else:
-                        #XXX Might as well check for type, doing it everywhere else
+                        #TODO Might as well check for type, doing it everywhere else
                         value['destinations'].append(place)
 
             if value['destinations']:
@@ -325,15 +324,18 @@ class TextAreaWidget(TypesWidget):
         'cols'  : 40,
         'format': 0,
         'append_only': False,
+        'timestamp' : False,        
         'divider':"\n\n========================\n\n",
+        'timestamp': False,
+        'maxlength' : False,
+        'helper_js': ('widgets/js/textcount.js',),        
         })
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """handle text formatting"""
         text_format = None
         value = None
@@ -346,25 +348,29 @@ class TextAreaWidget(TypesWidget):
         if emptyReturnsMarker and value == '':
             return empty_marker
 
-        if hasattr(field, 'allowable_content_types') and \
-               field.allowable_content_types:
-            format_field = "%s_text_format" % field.getName()
-            text_format = form.get(format_field, empty_marker)
+        format_field = "%s_text_format" % field.getName()
+        text_format = form.get(format_field, empty_marker)
         kwargs = {}
 
         if text_format is not empty_marker and text_format:
             kwargs['mimetype'] = text_format
 
-        """ handle append_only  """
-        # SPANKY: It would be nice to add a datestamp too, if desired
-
+        """ handle append_only """
         # Don't append if the existing data is empty or nothing was passed in
         if getattr(field.widget, 'append_only', None):
             if field.getEditAccessor(instance)():
                 if (value and not value.isspace()):
+                    
+                    divider = field.widget.divider
+                    
+                    # Add a datestamp along with divider if desired.
+                    if getattr(field.widget, 'timestamp', None):
+
+                        divider = "\n\n" + str(DateTime()) + divider
+                        
                     # using default_output_type caused a recursive transformation
                     # that sucked, thus mimetype= here to keep it in line
-                    value = value + field.widget.divider + \
+                    value = value + divider + \
                             field.getEditAccessor(instance)()
                 else:
                     # keep historical entries
@@ -395,10 +401,10 @@ class CalendarWidget(TypesWidget):
         'macro' : "widgets/calendar",
         'format' : '', # time.strftime string
         'show_hm' : True, 
-        'show_ymd' : True, # False not supported by the plone templates yet
-        'starting_year' : 1999, # not supported by the plone templates yet
-        'ending_year' : None, # not supported by the plone templates yet
-        'future_years' : 5, # not supported by the plone templates yet
+        'show_ymd' : True,
+        'starting_year' : None,
+        'ending_year' : None,
+        'future_years' : None,
         'helper_js': ('jscalendar/calendar_stripped.js',
                       'jscalendar/calendar-en.js'),
         'helper_css': ('jscalendar/calendar-system.css',),
@@ -406,11 +412,54 @@ class CalendarWidget(TypesWidget):
 
     security = ClassSecurityInfo()
 
+    security.declarePublic('process_form')
+    def process_form(self, instance, field, form, empty_marker=None,
+                     emptyReturnsMarker=False, validating=True):
+        """Basic impl for form processing in a widget"""
+
+        fname = field.getName()
+        value = form.get(fname, empty_marker)
+        if value is empty_marker:
+            return empty_marker
+        # If JS support is unavailable, the value
+        # in the request may be missing or incorrect
+        # since it won't have been assembled from the
+        # input components. Instead of relying on it,
+        # assemble the date/time from its input components.
+        year = form.get('%s_year' % fname, '0000')
+        month = form.get('%s_month' % fname, '00')
+        day = form.get('%s_day' % fname, '00')
+        hour = form.get('%s_hour' % fname, '00')
+        minute = form.get('%s_minute' % fname, '00')
+        ampm = form.get('%s_ampm' % fname, '')
+        if (year != '0000') and (day != '00') and (month != '00'):
+            value = "%s-%s-%s %s:%s" % (year, month, day, hour, minute)
+            if ampm:
+                value = '%s %s' % (value, ampm)
+        else:
+            value = ''
+        if emptyReturnsMarker and value == '':
+            return empty_marker
+        # stick it back in request.form
+        form[fname] = value
+        return value, {}
+
 class SelectionWidget(TypesWidget):
     _properties = TypesWidget._properties.copy()
     _properties.update({
         'format': "flex", # possible values: flex, select, radio
         'macro' : "widgets/selection",
+        'blurrable' : True,
+        })
+
+    security = ClassSecurityInfo()
+
+class LanguageWidget(TypesWidget):
+    _properties = TypesWidget._properties.copy()
+    _properties.update({
+        'format': "flex", # possible values: flex, select, radio
+        'macro' : "widgets/languagewidget",
+        'blurrable' : True,
         })
 
     security = ClassSecurityInfo()
@@ -421,13 +470,14 @@ class MultiSelectionWidget(TypesWidget):
         'format': "select", # possible values: select, checkbox
         'macro' : "widgets/multiselection",
         'size'  : 5,
+        'blurrable' : True,
         })
 
     security = ClassSecurityInfo()
 
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """Basic impl for form processing in a widget"""
         value = form.get(field.getName(), empty_marker)
         if value is empty_marker:
@@ -453,10 +503,9 @@ class KeywordWidget(TypesWidget):
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """process keywords from form where this widget has a list of
         available keywords and any new ones"""
         name = field.getName()
@@ -484,10 +533,9 @@ class FileWidget(TypesWidget):
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """form processing that deals with binary data"""
 
         delete = form.get('%s_delete' % field.getName(), empty_marker)
@@ -524,10 +572,9 @@ class RichWidget(TypesWidget):
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """complex form processing, includes handling for text
         formatting and file objects"""
         # This is basically the old processing chain from base object
@@ -535,12 +582,9 @@ class RichWidget(TypesWidget):
         isFile = False
         value = None
 
-        # text field with formatting
-        if hasattr(field, 'allowable_content_types') and \
-           field.allowable_content_types:
-            # was a mimetype specified
-            format_field = "%s_text_format" % field.getName()
-            text_format = form.get(format_field, empty_marker)
+        # was a mimetype specified
+        format_field = "%s_text_format" % field.getName()
+        text_format = form.get(format_field, empty_marker)
 
         # or a file?
         fileobj = form.get('%s_file' % field.getName(), empty_marker)
@@ -587,10 +631,9 @@ class IdWidget(TypesWidget):
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """the id might be hidden by the widget and not submitted"""
         value = form.get('id', empty_marker)
         if not value or value is empty_marker or not value.strip():
@@ -604,9 +647,9 @@ class RequiredIdWidget(IdWidget):
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
-    def process_form(self, instance, field, form, empty_marker=None):
+    def process_form(self, instance, field, form, empty_marker=None,
+                     emptyReturnsMarker=False, validating=True):
         """Override IdWidget.process_form to require id."""
         return TypesWidget.process_form(self, instance, field, form, empty_marker)
 
@@ -621,10 +664,9 @@ class ImageWidget(FileWidget):
 
     security = ClassSecurityInfo()
 
-    # XXX
     security.declarePublic('process_form')
     def process_form(self, instance, field, form, empty_marker=None,
-                     emptyReturnsMarker=False):
+                     emptyReturnsMarker=False, validating=True):
         """form processing that deals with image data (and its delete case)"""
         value = None
         ## check to see if the delete hidden was selected
@@ -721,6 +763,7 @@ __all__ = ('StringWidget', 'DecimalWidget', 'IntegerWidget',
            'RichWidget', 'FileWidget', 'IdWidget', 'ImageWidget',
            'LabelWidget', 'PasswordWidget', 'VisualWidget', 'EpozWidget',
            'InAndOutWidget', 'PicklistWidget', 'RequiredIdWidget',
+           'LanguageWidget',
            )
 
 registerWidget(StringWidget,
@@ -794,6 +837,15 @@ registerWidget(SelectionWidget,
                          'Products.Archetypes.Field.LinesField',)
                )
 
+registerWidget(LanguageWidget,
+              title='Language',
+              description=('Renders a HTML selection widget for choosing '
+                           'a language from a vocabulary. The widget can be '
+                           'represented as a dropdown, or as a group of'
+                           'of radio buttons'),
+              used_for=('Products.Archetypes.Field.StringField')
+              )
+
 registerWidget(MultiSelectionWidget,
                title='Multi Selection',
                description=('Renders a HTML selection widget, where '
@@ -891,6 +943,7 @@ registerPropertyType('rows', 'integer', TextAreaWidget)
 registerPropertyType('cols', 'integer', TextAreaWidget)
 registerPropertyType('append_only', 'boolean', TextAreaWidget)
 registerPropertyType('divider', 'string', TextAreaWidget)
+registerPropertyType('timestamp', 'boolean', TextAreaWidget)
 registerPropertyType('rows', 'integer', LinesWidget)
 registerPropertyType('cols', 'integer', LinesWidget)
 registerPropertyType('rows', 'integer', VisualWidget)
