@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 ################################################################################
 #
 # Copyright (c) 2002-2005, Benjamin Saller <bcsaller@ideasuite.com>, and
@@ -23,18 +22,15 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ################################################################################
-"""
-"""
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
-from Testing import ZopeTestCase
+from Testing.ZopeTestCase import user_password
+from Products.Five.testbrowser import Browser
 
 from Products.Archetypes.tests.atsitetestcase import ATSiteTestCase
+from Products.Archetypes.tests.atsitetestcase import ATFunctionalSiteTestCase
 from Products.Archetypes.tests.utils import makeContent
 
+
 from Products.CMFCore.utils import _checkPermission as checkPerm
 from Products.CMFCore import permissions
 
@@ -74,12 +70,44 @@ class TestPermissions(ATSiteTestCase):
             self.failUnless(content().strip().startswith('<!DOCTYPE'))
 
 
+class TestFTICopy(ATFunctionalSiteTestCase):
+    """Test for http://dev.plone.org/plone/ticket/6734: Cannot filter
+    Addable Types with folderish FTI in portal_types.
+    """
+    
+    def test6734(self):
+        self.loginAsPortalOwner()
+
+        # We start off by copying the existing SimpleFolder type to
+        # our own type 'MySimpleFolder'.  For this type, we set the
+        # SimpleFolder type to be the sole allowed content type.
+        types = self.portal.portal_types
+        types.manage_pasteObjects(types.manage_copyObjects(['SimpleFolder']))
+        types.manage_renameObjects(['copy_of_SimpleFolder'], ['MySimpleFolder'])
+        my_type = types['MySimpleFolder']
+        attrs = dict(allowed_content_types=('SimpleFolder',),
+                     filter_content_types=True,
+                     portal_type='MySimpleFolder',
+                     title='MySimpleFolder')
+        my_type.__dict__.update(attrs)
+
+        browser = Browser()
+        browser.addHeader('Authorization',
+                          'Basic %s:%s' % ('portal_owner', user_password))
+        browser.open(self.folder.absolute_url())
+        browser.getLink('Add new').click()
+        browser.getControl('MySimpleFolder').click()
+        browser.getControl('Add').click()
+
+        browser.getControl('Title').value = 'My dope folder'
+        browser.getControl('Save').click()
+        self.failUnless('Changes saved.' in browser.contents)
+        self.failUnless('My dope folder' in browser.contents)
+
 
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestPermissions))
+    suite.addTest(makeSuite(TestFTICopy))
     return suite
-
-if __name__ == '__main__':
-    framework()
