@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 ################################################################################
 #
 # Copyright (c) 2002-2005, Benjamin Saller <bcsaller@ideasuite.com>, and
@@ -26,16 +25,11 @@
 """
 Unittests for a copying/cutting and pasting archetypes objects.
 
-$Id: test_copying.py 5448 2006-01-06 18:34:27Z alecm $
+$Id: test_copying.py 7768 2007-03-18 23:38:08Z nouri $
 """
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
+import os
 
-from Testing import ZopeTestCase
-
-import types
 import transaction
 from Acquisition import aq_base
 
@@ -76,8 +70,6 @@ class CutPasteCopyPasteTests(ATSiteTestCase):
         self.failIf('tourist' in ffrom.contentIds())
         self.failIf('tourist' not in fto.contentIds())
 
-from Testing.ZopeTestCase.ZopeTestCase import user_name
-
 class PortalCopyTests(ATSiteTestCase):
 
     def afterSetUp(self):
@@ -170,12 +162,6 @@ class PortalCopyTests(ATSiteTestCase):
         # Copy/pasting a File should set new ownership including local roles
         # borrowed from CMFCore tests
 
-        # BBB this test will fail with CMF 1.4 as CMF 1.4 does not set local
-        # roles on copy, so let's not bother
-        qi = self.portal.portal_quickinstaller
-        if 'CMF-1.4' in qi.getProductVersion('CMFCore'):
-            return
-
         # First, add two users to the user folder, a member and a manager
         # and create a member area for the member
         uf = self.portal.acl_users
@@ -183,6 +169,7 @@ class PortalCopyTests(ATSiteTestCase):
         uf._doAddUser('manager1', 'secret', ['Manager'], [])
         member = uf.getUser('member').__of__(uf)
         manager1 = uf.getUser('manager1').__of__(uf)
+        self.portal.portal_membership.setMemberareaCreationFlag()
         self.portal.portal_membership.createMemberArea('member')
         member_area = self.portal.Members.member
 
@@ -320,6 +307,3 @@ def test_suite():
     suite.addTest(makeSuite(CutPasteCopyPasteTests))
     suite.addTest(makeSuite(PortalCopyTests))
     return suite
-
-if __name__ == '__main__':
-    framework()
