@@ -12,37 +12,42 @@
 ##############################################################################
 """ CMFCalendar portal_calendar tool.
 
-$Id: CalendarTool.py 66245 2006-03-28 17:02:36Z jens $
+$Id: CalendarTool.py 77004 2007-06-24 08:57:54Z yuppie $
 """
 
 import calendar
-calendar.setfirstweekday(6) #start day  Mon(0)-Sun(6)
 
 from AccessControl import ClassSecurityInfo
 from DateTime import DateTime
 from Globals import InitializeClass
 from OFS.SimpleItem import SimpleItem
+from zope.interface import implements
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
+from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.utils import UniqueObject
 
+from interfaces import ICalendarTool
 from permissions import ManagePortal
 
 class CalendarTool (UniqueObject, SimpleItem):
-    """ a calendar tool for encapsualting how calendars work and are displayed """
+
+    """ A tool for encapsulating how calendars work and are displayed """
+
     id = 'portal_calendar'
     meta_type= 'CMF Calendar Tool'
     security = ClassSecurityInfo()
 
+    implements(ICalendarTool)
+
     calendar_types = ('Event',)
     calendar_states = ('published',)
-    use_session = ''
+    use_session = False
+    firstweekday = 6 # 6 is Sunday
 
-    manage_options = ( ({ 'label' : 'Overview', 'action' : 'manage_overview' }
-                     ,  { 'label' : 'Configure', 'action' : 'manage_configure' }
-                     ,
-                     ) + SimpleItem.manage_options
-                     )
+    manage_options = (({'label' : 'Overview', 'action' : 'manage_overview'},
+                       {'label' : 'Configure', 'action' : 'manage_configure'},
+                      ) + SimpleItem.manage_options)
 
     #
     #   ZMI methods
@@ -56,49 +61,87 @@ class CalendarTool (UniqueObject, SimpleItem):
                                    __name__='manage_configure')
 
     security.declareProtected( ManagePortal, 'edit_configuration' )
-    def edit_configuration(self, show_types, use_session, show_states=None):
-        """ Change the configuration of the calendar tool """
+    def edit_configuration( self
+                          , show_types
+                          , use_session
+                          , show_states=None
+                          , firstweekday=None
+                          ):
+        """ Change the configuration of the calendar tool 
+        """
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on self.REQUEST
         self.calendar_types = tuple(show_types)
-        self.use_session = use_session
+        self.use_session = bool(use_session)
+
         if show_states is not None:
             self.calendar_states = tuple(show_states)
+
+        if firstweekday is not None:
+            try:
+                fwd = int(firstweekday)
+
+                if 0 <= fwd <= 6:
+                    # Do nothing with illegal values
+                    self.firstweekday = fwd
+            except ValueError:
+                # Do nothing with illegal values
+                pass
+
         if hasattr(self.REQUEST, 'RESPONSE'):
             self.REQUEST.RESPONSE.redirect('manage_configure')
 
+    security.declarePrivate('_getCalendar')
+    def _getCalendar(self):
+        """ Wrapper to ensure we set the first day of the week every time
+        """
+        calendar.setfirstweekday(self.getFirstWeekDay())
+        return calendar
+
+    security.declarePublic('getFirstWeekDay')
+    def getFirstWeekDay(self):
+        """ Get our first weekday setting
+        """
+        return self.firstweekday
+
     security.declarePublic('getCalendarTypes')
     def getCalendarTypes(self):
-        """ Returns a list of type that will show in the calendar """
+        """ Returns a list of type that will show in the calendar 
+        """
         return self.calendar_types
 
     security.declarePublic('getCalendarStates')
     def getCalendarStates(self):
-        """ Returns a list of workflow states that will show in the calendar """
+        """ Returns a list of workflow states that will show in the calendar 
+        """
         return self.calendar_states
 
     security.declarePublic('getUseSession')
     def getUseSession(self):
-        """ Returns the Use_Session option """
-        return self.use_session
+        """ Returns the Use_Session option 
+        """
+        return bool(self.use_session)
 
     security.declarePublic('getDays')
     def getDays(self):
-        """ Returns a list of days with the correct start day first """
-        return calendar.weekheader(2).split()
+        """ Returns a list of days with the correct start day first 
+        """
+        return self._getCalendar().weekheader(2).split()
 
     security.declarePublic('getWeeksList')
     def getWeeksList(self, month='1', year='2002'):
-        """Creates a series of weeks, each of which contains an integer day number.
-           A day number of 0 means that day is in the previous or next month.
+        """ Return a series of weeks, each containing an integer day number.
+        A day number of 0 means that day is in the previous or next month.
         """
-        year=int(year)
-        month=int(month)
+        year = int(year)
+        month = int(month)
         # daysByWeek is a list of days inside a list of weeks, like so:
         # [[0, 1, 2, 3, 4, 5, 6],
         #  [7, 8, 9, 10, 11, 12, 13],
         #  [14, 15, 16, 17, 18, 19, 20],
         #  [21, 22, 23, 24, 25, 26, 27],
         #  [28, 29, 30, 31, 0, 0, 0]]
-        daysByWeek=calendar.monthcalendar(year, month)
+        daysByWeek = self._getCalendar().monthcalendar(year, month)
 
         return daysByWeek
 
@@ -107,21 +150,21 @@ class CalendarTool (UniqueObject, SimpleItem):
         """ recreates a sequence of weeks, by days each day is a mapping.
             {'day': #, 'url': None}
         """
-        year=int(year)
-        month=int(month)
+        year = int(year)
+        month = int(month)
         # daysByWeek is a list of days inside a list of weeks, like so:
         # [[0, 1, 2, 3, 4, 5, 6],
         #  [7, 8, 9, 10, 11, 12, 13],
         #  [14, 15, 16, 17, 18, 19, 20],
         #  [21, 22, 23, 24, 25, 26, 27],
         #  [28, 29, 30, 31, 0, 0, 0]]
-        daysByWeek=calendar.monthcalendar(year, month)
-        weeks=[]
+        daysByWeek = self._getCalendar().monthcalendar(year, month)
+        weeks = []
 
-        events=self.catalog_getevents(year, month)
+        events = self.catalog_getevents(year, month)
 
         for week in daysByWeek:
-            days=[]
+            days = []
             for day in week:
                 if events.has_key(day):
                     days.append(events[day])
@@ -134,14 +177,18 @@ class CalendarTool (UniqueObject, SimpleItem):
 
     security.declarePublic('catalog_getevents')
     def catalog_getevents(self, year, month):
-        """ given a year and month return a list of days that have events """
-        year=int(year)
-        month=int(month)
-        last_day=calendar.monthrange(year, month)[1]
-        first_date=self.getBeginAndEndTimes(1, month, year)[0]
-        last_date=self.getBeginAndEndTimes(last_day, month, year)[1]
+        """ given a year and month return a list of days that have events 
+        """
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on a non-utility tool
+        year = int(year)
+        month = int(month)
+        last_day = self._getCalendar().monthrange(year, month)[1]
+        first_date = self.getBeginAndEndTimes(1, month, year)[0]
+        last_date = self.getBeginAndEndTimes(last_day, month, year)[1]
 
-        query = self.portal_catalog(
+        ctool = getToolByName(self, 'portal_catalog')
+        query = ctool(
                         portal_type=self.getCalendarTypes(),
                         review_state=self.getCalendarStates(),
                         start={'query': last_date, 'range': 'max'},
@@ -151,7 +198,9 @@ class CalendarTool (UniqueObject, SimpleItem):
         # compile a list of the days that have events
         eventDays={}
         for daynumber in range(1, 32): # 1 to 31
-            eventDays[daynumber] = {'eventslist':[], 'event':0, 'day':daynumber}
+            eventDays[daynumber] = {'eventslist': [],
+                                    'event': 0,
+                                    'day': daynumber}
         includedevents = []
         for result in query:
             if result.getRID() in includedevents:
@@ -169,7 +218,7 @@ class CalendarTool (UniqueObject, SimpleItem):
                 eventEndDay = result.end.day()
                 event['end'] = result.end.Time()
             # and events that started last month
-            if result.start.month() != month:  # same as above re: 12 month thing
+            if result.start.month() != month:  # same as above (12 month thing)
                 eventStartDay = 1
                 event['start'] = None
             else:
@@ -180,13 +229,17 @@ class CalendarTool (UniqueObject, SimpleItem):
 
             if eventStartDay != eventEndDay:
                 allEventDays = range(eventStartDay, eventEndDay+1)
-                eventDays[eventStartDay]['eventslist'].append( {'end': None,
-                        'start': result.start.Time(), 'title': event['title']} )
+                eventDays[eventStartDay]['eventslist'].append(
+                        {'end': None,
+                         'start': result.start.Time(),
+                         'title': event['title']} )
                 eventDays[eventStartDay]['event'] = 1
 
                 for eventday in allEventDays[1:-1]:
-                    eventDays[eventday]['eventslist'].append( {'end': None,
-                                       'start': None, 'title': event['title']} )
+                    eventDays[eventday]['eventslist'].append(
+                        {'end': None,
+                         'start': None,
+                         'title': event['title']} )
                     eventDays[eventday]['event'] = 1
 
                 if result.end == result.end.earliestTime():
@@ -194,8 +247,9 @@ class CalendarTool (UniqueObject, SimpleItem):
                     last_days_event = last_day_data['eventslist'][-1]
                     last_days_event['end'] = (result.end-1).latestTime().Time()
                 else:
-                    eventDays[eventEndDay]['eventslist'].append( {'end':
-                        result.end.Time(), 'start': None, 'title': event['title']} )
+                    eventDays[eventEndDay]['eventslist'].append( 
+                        { 'end': result.end.Time()
+                        , 'start': None, 'title': event['title']} )
                     eventDays[eventEndDay]['event'] = 1
             else:
                 eventDays[eventStartDay]['eventslist'].append(event)
@@ -213,9 +267,10 @@ class CalendarTool (UniqueObject, SimpleItem):
         """ given an exact day return ALL events that:
             A) Start on this day  OR
             B) End on this day  OR
-            C) Start before this day  AND  end after this day"""
-
-        catalog = self.portal_catalog
+            C) Start before this day  AND  end after this day
+        """
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on a non-utility tool
         day, month, year = ( int(thisDay.day())
                            , int(thisDay.month())
                            , int(thisDay.year())
@@ -227,21 +282,22 @@ class CalendarTool (UniqueObject, SimpleItem):
         after_midnight = DateTime(after_midnight_str)
 
         # Get all events that Start on this day
-        query = self.portal_catalog(
+        ctool = getToolByName(self, 'portal_catalog')
+        query = ctool(
                         portal_type=self.getCalendarTypes(),
                         review_state=self.getCalendarStates(),
                         start={'query': (first_date, last_date),
                                'range': 'minmax'} )
 
         # Get all events that End on this day
-        query += self.portal_catalog(
+        query += ctool(
                          portal_type=self.getCalendarTypes(),
                          review_state=self.getCalendarStates(),
                          end={'query': (after_midnight, last_date),
                               'range': 'minmax'} )
 
         # Get all events that Start before this day AND End after this day
-        query += self.portal_catalog(
+        query += ctool(
                          portal_type=self.getCalendarTypes(),
                          review_state=self.getCalendarStates(),
                          start={'query': first_date, 'range': 'max'},
@@ -269,49 +325,43 @@ class CalendarTool (UniqueObject, SimpleItem):
 
     security.declarePublic('getPreviousMonth')
     def getPreviousMonth(self, month, year):
-        # given any particular year and month, this method will return a 
-        # datetime object for one month prior
+        """ Get a DateTime object for one month prior to the given year/month
+        """
+        month = int(month)
+        year = int(year)
 
-        try: month=int(month)
-        except: raise "Calendar Type Error", month
-        try: year=int(year)
-        except: raise "Calendar Type Error", year
-
-        if month==0 or month==1:
+        if month == 0 or month == 1:
             month, year = 12, year - 1
         else:
-            month-=1
+            month -= 1
 
         return DateTime(year, month, 1)
 
     security.declarePublic('getNextMonth')
     def getNextMonth(self, month, year):
-        # given any particular year and month, this method will return a datetime object
-        # for one month after
+        """ Get a DateTime object for one month after the given year/month
+        """
+        month = int(month)
+        year = int(year)
 
-        try: month=int(month)
-        except: raise "Calendar Type Error", month
-        try: year=int(year)
-        except: raise "Calendar Type Error", year
-
-        if month==12:
+        if month == 12:
             month, year = 1, year + 1
         else:
-            month+=1
+            month += 1
 
         return DateTime(year, month, 1)
 
     security.declarePublic('getBeginAndEndTimes')
     def getBeginAndEndTimes(self, day, month, year):
-        # Given any day, month and year this method returns 2 DateTime objects
-        # That represent the exact start and the exact end of that particular day.
+        """ Get two DateTime objects representing the beginning and end
+        of the given day
+        """
+        day = int(day)
+        month = int(month)
+        year = int(year)
 
-        day=int(day)
-        month=int(month)
-        year=int(year)
-
-        begin=DateTime('%d-%02d-%02d 00:00:00' % (year, month, day))
-        end=DateTime('%d-%02d-%02d 23:59:59' % (year, month, day))
+        begin = DateTime('%d/%02d/%02d 00:00:00' % (year, month, day))
+        end = DateTime('%d/%02d/%02d 23:59:59' % (year, month, day))
 
         return (begin, end)
 
