@@ -12,53 +12,38 @@
 ##############################################################################
 """ Unit tests for CalendarTool module.
 
-$Id: test_Calendar.py 70893 2006-10-23 18:26:54Z jens $
+$Id: test_Calendar.py 76729 2007-06-17 14:08:32Z yuppie $
 """
 
 import unittest
-import Testing
-try:
-    import Zope2
-except ImportError:
-    # BBB: for Zope 2.7
-    import Zope as Zope2
-Zope2.startup()
+from Testing import ZopeTestCase
+ZopeTestCase.utils.setupCoreSessions()
 
 import locale
 
 from AccessControl.SecurityManagement import newSecurityManager
-from AccessControl.SecurityManagement import noSecurityManager
 from AccessControl.User import UnrestrictedUser
 from DateTime import DateTime
-import Products
-from Products.Five import zcml
-from Products.TemporaryFolder.TemporaryFolder import MountedTemporaryFolder
-from Products.Transience.Transience import TransientObjectContainer
-from Products.CMFCore.tests.base.testcase import WarningInterceptor
-from Products.CMFDefault.factory import addConfiguredSite
-from Testing.makerequest import makerequest
-try:
-    import transaction
-except ImportError:
-    # BBB: for Zope 2.7
-    from Products.CMFCore.utils import transaction
-from Products.CMFCore import Skinnable
+from zope.app.component.hooks import setSite
 
-try:
-    from zope.testing.cleanup import cleanUp
-except:
-    # BBB: for Zope 2.8
-    from zope.testing.cleanup import CleanUp
-    cleanup_ob = CleanUp()
-    cleanUp = cleanup_ob.cleanUp
+from Products.CMFCalendar.testing import FunctionalLayer
 
 
 class CalendarTests(unittest.TestCase):
 
-    def _makeOne(self, *args, **kw):
+    def _getTargetClass(self):
         from Products.CMFCalendar.CalendarTool import CalendarTool
 
-        return CalendarTool(*args, **kw)
+        return CalendarTool
+
+    def _makeOne(self, *args, **kw):
+        return self._getTargetClass()(*args, **kw)
+
+    def test_z3interfaces(self):
+        from zope.interface.verify import verifyClass
+        from Products.CMFCalendar.interfaces import ICalendarTool
+
+        verifyClass(ICalendarTool, self._getTargetClass())
 
     def test_new(self):
         ctool = self._makeOne()
@@ -92,74 +77,81 @@ class CalendarTests(unittest.TestCase):
         finally:
             locale.setlocale(locale.LC_ALL, old_locale)
 
+    def test_firstweekday(self):
+        ctool = self._makeOne()
+        ctool.firstweekday = 6
+        self.assertEqual(ctool.getFirstWeekDay(), 6)
 
-class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
+        # Try setting it to invalid values, the setting should not stick
+        ctool.edit_configuration([], None, firstweekday='insane')
+        self.assertEqual(ctool.getFirstWeekDay(), 6)
 
-    def setUp(self):
-        self._trap_warning_output()
-        zcml.load_config('meta.zcml', Products.Five)
-        zcml.load_config('configure.zcml', Products.Five)
-        zcml.load_config('configure.zcml', Products.GenericSetup)
-        zcml.load_config('configure.zcml', Products.CMFCore)
-        zcml.load_config('configure.zcml', Products.CMFDefault)
-        zcml.load_config('configure.zcml', Products.DCWorkflow)
-        self._oldSkindata = Skinnable.SKINDATA.copy()
-        transaction.begin()
+        ctool.edit_configuration([], None, firstweekday=42)
+        self.assertEqual(ctool.getFirstWeekDay(), 6)
 
-        app = self.app = makerequest(Zope2.app())
-        # Log in as a god :-)
-        newSecurityManager(None,
-                           UnrestrictedUser('god', 'god', ['Manager'], '') )
+        # Set it to a sane value
+        ctool.edit_configuration([], None, firstweekday=0)
+        self.assertEqual(ctool.getFirstWeekDay(), 0)
 
-        factory = app.manage_addProduct['CMFDefault'].addConfiguredSite
-        factory('CalendarTest', 'CMFDefault:default', snapshot=False,
-                extension_ids=('CMFCalendar:default',))
+        # Make sure the setting is being used...
+        old_locale = locale.getlocale(locale.LC_ALL)[0]
+        locale.setlocale(locale.LC_ALL, 'C')
+        try:
+            self.assertEqual( ctool.getDays(),
+                              ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa','Su'] )
+        finally:
+            locale.setlocale(locale.LC_ALL, old_locale)
 
-        self.Site = app.CalendarTest
 
-        self.Tool = app.CalendarTest.portal_calendar
+class CalendarRequestTests(ZopeTestCase.FunctionalTestCase):
+
+    layer = FunctionalLayer
+
+    def afterSetUp(self):
+        setSite(self.app.site)
+        self.app.site.setupCurrentSkin(self.app.REQUEST)
+        newSecurityManager(None, UnrestrictedUser('god', '', ['Manager'], ''))
 
         # sessioning setup
-        if getattr(app, 'temp_folder', None) is None:
-            temp_folder = MountedTemporaryFolder('temp_folder')
-            app._setObject('temp_folder', temp_folder)
-        if getattr(app.temp_folder, 'session_data', None) is None:
-            session_data = TransientObjectContainer('session_data')
-            app.temp_folder._setObject('session_data', session_data)
-        app.REQUEST.set_lazy( 'SESSION',
-                              app.session_data_manager.getSessionData )
+        sdm = self.app.session_data_manager
+        self.app.REQUEST.set_lazy('SESSION', sdm.getSessionData)
 
-    def tearDown(self):
-        self.app.REQUEST.close()
-        noSecurityManager()
-        transaction.abort()
-        self.app._p_jar.close()
-        Skinnable.SKINDATA = self._oldSkindata
-        self._free_warning_output()
-        cleanUp()
-
-    def _testURL(self,url,params=None):
-        Site = self.Site
-        obj = Site.restrictedTraverse(url)
+    def _testURL(self, url, params=None):
+        obj = self.app.site.restrictedTraverse(url)
         if params is None:
-            params=(obj, Site.REQUEST)
+            params=(obj, self.app.site.REQUEST)
         obj(*params)
 
-    def test_sessions(self):
-        self.Tool.edit_configuration(show_types=['Event'], use_session="True")
-
-        self._testURL('/CalendarTest/calendarBox', ())
+    def test_sessions_skinsview(self):
+        caltool = self.app.site.portal_calendar
+        caltool.edit_configuration(show_types=['Event'], use_session="True")
+        self._testURL('/site/calendarBox', ())
 
         self.failUnless(self.app.REQUEST.SESSION.get('calendar_year',None))
 
-    def test_noSessions(self):
-        self.Tool.edit_configuration(show_types=['Event'], use_session="")
+    def test_sessions_fiveview(self):
+        caltool = self.app.site.portal_calendar
+        caltool.edit_configuration(show_types=['Event'], use_session="True")
+        self._testURL('/site/@@calendar_widget', ())
 
-        self._testURL('/CalendarTest/calendarBox', ())
+        self.failUnless(self.app.REQUEST.SESSION.get('calendar_year',None))
+
+    def test_noSessions_skinsview(self):
+        caltool = self.app.site.portal_calendar
+        caltool.edit_configuration(show_types=['Event'], use_session="")
+        self._testURL('/site/calendarBox', ())
+
+        self.failIf(self.app.REQUEST.SESSION.get('calendar_year',None))
+
+    def test_noSessions_fiveview(self):
+        caltool = self.app.site.portal_calendar
+        caltool.edit_configuration(show_types=['Event'], use_session="")
+        self._testURL('/site/@@calendar_widget', ())
 
         self.failIf(self.app.REQUEST.SESSION.get('calendar_year',None))
 
     def test_simpleCalendarRendering(self):
+        caltool = self.app.site.portal_calendar
         data = [
                 [
                  {'day': 0, 'event': 0, 'eventslist':[]},
@@ -207,13 +199,14 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                  {'day': 0, 'event': 0, 'eventslist':[]},
                  ]
                 ]
-        result = self.Tool.getEventsForCalendar(month='5', year='2002')
+        result = caltool.getEventsForCalendar(month='5', year='2002')
         self.assertEqual(result, data)
 
     def test_singleEventCalendarRendering(self):
-
-        self.Site.Members.invokeFactory(type_name="Event",id='Event1')
-        event = self.app.restrictedTraverse('/CalendarTest/Members/Event1')
+        site = self.app.site
+        caltool = self.app.site.portal_calendar
+        site.Members.invokeFactory(type_name="Event",id='Event1')
+        event = self.app.restrictedTraverse('/site/Members/Event1')
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -228,17 +221,16 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stop_time="11:59"
                     , stopAMPM="PM"
                     )
-        self.Site.portal_workflow.doActionFor(
-                                              event,
-                                              'publish',
-                                              comment='testing')
+        site.portal_workflow.doActionFor(event, 'publish', comment='testing')
 
         data = [
                 [
                  {'day': 0, 'event': 0, 'eventslist':[]},
                  {'day': 0, 'event': 0, 'eventslist':[]},
                  {'day': 0, 'event': 0, 'eventslist':[]},
-                 {'day': 1, 'event': 1, 'eventslist':[{'title': 'title', 'end': '23:59:00', 'start': '00:00:00'}]},
+                 {'day': 1, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': '23:59:00',
+                                                       'start': '00:00:00'}]},
                  {'day': 2, 'event': 0, 'eventslist':[]},
                  {'day': 3, 'event': 0, 'eventslist':[]},
                  {'day': 4, 'event': 0, 'eventslist':[]},
@@ -280,13 +272,14 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                  {'day': 0, 'event': 0, 'eventslist':[]},
                  ]
                 ]
-        result = self.Tool.getEventsForCalendar(month='5', year='2002')
+        result = caltool.getEventsForCalendar(month='5', year='2002')
         self.assertEqual(result, data)
 
     def test_eventCalendarRenderingIssue411(self):
         #  http://www.zope.org/Collectors/CMF/411
-        self.Site.Members.invokeFactory(type_name="Event",id='Event1')
-        event = self.app.restrictedTraverse('/CalendarTest/Members/Event1')
+        site = self.app.site
+        site.Members.invokeFactory(type_name="Event",id='Event1')
+        event = self.app.restrictedTraverse('/site/Members/Event1')
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -301,13 +294,10 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stop_time="00:00"
                     , stopAMPM="AM"
                     )
-        self.Site.portal_workflow.doActionFor(
-                                              event,
-                                              'publish',
-                                              comment='testing')
+        site.portal_workflow.doActionFor(event, 'publish', comment='testing')
 
-        self.Site.Members.invokeFactory(type_name="Event",id='Event2')
-        event = self.app.restrictedTraverse('/CalendarTest/Members/Event2')
+        site.Members.invokeFactory(type_name="Event",id='Event2')
+        event = self.app.restrictedTraverse('/site/Members/Event2')
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -322,19 +312,16 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stop_time="00:00"
                     , stopAMPM="AM"
                     )
-        self.Site.portal_workflow.doActionFor(
-                                              event,
-                                              'publish',
-                                              comment='testing')
+        site.portal_workflow.doActionFor(event, 'publish', comment='testing')
 
         # With the bug unfixed, this raises a TypeError
-        ignored = self.Site.portal_calendar.catalog_getevents(2006, 3)
-
+        ignored = site.portal_calendar.catalog_getevents(2006, 3)
 
     def test_spanningEventCalendarRendering(self):
-
-        self.Site.Members.invokeFactory(type_name="Event",id='Event1')
-        event = self.app.restrictedTraverse('/CalendarTest/Members/Event1')
+        site = self.app.site
+        caltool = self.app.site.portal_calendar
+        site.Members.invokeFactory(type_name="Event",id='Event1')
+        event = self.app.restrictedTraverse('/site/Members/Event1')
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -349,83 +336,150 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stop_time="11:59"
                     , stopAMPM="PM"
                     )
-        self.Site.portal_workflow.doActionFor(
-                                              event,
-                                              'publish',
-                                              comment='testing')
+        site.portal_workflow.doActionFor(event, 'publish', comment='testing')
 
         data = [
                 [
                  {'day': 0, 'event': 0, 'eventslist':[]},
                  {'day': 0, 'event': 0, 'eventslist':[]},
                  {'day': 0, 'event': 0, 'eventslist':[]},
-                 {'day': 1, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': '00:00:00'}]},
-                 {'day': 2, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day': 3, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day': 4, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
+                 {'day': 1, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': '00:00:00'}]},
+                 {'day': 2, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day': 3, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day': 4, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                ],
+                [
+                 {'day': 5, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day': 6, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day': 7, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day': 8, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day': 9, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':10, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':11, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                ],
+                [
+                 {'day':12, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':13, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':14, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':15, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':16, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':17, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':18, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                ],
+                [
+                 {'day':19, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':20, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':21, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':22, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':23, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':24, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':25, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
                  ],
                 [
-                 {'day': 5, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day': 6, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day': 7, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day': 8, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day': 9, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':10, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':11, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 ],
-                [
-                 {'day':12, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':13, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':14, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':15, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':16, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':17, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':18, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 ],
-                [
-                 {'day':19, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':20, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':21, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':22, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':23, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':24, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':25, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 ],
-                [
-                 {'day':26, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':27, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':28, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':29, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':30, 'event': 1, 'eventslist':[{'title': 'title', 'end': None, 'start': None}]},
-                 {'day':31, 'event': 1, 'eventslist':[{'title': 'title', 'end': '23:59:00', 'start': None}]},
+                 {'day':26, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':27, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':28, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':29, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':30, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': None,
+                                                       'start': None}]},
+                 {'day':31, 'event': 1, 'eventslist':[{'title': 'title',
+                                                       'end': '23:59:00',
+                                                       'start': None}]},
                  {'day': 0, 'event': 0, 'eventslist':[]},
-                 ]
                 ]
-        result = self.Tool.getEventsForCalendar(month='5', year='2002')
+               ]
+        result = caltool.getEventsForCalendar(month='5', year='2002')
         self.assertEqual(result, data)
 
     def test_getPreviousMonth(self):
-        self.assertEqual( self.Tool.getPreviousMonth(2,2002),
+        caltool = self.app.site.portal_calendar
+
+        self.assertEqual( caltool.getPreviousMonth(2,2002),
                           DateTime('2002/1/1') )
-        self.assertEqual( self.Tool.getPreviousMonth(1,2002),
+        self.assertEqual( caltool.getPreviousMonth(1,2002),
                           DateTime('2001/12/1') )
 
     def test_getNextMonth(self):
-        self.assertEqual( self.Tool.getNextMonth(12,2001),
+        caltool = self.app.site.portal_calendar
+
+        self.assertEqual( caltool.getNextMonth(12,2001),
                           DateTime('2002/1/1') )
-        self.assertEqual( self.Tool.getNextMonth(1,2002),
+        self.assertEqual( caltool.getNextMonth(1,2002),
                           DateTime('2002/2/1') )
 
     def test_getBeginAndEndTimes(self):
-        self.assertEqual( self.Tool.getBeginAndEndTimes(1,12,2001),
+        caltool = self.app.site.portal_calendar
+
+        self.assertEqual( caltool.getBeginAndEndTimes(1,12,2001),
                           ( DateTime('2001/12/1 12:00:00AM'),
                             DateTime('2001/12/1 11:59:59PM') ) )
 
     def test_singleDayRendering(self):
-        wftool = self.Site.portal_workflow
+        site = self.app.site
+        caltool = self.app.site.portal_calendar
+        wftool = self.app.site.portal_workflow
 
-        self.Site.Members.invokeFactory(type_name="Event",id='Event1')
-        event = self.Site.Members.Event1
+        site.Members.invokeFactory(type_name="Event",id='Event1')
+        event = site.Members.Event1
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -441,11 +495,11 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stopAMPM="PM"
                     )
         wftool.doActionFor(event, 'publish', comment='testing')
-        events = self.Tool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
+        events = caltool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
         self.assertEqual( len(events), 1 )
 
-        self.Site.Members.invokeFactory(type_name="Event",id='Event2')
-        event = self.Site.Members.Event2
+        site.Members.invokeFactory(type_name="Event",id='Event2')
+        event = site.Members.Event2
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -461,11 +515,11 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stopAMPM="PM"
                     )
         wftool.doActionFor(event, 'publish', comment='testing')
-        events = self.Tool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
+        events = caltool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
         self.assertEqual( len(events), 2 )
 
-        self.Site.Members.invokeFactory(type_name="Event",id='Event3')
-        event = self.Site.Members.Event3
+        site.Members.invokeFactory(type_name="Event",id='Event3')
+        event = site.Members.Event3
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -481,11 +535,11 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stopAMPM="PM"
                     )
         wftool.doActionFor(event, 'publish', comment='testing')
-        events = self.Tool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
+        events = caltool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
         self.assertEqual( len(events), 3 )
 
-        self.Site.Members.invokeFactory(type_name="Event",id='Event4')
-        event = self.Site.Members.Event4
+        site.Members.invokeFactory(type_name="Event",id='Event4')
+        event = site.Members.Event4
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -501,11 +555,11 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stopAMPM="PM"
                     )
         wftool.doActionFor(event, 'publish', comment='testing')
-        events = self.Tool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
+        events = caltool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
         self.assertEqual( len(events), 4 )
 
-        self.Site.Members.invokeFactory(type_name="Event",id='Event5')
-        event = self.Site.Members.Event5
+        site.Members.invokeFactory(type_name="Event",id='Event5')
+        event = site.Members.Event5
         event.edit( title='title'
                     , description='description'
                     , eventType=( 'eventType', )
@@ -521,24 +575,25 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                     , stopAMPM="PM"
                     )
         wftool.doActionFor(event, 'publish', comment='testing')
-        events = self.Tool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
+        events = caltool.getEventsForThisDay(thisDay=DateTime('2002/5/1'))
         self.assertEqual( len(events), 4 )
-        events = self.Tool.getEventsForThisDay(thisDay=DateTime('2002/5/31'))
+        events = caltool.getEventsForThisDay(thisDay=DateTime('2002/5/31'))
         self.assertEqual( len(events), 3 )
 
     def test_lastDayRendering(self):
-        # Bug in catalog_getevents included events starting at 00:00:00 on the next day
+        # Bug in catalog_getevents included events starting at 00:00:00
+        # on the next day
+        site = self.app.site
+        site.invokeFactory('Event', id='today', title='today',
+                           start_date='2002/05/31 23:50:00',
+                           end_date='2002/05/31 23:59:59')
 
-        self.Site.invokeFactory('Event', id='today', title='today',
-                                 start_date='2002/05/31 23:50:00', 
-                                 end_date='2002/05/31 23:59:59')
+        site.invokeFactory('Event', id='tomorrow', title='tomorrow',
+                           start_date='2002/06/01 00:00:00',
+                           end_date='2002/06/01 00:10:00')
 
-        self.Site.invokeFactory('Event', id='tomorrow', title='tomorrow',
-                                 start_date='2002/06/01 00:00:00', 
-                                 end_date='2002/06/01 00:10:00')
-
-        self.Site.portal_workflow.doActionFor(self.Site.today, 'publish')
-        self.Site.portal_workflow.doActionFor(self.Site.tomorrow, 'publish')
+        site.portal_workflow.doActionFor(site.today, 'publish')
+        site.portal_workflow.doActionFor(site.tomorrow, 'publish')
 
         # Last week of May 2002
         data = [
@@ -548,29 +603,33 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                {'day': 28, 'event': 0, 'eventslist':[]},
                {'day': 29, 'event': 0, 'eventslist':[]},
                {'day': 30, 'event': 0, 'eventslist':[]},
-               {'day': 31, 'event': 1, 'eventslist':[{'start': '23:50:00', 'end': '23:59:59', 'title': 'today'}]},
+               {'day': 31, 'event': 1, 'eventslist':[{'start': '23:50:00',
+                                                      'end': '23:59:59',
+                                                      'title': 'today'}]},
                ]
 
-        events = self.Site.portal_calendar.catalog_getevents(2002, 5)
+        events = site.portal_calendar.catalog_getevents(2002, 5)
         self.assertEqual([events[e] for e in range(25, 32)], data)
 
     def test_firstDayRendering(self):
         # Double check it works on the other boundary as well
+        site = self.app.site
+        site.invokeFactory('Event', id='yesterday', title='yesterday',
+                           start_date='2002/05/31 23:50:00',
+                           end_date='2002/05/31 23:59:59')
 
-        self.Site.invokeFactory('Event', id='yesterday', title='yesterday',
-                                 start_date='2002/05/31 23:50:00', 
-                                 end_date='2002/05/31 23:59:59')
+        site.invokeFactory('Event', id='today', title='today',
+                           start_date='2002/06/01 00:00:00',
+                           end_date='2002/06/01 00:10:00')
 
-        self.Site.invokeFactory('Event', id='today', title='today',
-                                 start_date='2002/06/01 00:00:00', 
-                                 end_date='2002/06/01 00:10:00')
-
-        self.Site.portal_workflow.doActionFor(self.Site.yesterday, 'publish')
-        self.Site.portal_workflow.doActionFor(self.Site.today, 'publish')
+        site.portal_workflow.doActionFor(site.yesterday, 'publish')
+        site.portal_workflow.doActionFor(site.today, 'publish')
 
         # First week of June 2002
         data = [
-               {'day': 1, 'event': 1, 'eventslist':[{'start': '00:00:00', 'end': '00:10:00', 'title': 'today'}]},
+               {'day': 1, 'event': 1, 'eventslist':[{'start': '00:00:00',
+                                                     'end': '00:10:00',
+                                                     'title': 'today'}]},
                {'day': 2, 'event': 0, 'eventslist':[]},
                {'day': 3, 'event': 0, 'eventslist':[]},
                {'day': 4, 'event': 0, 'eventslist':[]},
@@ -579,67 +638,73 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                {'day': 7, 'event': 0, 'eventslist':[]},
                ]
 
-        events = self.Site.portal_calendar.catalog_getevents(2002, 6)
+        events = site.portal_calendar.catalog_getevents(2002, 6)
         self.assertEqual([events[e] for e in range(1, 8)], data)
 
     def test_workflowStateRendering(self):
         # Calendar should return events in all of the selected workflow states
+        site = self.app.site
+        caltool = self.app.site.portal_calendar
+        site.invokeFactory('Event', id='meeting',
+                           start_date='2002/05/01 11:00:00',
+                           end_date='2002/05/01 13:30:00')
 
-        self.Site.invokeFactory('Event', id='meeting',
-                                 start_date='2002/05/01 11:00:00', 
-                                 end_date='2002/05/01 13:30:00')
+        site.invokeFactory('Event', id='dinner',
+                           start_date='2002/05/01 20:00:00',
+                           end_date='2002/05/01 22:00:00')
 
-        self.Site.invokeFactory('Event', id='dinner',
-                                 start_date='2002/05/01 20:00:00', 
-                                 end_date='2002/05/01 22:00:00')
-
-        self.assertEqual(len(self.Site.portal_catalog(portal_type='Event')), 2)
+        self.assertEqual(len(site.portal_catalog(portal_type='Event')), 2)
 
         # No published events
-        self.assertEqual(len(self.Site.portal_calendar.getEventsForThisDay(DateTime('2002/05/01'))), 0) 
-        
-        # One published event
-        self.Site.portal_workflow.doActionFor(self.Site.meeting, 'publish')
-        self.assertEqual(len(self.Site.portal_catalog(review_state='published')), 1)
+        self.assertEqual(
+            len(caltool.getEventsForThisDay(DateTime('2002/05/01'))), 0)
 
-        self.assertEqual(len(self.Site.portal_calendar.getEventsForThisDay(DateTime('2002/05/01'))), 1) 
+        # One published event
+        site.portal_workflow.doActionFor(site.meeting, 'publish')
+        self.assertEqual(len(site.portal_catalog(review_state='published')), 1)
+
+        self.assertEqual(
+            len(caltool.getEventsForThisDay(DateTime('2002/05/01'))), 1)
 
         # One pending event
-        self.Site.portal_workflow.doActionFor(self.Site.dinner, 'submit')
-        self.assertEqual(len(self.Site.portal_catalog(review_state='pending')), 1)
+        site.portal_workflow.doActionFor(site.dinner, 'submit')
+        self.assertEqual(len(site.portal_catalog(review_state='pending')), 1)
 
-        self.assertEqual(len(self.Site.portal_calendar.getEventsForThisDay(DateTime('2002/05/01'))), 1) 
+        self.assertEqual(
+            len(caltool.getEventsForThisDay(DateTime('2002/05/01'))), 1)
 
         # Make calendar return pending events
-        self.Site.portal_calendar.edit_configuration(show_types=('Event',), 
-                                                     show_states=('pending', 'published'), 
-                                                     use_session='')
+        caltool.edit_configuration(show_types=('Event',),
+                                   show_states=('pending', 'published'),
+                                   use_session='')
 
-        self.assertEqual(len(self.Site.portal_calendar.getEventsForThisDay(DateTime('2002/05/01'))), 2)
+        self.assertEqual(
+            len(caltool.getEventsForThisDay(DateTime('2002/05/01'))), 2)
 
     def test_EventEndingMidnight(self):
         # Events ending exactly at midnight should not be shown for the day
         # after (see http://www.zope.org/Collectors/CMF/246)
-        cal = self.Site.portal_calendar
+        site = self.app.site
+        caltool = self.app.site.portal_calendar
         the_day = DateTime('2002/05/01')
         day_after = DateTime('2002/05/02')
 
-        self.Site.invokeFactory( 'Event'
-                               , id='party'
-                               , start_date=the_day
-                               , end_date=day_after
-                               )
-        self.Site.portal_workflow.doActionFor(self.Site.party, 'publish')
+        site.invokeFactory('Event', id='party',
+                           start_date=the_day,
+                           end_date=day_after)
+        site.portal_workflow.doActionFor(site.party, 'publish')
 
         # One entry should be present for the day of the event
-        self.assertEqual(len(cal.getEventsForThisDay(the_day)), 1)
+        self.assertEqual(len(caltool.getEventsForThisDay(the_day)), 1)
 
         # No entry should be present for the day after
-        self.assertEqual(len(cal.getEventsForThisDay(day_after)), 0)
+        self.assertEqual(len(caltool.getEventsForThisDay(day_after)), 0)
 
         # First week of May 2002
         data = [
-               {'day': 1, 'event': 1, 'eventslist':[{'start': '00:00:00', 'end': '23:59:59', 'title': 'party'}]},
+               {'day': 1, 'event': 1, 'eventslist':[{'start': '00:00:00',
+                                                     'end': '23:59:59',
+                                                     'title': 'party'}]},
                {'day': 2, 'event': 0, 'eventslist':[]},
                {'day': 3, 'event': 0, 'eventslist':[]},
                {'day': 4, 'event': 0, 'eventslist':[]},
@@ -648,7 +713,7 @@ class CalendarRequestTests(unittest.TestCase, WarningInterceptor):
                {'day': 7, 'event': 0, 'eventslist':[]},
                ]
 
-        events = self.Site.portal_calendar.catalog_getevents(2002, 5)
+        events = caltool.catalog_getevents(2002, 5)
         self.assertEqual([events[e] for e in range(1, 8)], data)
 
 
@@ -659,4 +724,5 @@ def test_suite():
         ))
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
