@@ -12,16 +12,25 @@
 ##############################################################################
 """ Base class for catalog aware content items.
 
-$Id: CMFCatalogAware.py 68523 2006-06-08 16:23:41Z efge $
+$Id: CMFCatalogAware.py 82471 2007-12-27 18:03:03Z yuppie $
 """
 
 import logging
+
 from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base
 from ExtensionClass import Base
 from Globals import DTMLFile
 from Globals import InitializeClass
+from OFS.interfaces import IObjectClonedEvent
+from OFS.interfaces import IObjectWillBeMovedEvent
+from zope.app.container.interfaces import IObjectAddedEvent
+from zope.app.container.interfaces import IObjectMovedEvent
+from zope.component import subscribers
 
+from interfaces import ICallableOpaqueItem
+from interfaces.IOpaqueItems \
+        import ICallableOpaqueItem as z2ICallableOpaqueItem
 from permissions import AccessContentsInformation
 from permissions import ManagePortal
 from permissions import ModifyPortalContent
@@ -29,13 +38,11 @@ from utils import _dtmldir
 from utils import _getAuthenticatedUser
 from utils import getToolByName
 
-from interfaces.IOpaqueItems import ICallableOpaqueItem
-
-
 logger = logging.getLogger('CMFCore.CMFCatalogAware')
 
 
 class CMFCatalogAware(Base):
+
     """Mix-in for notifying portal_catalog and portal_workflow
     """
 
@@ -114,14 +121,10 @@ class CMFCatalogAware(Base):
             if brain_path == path and skip_self:
                 continue
             # Get the object
-            if hasattr(aq_base(brain), '_unrestrictedGetObject'):
-                ob = brain._unrestrictedGetObject()
-            else:
-                # BBB: Zope 2.7
-                ob = self.unrestrictedTraverse(brain_path, None)
+            ob = brain._unrestrictedGetObject()
             if ob is None:
                 # BBB: Ignore old references to deleted objects.
-                # Can happen only in Zope 2.7, or when using
+                # Can happen only when using
                 # catalog-getObject-raises off in Zope 2.8
                 logger.warning("reindexObjectSecurity: Cannot get %s from "
                                "catalog", brain_path)
@@ -169,8 +172,9 @@ class CMFCatalogAware(Base):
         # implementing 'ICallableOpaqueItem'.
         self_base = aq_base(self)
         for name in self_base.__dict__.keys():
-            obj = getattr(self_base, name)
-            if ICallableOpaqueItem.isImplementedBy(obj):
+            obj = getattr(self, name)
+            if ICallableOpaqueItem.providedBy(obj) \
+                    or z2ICallableOpaqueItem.isImplementedBy(obj):
                 items.append((obj.getId(), obj))
 
         return tuple(items)
@@ -191,54 +195,6 @@ class CMFCatalogAware(Base):
         """
         return [t[1] for t in self.opaqueItems()]
 
-    # Hooks
-    # -----
-
-    def manage_afterAdd(self, item, container):
-        """
-            Add self to the catalog.
-            (Called when the object is created or moved.)
-        """
-        self.indexObject()
-        self.__recurse('manage_afterAdd', item, container)
-
-    def manage_afterClone(self, item):
-        """
-            Add self to the workflow.
-            (Called when the object is cloned.)
-        """
-        self.notifyWorkflowCreated()
-        self.__recurse('manage_afterClone', item)
-
-        # Make sure owner local role is set after pasting
-        # The standard Zope mechanisms take care of executable ownership
-        current_user = _getAuthenticatedUser(self)
-        if current_user is not None:
-            local_role_holders = [x[0] for x in self.get_local_roles()]
-            self.manage_delLocalRoles(local_role_holders)
-            self.manage_setLocalRoles(current_user.getId(), ['Owner'])
-
-    def manage_beforeDelete(self, item, container):
-        """
-            Remove self from the catalog.
-            (Called when the object is deleted or moved.)
-        """
-        self.__recurse('manage_beforeDelete', item, container)
-        self.unindexObject()
-
-    def __recurse(self, name, *args):
-        """
-            Recurse in both normal and opaque subobjects.
-        """
-        values = self.objectValues()
-        opaque_values = self.opaqueValues()
-        for subobjects in values, opaque_values:
-            for ob in subobjects:
-                s = getattr(ob, '_p_changed', 0)
-                if hasattr(aq_base(ob), name):
-                    getattr(ob, name)(*args)
-                if s is None: ob._p_deactivate()
-
     # ZMI
     # ---
 
@@ -283,3 +239,65 @@ class CMFCatalogAware(Base):
             manage_tabs_message=manage_tabs_message)
 
 InitializeClass(CMFCatalogAware)
+
+
+def handleContentishEvent(ob, event):
+    """ Event subscriber for (IContentish, IObjectEvent) events.
+    """
+    if IObjectAddedEvent.providedBy(event):
+        if event.newParent is not None:
+            ob.indexObject()
+
+    elif IObjectClonedEvent.providedBy(event):
+        ob.notifyWorkflowCreated()
+
+    elif IObjectMovedEvent.providedBy(event):
+        if event.newParent is not None:
+            ob.indexObject()
+
+    elif IObjectWillBeMovedEvent.providedBy(event):
+        if event.oldParent is not None:
+            ob.unindexObject()
+
+def handleDynamicTypeCopiedEvent(ob, event):
+    """ Event subscriber for (IDynamicType, IObjectCopiedEvent) events.
+    """
+    # Make sure owner local role is set after pasting
+    # The standard Zope mechanisms take care of executable ownership
+    current_user = _getAuthenticatedUser(ob)
+    if current_user is None:
+        return
+
+    current_user_id = current_user.getId()
+    if current_user_id is not None:
+        local_role_holders = [ x[0] for x in ob.get_local_roles() ]
+        ob.manage_delLocalRoles(local_role_holders)
+        ob.manage_setLocalRoles(current_user_id, ['Owner'])
+
+def dispatchToOpaqueItems(ob, event):
+    """Dispatch an event to opaque sub-items of a given object.
+    """
+    for opaque in ob.opaqueValues():
+        s = getattr(opaque, '_p_changed', 0)
+        for ignored in subscribers((opaque, event), None):
+            pass # They do work in the adapter fetch
+        if s is None:
+            opaque._p_deactivate()
+
+def handleOpaqueItemEvent(ob, event):
+    """ Event subscriber for (ICallableOpaqueItemEvents, IObjectEvent) events.
+    """
+    if IObjectAddedEvent.providedBy(event):
+        if event.newParent is not None:
+            ob.manage_afterAdd(ob, event.newParent)
+
+    elif IObjectClonedEvent.providedBy(event):
+        ob.manage_afterClone(ob)
+
+    elif IObjectMovedEvent.providedBy(event):
+        if event.newParent is not None:
+            ob.manage_afterAdd(ob, event.newParent)
+
+    elif IObjectWillBeMovedEvent.providedBy(event):
+        if event.oldParent is not None:
+            ob.manage_beforeDelete(ob, event.oldParent)
