@@ -12,9 +12,10 @@
 ##############################################################################
 """ Customizable Python scripts that come from the filesystem.
 
-$Id: FSPythonScript.py 41760 2006-02-23 14:02:19Z mj $
+$Id: FSPythonScript.py 76464 2007-06-07 15:38:16Z tseaver $
 """
 
+from difflib import unified_diff
 import new
 
 from AccessControl import ClassSecurityInfo
@@ -23,6 +24,7 @@ from ComputedAttribute import ComputedAttribute
 from Globals import DTMLFile
 from Globals import InitializeClass
 from OFS.Cache import Cacheable
+from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from Products.PythonScripts.PythonScript import PythonScript
 from Shared.DC.Scripts.Script import Script
 
@@ -33,17 +35,56 @@ from permissions import FTPAccess
 from permissions import View
 from permissions import ViewManagementScreens
 from utils import _dtmldir
-from utils import expandpath
 
-_marker = []
+_marker = object()
 
 
 class bad_func_code:
+
     co_varnames = ()
     co_argcount = 0
 
 
-class FSPythonScript (FSObject, Script):
+class CustomizedPythonScript(PythonScript):
+
+    """ Subclass which captures the "source" version's text.
+    """
+
+    #meta_type = 'Customized Python Script'  #(need permissions here)
+
+    security = ClassSecurityInfo()
+
+    def __init__(self, id, text):
+        self._setId(id)
+        self.write(text)
+        self.original_source = text
+
+    security.declareProtected(ViewManagementScreens, 'getDiff')
+    def getDiff(self):
+        """ Return a diff of the current source with the original source.
+        """
+        return unified_diff( self.original_source.splitlines()
+                           , self.read().splitlines()
+                           , 'original'
+                           , 'modified'
+                           , ''
+                           , ''
+                           , lineterm=""
+                           )
+
+    security.declareProtected(ViewManagementScreens, 'manage_showDiff')
+    manage_showDiff = PageTemplateFile('www/cpsDiff.pt', globals())
+
+    manage_options = (PythonScript.manage_options[:1]
+                    + ({'label': 'Diff', 'action': 'manage_showDiff'},)
+                    + PythonScript.manage_options[1:]
+                     )
+
+InitializeClass(CustomizedPythonScript)
+
+
+class FSPythonScript(FSObject, Script):
+
     """FSPythonScripts act like Python Scripts but are not directly
     modifiable from the management interface."""
 
@@ -51,46 +92,37 @@ class FSPythonScript (FSObject, Script):
     _params = _body = ''
     _v_f = None
     _proxy_roles = ()
-
     _owner = None  # Unowned
 
-    manage_options=(
-        (
-            {'label':'Customize', 'action':'manage_main'},
-            {'label':'Test',
-             'action':'ZScriptHTML_tryForm',
-             'help': ('PythonScripts', 'PythonScript_test.stx')},
-            )
-            + Cacheable.manage_options
-        )
+    manage_options = ({'label':'Customize', 'action':'manage_main'},
+                      {'label':'Test', 'action':'ZScriptHTML_tryForm',
+                       'help': ('PythonScripts', 'PythonScript_test.stx')},
+                     )
 
-    # Use declarative security
     security = ClassSecurityInfo()
     security.declareObjectProtected(View)
+
+    security.declareProtected(ViewManagementScreens, 'manage_main')
+    manage_main = DTMLFile('custpy', _dtmldir)
+
     security.declareProtected(View, 'index_html',)
     # Prevent the bindings from being edited TTW
     security.declarePrivate('ZBindings_edit','ZBindingsHTML_editForm',
                             'ZBindingsHTML_editAction')
 
-    security.declareProtected(ViewManagementScreens, 'manage_main')
-    manage_main = DTMLFile('custpy', _dtmldir)
-
     def _createZODBClone(self):
         """Create a ZODB (editable) equivalent of this object."""
-        obj = PythonScript(self.getId())
-        obj.write(self.read())
-        return obj
+        return CustomizedPythonScript(self.getId(), self.read())
 
     def _readFile(self, reparse):
         """Read the data from the filesystem.
-
-        Read the file (indicated by exandpath(self._filepath), and parse the
-        data if necessary.
         """
-        fp = expandpath(self._filepath)
-        file = open(fp, 'rU')
-        try: data = file.read()
-        finally: file.close()
+        file = open(self._filepath, 'rU')
+        try:
+            data = file.read()
+        finally:
+            file.close()
+
         if reparse:
             self._write(data, reparse)
 
@@ -279,10 +311,12 @@ InitializeClass(FSPythonScript)
 
 
 class FSPythonScriptTracebackSupplement:
+
     """Implementation of ITracebackSupplement
 
     Makes script-specific info available in exception tracebacks.
     """
+
     def __init__(self, script, line=-1):
         self.object = script
         # If line is set to -1, it means to use tb_lineno.
