@@ -12,11 +12,13 @@
 ##############################################################################
 """ Basic membership tool.
 
-$Id: MembershipTool.py 74141 2007-04-15 04:39:02Z alecm $
+$Id: MembershipTool.py 77182 2007-06-28 17:25:27Z yuppie $
 """
-
 import logging
+from warnings import warn
+
 from AccessControl import ClassSecurityInfo
+from AccessControl.requestmethod import postonly
 from AccessControl.User import nobody
 from Acquisition import aq_base
 from Acquisition import aq_inner
@@ -27,12 +29,15 @@ from Globals import MessageDialog
 from Globals import PersistentMapping
 from OFS.Folder import Folder
 from ZODB.POSException import ConflictError
+from zope.component import getUtility
+from zope.interface import implements
 
-from ActionProviderBase import ActionProviderBase
 from exceptions import AccessControl_Unauthorized
 from exceptions import BadRequest
+from interfaces import IMembershipTool
+from interfaces import ISiteRoot
 from interfaces.portal_membership \
-        import portal_membership as IMembershipTool
+        import portal_membership as z2IMembershipTool
 from permissions import AccessContentsInformation
 from permissions import ChangeLocalRoles
 from permissions import ListPortalMembers
@@ -45,25 +50,23 @@ from utils import _dtmldir
 from utils import _getAuthenticatedUser
 from utils import getToolByName
 from utils import UniqueObject
-from utils import postonly
-
 
 logger = logging.getLogger('CMFCore.MembershipTool')
 
 
-class MembershipTool(UniqueObject, Folder, ActionProviderBase):
+class MembershipTool(UniqueObject, Folder):
+
     """ This tool accesses member data through an acl_users object.
 
     It can be replaced with something that accesses member data in a
     different way.
     """
 
-    __implements__ = (IMembershipTool, ActionProviderBase.__implements__)
+    implements(IMembershipTool)
+    __implements__ = (z2IMembershipTool, )
 
     id = 'portal_membership'
     meta_type = 'CMF Membership Tool'
-    _actions = ()
-
     memberareaCreationFlag = 1
 
     security = ClassSecurityInfo()
@@ -71,7 +74,6 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
     manage_options=( ({ 'label' : 'Configuration'
                      , 'action' : 'manage_mapRoles'
                      },) +
-                     ActionProviderBase.manage_options +
                    ( { 'label' : 'Overview'
                      , 'action' : 'manage_overview'
                      },
@@ -90,9 +92,12 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
     manage_mapRoles = DTMLFile('membershipRolemapping', _dtmldir )
 
     security.declareProtected(SetOwnPassword, 'setPassword')
+    @postonly
     def setPassword(self, password, domains=None, REQUEST=None):
         '''Allows the authenticated member to set his/her own password.
         '''
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on a non-utility tool
         registration = getToolByName(self, 'portal_registration', None)
         if not self.isAnonymousUser():
             member = self.getAuthenticatedMember()
@@ -103,7 +108,6 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             member.setSecurityProfile(password=password, domains=domains)
         else:
             raise BadRequest('Not logged in.')
-    setPassword = postonly(setPassword)
 
     security.declarePublic('getAuthenticatedMember')
     def getAuthenticatedMember(self):
@@ -123,6 +127,8 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
         Provides an opportunity for a portal_memberdata tool to retrieve and
         store member data independently of the user object.
         """
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on a non-utility tool
         b = getattr(u, 'aq_base', None)
         if b is None:
             # u isn't wrapped at all.  Wrap it in self.acl_users.
@@ -148,7 +154,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             except ConflictError:
                 raise
             except:
-                logger.error("Error during wrapUser", exc_info=True)
+                logger.exception("Error during wrapUser")
         return u
 
     security.declareProtected(ManagePortal, 'getPortalRoles')
@@ -168,6 +174,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
         return roles
 
     security.declareProtected(ManagePortal, 'setRoleMapping')
+    @postonly
     def setRoleMapping(self, portal_role, userfolder_role, REQUEST=None):
         """
         set the mapping of roles between roles understood by
@@ -184,7 +191,6 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
                title  ='Mapping updated',
                message='The Role mappings have been updated',
                action ='manage_mapRoles')
-    setRoleMapping = postonly(setRoleMapping)
 
     security.declareProtected(ManagePortal, 'getMappedRole')
     def getMappedRole(self, portal_role):
@@ -243,7 +249,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
         if not self.getMemberareaCreationFlag():
             return None
         members = self.getMembersFolder()
-        if not members:
+        if members is None:
             return None
         if self.isAnonymousUser():
             return None
@@ -256,9 +262,9 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             member_id = user_id
         else:
             if _checkPermission(ManageUsers, self):
-                member = self.acl_users.getUserById(member_id, None)
-                if member:
-                    member = member.__of__(self.acl_users)
+                uf = self._huntUserFolder(member_id, self)
+                if uf:
+                    member = uf.getUserById(member_id).__of__(uf)
                 else:
                     raise ValueError('Member %s does not exist' % member_id)
             else:
@@ -285,6 +291,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
     createMemberarea = createMemberArea
 
     security.declareProtected(ManageUsers, 'deleteMemberArea')
+    @postonly
     def deleteMemberArea(self, member_id, REQUEST=None):
         """ Delete member area of member specified by member_id.
         """
@@ -296,7 +303,6 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             return 1
         else:
             return 0
-    deleteMemberArea = postonly(deleteMemberArea)
 
     security.declarePublic('isAnonymousUser')
     def isAnonymousUser(self):
@@ -319,13 +325,21 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
         return _checkPermission(permissionName, object)
 
     security.declarePublic('credentialsChanged')
-    def credentialsChanged(self, password):
+    def credentialsChanged(self, password, REQUEST=None):
         '''
         Notifies the authentication mechanism that this user has changed
         passwords.  This can be used to update the authentication cookie.
         Note that this call should *not* cause any change at all to user
         databases.
         '''
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on self.REQUEST
+        if REQUEST is None:
+            REQUEST = self.REQUEST
+            warn("credentialsChanged should be called with 'REQUEST' as "
+                 "second argument. The BBB code will be removed in CMF 2.3.",
+                 DeprecationWarning, stacklevel=2)
+
         if not self.isAnonymousUser():
             acl_users = self.acl_users
             user = _getAuthenticatedUser(self)
@@ -336,8 +350,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
                 # Use an interface provided by LoginManager.
                 acl_users.credentialsChanged(user, name, password)
             else:
-                req = self.REQUEST
-                p = getattr(req, '_credentials_changed_path', None)
+                p = getattr(REQUEST, '_credentials_changed_path', None)
                 if p is not None:
                     # Use an interface provided by CookieCrumbler.
                     change = self.restrictedTraverse(p)
@@ -353,19 +366,28 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             user = self.wrapUser(user)
         return user
 
-    def _huntUser(self, username, context):
-        """Find user in the hierarchy starting from bottom level 'start'.
+    def _huntUserFolder(self, username, context):
+        """Find userfolder containing user in the hierarchy
+           starting from context
         """
         uf = context.acl_users
         while uf is not None:
             user = uf.getUserById(username)
             if user is not None:
-                return user
+                return uf
             container = aq_parent(aq_inner(uf))
             parent = aq_parent(aq_inner(container))
             uf = getattr(parent, 'acl_users', None)
         return None
 
+    def _huntUser(self, username, context):
+        """Find user in the hierarchy of userfolders
+           starting from context
+        """
+        uf = self._huntUserFolder(username, context)
+        if uf is not None:
+            return uf.getUserById(username)
+
     def __getPUS(self):
         # Gets something we can call getUsers() and getUserNames() on.
         acl_users = self.acl_users
@@ -396,6 +418,8 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
     security.declareProtected(ListPortalMembers, 'searchMembers')
     def searchMembers( self, search_param, search_term ):
         """ Search the membership """
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on a non-utility tool
         md = getToolByName( self, 'portal_memberdata' )
 
         return md.searchMemberData( search_param, search_term )
@@ -417,6 +441,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
         return tuple(local_roles)
 
     security.declareProtected(View, 'setLocalRoles')
+    @postonly
     def setLocalRoles(self, obj, member_ids, member_role, reindex=1,
                       REQUEST=None):
         """ Add local roles on an item.
@@ -435,9 +460,9 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             # reindexObjectSecurity, which is in CMFCatalogAware and
             # thus PortalContent and PortalFolder.
             obj.reindexObjectSecurity()
-    setLocalRoles = postonly(setLocalRoles)
 
     security.declareProtected(View, 'deleteLocalRoles')
+    @postonly
     def deleteLocalRoles(self, obj, member_ids, reindex=1, recursive=0,
                          REQUEST=None):
         """ Delete local roles of specified members.
@@ -455,7 +480,6 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
         if reindex:
             # reindexObjectSecurity is always recursive
             obj.reindexObjectSecurity()
-    deleteLocalRoles = postonly(deleteLocalRoles)
 
     security.declarePrivate('addMember')
     def addMember(self, id, password, roles, domains, properties=None):
@@ -478,10 +502,13 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
             member.setMemberProperties(properties)
 
     security.declareProtected(ManageUsers, 'deleteMembers')
+    @postonly
     def deleteMembers(self, member_ids, delete_memberareas=1,
                       delete_localroles=1, REQUEST=None):
         """ Delete members specified by member_ids.
         """
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on a non-utility tool
 
         # Delete members in acl_users.
         acl_users = self.acl_users
@@ -494,7 +521,7 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
                     member_ids.remove(member_id)
             try:
                 acl_users.userFolderDelUsers(member_ids)
-            except (NotImplementedError, 'NotImplemented'):
+            except (AttributeError, NotImplementedError, 'NotImplemented'):
                 raise NotImplementedError('The underlying User Folder '
                                          'doesn\'t support deleting members.')
         else:
@@ -514,12 +541,10 @@ class MembershipTool(UniqueObject, Folder, ActionProviderBase):
 
         # Delete members' local roles.
         if delete_localroles:
-            utool = getToolByName(self, 'portal_url', None)
-            self.deleteLocalRoles( utool.getPortalObject(), member_ids,
+            self.deleteLocalRoles( getUtility(ISiteRoot), member_ids,
                                    reindex=1, recursive=1 )
 
         return tuple(member_ids)
-    deleteMembers = postonly(deleteMembers)
 
     security.declarePublic('getHomeFolder')
     def getHomeFolder(self, id=None, verifyPermission=0):
