@@ -12,31 +12,30 @@
 ##############################################################################
 """ PortalContent: Base class for all CMF content.
 
-$Id: PortalContent.py 69189 2006-07-18 18:48:28Z tseaver $
+$Id: PortalContent.py 77186 2007-06-28 19:06:19Z yuppie $
 """
 
-from Globals import InitializeClass
-from Acquisition import aq_base
-from OFS.SimpleItem import SimpleItem
 from AccessControl import ClassSecurityInfo
-from webdav.WriteLockInterface import WriteLockInterface
+from Acquisition import aq_base
+from Globals import InitializeClass
+from OFS.SimpleItem import SimpleItem
+from webdav.WriteLockInterface import WriteLockInterface as z2IWriteLock
+from zope.interface import implements
 
-from interfaces.Contentish import Contentish
-from DynamicType import DynamicType
-from utils import _getViewFor
 from CMFCatalogAware import CMFCatalogAware
+from DynamicType import DynamicType
+from exceptions import NotFound
 from exceptions import ResourceLockedError
+from interfaces import IContentish
+from interfaces.Contentish import Contentish as z2IContentish
 from permissions import FTPAccess
 from permissions import View
-
-
-# Old names that some third-party packages may need.
-NoWL = 0
+from utils import Message as _
 
 
 class PortalContent(DynamicType, CMFCatalogAware, SimpleItem):
-    """
-        Base class for portal objects.
+
+    """ Base class for portal objects.
 
         Provides hooks for reviewing, indexing, and CMF UI.
 
@@ -44,12 +43,8 @@ class PortalContent(DynamicType, CMFCatalogAware, SimpleItem):
         interfaces/DublinCore.py.
     """
 
-    __implements__ = (Contentish,
-                      WriteLockInterface,
-                      DynamicType.__implements__)
-
-    isPortalContent = 1
-    _isPortalContent = 1  # More reliable than 'isPortalContent'.
+    implements(IContentish)
+    __implements__ = (z2IContentish, z2IWriteLock, DynamicType.__implements__)
 
     manage_options = ( ( { 'label'  : 'Dublin Core'
                          , 'action' : 'manage_metadata'
@@ -75,10 +70,11 @@ class PortalContent(DynamicType, CMFCatalogAware, SimpleItem):
     security.declareProtected(FTPAccess, 'manage_FTPlist')
 
     def failIfLocked(self):
-        """ Check if isLocked via webDav
+        """ Check if isLocked via webDav.
         """
         if self.wl_isLocked():
-            raise ResourceLockedError('This resource is locked via webDAV.')
+            raise ResourceLockedError(_(u'This resource is locked via '
+                                        u'webDAV.'))
         return 0
 
     #
@@ -99,20 +95,12 @@ class PortalContent(DynamicType, CMFCatalogAware, SimpleItem):
         method_id = ti and ti.queryMethodID('(Default)', context=self)
         if method_id and method_id!='(Default)':
             method = getattr(self, method_id)
+            if getattr(aq_base(method), 'isDocTemp', 0):
+                return method(self, self.REQUEST, self.REQUEST['RESPONSE'])
+            else:
+                return method()
         else:
-            method = _getViewFor(self)
-
-        if getattr(aq_base(method), 'isDocTemp', 0):
-            return method(self, self.REQUEST, self.REQUEST['RESPONSE'])
-        else:
-            return method()
-
-    index_html = None  # This special value informs ZPublisher to use __call__
-
-    security.declareProtected(View, 'view')
-    def view(self):
-        """ Returns the default view even if index_html is overridden.
-        """
-        return self()
+            raise NotFound( 'Cannot find default view for "%s"' %
+                            '/'.join( self.getPhysicalPath() ) )
 
 InitializeClass(PortalContent)
