@@ -12,12 +12,13 @@
 ##############################################################################
 """ Type registration tool.
 
-$Id: TypesTool.py 68524 2006-06-08 16:54:49Z efge $
+$Id: TypesTool.py 77288 2007-07-02 07:29:27Z hannosch $
 """
 
-from warnings import warn
 import logging
+from warnings import warn
 
+import Products
 from AccessControl import ClassSecurityInfo
 from AccessControl import getSecurityManager
 from Acquisition import aq_base
@@ -27,7 +28,11 @@ from Globals import InitializeClass
 from OFS.Folder import Folder
 from OFS.ObjectManager import IFAwareObjectManager
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
-import Products
+from zope.component import getUtility
+from zope.component import queryUtility
+from zope.component.interfaces import IFactory
+from zope.i18nmessageid import Message
+from zope.interface import implements
 
 from ActionProviderBase import ActionProviderBase
 from exceptions import AccessControl_Unauthorized
@@ -36,7 +41,7 @@ from exceptions import zExceptions_Unauthorized
 from interfaces import ITypeInformation
 from interfaces import ITypesTool
 from interfaces.portal_types \
-     import ContentTypeInformation as z2ITypeInformation
+        import ContentTypeInformation as z2ITypeInformation
 from interfaces.portal_types import portal_types as z2ITypesTool
 from permissions import AccessContentsInformation
 from permissions import ManagePortal
@@ -44,26 +49,18 @@ from permissions import View
 from utils import _checkPermission
 from utils import _dtmldir
 from utils import _wwwdir
-from utils import cookString
-from utils import getActionContext
 from utils import SimpleItemWithProperties
 from utils import UniqueObject
-from utils import getToolByName
-
-from zope.interface import implements
 
 logger = logging.getLogger('CMFCore.TypesTool')
 
-
 _marker = []  # Create a new marker.
 
 
 class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
-    """
-    Base class for information about a content type.
-    """
 
-    _isTypeInformation = 1
+    """ Base class for information about a content type.
+    """
 
     manage_options = ( SimpleItemWithProperties.manage_options[:1]
                      + ( {'label':'Aliases',
@@ -83,6 +80,8 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
          'label':'Title'},
         {'id':'description', 'type': 'text', 'mode':'w',
          'label':'Description'},
+        {'id':'i18n_domain', 'type': 'string', 'mode':'w',
+         'label':'I18n Domain'},
         {'id':'content_icon', 'type': 'string', 'mode':'w',
          'label':'Icon'},
         {'id':'content_meta_type', 'type': 'string', 'mode':'w',
@@ -109,6 +108,7 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
 
     title = ''
     description = ''
+    i18n_domain = ''
     content_meta_type = ''
     content_icon = ''
     immediate_view = ''
@@ -120,6 +120,8 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
     def __init__(self, id, **kw):
 
         self.id = id
+        self._actions = ()
+        self._aliases = {}
 
         if not kw:
             return
@@ -137,21 +139,18 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
         self.manage_changeProperties(**kw)
 
         actions = kw.get( 'actions', () )
-        # make sure we have a copy
-        _actions = []
         for action in actions:
-            _actions.append( action.copy() )
-        actions = tuple(_actions)
-        # We don't know if actions need conversion, so we always add oldstyle
-        # _actions and convert them.
-        self._actions = actions
-        self._convertActions()
+            self.addAction(
+                  id=action['id']
+                , name=action['title']
+                , action=action['action']
+                , condition=action.get('condition')
+                , permission=action.get( 'permissions', () )
+                , category=action.get('category', 'object')
+                , visible=action.get('visible', True)
+                )
 
-        aliases = kw.get( 'aliases', _marker )
-        if aliases is _marker:
-            self._guessMethodAliases()
-        else:
-            self.setMethodAliases(aliases)
+        self.setMethodAliases(kw.get('aliases', {}))
 
     #
     #   ZMI methods
@@ -180,13 +179,6 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
     #
     #   Accessors
     #
-    security.declareProtected(View, 'Type')
-    def Type(self):
-        """ Deprecated. Use Title(). """
-        warn('TypeInformation.Type() is deprecated, use Title().',
-             DeprecationWarning)
-        return self.Title()
-
     security.declareProtected(View, 'Title')
     def Title(self):
         """
@@ -195,7 +187,10 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
             l10n/i18n or where a single content class is being
             used twice, under different names.
         """
-        return self.title or self.getId()
+        if self.title and self.i18n_domain:
+            return Message(self.title, self.i18n_domain)
+        else:
+            return self.title or self.getId()
 
     security.declareProtected(View, 'Description')
     def Description(self):
@@ -203,7 +198,10 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
             Textual description of the class of objects (intended
             for display in a "constructor list").
         """
-        return self.description
+        if self.description and self.i18n_domain:
+            return Message(self.description, self.i18n_domain)
+        else:
+            return self.description
 
     security.declareProtected(View, 'Metatype')
     def Metatype(self):
@@ -263,73 +261,8 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
     def listActions(self, info=None, object=None):
         """ Return a sequence of the action info objects for this type.
         """
-        if self._actions and isinstance(self._actions[0], dict):
-            self._convertActions()
-
         return self._actions or ()
 
-    security.declarePublic('getActionById')
-    def getActionById( self, id, default=_marker ):
-        """ Get method ID by action ID.
-        """
-        warn('getActionById() is deprecated and will be removed in CMF 2.0. '
-             'Please use getActionInfo()[\'url\'] if you need an URL or '
-             'queryMethodID() if you need a method ID.',
-             DeprecationWarning)
-        context = getActionContext( self )
-        for action in self.listActions():
-
-            __traceback_info__ = (self.getId(), action)
-
-            if action.getId() == id:
-                target = action.action(context).strip()
-                if target.startswith('/'):
-                    target = target[1:]
-                return target
-            else:
-                # Temporary backward compatibility.
-                if action.Title().lower() == id:
-                    target = action.action(context).strip()
-                    if target.startswith('/'):
-                        target = target[1:]
-                    return target
-
-        if default is _marker:
-            raise ValueError, ('No action "%s" for type "%s"'
-                               % (id, self.getId()))
-        else:
-            return default
-
-    security.declarePrivate( '_convertActions' )
-    def _convertActions( self ):
-        """ Upgrade dictionary-based actions.
-        """
-        aa, self._actions = self._actions, ()
-
-        for action in aa:
-
-            # Some backward compatibility stuff.
-            if not 'id' in action:
-                action['id'] = cookString(action['name'])
-
-            if not 'title' in action:
-                action['title'] = action.get('name', action['id'].capitalize())
-
-            # historically, action['action'] is simple string
-            actiontext = action.get('action').strip() or 'string:${object_url}'
-            if actiontext[:7] not in ('python:', 'string:'):
-                actiontext = 'string:${object_url}/%s' % actiontext
-
-            self.addAction(
-                  id=action['id']
-                , name=action['title']
-                , action=actiontext
-                , condition=action.get('condition')
-                , permission=action.get( 'permissions', () )
-                , category=action.get('category', 'object')
-                , visible=action.get('visible', True)
-                )
-
     security.declarePublic('constructInstance')
     def constructInstance(self, container, id, *args, **kw):
         """Build an instance of the type.
@@ -363,8 +296,6 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
     def getMethodAliases(self):
         """ Get method aliases dict.
         """
-        if not hasattr(self, '_aliases'):
-            self._guessMethodAliases()
         aliases = self._aliases
         # for aliases created with CMF 1.5.0beta
         for key, method_id in aliases.items():
@@ -392,8 +323,6 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
     def queryMethodID(self, alias, default=None, context=None):
         """ Query method ID by alias.
         """
-        if not hasattr(self, '_aliases'):
-            self._guessMethodAliases()
         aliases = self._aliases
         method_id = aliases.get(alias, default)
         # for aliases created with CMF 1.5.0beta
@@ -401,94 +330,24 @@ class TypeInformation(SimpleItemWithProperties, ActionProviderBase):
             method_id = method_id[0]
         return method_id
 
-    security.declarePrivate('_guessMethodAliases')
-    def _guessMethodAliases(self):
-        """ Guess and set Method Aliases. Used for upgrading old TIs.
-        """
-        context = getActionContext(self)
-        actions = self.listActions()
-        ordered = []
-        _dict = {}
-        viewmethod = ''
-
-        # order actions and search 'mkdir' action
-        for action in actions:
-            if action.getId() == 'view':
-                ordered.insert(0, action)
-            elif action.getId() == 'mkdir':
-                try:
-                    mkdirmethod = action.action(context).strip()
-                except AttributeError:
-                    continue
-                if mkdirmethod.startswith('/'):
-                    mkdirmethod = mkdirmethod[1:]
-                _dict['mkdir'] = mkdirmethod
-            else:
-                ordered.append(action)
-
-        # search 'view' action
-        for action in ordered:
-            perms = action.getPermissions()
-            if not perms or View in perms:
-                try:
-                    viewmethod = action.action(context).strip()
-                except (AttributeError, TypeError):
-                    break
-                if viewmethod.startswith('/'):
-                    viewmethod = viewmethod[1:]
-                if not viewmethod:
-                    viewmethod = '(Default)'
-                break
-        else:
-            viewmethod = '(Default)'
-        if viewmethod:
-            _dict['view'] = viewmethod
-
-        # search default action
-        for action in ordered:
-            try:
-                defmethod = action.action(context).strip()
-            except (AttributeError, TypeError):
-                break
-            if defmethod.startswith('/'):
-                defmethod = defmethod[1:]
-            if not defmethod:
-                break
-        else:
-            if viewmethod:
-                _dict['(Default)'] = viewmethod
-
-        # correct guessed values if we know better
-        if self.content_meta_type in ('Portal File', 'Portal Folder',
-                                      'Portal Image'):
-            _dict['(Default)'] = 'index_html'
-            if viewmethod == '(Default)':
-                _dict['view'] = 'index_html'
-        if self.content_meta_type in ('Document', 'News Item'):
-            _dict['gethtml'] = 'source_html'
-
-        self.setMethodAliases(_dict)
-        return 1
-
-InitializeClass( TypeInformation )
+InitializeClass(TypeInformation)
 
 
 class FactoryTypeInformation(TypeInformation):
-    """
-    Portal content factory.
+
+    """ Portal content factory.
     """
 
     implements(ITypeInformation)
     __implements__ = z2ITypeInformation
 
-    meta_type = 'Factory-based Type Information'
     security = ClassSecurityInfo()
 
     _properties = (TypeInformation._basic_properties + (
         {'id':'product', 'type': 'string', 'mode':'w',
          'label':'Product name'},
         {'id':'factory', 'type': 'string', 'mode':'w',
-         'label':'Product factory method'},
+         'label':'Product factory'},
         ) + TypeInformation._advanced_properties)
 
     product = ''
@@ -543,7 +402,7 @@ class FactoryTypeInformation(TypeInformation):
         return default
 
     security.declarePublic('isConstructionAllowed')
-    def isConstructionAllowed( self, container ):
+    def isConstructionAllowed(self, container):
         """
         a. Does the factory method exist?
 
@@ -552,8 +411,21 @@ class FactoryTypeInformation(TypeInformation):
         c. Does the current user have the permission required in
         order to invoke the factory method?
         """
-        m = self._queryFactoryMethod(container)
-        return (m is not None)
+        if self.product:
+            # oldstyle factory
+            m = self._queryFactoryMethod(container)
+            return (m is not None)
+
+        elif container is not None:
+            # newstyle factory
+            m = queryUtility(IFactory, self.factory, None)
+            if m is not None:
+                for d in container.all_meta_types():
+                    if d['name'] == self.content_meta_type:
+                        sm = getSecurityManager()
+                        return sm.checkPermission(d['permission'], container)
+
+        return False
 
     security.declarePrivate('_constructInstance')
     def _constructInstance(self, container, id, *args, **kw):
@@ -563,32 +435,42 @@ class FactoryTypeInformation(TypeInformation):
 
         Returns the object without calling _finishConstruction().
         """
-        m = self._getFactoryMethod(container, check_security=0)
-
+        # XXX: this method violates the rules for tools/utilities:
+        # it depends on self.REQUEST
         id = str(id)
 
-        if getattr(aq_base(m), 'isDocTemp', 0):
-            kw['id'] = id
-            newid = m(m.aq_parent, self.REQUEST, *args, **kw)
+        if self.product:
+            # oldstyle factory
+            m = self._getFactoryMethod(container, check_security=0)
+
+            if getattr(aq_base(m), 'isDocTemp', 0):
+                kw['id'] = id
+                newid = m(m.aq_parent, self.REQUEST, *args, **kw)
+            else:
+                newid = m(id, *args, **kw)
+            # allow factory to munge ID
+            newid = newid or id
+
         else:
-            newid = m(id, *args, **kw)
-        # allow factory to munge ID
-        newid = newid or id
+            # newstyle factory
+            factory = getUtility(IFactory, self.factory)
+            obj = factory(id, *args, **kw)
+            rval = container._setObject(id, obj)
+            newid = isinstance(rval, basestring) and rval or id
 
         return container._getOb(newid)
 
-InitializeClass( FactoryTypeInformation )
+InitializeClass(FactoryTypeInformation)
 
 
-class ScriptableTypeInformation( TypeInformation ):
-    """
-    Invokes a script rather than a factory to create the content.
+class ScriptableTypeInformation(TypeInformation):
+
+    """ Invokes a script rather than a factory to create the content.
     """
 
     implements(ITypeInformation)
     __implements__ = z2ITypeInformation
 
-    meta_type = 'Scriptable Type Information'
     security = ClassSecurityInfo()
 
     _properties = (TypeInformation._basic_properties + (
@@ -605,7 +487,7 @@ class ScriptableTypeInformation( TypeInformation ):
     #   Agent methods
     #
     security.declarePublic('isConstructionAllowed')
-    def isConstructionAllowed( self, container ):
+    def isConstructionAllowed(self, container):
         """
         Does the current user have the permission required in
         order to construct an instance?
@@ -634,12 +516,7 @@ class ScriptableTypeInformation( TypeInformation ):
         id = str(id)
         return constructor(container, id, *args, **kw)
 
-InitializeClass( ScriptableTypeInformation )
-
-
-# Provide aliases for backward compatibility.
-ContentFactoryMetadata = FactoryTypeInformation
-ContentTypeInformation = ScriptableTypeInformation
+InitializeClass(ScriptableTypeInformation)
 
 
 allowedTypes = [
@@ -652,8 +529,8 @@ allowedTypes = [
 
 class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
                 ActionProviderBase):
-    """
-        Provides a configurable registry of portal content types.
+
+    """ Provides a configurable registry of portal content types.
     """
 
     implements(ITypesTool)
@@ -686,7 +563,7 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
     #
     #   ObjectManager methods
     #
-    def all_meta_types(self):
+    def all_meta_types(self, interfaces=None):
         # this is a workaround and should be removed again if allowedTypes
         # have an interface we can use in _product_interfaces
         all = TypesTool.inheritedAttribute('all_meta_types')(self)
@@ -697,111 +574,12 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
     #
     #   other methods
     #
-    security.declareProtected(ManagePortal, 'listDefaultTypeInformation')
-    def listDefaultTypeInformation(self):
-        # Scans for factory_type_information attributes
-        # of all products and factory dispatchers within products.
-        res = []
-        products = self.aq_acquire('_getProducts')()
-        for product in products.objectValues():
-            product_id = product.getId()
-
-            if hasattr(aq_base(product), 'factory_type_information'):
-                ftis = product.factory_type_information
-            else:
-                package = getattr(Products, product_id, None)
-                dispatcher = getattr(package, '__FactoryDispatcher__', None)
-                ftis = getattr(dispatcher, 'factory_type_information', None)
-
-            if ftis is not None:
-                if callable(ftis):
-                    ftis = ftis()
-
-                for fti in ftis:
-                    mt = fti.get('meta_type', None)
-                    id = fti.get('id', '')
-
-                    if mt:
-                        p_id = '%s: %s (%s)' % (product_id, id, mt)
-                        res.append( (p_id, fti) )
-
-        return res
-
-    # BBB: DTML based ZMI form and the following add methods are for
-    #      CMF-1.5 compatibility
-    _addTIForm = DTMLFile( 'addTypeInfo', _dtmldir )
-
-    security.declareProtected(ManagePortal, 'manage_addFactoryTIForm')
-    def manage_addFactoryTIForm(self, REQUEST):
-        ' '
-        warn('Please use the manage_addFactoryTIForm function in the '
-             'TypesTool module; this method on the TypesTool itself '
-             'will disappear in CMF 2.0', DeprecationWarning,
-             stacklevel=2)
-        return self._addTIForm(
-            self, REQUEST,
-            add_meta_type=FactoryTypeInformation.meta_type,
-            types=self.listDefaultTypeInformation())
-
-    security.declareProtected(ManagePortal, 'manage_addScriptableTIForm')
-    def manage_addScriptableTIForm(self, REQUEST):
-        ' '
-        warn('Please use the manage_addScriptableTIForm function in the '
-             'TypesTool module; this method on the TypesTool itself '
-             'will disappear in CMF 2.0', DeprecationWarning,
-             stacklevel=2)
-        return self._addTIForm(
-            self, REQUEST,
-            add_meta_type=ScriptableTypeInformation.meta_type,
-            types=self.listDefaultTypeInformation())
-
     security.declareProtected(ManagePortal, 'manage_addTypeInformation')
     def manage_addTypeInformation(self, add_meta_type, id=None,
                                   typeinfo_name=None, RESPONSE=None):
+        """Create a TypeInformation in self.
         """
-        Create a TypeInformation in self.
-        """
-        fti = None
-        if typeinfo_name:
-            info = self.listDefaultTypeInformation()
-
-            # Nasty workaround to stay backwards-compatible
-            # This workaround will disappear in CMF 2.0
-            if typeinfo_name.endswith(')'):
-                # This is a new-style name. Proceed normally.
-                for (name, ft) in info:
-                    if name == typeinfo_name:
-                        fti = ft
-                        break
-            else:
-                # Attempt to work around the old way
-                # This attempt harbors the problem that the first match on
-                # meta_type will be used. There could potentially be more
-                # than one TypeInformation sharing the same meta_type.
-                warn("Please switch to the new format "
-                     "'product_id: type_id (meta_type)' "
-                     "for typeinfo name %r, the old "
-                     "spelling will disappear in CMF 2.0" % typeinfo_name,
-                     DeprecationWarning, stacklevel=2)
-
-                ti_prod, ti_mt = [x.strip() for x in typeinfo_name.split(':')]
-
-                for name, ft in info:
-                    if ( name.startswith(ti_prod) and
-                         name.endswith('(%s)' % ti_mt) ):
-                        fti = ft
-                        break
-
-            if fti is None:
-                warn("Typeinfo name %r not found. "
-                     "Note that the typeinfo_name "
-                     "argument will not be used at all "
-                     "in CMF 2.0." % typeinfo_name,
-                     DeprecationWarning, stacklevel=2)
-            else:
-                if not id:
-                    id = fti.get('id', None)
-
+        # BBB: typeinfo_name is ignored
         if not id:
             raise BadRequest('An id is required.')
         for mt in Products.meta_types:
@@ -812,13 +590,7 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
             raise ValueError, (
                 'Meta type %s is not a type class.' % add_meta_type)
         id = str(id)
-        if fti is not None:
-            fti = fti.copy()
-            if fti.has_key('id'):
-                del fti['id']
-            ob = klass(id, **fti)
-        else:
-            ob = klass(id)
+        ob = klass(id)
         self._setObject(id, ob)
         if RESPONSE is not None:
             RESPONSE.redirect('%s/manage_main' % self.absolute_url())
@@ -859,7 +631,14 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
             else:
                 return None
         ob = getattr( self, contentType, None )
+        if ITypeInformation.providedBy(ob):
+            return ob
         if getattr(aq_base(ob), '_isTypeInformation', 0):
+            # BBB
+            warn("The '_isTypeInformation' marker attribute is deprecated, "
+                 "and will be removed in CMF 2.3.  Please mark the instance "
+                 "with the 'ITypeInformation' interface instead.",
+                 DeprecationWarning, stacklevel=2)
             return ob
         else:
             return None
@@ -875,26 +654,29 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
         for t in self.objectValues():
             # Filter out things that aren't TypeInformation and
             # types for which the user does not have adequate permission.
-            if not getattr(aq_base(t), '_isTypeInformation', 0):
-                continue
-            if not t.getId():
-                # XXX What's this used for ?
-                # Not ready.
-                continue
-            # check we're allowed to access the type object
-            if container is not None:
-                if not t.isConstructionAllowed(container):
-                    continue
-            rval.append(t)
+            if ITypeInformation.providedBy(t):
+                rval.append(t)
+            elif getattr(aq_base(t), '_isTypeInformation', 0):
+                # BBB
+                warn("The '_isTypeInformation' marker attribute is deprecated, "
+                     "and will be removed in CMF 2.3.  Please mark the "
+                     "instance with the 'ITypeInformation' interface instead.",
+                     DeprecationWarning, stacklevel=2)
+                rval.append(t)
+        # Skip items with no ID:  old signal for "not ready"
+        rval = [t for t in rval if t.getId()]
+        # check we're allowed to access the type object
+        if container is not None:
+            rval = [t for t in rval if t.isConstructionAllowed(container)]
         return rval
 
     security.declareProtected(AccessContentsInformation, 'listContentTypes')
-    def listContentTypes( self, container=None, by_metatype=0 ):
-        """
-            Return list of content types.
+    def listContentTypes(self, container=None, by_metatype=0):
+        """ List type info IDs.
 
-        o Passing 'by_metatype' is deprecated (type information may not
-          correspond 1:1 to an underlying meta_type).
+        Passing 'by_metatype' is deprecated (type information may not
+        correspond 1:1 to an underlying meta_type). This argument will be
+        removed when CMFCore/dtml/catalogFind.dtml doesn't need it anymore.
         """
         typenames = {}
         for t in self.listTypeInfo( container ):
@@ -951,7 +733,7 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
         if object is not None:
             type_info = self.getTypeInfo(object)
             if type_info is not None:
-                actions.extend( type_info.listActions() )
+                actions.extend( type_info.listActions(info, object) )
 
         return actions
 
@@ -968,4 +750,4 @@ class TypesTool(UniqueObject, IFAwareObjectManager, Folder,
         rval.sort()
         return rval
 
-InitializeClass( TypesTool )
+InitializeClass(TypesTool)
