@@ -12,51 +12,89 @@
 ##############################################################################
 """Actions tool node adapter unit tests.
 
-$Id: test_actions.py 39983 2005-11-08 18:45:42Z yuppie $
+$Id: test_actions.py 77004 2007-06-24 08:57:54Z yuppie $
 """
 
 import unittest
 import Testing
-import Zope2
-Zope2.startup()
 
-import Products
-from Acquisition import Implicit
 from Acquisition import aq_parent
-from OFS.Folder import Folder
+from Acquisition import Implicit
 from OFS.OrderedFolder import OrderedFolder
-from Products.Five import zcml
 from zope.interface import implements
+from zope.interface import Interface
 
 from Products.CMFCore.ActionProviderBase import ActionProviderBase
 from Products.CMFCore.interfaces import IActionsTool
 from Products.CMFCore.interfaces.portal_actions \
     import ActionProvider as IActionProvider
+from Products.CMFCore.testing import ExportImportZCMLLayer
 from Products.CMFCore.tests.base.dummy import DummySite
-from Products.CMFCore.tests.base.testcase import PlacelessSetup
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.testing import NodeAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
 
+_ACTION_XML = """\
+<object name="foo_action" meta_type="CMF Action">
+ <property name="title">Foo</property>
+ <property name="description"></property>
+ <property name="url_expr">string:${object_url}/foo</property>
+ <property name="icon_expr"></property>
+ <property name="available_expr">python:1</property>
+ <property name="permissions"/>
+ <property name="visible">True</property>
+</object>
+"""
+
+_ACTIONCATEGORY_XML = """\
+<object name="foo_category" meta_type="CMF Action Category">
+ <property name="title"></property>
+ <object name="foo_action" meta_type="CMF Action">
+  <property name="title"></property>
+  <property name="description"></property>
+  <property name="url_expr"></property>
+  <property name="icon_expr"></property>
+  <property name="available_expr"></property>
+  <property name="permissions"/>
+  <property name="visible">True</property>
+ </object>
+</object>
+"""
+
 _ACTIONSTOOL_BODY = """\
 <?xml version="1.0"?>
-<object name="portal_actions" meta_type="CMF Actions Tool">
+<object name="portal_actions" meta_type="CMF Actions Tool"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
  <action-provider name="portal_actions"/>
+ <object name="foo_category" meta_type="CMF Action Category">
+  <property name="title"></property>
+  <object name="foo_action" meta_type="CMF Action" i18n:domain="foo_domain">
+   <property name="title" i18n:translate=""></property>
+   <property name="description" i18n:translate=""></property>
+   <property name="url_expr"></property>
+   <property name="icon_expr"></property>
+   <property name="available_expr"></property>
+   <property name="permissions"/>
+   <property name="visible">True</property>
+  </object>
+ </object>
 </object>
 """
 
 _EMPTY_EXPORT = """\
 <?xml version="1.0"?>
-<object meta_type="CMF Actions Tool" name="portal_actions">
+<object name="portal_actions" meta_type="CMF Actions Tool"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
  <action-provider name="portal_actions"/>
 </object>
 """
 
 _NORMAL_EXPORT = """\
 <?xml version="1.0"?>
-<object meta_type="CMF Actions Tool" name="portal_actions">
+<object name="portal_actions" meta_type="CMF Actions Tool"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
  <action-provider name="portal_actions"/>
  <action-provider name="portal_foo">
   <action action_id="foo"
@@ -79,16 +117,85 @@ _NORMAL_EXPORT = """\
 </object>
 """
 
+_NEWSYTLE_EXPORT = """\
+<?xml version="1.0"?>
+<object name="portal_actions" meta_type="CMF Actions Tool"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
+ <action-provider name="portal_actions"/>
+ <object name="dummy" meta_type="CMF Action Category">
+  <property name="title"></property>
+  <object name="foo" meta_type="CMF Action">
+   <property name="title">Foo</property>
+   <property name="description"></property>
+   <property name="url_expr">string:${object_url}/foo</property>
+   <property name="icon_expr"></property>
+   <property name="available_expr">python:1</property>
+   <property name="permissions"></property>
+   <property name="visible">True</property>
+  </object>
+  <object name="bar" meta_type="CMF Action">
+   <property name="title">Bar</property>
+   <property name="description"></property>
+   <property name="url_expr">string:${object_url}/bar</property>
+   <property name="icon_expr"></property>
+   <property name="available_expr">python:0</property>
+   <property name="permissions">
+    <element value="Manage portal"/>
+   </property>
+   <property name="visible">False</property>
+  </object>
+ </object>
+</object>
+"""
+
+_I18N_IMPORT = """\
+<?xml version="1.0"?>
+<object name="portal_actions" meta_type="CMF Actions Tool"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
+ <action-provider name="portal_actions"/>
+ <object name="dummy" meta_type="CMF Action Category">
+  <property name="title"></property>
+  <object name="foo" meta_type="CMF Action" i18n:domain="foo_domain">
+   <property name="title" i18n:translate="">Foo</property>
+   <property name="description" i18n:translate=""></property>
+   <property name="url_expr">string:${object_url}/foo</property>
+   <property name="icon_expr"></property>
+   <property name="available_expr">python:1</property>
+   <property name="permissions"></property>
+   <property name="visible">True</property>
+  </object>
+ </object>
+</object>
+"""
+
+_INSERT_IMPORT = """\
+<?xml version="1.0"?>
+<object name="portal_actions">
+ <object name="dummy">
+ <object name="spam" meta_type="CMF Action" insert-before="*">
+  <property name="title">Spam</property>
+  <property name="description"></property>
+  <property name="url_expr">string:${object_url}/spam</property>
+  <property name="icon_expr">string:spam_icon.png</property>
+  <property name="available_expr"></property>
+  <property name="permissions">
+   <element value="View" /></property>
+  <property name="visible">True</property>
+ </object>
+ <object name="foo" insert-after="*">
+  <property name="icon_expr">string:foo_icon.png</property>
+ </object>
+ </object>
+</object>
+"""
+
 _REMOVE_IMPORT = """\
 <?xml version="1.0"?>
-<actions-tool>
- <action-provider id="portal_actions" remove="">
- </action-provider>
- <action-provider id="not_existing" remove="">
- </action-provider>
- <action-provider id="portal_bar" remove="">
- </action-provider>
-</actions-tool>
+<object name="portal_actions">
+ <action-provider name="portal_actions" remove=""/>
+ <action-provider name="not_existing" remove=""/>
+ <action-provider name="portal_bar" remove=""/>
+</object>
 """
 
 
@@ -131,8 +238,75 @@ class DummyActionsTool(DummyTool):
         self._providers = [ x for x in self._providers if x != provider_name ]
 
 
+class ActionNodeAdapterTests(NodeAdapterTestCase):
+
+    layer = ExportImportZCMLLayer
+
+    def _getTargetClass(self):
+        from Products.CMFCore.exportimport.actions import ActionNodeAdapter
+
+        return ActionNodeAdapter
+
+    def _populate(self, obj):
+        obj._setPropValue('title', 'Foo')
+        obj._setPropValue('url_expr', 'string:${object_url}/foo')
+        obj._setPropValue('available_expr', 'python:1')
+
+    def _verifyImport(self, obj):
+        self.assertEqual(type(obj.title), str)
+        self.assertEqual(obj.title, 'Foo')
+        self.assertEqual(type(obj.description), str)
+        self.assertEqual(obj.description, '')
+        self.assertEqual(type(obj.url_expr), str)
+        self.assertEqual(obj.url_expr, 'string:${object_url}/foo')
+        self.assertEqual(type(obj.icon_expr), str)
+        self.assertEqual(obj.icon_expr, '')
+        self.assertEqual(type(obj.available_expr), str)
+        self.assertEqual(obj.available_expr, 'python:1')
+        self.assertEqual(type(obj.permissions), tuple)
+        self.assertEqual(obj.permissions, ())
+        self.assertEqual(type(obj.visible), bool)
+        self.assertEqual(obj.visible, True)
+
+    def setUp(self):
+        from Products.CMFCore.ActionInformation import Action
+
+        NodeAdapterTestCase.setUp(self)
+        self._obj = Action('foo_action')
+        self._XML = _ACTION_XML
+
+
+class ActionCategoryNodeAdapterTests(NodeAdapterTestCase):
+
+    layer = ExportImportZCMLLayer
+
+    def _getTargetClass(self):
+        from Products.CMFCore.exportimport.actions \
+                import ActionCategoryNodeAdapter
+
+        return ActionCategoryNodeAdapter
+
+    def _populate(self, obj):
+        from Products.CMFCore.ActionInformation import Action
+
+        obj._setObject('foo_action', Action('foo_action'))
+
+    def _verifyImport(self, obj):
+        self.assertEqual(type(obj.title), str)
+        self.assertEqual(obj.title, '')
+
+    def setUp(self):
+        from Products.CMFCore.ActionInformation import ActionCategory
+
+        NodeAdapterTestCase.setUp(self)
+        self._obj = ActionCategory('foo_category')
+        self._XML = _ACTIONCATEGORY_XML
+
+
 class ActionsToolXMLAdapterTests(BodyAdapterTestCase):
 
+    layer = ExportImportZCMLLayer
+
     def _getTargetClass(self):
         from Products.CMFCore.exportimport.actions \
                 import ActionsToolXMLAdapter
@@ -140,8 +314,13 @@ class ActionsToolXMLAdapterTests(BodyAdapterTestCase):
         return ActionsToolXMLAdapter
 
     def _populate(self, obj):
+        from Products.CMFCore.ActionInformation import Action
+        from Products.CMFCore.ActionInformation import ActionCategory
+
+        obj._setObject('foo_category', ActionCategory('foo_category'))
         obj.action_providers = ('portal_actions',)
-        obj._actions = ()
+        obj.foo_category._setObject('foo_action', Action('foo_action'))
+        obj.foo_category.foo_action.i18n_domain = 'foo_domain'
 
     def _verifyImport(self, obj):
         self.assertEqual(type(obj.action_providers), tuple)
@@ -150,22 +329,19 @@ class ActionsToolXMLAdapterTests(BodyAdapterTestCase):
         self.assertEqual(obj.action_providers[0], 'portal_actions')
 
     def setUp(self):
-        import Products.CMFCore.exportimport
         from Products.CMFCore.ActionsTool import ActionsTool
 
         BodyAdapterTestCase.setUp(self)
-        zcml.load_config('configure.zcml', Products.CMFCore.exportimport)
-
         site = DummySite('site')
         site._setObject('portal_actions', ActionsTool('portal_actions'))
         self._obj = site.portal_actions
         self._BODY = _ACTIONSTOOL_BODY
 
 
-class _ActionSetup(PlacelessSetup, BaseRegistryTests):
+class _ActionSetup(BaseRegistryTests):
 
     def _initSite(self, foo=2, bar=2):
-        self.root.site = Folder(id='site')
+        self.root.site = DummySite('site')
         site = self.root.site
         site.portal_membership = DummyMembershipTool()
 
@@ -200,19 +376,11 @@ class _ActionSetup(PlacelessSetup, BaseRegistryTests):
 
         return site
 
-    def setUp(self):
-        PlacelessSetup.setUp(self)
-        BaseRegistryTests.setUp(self)
-        zcml.load_config('meta.zcml', Products.Five)
-        zcml.load_config('configure.zcml', Products.CMFCore.exportimport)
-
-    def tearDown(self):
-        BaseRegistryTests.tearDown(self)
-        PlacelessSetup.tearDown(self)
-
 
 class exportActionProvidersTests(_ActionSetup):
 
+    layer = ExportImportZCMLLayer
+
     def test_unchanged(self):
         from Products.CMFCore.exportimport.actions \
                 import exportActionProviders
@@ -244,6 +412,8 @@ class exportActionProvidersTests(_ActionSetup):
 
 class importActionProvidersTests(_ActionSetup):
 
+    layer = ExportImportZCMLLayer
+
     def test_empty_default_purge(self):
         from Products.CMFCore.exportimport.actions \
                 import importActionProviders
@@ -325,12 +495,17 @@ class importActionProvidersTests(_ActionSetup):
         context._files['actions.xml'] = _NORMAL_EXPORT
         importActionProviders(context)
 
-        self.assertEqual(len(atool.listActionProviders()), 3)
+        self.assertEqual(len(atool.listActionProviders()), 1)
+        self.failIf('portal_foo' in atool.listActionProviders())
         self.failUnless('portal_actions' in atool.listActionProviders())
-        self.failUnless('portal_foo' in atool.listActionProviders())
-        self.failUnless(foo.listActions())
-        self.failUnless('portal_bar' in atool.listActionProviders())
-        self.failUnless(bar.listActions())
+
+        self.assertEqual(len(atool.objectIds()), 1)
+        self.failUnless('dummy' in atool.objectIds())
+        self.assertEqual(len(atool.dummy.objectIds()) , 2)
+        self.failUnless('foo' in atool.dummy.objectIds())
+        self.failUnless('bar' in atool.dummy.objectIds())
+        self.failIf(foo.listActions())
+        self.failIf(bar.listActions())
 
         # complete the roundtrip
         context = DummyExportContext(site)
@@ -339,51 +514,61 @@ class importActionProvidersTests(_ActionSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'actions.xml')
-        self._compareDOM(text, _NORMAL_EXPORT)
+        self._compareDOM(text, _NEWSYTLE_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
-    def test_import_extension(self):
-        from Products.CMFCore.exportimport.actions import importActionProviders
+    def test_i18n(self):
+        from Products.CMFCore.exportimport.actions \
+                import exportActionProviders
+        from Products.CMFCore.exportimport.actions \
+                import importActionProviders
 
-        site = self._initSite(2, 2)
+        site = self._initSite(0, 0)
         atool = site.portal_actions
-        foo = site.portal_foo
-        bar = site.portal_bar
 
-        # Normal import.
         context = DummyImportContext(site)
-        context._files['actions.xml'] = _NORMAL_EXPORT
+        context._files['actions.xml'] = _I18N_IMPORT
         importActionProviders(context)
 
-        self.assertEqual(len(atool.listActionProviders()), 3)
-        self.assertEqual([a.id for a in foo.listActions()], ['foo'])
-        self.assertEqual([a.id for a in bar.listActions()], ['bar'])
+        self.assertEqual(len(atool.listActionProviders()), 1)
+        self.assertEqual(atool.objectIds(), ['dummy'])
+        self.assertEqual(atool.dummy.objectIds(), ['foo'])
+        self.assertEqual(atool.dummy.foo.i18n_domain, 'foo_domain')
 
-        # Add an action manually to bar, it shouldn't get
-        # removed by the next non-purge import.
-        bar.addAction(id='gee',
-                      name='Gee',
-                      action='geeman',
-                      condition='python:maybe()',
-                      permission=('Manage portal',),
-                      category='dummy',
-                      visible=0)
-        # Modify actions.
-        foo.listActions()[0].title = 'OtherFoo'
-        bar.listActions()[0].title = 'OtherBar'
+        # complete the roundtrip
+        context = DummyExportContext(site)
+        exportActionProviders(context)
 
-        self.assertEqual([a.id for a in bar.listActions()], ['bar', 'gee'])
+        self.assertEqual(len(context._wrote), 1)
+        filename, text, content_type = context._wrote[0]
+        self.assertEqual(filename, 'actions.xml')
+        self._compareDOM(text, _I18N_IMPORT)
+        self.assertEqual(content_type, 'text/xml')
+
+    def test_insert_skip_purge(self):
+        from Products.CMFCore.exportimport.actions \
+                import importActionProviders
+
+        site = self._initSite(0, 0)
+        atool = site.portal_actions
+
+        context = DummyImportContext(site)
+        context._files['actions.xml'] = _NEWSYTLE_EXPORT
+        importActionProviders(context)
+
+        self.assertEqual(len(atool.listActionProviders()), 1)
+        self.assertEqual(atool.objectIds(), ['dummy'])
+        self.assertEqual(atool.dummy.objectIds(), ['foo', 'bar'])
+        self.assertEqual(atool.dummy.foo.icon_expr, '')
 
-        # Now reimport as extension profile, without purge.
         context = DummyImportContext(site, False)
-        context._files['actions.xml'] = _NORMAL_EXPORT
+        context._files['actions.xml'] = _INSERT_IMPORT
         importActionProviders(context)
 
-        self.assertEqual(len(atool.listActionProviders()), 3)
-        self.assertEqual([a.id for a in foo.listActions()], ['foo'])
-        self.assertEqual(foo.listActions()[0].title, 'Foo')
-        self.assertEqual([a.id for a in bar.listActions()], ['gee', 'bar'])
-        self.assertEqual([a.title for a in bar.listActions()], ['Gee', 'Bar'])
+        self.assertEqual(len(atool.listActionProviders()), 1)
+        self.assertEqual(atool.objectIds(), ['dummy'])
+        self.assertEqual(atool.dummy.objectIds(), ['spam', 'bar', 'foo'])
+        self.assertEqual(atool.dummy.foo.icon_expr, 'string:foo_icon.png')
 
     def test_remove_skip_purge(self):
         from Products.CMFCore.exportimport.actions \
@@ -404,10 +589,13 @@ class importActionProvidersTests(_ActionSetup):
 
 def test_suite():
     return unittest.TestSuite((
+        unittest.makeSuite(ActionNodeAdapterTests),
+        unittest.makeSuite(ActionCategoryNodeAdapterTests),
         unittest.makeSuite(ActionsToolXMLAdapterTests),
         unittest.makeSuite(exportActionProvidersTests),
         unittest.makeSuite(importActionProvidersTests),
         ))
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
