@@ -12,15 +12,13 @@
 ##############################################################################
 """Types tool xml adapter and setup handler unit tests.
 
-$Id: test_typeinfo.py 39983 2005-11-08 18:45:42Z yuppie $
+$Id: test_typeinfo.py 77004 2007-06-24 08:57:54Z yuppie $
 """
 
 import unittest
 import Testing
 
-import Products
 from OFS.Folder import Folder
-from Products.Five import zcml
 
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
@@ -30,7 +28,7 @@ from Products.GenericSetup.tests.common import DummyImportContext
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import AccessContentsInformation
 from Products.CMFCore.permissions import ModifyPortalContent
-from Products.CMFCore.tests.base.testcase import PlacelessSetup
+from Products.CMFCore.testing import ExportImportZCMLLayer
 from Products.CMFCore.TypesTool import FactoryTypeInformation
 from Products.CMFCore.TypesTool import ScriptableTypeInformation
 from Products.CMFCore.TypesTool import TypesTool
@@ -84,17 +82,17 @@ _TI_LIST = ({
                 'view':      'foo_view',
                 },
     'actions': ({'id':     'view',
-                 'name':   'View',
+                 'title':  'View',
                  'action': 'string:${object_url}/foo_view',
                  'permissions': (View,),
                  },
                 {'id':     'edit',
-                 'name':   'Edit',
+                 'title':  'Edit',
                  'action': 'string:${object_url}/foo_edit_form',
                  'permissions': (ModifyPortalContent,),
                  },
                 {'id':     'metadata',
-                 'name':   'Metadata',
+                 'title':  'Metadata',
                  'action': 'string:${object_url}/metadata_edit_form',
                  'permissions': (ModifyPortalContent,),
                  },
@@ -116,22 +114,22 @@ _TI_LIST = ({
                 'view':      'bar_view',
                 },
     'actions': ({'id':     'view',
-                 'name':   'View',
+                 'title':  'View',
                  'action': 'string:${object_url}/bar_view',
                  'permissions': (View,),
                  },
                 {'id':     'edit',
-                 'name':   'Edit',
+                 'title':  'Edit',
                  'action': 'string:${object_url}/bar_edit_form',
                  'permissions': (ModifyPortalContent,),
                  },
                 {'id':     'contents',
-                 'name':   'Contents',
+                 'title':  'Contents',
                  'action': 'string:${object_url}/folder_contents',
                  'permissions': (AccessContentsInformation,),
                  },
                 {'id':     'metadata',
-                 'name':   'Metadata',
+                 'title':  'Metadata',
                  'action': 'string:${object_url}/metadata_edit_form',
                  'permissions': (ModifyPortalContent,),
                  },
@@ -152,12 +150,6 @@ _EMPTY_TOOL_EXPORT = """\
 </object>
 """
 
-_EMPTY_TOOL_EXPORT_V1 = """\
-<?xml version="1.0"?>
-<types-tool>
-</types-tool>
-"""
-
 _NORMAL_TOOL_EXPORT = """\
 <?xml version="1.0"?>
 <object name="portal_types" meta_type="CMF Types Tool">
@@ -167,14 +159,6 @@ _NORMAL_TOOL_EXPORT = """\
 </object>
 """
 
-_NORMAL_TOOL_EXPORT_V1 = """\
-<?xml version="1.0"?>
-<types-tool>
- <type id="bar" />
- <type id="foo" />
-</types-tool>
-"""
-
 _FILENAME_EXPORT = """\
 <?xml version="1.0"?>
 <object name="portal_types" meta_type="CMF Types Tool">
@@ -184,14 +168,6 @@ _FILENAME_EXPORT = """\
 </object>
 """
 
-_FILENAME_EXPORT_V1 = """\
-<?xml version="1.0"?>
-<types-tool>
- <type id="bar object" filename="types/bar_object.xml" />
- <type id="foo object" filename="types/foo_object.xml" />
-</types-tool>
-"""
-
 _UPDATE_TOOL_IMPORT = """\
 <?xml version="1.0"?>
 <types-tool>
@@ -199,61 +175,12 @@ _UPDATE_TOOL_IMPORT = """\
 </types-tool>
 """
 
-_FOO_OLD_EXPORT = """\
-<?xml version="1.0"?>
-<type-info
-   id="%s"
-   kind="Factory-based Type Information"
-   title="Foo"
-   meta_type="Foo Thing"
-   icon="foo.png"
-   product="CMFSetup"
-   factory="addFoo"
-   immediate_view="foo_view"
-   filter_content_types="False"
-   allow_discussion="False"
-   global_allow="False" >
-  <description>Foo things</description>
-  <aliases>
-   <alias from="(Default)" to="foo_view" />
-   <alias from="view" to="foo_view" />
-  </aliases>
-  <action
-     action_id="view"
-     title="View"
-     url_expr="string:${object_url}/foo_view"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>View</permission>
-  </action>
-  <action
-     action_id="edit"
-     title="Edit"
-     url_expr="string:${object_url}/foo_edit_form"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>Modify portal content</permission>
-  </action>
-  <action
-     action_id="metadata"
-     title="Metadata"
-     url_expr="string:${object_url}/metadata_edit_form"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>Modify portal content</permission>
-  </action>
-</type-info>
-"""
-
 _FOO_EXPORT = """\
 <?xml version="1.0"?>
 <object name="%s" meta_type="Factory-based Type Information"
-   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
- <property name="title">Foo</property>
- <property name="description">Foo things</property>
+   i18n:domain="foo_domain" xmlns:i18n="http://xml.zope.org/namespaces/i18n">
+ <property name="title" i18n:translate="">Foo</property>
+ <property name="description" i18n:translate="">Foo things</property>
  <property name="content_icon">foo.png</property>
  <property name="content_meta_type">Foo Thing</property>
  <property name="product">CMFSetup</property>
@@ -281,65 +208,6 @@ _FOO_EXPORT = """\
 </object>
 """
 
-_BAR_OLD_EXPORT = """\
-<?xml version="1.0"?>
-<type-info
-   id="%s"
-   kind="Scriptable Type Information"
-   title="Bar"
-   meta_type="Bar Thing"
-   icon="bar.png"
-   constructor_path="make_bar"
-   permission="Add portal content"
-   immediate_view="bar_view"
-   filter_content_types="True"
-   allow_discussion="True"
-   global_allow="True" >
-  <description>Bar things</description>
-  <allowed_content_type>foo</allowed_content_type>
-  <aliases>
-   <alias from="(Default)" to="bar_view" />
-   <alias from="view" to="bar_view" />
-  </aliases>
-  <action
-     action_id="view"
-     title="View"
-     url_expr="string:${object_url}/bar_view"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>View</permission>
-  </action>
-  <action
-     action_id="edit"
-     title="Edit"
-     url_expr="string:${object_url}/bar_edit_form"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>Modify portal content</permission>
-  </action>
-  <action
-     action_id="contents"
-     title="Contents"
-     url_expr="string:${object_url}/folder_contents"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>Access contents information</permission>
-  </action>
-  <action
-     action_id="metadata"
-     title="Metadata"
-     url_expr="string:${object_url}/metadata_edit_form"
-     condition_expr=""
-     category="object"
-     visible="True">
-   <permission>Modify portal content</permission>
-  </action>
-</type-info>
-"""
-
 _BAR_EXPORT = """\
 <?xml version="1.0"?>
 <object name="%s" meta_type="Scriptable Type Information"
@@ -389,6 +257,8 @@ _UPDATE_FOO_IMPORT = """\
 
 class TypeInformationXMLAdapterTests(BodyAdapterTestCase):
 
+    layer = ExportImportZCMLLayer
+
     def _getTargetClass(self):
         from Products.CMFCore.exportimport.typeinfo \
                 import TypeInformationXMLAdapter
@@ -396,6 +266,7 @@ class TypeInformationXMLAdapterTests(BodyAdapterTestCase):
         return TypeInformationXMLAdapter
 
     def _populate(self, obj):
+        obj.setMethodAliases({'(Default)': 'foo', 'view': 'foo'})
         obj.addAction('foo_action', 'Foo', 'string:${object_url}/foo',
                       'python:1', (), 'Bar')
 
@@ -417,18 +288,15 @@ class TypeInformationXMLAdapterTests(BodyAdapterTestCase):
         self.assertEqual(obj._actions[0].condition.text, 'python:1')
 
     def setUp(self):
-        import Products.CMFCore
-        from Products.CMFCore.TypesTool import FactoryTypeInformation
-
         BodyAdapterTestCase.setUp(self)
-        zcml.load_config('configure.zcml', Products.CMFCore)
-
         self._obj = FactoryTypeInformation('foo_fti')
         self._BODY = _FTI_BODY
 
 
 class TypesToolXMLAdapterTests(BodyAdapterTestCase):
 
+    layer = ExportImportZCMLLayer
+
     def _getTargetClass(self):
         from Products.CMFCore.exportimport.typeinfo \
                 import TypesToolXMLAdapter
@@ -436,22 +304,15 @@ class TypesToolXMLAdapterTests(BodyAdapterTestCase):
         return TypesToolXMLAdapter
 
     def _populate(self, obj):
-        from Products.CMFCore.TypesTool import FactoryTypeInformation
-
         obj._setObject('foo_type', FactoryTypeInformation('foo_type'))
 
     def setUp(self):
-        import Products.CMFCore
-        from Products.CMFCore.TypesTool import TypesTool
-
         BodyAdapterTestCase.setUp(self)
-        zcml.load_config('configure.zcml', Products.CMFCore)
-
         self._obj = TypesTool()
         self._BODY = _TYPESTOOL_BODY
 
 
-class _TypeInfoSetup(PlacelessSetup, BaseRegistryTests):
+class _TypeInfoSetup(BaseRegistryTests):
 
     def _initSite(self, foo=0):
         self.root.site = Folder(id='site')
@@ -471,20 +332,11 @@ class _TypeInfoSetup(PlacelessSetup, BaseRegistryTests):
 
         return site
 
-    def setUp(self):
-        PlacelessSetup.setUp(self)
-        BaseRegistryTests.setUp(self)
-        zcml.load_config('meta.zcml', Products.Five)
-        zcml.load_config('permissions.zcml', Products.Five)
-        zcml.load_config('configure.zcml', Products.CMFCore)
-
-    def tearDown(self):
-        BaseRegistryTests.tearDown(self)
-        PlacelessSetup.tearDown(self)
-
 
 class exportTypesToolTests(_TypeInfoSetup):
 
+    layer = ExportImportZCMLLayer
+
     def test_empty(self):
         from Products.CMFCore.exportimport.typeinfo import exportTypesTool
 
@@ -545,6 +397,8 @@ class exportTypesToolTests(_TypeInfoSetup):
 
 class importTypesToolTests(_TypeInfoSetup):
 
+    layer = ExportImportZCMLLayer
+
     _EMPTY_TOOL_EXPORT = _EMPTY_TOOL_EXPORT
     _FILENAME_EXPORT = _FILENAME_EXPORT
     _NORMAL_TOOL_EXPORT = _NORMAL_TOOL_EXPORT
@@ -609,33 +463,6 @@ class importTypesToolTests(_TypeInfoSetup):
         self.failUnless('foo' in tool.objectIds())
         self.failUnless('bar' in tool.objectIds())
 
-    def test_old_xml(self):
-        from Products.CMFCore.exportimport.typeinfo import exportTypesTool
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
-
-        site = self._initSite()
-        tool = site.portal_types
-
-        self.assertEqual(len(tool.objectIds()), 0)
-
-        context = DummyImportContext(site)
-        context._files['types.xml'] = self._NORMAL_TOOL_EXPORT
-        context._files['types/foo.xml'] = _FOO_OLD_EXPORT % 'foo'
-        context._files['types/bar.xml'] = _BAR_OLD_EXPORT % 'bar'
-        importTypesTool(context)
-
-        self.assertEqual(len(tool.objectIds()), 2)
-        self.failUnless('foo' in tool.objectIds())
-        self.failUnless('bar' in tool.objectIds())
-
-        context = DummyExportContext(site)
-        exportTypesTool(context)
-
-        filename, text, content_type = context._wrote[1]
-        self.assertEqual(filename, 'types/bar.xml')
-        self._compareDOM(text, _BAR_EXPORT % 'bar')
-        self.assertEqual(content_type, 'text/xml')
-
     def test_with_filenames(self):
         from Products.CMFCore.exportimport.typeinfo import importTypesTool
 
@@ -685,12 +512,6 @@ class importTypesToolTests(_TypeInfoSetup):
         self.assertEqual(tool.foo._aliases,
                {'(Default)': 'foo_view', 'view': 'foo_view', 'spam': 'eggs'})
 
-class importTypesToolV1Tests(importTypesToolTests):
-
-    _EMPTY_TOOL_EXPORT = _EMPTY_TOOL_EXPORT_V1
-    _FILENAME_EXPORT = _FILENAME_EXPORT_V1
-    _NORMAL_TOOL_EXPORT = _NORMAL_TOOL_EXPORT_V1
-
 
 def test_suite():
     return unittest.TestSuite((
@@ -698,8 +519,8 @@ def test_suite():
         unittest.makeSuite(TypesToolXMLAdapterTests),
         unittest.makeSuite(exportTypesToolTests),
         unittest.makeSuite(importTypesToolTests),
-        unittest.makeSuite(importTypesToolV1Tests),
         ))
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
