@@ -12,37 +12,31 @@
 ##############################################################################
 """ Unit tests for PortalContent module.
 
-$Id: test_PortalContent.py 74719 2007-04-24 20:13:48Z tseaver $
+$Id: test_PortalContent.py 77004 2007-06-24 08:57:54Z yuppie $
 """
 
-from unittest import TestCase, TestSuite, makeSuite, main
+import unittest
 import Testing
-try:
-    import Zope2
-except ImportError:
-    # BBB: for Zope 2.7
-    import Zope as Zope2
-Zope2.startup()
 
 from AccessControl.SecurityManagement import newSecurityManager
-from AccessControl.User import SimpleUser
 from Acquisition import aq_base
-try:
-    import transaction
-except ImportError:
-    # BBB: for Zope 2.7
-    from Products.CMFCore.utils import transaction
+from OFS.Folder import Folder
+from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.tests.base.dummy import DummySite
-from Products.CMFCore.tests.base.dummy import DummyUserFolder
-from Products.CMFCore.tests.base.testcase import SecurityRequestTest
-from Products.CMFCore.tests.base.testcase import WarningInterceptor
-from Products.CMFCore.tests.base.dummy import DummyTool
+from Products.CMFCore.exceptions import NotFound
+from Products.CMFCore.testing import TraversingEventZCMLLayer
 from Products.CMFCore.tests.base.dummy import DummyContent
 from Products.CMFCore.tests.base.dummy import DummyObject
-from OFS.Folder import Folder
+from Products.CMFCore.tests.base.dummy import DummySite
+from Products.CMFCore.tests.base.dummy import DummyTool
+from Products.CMFCore.tests.base.dummy import DummyUserFolder
+from Products.CMFCore.tests.base.testcase import SecurityRequestTest
 
-class PortalContentTests(TestCase, WarningInterceptor):
+
+class PortalContentTests(unittest.TestCase):
+
+    def tearDown(self):
+        cleanUp()
 
     def test_z2interfaces(self):
         from Interface.Verify import verifyClass
@@ -56,13 +50,9 @@ class PortalContentTests(TestCase, WarningInterceptor):
         verifyClass(IDynamicType, PortalContent)
 
     def test_z3interfaces(self):
-        try:
-            from zope.interface.verify import verifyClass
-            from Products.CMFCore.interfaces import IContentish
-            from Products.CMFCore.interfaces import IDynamicType
-        except ImportError:
-            # BBB: for Zope 2.7
-            return
+        from zope.interface.verify import verifyClass
+        from Products.CMFCore.interfaces import IContentish
+        from Products.CMFCore.interfaces import IDynamicType
         from Products.CMFCore.PortalContent import PortalContent
 
         verifyClass(IContentish, PortalContent)
@@ -74,7 +64,7 @@ class PortalContentTests(TestCase, WarningInterceptor):
 
         # set up dummy type info with problematic double-default alias
         root._setObject( 'portal_types', DummyTool() )
-        root.portal_types.view_actions = aliases
+        root.portal_types._type_actions = aliases
 
         # dummy content and skin
         root._setObject( 'dummycontent', DummyContent() )
@@ -86,20 +76,16 @@ class PortalContentTests(TestCase, WarningInterceptor):
                          ('view', 'dummy_view'),
                        )
         ob = self._setupCallTests(test_aliases)
-        # in unfixed version fail here with AttributeError
-        # can end up with this arrangement using _getAliases though
-        # in fixed version, falls through to _getViewFor, which is BBB
-        self._trap_warning_output()
-        self.assertEqual( ob(), 'dummy' )
+        # PortalContent no longer supports the BBB '(Default)' alias
+        self.assertRaises(NotFound, ob)
 
     def test_BlankDefaultAlias(self):
         test_aliases = ( ('(Default)', ''),
                          ('view', 'dummy_view'),
                        )
         ob = self._setupCallTests(test_aliases)
-        # blank default is BBB
-        self._trap_warning_output()
-        self.assertEqual( ob(), 'dummy' )
+        # blank values are not valid
+        self.assertRaises(NotFound, ob)
 
     def test_SpecificAlias(self):
         test_aliases = ( ('(Default)', 'dummy_view'),
@@ -107,11 +93,14 @@ class PortalContentTests(TestCase, WarningInterceptor):
         ob = self._setupCallTests(test_aliases)
         self.assertEqual( ob(), 'dummy' )
 
+
 class TestContentCopyPaste(SecurityRequestTest):
 
     # Tests related to http://www.zope.org/Collectors/CMF/205
     # Copy/pasting a content item must set ownership to pasting user
 
+    layer = TraversingEventZCMLLayer
+
     def setUp(self):
         SecurityRequestTest.setUp(self)
 
@@ -159,10 +148,11 @@ class TestContentCopyPaste(SecurityRequestTest):
 
 
 def test_suite():
-    return TestSuite((
-        makeSuite(PortalContentTests),
-        makeSuite(TestContentCopyPaste),
+    return unittest.TestSuite((
+        unittest.makeSuite(PortalContentTests),
+        unittest.makeSuite(TestContentCopyPaste),
         ))
 
 if __name__ == '__main__':
-    main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
