@@ -12,43 +12,35 @@
 ##############################################################################
 """ Unit tests for PortalFolder module.
 
-$Id: test_PortalFolder.py 40496 2005-12-02 18:03:47Z yuppie $
+$Id: test_PortalFolder.py 77004 2007-06-24 08:57:54Z yuppie $
 """
 
-from unittest import TestCase, TestSuite, makeSuite, main
+import unittest
 import Testing
-try:
-    import Zope2
-except ImportError:
-    # BBB: for Zope 2.7
-    import Zope as Zope2
-Zope2.startup()
-
-import cStringIO
 
+import transaction
 from AccessControl import SecurityManager
 from AccessControl import Unauthorized
+from AccessControl.SecurityManagement import newSecurityManager
 from Acquisition import aq_base
 from Acquisition import Implicit
 from DateTime import DateTime
-from OFS.Application import Application
 from OFS.Image import manage_addFile
-from OFS.tests.testCopySupport import makeConnection
-from Testing.makerequest import makerequest
-try:
-    import transaction
-except ImportError:
-    # BBB: for Zope 2.7
-    from Products.CMFCore.utils import transaction
+from zope.component import getSiteManager
+from zope.component.interfaces import IFactory
+from zope.interface import implements
 
 from Products.CMFCore.CatalogTool import CatalogTool
 from Products.CMFCore.exceptions import BadRequest
+from Products.CMFCore.interfaces import ITypesTool
+from Products.CMFCore.testing import ConformsToFolder
+from Products.CMFCore.testing import FunctionalZCMLLayer
+from Products.CMFCore.testing import TraversingEventZCMLLayer
 from Products.CMFCore.tests.base.dummy import DummyContent
-from Products.CMFCore.tests.base.dummy import DummyFactory
+from Products.CMFCore.tests.base.dummy import DummyFactoryDispatcher
 from Products.CMFCore.tests.base.dummy import DummySite
 from Products.CMFCore.tests.base.dummy import DummyUserFolder
-from Products.CMFCore.tests.base.testcase import newSecurityManager
-from Products.CMFCore.tests.base.testcase import noSecurityManager
+from Products.CMFCore.tests.base.testcase import SecurityRequestTest
 from Products.CMFCore.tests.base.testcase import SecurityTest
 from Products.CMFCore.tests.base.tidata import FTIDATA_CMF15
 from Products.CMFCore.tests.base.tidata import FTIDATA_DUMMY
@@ -63,37 +55,43 @@ def extra_meta_types():
              'permission': 'View'}]
 
 
-class PortalFolderFactoryTests( SecurityTest ):
+class PortalFolderFactoryTests(SecurityTest):
 
-    def setUp( self ):
+    layer = TraversingEventZCMLLayer
+    _PORTAL_TYPE = 'Test Folder'
+
+    def _getTargetObject(self):
+        from Products.CMFCore.PortalFolder import PortalFolderFactory
+
+        return PortalFolderFactory
+
+    def setUp(self):
         from Products.CMFCore.PortalFolder import PortalFolder
-        SecurityTest.setUp( self )
 
-        self.root._setObject( 'portal_types', TypesTool() )
-        types_tool = self.root.portal_types
-        types_tool._setObject( 'Folder'
-                             , FTI( id='Folder'
-                                  , title='Folder or Directory'
-                                  , meta_type=PortalFolder.meta_type
-                                  , product='CMFCore'
-                                  , factory='manage_addPortalFolder'
-                                  , filter_content_types=0
-                                  )
-                             )
-        fti = FTIDATA_DUMMY[0].copy()
-        types_tool._setObject( 'Dummy Content', FTI(**fti) )
+        SecurityTest.setUp(self)
+        sm = getSiteManager()
+        sm.registerUtility(self._getTargetObject(), IFactory, 'cmf.folder')
+        self.site = DummySite('site').__of__(self.root)
+        acl_users = self.site._setObject('acl_users', DummyUserFolder())
+        newSecurityManager(None, acl_users.all_powerful_Oz)
 
-    def _makeOne( self, id ):
-        from Products.CMFCore.PortalFolder import PortalFolder
-        return PortalFolder( id ).__of__( self.root )
+        ttool = self.site._setObject('portal_types', TypesTool())
+        ttool._setObject(self._PORTAL_TYPE,
+                         FTI(id=self._PORTAL_TYPE,
+                             title='Folder or Directory',
+                             meta_type=PortalFolder.meta_type,
+                             factory='cmf.folder',
+                             filter_content_types=0))
+        ttool._setObject('Dummy Content', FTI(**FTIDATA_DUMMY[0].copy()))
 
-    def test_invokeFactory( self ):
-
-        f = self._makeOne( 'container' )
+        self.f = self.site._setObject('container', PortalFolder('container'))
+        self.f._setPortalTypeName(self._PORTAL_TYPE)
 
+    def test_invokeFactory(self):
+        f = self.f
         self.failIf( 'foo' in f.objectIds() )
 
-        f.manage_addProduct = { 'FooProduct' : DummyFactory(f) }
+        f.manage_addProduct = {'FooProduct': DummyFactoryDispatcher(f)}
         f.invokeFactory( type_name='Dummy Content', id='foo' )
 
         self.failUnless( 'foo' in f.objectIds() )
@@ -102,63 +100,47 @@ class PortalFolderFactoryTests( SecurityTest ):
         self.assertEqual( foo.getPortalTypeName(), 'Dummy Content' )
         self.assertEqual( foo.Type(), 'Dummy Content Title' )
 
-    def test_invokeFactory_disallowed_type( self ):
-
-        f = self._makeOne( 'container' )
-
-        ftype = self.root.portal_types.Folder
+    def test_invokeFactory_disallowed_type(self):
+        f = self.f
+        ftype = getattr(self.site.portal_types, self._PORTAL_TYPE)
         ftype.filter_content_types = 1
+        self.assertRaises(ValueError,
+                          f.invokeFactory, self._PORTAL_TYPE, 'sub')
 
-        self.assertRaises( ValueError
-                         , f.invokeFactory, type_name='Folder', id='sub' )
-
-        ftype.allowed_content_types = ( 'Folder', )
-        f.invokeFactory( type_name='Folder', id='sub' )
-        self.failUnless( 'sub' in f.objectIds() )
-
-        self.assertRaises( ValueError
-                         , f.invokeFactory
-                         , type_name='Dummy Content', id='foo' )
+        ftype.allowed_content_types = (self._PORTAL_TYPE,)
+        f.invokeFactory(self._PORTAL_TYPE, id='sub')
+        self.failUnless('sub' in f.objectIds())
+        self.assertRaises(ValueError, f.invokeFactory, 'Dummy Content', 'foo')
 
 
-class PortalFolderTests(SecurityTest):
+class PortalFolderTests(ConformsToFolder, SecurityTest):
+
+    layer = FunctionalZCMLLayer
+
+    def _getTargetClass(self):
+        from Products.CMFCore.PortalFolder import PortalFolder
+
+        return PortalFolder
+
+    def _makeOne(self, id, *args, **kw):
+        return self.site._setObject(id,
+                                    self._getTargetClass()(id, *args, **kw))
 
     def setUp(self):
         SecurityTest.setUp(self)
         self.site = DummySite('site').__of__(self.root)
 
-    def _makeOne(self, id, *args, **kw):
-        from Products.CMFCore.PortalFolder import PortalFolder
-
-        return self.site._setObject( id, PortalFolder(id, *args, **kw) )
-
     def test_z2interfaces(self):
         from Interface.Verify import verifyClass
         from OFS.IOrderSupport import IOrderedContainer
-        from webdav.WriteLockInterface import WriteLockInterface
-        from Products.CMFCore.interfaces.Dynamic \
-                import DynamicType as IDynamicType
-        from Products.CMFCore.interfaces.Folderish \
-                import Folderish as IFolderish
-        from Products.CMFCore.PortalFolder import PortalFolder
 
-        verifyClass(IDynamicType, PortalFolder)
-        verifyClass(IFolderish, PortalFolder)
-        verifyClass(IOrderedContainer, PortalFolder)
-        verifyClass(WriteLockInterface, PortalFolder)
+        verifyClass(IOrderedContainer, self._getTargetClass())
 
     def test_z3interfaces(self):
-        try:
-            from zope.interface.verify import verifyClass
-            from Products.CMFCore.interfaces import IDynamicType
-            from Products.CMFCore.interfaces import IFolderish
-        except ImportError:
-            # BBB: for Zope 2.7
-            return
-        from Products.CMFCore.PortalFolder import PortalFolder
+        from zope.interface.verify import verifyClass
+        from OFS.interfaces import IOrderedContainer
 
-        verifyClass(IDynamicType, PortalFolder)
-        verifyClass(IFolderish, PortalFolder)
+        verifyClass(IOrderedContainer, self._getTargetClass())
 
     def test_contents_methods(self):
         ttool = self.site._setObject( 'portal_types', TypesTool() )
@@ -262,9 +244,7 @@ class PortalFolderTests(SecurityTest):
         wftool.notifyCreated(test)
         self.assertEqual( len(ctool), 0 )
 
-
     def test_tracker261(self):
-
         #
         #   Tracker issue #261 says that content in a deleted folder
         #   is not being uncatalogued.  Try creating a subfolder with
@@ -288,7 +268,7 @@ class PortalFolderTests(SecurityTest):
         self.assertEqual( len(ctool), 1 )
 
         foo.reset()
-        test.manage_delObjects( ids=['sub'] )
+        test._delObject('sub')
         self.failIf( foo.after_add_called )
         self.failUnless( foo.before_delete_called )
         self.assertEqual( len(ctool), 0 )
@@ -306,8 +286,7 @@ class PortalFolderTests(SecurityTest):
                         , FTI( id='Folder'
                              , title='Folder or Directory'
                              , meta_type=PortalFolder.meta_type
-                             , product='CMFCore'
-                             , factory='manage_addPortalFolder'
+                             , factory='cmf.folder'
                              , filter_content_types=0
                              )
                         )
@@ -315,8 +294,7 @@ class PortalFolderTests(SecurityTest):
                         , FTI( 'Grabbed'
                              , title='Grabbed Content'
                              , meta_type=PortalFolder.meta_type
-                             , product='CMFCore'
-                             , factory='manage_addPortalFolder'
+                             , factory='cmf.folder'
                              )
                         )
 
@@ -411,14 +389,6 @@ class PortalFolderTests(SecurityTest):
         newSecurityManager(None, acl_users.user_foo)
         self.assertRaises(BadRequest, test._checkId, 'view.html')
 
-    def test_checkIdAvailableCatchesBadRequest(self):
-        #
-        #   checkIdAvailable() should catch BadRequest
-        #
-        test = self._makeOne('test')
-        test._setObject('foo', DummyContent('foo'))
-        self.failIf(test.checkIdAvailable('foo'))
-
     def test__checkId_starting_with_dot(self):
         #
         # doted prefixed names at the root of the portal can be overriden
@@ -437,8 +407,24 @@ class PortalFolderTests(SecurityTest):
 
         self.assert_(sub.checkIdAvailable('.foo'))
 
+    def test__checkId_Five(self):
+        test = self._makeOne('test')
+        self.assertRaises(BadRequest, test._checkId, '@@view.html')
+        self.assertRaises(BadRequest, test._checkId, '++resource++icon.png')
+
+    def test_checkIdAvailableCatchesBadRequest(self):
+        #
+        #   checkIdAvailable() should catch BadRequest
+        #
+        test = self._makeOne('test')
+        test._setObject('foo', DummyContent('foo'))
+        self.failIf(test.checkIdAvailable('foo'))
+
+
 class PortalFolderMoveTests(SecurityTest):
 
+    layer = TraversingEventZCMLLayer
+
     def setUp(self):
         SecurityTest.setUp(self)
         self.root._setObject( 'site', DummySite('site') )
@@ -457,6 +443,7 @@ class PortalFolderMoveTests(SecurityTest):
 
         ttool = self.site._setObject( 'portal_types', TypesTool() )
         ctool = self.site._setObject( 'portal_catalog', CatalogTool() )
+        ctool.addIndex('getId', 'FieldIndex')
         self.assertEqual( len(ctool), 0 )
 
         folder = self._makeOne('folder')
@@ -467,7 +454,7 @@ class PortalFolderMoveTests(SecurityTest):
         self.failUnless( has_path(ctool._catalog,
                                   '/bar/site/folder/sub/foo') )
 
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         folder.manage_renameObject(id='sub', new_id='new_sub')
         self.assertEqual( len(ctool), 1 )
         self.failUnless( 'foo' in ctool.uniqueValuesFor('getId') )
@@ -486,7 +473,7 @@ class PortalFolderMoveTests(SecurityTest):
         sub2.all_meta_types.extend( sub2.all_meta_types )
         sub2.all_meta_types.extend( extra_meta_types() )
 
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         cookie = folder.manage_cutObjects(ids=['bar'])
         sub2.manage_pasteObjects(cookie)
 
@@ -536,7 +523,7 @@ class PortalFolderMoveTests(SecurityTest):
         self.failUnless( has_path(ctool._catalog, '/bar/site/sub2/dummy') )
         self.failIf( has_path(ctool._catalog, '/bar/site/sub3/dummy') )
 
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         cookie = sub1.manage_cutObjects( ids = ('dummy',) )
         # Waaa! force sub2 to allow paste of Dummy object.
         sub3.all_meta_types = []
@@ -554,7 +541,7 @@ class PortalFolderMoveTests(SecurityTest):
         self.failUnless( has_path(ctool._catalog, '/bar/site/sub3/dummy') )
 
 
-class ContentFilterTests( TestCase ):
+class ContentFilterTests(unittest.TestCase):
 
     def setUp( self ):
         self.dummy=DummyContent('Dummy')
@@ -857,63 +844,26 @@ class _AllowedUser( Implicit ):
     def allowed( self, object, object_roles=None ):
         return self._lambdas[ 0 ]( object, object_roles )
 
-class PortalFolderCopySupportTests( TestCase ):
 
-    _old_policy = None
+class PortalFolderCopySupportTests(SecurityRequestTest):
 
-    def setUp( self ):
-        self._scrubSecurity()
+    layer = FunctionalZCMLLayer
 
-    def tearDown( self ):
-
-        self._scrubSecurity()
-        self._cleanApp()
-
-    def _initFolders( self ):
+    def _initFolders(self):
         from Products.CMFCore.PortalFolder import PortalFolder
 
-        self.connection = makeConnection()
-        try:
-            r = self.connection.root()
-            a = Application()
-            r['Application'] = a
-            self.root = a
-            responseOut = self.responseOut = cStringIO.StringIO()
-            self.app = makerequest( self.root, stdout=responseOut )
-            self.app._setObject( 'folder1', PortalFolder( 'folder1' ) )
-            self.app._setObject( 'folder2', PortalFolder( 'folder2' ) )
-            folder1 = getattr( self.app, 'folder1' )
-            folder2 = getattr( self.app, 'folder2' )
-
-            manage_addFile( folder1, 'file'
-                          , file='', content_type='text/plain')
-
-            # Hack, we need a _p_mtime for the file, so we make sure that it
-            # has one. We use a subtransaction, which means we can rollback
-            # later and pretend we didn't touch the ZODB.
-            transaction.commit(1)
-        except:
-            self.connection.close()
-            raise
+        self.app._setObject( 'folder1', PortalFolder( 'folder1' ) )
+        self.app._setObject( 'folder2', PortalFolder( 'folder2' ) )
+        folder1 = getattr( self.app, 'folder1' )
+        folder2 = getattr( self.app, 'folder2' )
+        manage_addFile(folder1, 'file', file='', content_type='text/plain')
 
+        # Hack, we need a _p_mtime for the file, so we make sure that it
+        # has one. We use a subtransaction, which means we can rollback
+        # later and pretend we didn't touch the ZODB.
+        transaction.savepoint(optimistic=True)
         return self.app._getOb( 'folder1' ), self.app._getOb( 'folder2' )
 
-    def _cleanApp( self ):
-
-        transaction.abort()
-        self.connection.close()
-        del self.app
-        del self.responseOut
-        del self.root
-        del self.connection
-
-    def _scrubSecurity( self ):
-
-        noSecurityManager()
-
-        if self._old_policy is not None:
-            SecurityManager.setSecurityPolicy( self._old_policy )
-
     def _assertCopyErrorUnauth( self, callable, *args, **kw ):
 
         import re
@@ -962,10 +912,10 @@ class PortalFolderCopySupportTests( TestCase ):
             c_lambda = _promiscuous
 
         scp = _SensitiveSecurityPolicy( v_lambda, c_lambda )
-        self._old_policy = SecurityManager.setSecurityPolicy( scp )
+        SecurityManager.setSecurityPolicy( scp )
 
         newSecurityManager( None
-                          , _AllowedUser( a_lambda ).__of__( self.root ) )
+                          , _AllowedUser(a_lambda).__of__(self.app.acl_users))
 
     def test_copy_baseline( self ):
 
@@ -1002,9 +952,6 @@ class PortalFolderCopySupportTests( TestCase ):
                                    )
 
     def test_copy_cant_create_target_metatype_not_supported( self ):
-
-        from OFS.CopySupport import CopyError
-
         folder1, folder2 = self._initFolders()
         folder2.all_meta_types = ()
 
@@ -1033,9 +980,6 @@ class PortalFolderCopySupportTests( TestCase ):
         self.failUnless( 'file' in folder2.objectIds() )
 
     def test_move_cant_read_source( self ):
-
-        from OFS.CopySupport import CopyError
-
         folder1, folder2 = self._initFolders()
         folder2.all_meta_types = FILE_META_TYPES
 
@@ -1053,9 +997,6 @@ class PortalFolderCopySupportTests( TestCase ):
                                    )
 
     def test_move_cant_create_target_metatype_not_supported( self ):
-
-        from OFS.CopySupport import CopyError
-
         folder1, folder2 = self._initFolders()
         folder2.all_meta_types = ()
 
@@ -1078,8 +1019,6 @@ class PortalFolderCopySupportTests( TestCase ):
         #   If you are running with such a Zope, this test will error out
         #   with an AttributeError (instead of the expected Unauthorized).
         #
-        from OFS.CopySupport import CopyError
-
         folder1, folder2 = self._initFolders()
         folder2.all_meta_types = FILE_META_TYPES
 
@@ -1113,23 +1052,13 @@ class PortalFolderCopySupportTests( TestCase ):
         #   allowed.
         #
         from AccessControl.Permissions import delete_objects as DeleteObjects
-        from OFS.CopySupport import CopyError
         from Products.CMFCore.PortalFolder import PortalFolder
-        from Products.CMFCore.permissions import AddPortalFolders
 
         folder1, folder2 = self._initFolders()
         folder1.manage_permission( DeleteObjects, roles=(), acquire=0 )
 
         folder1._setObject( 'sub', PortalFolder( 'sub' ) )
-        transaction.commit(1) # get a _p_jar for 'sub'
-
-        FOLDER_CTOR = 'manage_addProducts/CMFCore/manage_addPortalFolder'
-        folder2.all_meta_types = ( { 'name'        : 'CMF Core Content'
-                                   , 'action'      : FOLDER_CTOR
-                                   , 'permission'  : AddPortalFolders
-                                   }
-                                 ,
-                                 )
+        transaction.savepoint(optimistic=True) # get a _p_jar for 'sub'
 
         self.app.portal_types = DummyTypesTool()
 
@@ -1287,19 +1216,22 @@ class DummyTypeInfo:
 
 class DummyTypesTool( Implicit ):
 
+    implements(ITypesTool)
+
     def getTypeInfo( self, portal_type ):
 
         return DummyTypeInfo()
 
 
 def test_suite():
-    return TestSuite((
-        makeSuite( PortalFolderFactoryTests ),
-        makeSuite( PortalFolderTests ),
-        makeSuite( PortalFolderMoveTests ),
-        makeSuite( ContentFilterTests ),
-        makeSuite( PortalFolderCopySupportTests ),
+    return unittest.TestSuite((
+        unittest.makeSuite(PortalFolderFactoryTests),
+        unittest.makeSuite(PortalFolderTests),
+        unittest.makeSuite(PortalFolderMoveTests),
+        unittest.makeSuite(ContentFilterTests),
+        unittest.makeSuite(PortalFolderCopySupportTests),
         ))
 
 if __name__ == '__main__':
-    main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
