@@ -12,67 +12,69 @@
 ##############################################################################
 """ Unit tests for TypesTool module.
 
-$Id: test_TypesTool.py 40450 2005-12-01 16:56:13Z yuppie $
+$Id: test_TypesTool.py 77186 2007-06-28 19:06:19Z yuppie $
 """
 
 import unittest
 import Testing
 
-import Products
 from AccessControl import Unauthorized
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import noSecurityManager
 from AccessControl.SecurityManager import setSecurityPolicy
 from Acquisition import aq_base
-from Products.Five import zcml
 from Products.PythonScripts.PythonScript import PythonScript
 from Products.PythonScripts.standard import html_quote
 from webdav.NullResource import NullResource
+from zope.component import getSiteManager
+from zope.component.interfaces import IFactory
+from zope.testing.cleanup import cleanUp
 
 from Products.CMFCore.ActionInformation import ActionInformation
 from Products.CMFCore.PortalFolder import PortalFolder
+from Products.CMFCore.testing import FunctionalZCMLLayer
 from Products.CMFCore.tests.base.dummy import DummyFactory
+from Products.CMFCore.tests.base.dummy import DummyFactoryDispatcher
+from Products.CMFCore.tests.base.dummy import DummyContent
 from Products.CMFCore.tests.base.dummy import DummyFolder
-from Products.CMFCore.tests.base.dummy import DummyObject
 from Products.CMFCore.tests.base.dummy import DummySite
 from Products.CMFCore.tests.base.dummy import DummyUserFolder
 from Products.CMFCore.tests.base.security import OmnipotentUser
 from Products.CMFCore.tests.base.security import UserWithRoles
-from Products.CMFCore.tests.base.testcase import _TRAVERSE_ZCML
-from Products.CMFCore.tests.base.testcase import PlacelessSetup
 from Products.CMFCore.tests.base.testcase import SecurityTest
 from Products.CMFCore.tests.base.testcase import WarningInterceptor
 from Products.CMFCore.tests.base.tidata import FTIDATA_ACTIONS
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF13
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF13_FOLDER
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF14
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF14_FOLDER
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF14_SPECIAL
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF14_SPECIAL2
 from Products.CMFCore.tests.base.tidata import FTIDATA_CMF15
 from Products.CMFCore.tests.base.tidata import FTIDATA_DUMMY
 from Products.CMFCore.tests.base.tidata import STI_SCRIPT
-from Products.CMFCore.utils import _getViewFor
 
+from zope.interface import implements
+from Products.CMFCore.interfaces import ITypeInformation
 
-class TypesToolTests(PlacelessSetup, SecurityTest, WarningInterceptor):
+class ActionTesterTypeInfo:
+
+    implements(ITypeInformation)
+
+    id = 'Dummy Content'
+
+    def listActions(self, info=None, obj=None):
+        self._action_info = info
+        self._action_obj = obj
+        return ()
+
+class TypesToolTests(SecurityTest, WarningInterceptor):
+
+    layer = FunctionalZCMLLayer
 
     def _makeOne(self):
         from Products.CMFCore.TypesTool import TypesTool
 
         return TypesTool()
 
-    def setUp( self ):
+    def setUp(self):
         from Products.CMFCore.TypesTool import FactoryTypeInformation as FTI
 
-        PlacelessSetup.setUp(self)
         SecurityTest.setUp(self)
-        zcml.load_config('meta.zcml', Products.Five)
-        zcml.load_config('permissions.zcml', Products.Five)
-        zcml.load_config('configure.zcml', Products.Five.browser)
-        zcml.load_config('configure.zcml', Products.CMFCore)
-        zcml.load_string(_TRAVERSE_ZCML)
-
         self.site = DummySite('site').__of__(self.root)
         self.acl_users = self.site._setObject( 'acl_users', DummyUserFolder() )
         self.ttool = self.site._setObject( 'portal_types', self._makeOne() )
@@ -81,7 +83,6 @@ class TypesToolTests(PlacelessSetup, SecurityTest, WarningInterceptor):
 
     def tearDown(self):
         SecurityTest.tearDown(self)
-        PlacelessSetup.tearDown(self)
         self._free_warning_output()
 
     def test_z2interfaces(self):
@@ -104,30 +105,19 @@ class TypesToolTests(PlacelessSetup, SecurityTest, WarningInterceptor):
         verifyClass(IActionProvider, TypesTool)
         verifyClass(ITypesTool, TypesTool)
 
-    def test_processActions( self ):
+    def test_listActions(self):
+        """test that a full set of context information is passed
+           by the types tool
         """
-        Are the correct, permitted methods returned for actions?
-        """
-        site = self.site
-        portal = site._setObject( 'portal', PortalFolder(id='portal') )
-        portal.manage_addProduct = { 'FooProduct' : DummyFactory(portal) }
-        portal.invokeFactory( 'Dummy Content', 'actions_dummy' )
-        dummy = portal._getOb( 'actions_dummy' )
+        tool = self.ttool
+        ti = ActionTesterTypeInfo()
+        setattr( tool, 'Dummy Content', ti )
 
-        # so we can traverse to it:
-        dummy.view = DummyObject("view")
-        dummy.view2 = DummyObject("view2")
-        dummy.edit = DummyObject("edit")
+        dummy = self.site._setObject('dummy', DummyContent('dummy'))
+        tool.listActions('fake_info', dummy)
 
-        default_view = dummy()
-        self._trap_warning_output()
-        custom_view = _getViewFor( dummy, view='view2' )()
-        unpermitted_view = _getViewFor( dummy, view='edit' )()
-
-        self.failUnlessEqual(default_view, 'view')
-        self.failUnlessEqual(custom_view, 'view2')
-        self.failIf(unpermitted_view == 'edit')
-        self.failUnlessEqual(unpermitted_view, 'view')
+        self.assertEqual(ti._action_info, 'fake_info')
+        self.assertEqual(ti._action_obj, dummy)
 
     def test_allMetaTypes(self):
         """
@@ -168,7 +158,7 @@ class TypesToolTests(PlacelessSetup, SecurityTest, WarningInterceptor):
         s.write(STI_SCRIPT)
 
         f = site._setObject( 'folder', PortalFolder(id='folder') )
-        f.manage_addProduct = { 'FooProduct' : DummyFactory(f) }
+        f.manage_addProduct = { 'FooProduct' : DummyFactoryDispatcher(f) }
         f._owner = (['acl_users'], 'user_foo')
         self.assertEqual( f.getOwner(), acl_users.user_foo )
 
@@ -179,66 +169,14 @@ class TypesToolTests(PlacelessSetup, SecurityTest, WarningInterceptor):
             self.fail('CMF Collector issue #165 (Ownership bug): '
                       'Unauthorized raised' )
 
-    def test_CMFCollector_49(self):
-        #http://www.zope.org/Collectors/CMF/49
 
-        #If you have two FTIs on the file system, both with the same meta_type
-        #but with different id values, the way listDefaultTypeInformation
-        #listed them in the dropdown list made it impossible to distinguish
-        #the two because the identifier string only contained the CMF package
-        #name and the meta_type
-
-        # Extreme nastiness: Fake out a /Control_Panel/Products registry
-        # inside the fake site by putting dummy objects with a
-        # factory_type_information attribute on them...
-        import copy
-        fti1 = copy.deepcopy(FTIDATA_DUMMY)
-        fti2 = copy.deepcopy(FTIDATA_DUMMY)
-        fti2[0]['id'] = 'Other Content'
-        product1 = DummyObject('product1')
-        product1.factory_type_information = fti1 + fti2
-        self.site._setObject('product1', product1)
-        def fakeGetProducts(*ign, **igntoo):
-            return self.site
-        def fakeObjectValues(*ign, **igntoo):
-            return (self.site.product1,)
-        self.ttool._getProducts = fakeGetProducts
-        self.site.objectValues = fakeObjectValues
-
-        types = self.ttool.listDefaultTypeInformation()
-        dropdown_representation = [x[0] for x in types]
-        self.failIf(dropdown_representation[0]==dropdown_representation[1])
-
-        # Backwards-compatibility tests
-        # Make sure the old representation still works, for now
-        ti_factory = self.ttool.manage_addTypeInformation
-        ti_type = 'Factory-based Type Information'
-        new_repr = 'product1: Dummy Content (Dummy)'
-        old_repr = 'product1: Dummy'
-
-        # This one uses the new representation. We do not expect an Exception
-        ti_factory(ti_type, id='NewType1', typeinfo_name=new_repr)
-        self.failUnless('NewType1' in self.ttool.objectIds())
-
-        # Now try with the old representation, which will throw a BadRequest
-        # unless the workaround in the code is used
-        self._trap_warning_output()
-        ti_factory(ti_type, id='NewType2', typeinfo_name=old_repr)
-        self.failUnless('NewType2' in self.ttool.objectIds())
-        self.failUnless('DeprecationWarning' in
-                            self._our_stderr_stream.getvalue())
-
-
-class TypeInfoTests(unittest.TestCase, WarningInterceptor):
+class TypeInfoTests(unittest.TestCase):
 
     def _makeTypesTool(self):
         from Products.CMFCore.TypesTool import TypesTool
 
         return TypesTool()
 
-    def tearDown(self):
-        self._free_warning_output()
-
     def test_construction( self ):
         ti = self._makeInstance( 'Foo'
                                , description='Description'
@@ -334,31 +272,6 @@ class TypeInfoTests(unittest.TestCase, WarningInterceptor):
         self.failUnless( 'objectproperties' in visible )
         self.failIf( 'slot' in visible )
 
-    def test_getActionById( self ):
-        self._trap_warning_output()
-        ti = self._makeInstance( 'Foo' )
-        marker = []
-        self.assertEqual( id( ti.getActionById( 'view', marker ) )
-                        , id( marker ) )
-        self.assertRaises( ValueError, ti.getActionById, 'view' )
-
-        ti = self._makeInstance( **FTIDATA_ACTIONS[0] )
-        self.assertEqual( id( ti.getActionById( 'foo', marker ) )
-                        , id( marker ) )
-        self.assertRaises( ValueError, ti.getActionById, 'foo' )
-
-        action = ti.getActionById( 'view' )
-        self.assertEqual( action, '' )
-
-        action = ti.getActionById( 'edit' )
-        self.assertEqual( action, 'foo_edit' )
-
-        action = ti.getActionById( 'objectproperties' )
-        self.assertEqual( action, 'foo_properties' )
-
-        action = ti.getActionById( 'slot' )
-        self.assertEqual( action, 'foo_slot' )
-
     def test_MethodAliases_methods(self):
         ti = self._makeInstance( **FTIDATA_CMF15[0] )
         self.assertEqual( ti.getMethodAliases(), FTIDATA_CMF15[0]['aliases'] )
@@ -403,110 +316,6 @@ class TypeInfoTests(unittest.TestCase, WarningInterceptor):
         self.assertEqual(ti._actions[1].action.text, wanted_actions_text1)
         self.assertEqual(ti._actions[2].action.text, wanted_actions_text2)
 
-    def test_CMF13_content_migration(self):
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF13[0] )
-        self._checkContentTI(ti)
-
-        # simulate old FTI
-        del ti._aliases
-        self.failIf( hasattr(ti, '_aliases') )
-        ti._actions = FTIDATA_CMF13[0]['actions']
-        self.failUnless( isinstance(ti._actions[0], dict) )
-
-        # migrate FTI
-        ti.queryMethodID('view')
-        self._checkContentTI(ti)
-
-    def test_CMF13_folder_migration(self):
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF13_FOLDER[0] )
-        self._checkFolderTI(ti)
-
-        # simulate old FTI
-        del ti._aliases
-        self.failIf( hasattr(ti, '_aliases') )
-        ti._actions = FTIDATA_CMF13_FOLDER[0]['actions']
-        self.failUnless( isinstance(ti._actions[0], dict) )
-
-        # migrate FTI
-        ti.queryMethodID('view')
-        self._checkFolderTI(ti)
-
-    def test_CMF14_content_migration(self):
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF14[0] )
-        self._checkContentTI(ti)
-
-        # simulate old FTI
-        del ti._aliases
-        self.failIf( hasattr(ti, '_aliases') )
-
-        # migrate FTI
-        ti.queryMethodID('view')
-        self._checkContentTI(ti)
-
-    def test_CMF14_folder_migration(self):
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF14_FOLDER[0] )
-        self._checkFolderTI(ti)
-
-        # simulate old FTI
-        del ti._aliases
-        self.failIf( hasattr(ti, '_aliases') )
-
-        # migrate FTI
-        ti.queryMethodID('view')
-        self._checkFolderTI(ti)
-
-    def test_CMF14_special_migration(self):
-        wanted = { 'view': 'dummy_view', 'mkdir': 'dummy_mkdir' }
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF14_SPECIAL[0] )
-        self.assertEqual(ti._aliases, wanted)
-
-        # simulate old FTI
-        del ti._aliases
-        self.failIf( hasattr(ti, '_aliases') )
-
-        # migrate FTI
-        ti.queryMethodID('view')
-        self.assertEqual(ti._aliases, wanted)
-
-    def test_CMF14_special2_migration(self):
-        wanted = {}
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF14_SPECIAL2[0] )
-        self.assertEqual(ti._aliases, wanted)
-
-        # simulate old FTI
-        del ti._aliases
-        self.failIf( hasattr(ti, '_aliases') )
-
-        # migrate FTI
-        ti.queryMethodID('view')
-        self.assertEqual(ti._aliases, wanted)
-
-    def test_CMF150beta_content_migration(self):
-
-        # use old FTI Data
-        ti = self._makeInstance( **FTIDATA_CMF14[0] )
-        self._checkContentTI(ti)
-
-        # simulate old FTI
-        ti._aliases = { 'view': ('dummy_view',),
-                        '(Default)': ('dummy_view',) }
-
-        # migrate FTI
-        ti.getMethodAliases()
-        self._checkContentTI(ti)
-
 
 class FTIDataTests( TypeInfoTests ):
 
@@ -578,153 +387,104 @@ class STIDataTests( TypeInfoTests ):
         self.assertEqual( ti.constructor_path, 'foo_add' )
 
 
-class FTIConstructionTests(unittest.TestCase):
+class FTIConstructionTestCase(unittest.TestCase):
 
-    def setUp( self ):
-        noSecurityManager()
-
-    def _makeInstance(self, id, **kw):
+    def _getTargetClass(self):
         from Products.CMFCore.TypesTool import FactoryTypeInformation
 
-        return FactoryTypeInformation(id, **kw)
+        return FactoryTypeInformation
 
-    def _makeFolder( self, fake_product=0 ):
-        return DummyFolder( fake_product )
+    def _makeOne(self, *args, **kw):
+        return self._getTargetClass()(*args, **kw)
 
-    def test_isConstructionAllowed_wo_Container( self ):
+    def test_isConstructionAllowed_wo_Container(self):
+        self.failIf(self.ti.isConstructionAllowed(None))
 
-        ti = self._makeInstance( 'foo' )
+    def test_isConstructionAllowed_wo_ProductFactory(self):
+        ti = self._makeOne('foo')
+        self.failIf(ti.isConstructionAllowed(self.f))
 
-        self.failIf( ti.isConstructionAllowed( None ) )
-
-        ti = self._makeInstance( 'Foo'
-                               , product='FooProduct'
-                               , factory='addFoo'
-                               )
-
-        self.failIf( ti.isConstructionAllowed( None ) )
-
-    def test_isConstructionAllowed_wo_ProductFactory( self ):
-
-        ti = self._makeInstance( 'foo' )
-
-        folder = self._makeFolder()
-        self.failIf( ti.isConstructionAllowed( folder ) )
-
-        folder = self._makeFolder( fake_product=1 )
-        self.failIf( ti.isConstructionAllowed( folder ) )
-
-    def test_isConstructionAllowed_wo_Security( self ):
-
-        ti = self._makeInstance( 'Foo'
-                               , product='FooProduct'
-                               , factory='addFoo'
-                               )
-        folder = self._makeFolder( fake_product=1 )
-
-        self.failIf( ti.isConstructionAllowed( folder ) )
-
-
-class FTIConstructionTests_w_Roles(unittest.TestCase):
-
-    def tearDown( self ):
+    def test_isConstructionAllowed_wo_Security(self):
         noSecurityManager()
+        self.failIf(self.ti.isConstructionAllowed(self.f))
 
-    def _makeStuff( self, prefix='' ):
-        from Products.CMFCore.TypesTool import FactoryTypeInformation as FTI
+    def test_isConstructionAllowed_for_Omnipotent(self):
+        newSecurityManager(None, OmnipotentUser().__of__(self.f))
+        self.failUnless(self.ti.isConstructionAllowed(self.f))
 
-        ti = FTI( 'Foo'
-                  , product='FooProduct'
-                  , factory='addFoo'
-                  )
-        folder = DummyFolder( fake_product=1,prefix=prefix )
+    def test_isConstructionAllowed_w_Role(self):
+        self.failUnless(self.ti.isConstructionAllowed(self.f))
 
-        return ti, folder
+    def test_isConstructionAllowed_wo_Role(self):
+        newSecurityManager(None, UserWithRoles('FooViewer').__of__(self.f))
+        self.failIf(self.ti.isConstructionAllowed(self.f))
 
-    def test_isConstructionAllowed_for_Omnipotent( self ):
+    def test_constructInstance_wo_Roles(self):
+        newSecurityManager(None, UserWithRoles('FooViewer').__of__(self.f))
+        self.assertRaises(Unauthorized,
+                          self.ti.constructInstance, self.f, 'foo')
 
-        ti, folder = self._makeStuff()
-        newSecurityManager( None
-                          , OmnipotentUser().__of__( folder ) )
-        self.failUnless( ti.isConstructionAllowed( folder ) )
-
-    def test_isConstructionAllowed_w_Role( self ):
-
-        ti, folder = self._makeStuff()
-
-        newSecurityManager( None
-                          , UserWithRoles( 'FooAdder' ).__of__( folder ) )
-        self.failUnless( ti.isConstructionAllowed( folder ) )
-
-    def test_isConstructionAllowed_wo_Role( self ):
-
-        ti, folder = self._makeStuff()
-
-        newSecurityManager( None
-                          , UserWithRoles( 'FooViewer' ).__of__( folder ) )
-
-    def test_constructInstance_wo_Roles( self ):
-
-        ti, folder = self._makeStuff()
-
-        newSecurityManager( None
-                          , UserWithRoles( 'FooViewer' ).__of__( folder ) )
-
-        self.assertRaises( Unauthorized
-                         , ti.constructInstance, folder, 'foo' )
-
-    def test_constructInstance( self ):
-
-        ti, folder = self._makeStuff()
-
-        newSecurityManager( None
-                          , UserWithRoles( 'FooAdder' ).__of__( folder ) )
-
-        ti.constructInstance( folder, 'foo' )
-        foo = folder._getOb( 'foo' )
-        self.assertEqual( foo.id, 'foo' )
-
-    def test_constructInstance_private(self):
-        ti, folder = self._makeStuff()
-        newSecurityManager(None,
-                           UserWithRoles('NotAFooAdder').__of__(folder))
-        ti._constructInstance(folder, 'foo')
-        foo = folder._getOb('foo')
+    def test_constructInstance(self):
+        self.ti.constructInstance(self.f, 'foo')
+        foo = self.f._getOb('foo')
         self.assertEqual(foo.id, 'foo')
 
-    def test_constructInstance_w_args_kw( self ):
+    def test_constructInstance_private(self):
+        newSecurityManager(None, UserWithRoles('NotAFooAdder').__of__(self.f))
+        self.ti._constructInstance(self.f, 'foo')
+        foo = self.f._getOb('foo')
+        self.assertEqual(foo.id, 'foo')
 
-        ti, folder = self._makeStuff()
+    def test_constructInstance_w_args_kw(self):
+        self.ti.constructInstance(self.f, 'bar', 0, 1)
+        bar = self.f._getOb('bar')
+        self.assertEqual(bar.id, 'bar')
+        self.assertEqual(bar._args, (0, 1))
 
-        newSecurityManager( None
-                          , UserWithRoles( 'FooAdder' ).__of__( folder ) )
+        self.ti.constructInstance(self.f, 'baz', frickle='natz')
+        baz = self.f._getOb('baz')
+        self.assertEqual(baz.id, 'baz')
+        self.assertEqual(baz._kw['frickle'], 'natz')
 
-        ti.constructInstance( folder, 'bar', 0, 1 )
-        bar = folder._getOb( 'bar' )
-        self.assertEqual( bar.id, 'bar' )
-        self.assertEqual( bar._args, ( 0, 1 ) )
+        self.ti.constructInstance(self.f, 'bam', 0, 1, frickle='natz')
+        bam = self.f._getOb('bam')
+        self.assertEqual(bam.id, 'bam')
+        self.assertEqual(bam._args, (0, 1))
+        self.assertEqual(bam._kw['frickle'], 'natz')
 
-        ti.constructInstance( folder, 'baz', frickle='natz' )
-        baz = folder._getOb( 'baz' )
-        self.assertEqual( baz.id, 'baz' )
-        self.assertEqual( baz._kw[ 'frickle' ], 'natz' )
 
-        ti.constructInstance( folder, 'bam', 0, 1, frickle='natz' )
-        bam = folder._getOb( 'bam' )
-        self.assertEqual( bam.id, 'bam' )
-        self.assertEqual( bam._args, ( 0, 1 ) )
-        self.assertEqual( bam._kw[ 'frickle' ], 'natz' )
+class FTIOldstyleConstructionTests(FTIConstructionTestCase):
 
-    def test_constructInstance_w_id_munge( self ):
+    def setUp(self):
+        self.f = DummyFolder(fake_product=1)
+        self.ti = self._makeOne('Foo', product='FooProduct', factory='addFoo')
+        newSecurityManager(None, UserWithRoles('FooAdder').__of__(self.f))
 
-        ti, folder = self._makeStuff( 'majyk' )
+    def tearDown(self):
+        noSecurityManager()
 
-        newSecurityManager( None
-                          , UserWithRoles( 'FooAdder' ).__of__( folder ) )
+    def test_constructInstance_w_id_munge(self):
+        self.f._prefix = 'majyk'
+        self.ti.constructInstance(self.f, 'dust')
+        majyk_dust = self.f._getOb('majyk_dust')
+        self.assertEqual(majyk_dust.id, 'majyk_dust')
 
-        ti.constructInstance( folder, 'dust' )
-        majyk_dust = folder._getOb( 'majyk_dust' )
-        self.assertEqual( majyk_dust.id, 'majyk_dust' )
+
+class FTINewstyleConstructionTests(FTIConstructionTestCase, SecurityTest):
+
+    def setUp(self):
+        SecurityTest.setUp(self)
+        sm = getSiteManager()
+        sm.registerUtility(DummyFactory, IFactory, 'test.dummy')
+
+        self.f = DummyFolder()
+        self.ti = self._makeOne('Foo', meta_type='Dummy',
+                                factory='test.dummy')
+        newSecurityManager(None, UserWithRoles('FooAdder').__of__(self.f))
+
+    def tearDown(self):
+        cleanUp()
+        SecurityTest.tearDown(self)
 
 
 def test_suite():
@@ -732,9 +492,10 @@ def test_suite():
         unittest.makeSuite(TypesToolTests),
         unittest.makeSuite(FTIDataTests),
         unittest.makeSuite(STIDataTests),
-        unittest.makeSuite(FTIConstructionTests),
-        unittest.makeSuite(FTIConstructionTests_w_Roles),
+        unittest.makeSuite(FTIOldstyleConstructionTests),
+        unittest.makeSuite(FTINewstyleConstructionTests),
         ))
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
