@@ -12,20 +12,23 @@
 ##############################################################################
 """ Unit tests for WorkflowTool module.
 
-$Id: test_WorkflowTool.py 40364 2005-11-24 18:23:00Z yuppie $
+$Id: test_WorkflowTool.py 77004 2007-06-24 08:57:54Z yuppie $
 """
 
-from unittest import TestCase, TestSuite, makeSuite, main
+import unittest
 import Testing
-try:
-    import Zope2
-except ImportError: # BBB: for Zope 2.7
-    import Zope as Zope2
-Zope2.startup()
 
 from OFS.SimpleItem import SimpleItem
+from zope.component import adapter
+from zope.component import provideHandler
+from zope.interface import implements
+from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.tests.base.testcase import WarningInterceptor
+from Products.CMFCore.interfaces import IActionRaisedExceptionEvent
+from Products.CMFCore.interfaces import IActionSucceededEvent
+from Products.CMFCore.interfaces import IActionWillBeInvokedEvent
+from Products.CMFCore.interfaces import IContentish
+from Products.CMFCore.interfaces import IWorkflowDefinition
 
 
 class Dummy( SimpleItem ):
@@ -39,6 +42,7 @@ class Dummy( SimpleItem ):
 
 class DummyWorkflow( Dummy ):
 
+    implements(IWorkflowDefinition)
     meta_type = 'DummyWorkflow'
     _isAWorkflow = 1
     _known_actions=()
@@ -105,11 +109,24 @@ class DummyWorkflow( Dummy ):
     def notifyException( self, ob, action, exc ):
         self.notified( 'exception' ).append( ( ob, action, exc ) )
 
+@adapter(IActionWillBeInvokedEvent)
+def notifyBeforeHandler(evt):
+    evt.workflow.notified( 'before-evt' ).append( (evt.object, evt.action) )
+
+@adapter(IActionSucceededEvent)
+def notifySuccessHandler(evt):
+    evt.workflow.notified( 'success-evt' ).append( (evt.object, evt.action,
+                                                    evt.result ) )
+
+@adapter(IActionRaisedExceptionEvent)
+def notifyExceptionHandler(evt):
+    evt.workflow.notified( 'exception-evt' ).append( (evt.object, evt.action,
+                                                      evt.exc) )
 
 class DummyContent( Dummy ):
 
+    implements(IContentish)
     meta_type = 'Dummy'
-    _isPortalContent = 1
 
     def getPortalTypeName(self):
         return 'Dummy Content'
@@ -136,16 +153,7 @@ class DummyTypesTool( SimpleItem ):
         return None
 
 
-class WorkflowToolTests(TestCase, WarningInterceptor):
-
-    def setUp( self ):
-        from Products.CMFCore.WorkflowTool import addWorkflowFactory
-        addWorkflowFactory( DummyWorkflow )
-
-    def tearDown( self ):
-        from Products.CMFCore.WorkflowTool import _removeWorkflowFactory
-        _removeWorkflowFactory( DummyWorkflow )
-        self._free_warning_output()
+class WorkflowToolTests(unittest.TestCase):
 
     def _makeOne( self, workflow_ids=() ):
         from Products.CMFCore.WorkflowTool import WorkflowTool
@@ -153,7 +161,7 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         tool = WorkflowTool()
 
         for workflow_id in workflow_ids:
-            tool.manage_addWorkflow( DummyWorkflow.meta_type, workflow_id )
+            tool._setObject(workflow_id, DummyWorkflow(workflow_id))
 
         return tool
 
@@ -175,6 +183,9 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         tool.setChainForPortalTypes( ( 'Dummy Content', ), ( 'a', 'b' ) )
         return tool
 
+    def tearDown(self):
+        cleanUp()
+
     def test_z2interfaces(self):
         from Interface.Verify import verifyClass
         from Products.CMFCore.interfaces.portal_actions \
@@ -187,16 +198,14 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         verifyClass(IWorkflowTool, WorkflowTool)
 
     def test_z3interfaces(self):
-        try:
-            from zope.interface.verify import verifyClass
-            from Products.CMFCore.interfaces import IActionProvider
-            from Products.CMFCore.interfaces import IWorkflowTool
-        except ImportError:
-            # BBB: for Zope 2.7
-            return
+        from zope.interface.verify import verifyClass
+        from Products.CMFCore.interfaces import IActionProvider
+        from Products.CMFCore.interfaces import IConfigurableWorkflowTool
+        from Products.CMFCore.interfaces import IWorkflowTool
         from Products.CMFCore.WorkflowTool import WorkflowTool
 
         verifyClass(IActionProvider, WorkflowTool)
+        verifyClass(IConfigurableWorkflowTool, WorkflowTool)
         verifyClass(IWorkflowTool, WorkflowTool)
 
     def test_empty( self ):
@@ -235,6 +244,8 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
 
         tool = self._makeWithTypesAndChain()
         self.assertEquals( len( tool.getDefaultChainFor( None ) ), 0 )
+        self.assertEquals( len( tool.getDefaultChain() ), 1 )
+        self.assertEquals( len( tool.listChainOverrides() ), 1 )
         self.assertEquals( len( tool.getChainFor( None ) ), 0 )
         self.assertEquals( len( tool.getCatalogVariablesFor( None ) ), 0 )
 
@@ -243,6 +254,8 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         tool = self._makeWithTypesAndChain()
         dummy = DummyNotReallyContent( 'doh' )
         self.assertEquals( len( tool.getDefaultChainFor( dummy ) ), 0 )
+        self.assertEquals( len( tool.getDefaultChain() ), 1 )
+        self.assertEquals( len( tool.listChainOverrides() ), 1 )
         self.assertEquals( len( tool.getChainFor( dummy ) ), 0 )
         self.assertEquals( len( tool.getCatalogVariablesFor( dummy ) ), 0 )
 
@@ -251,10 +264,11 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         tool = self._makeWithTypes()
         dummy = DummyContent( 'dummy' )
         self.assertEquals( len( tool.getDefaultChainFor( dummy ) ), 1 )
+        self.assertEquals( len( tool.getDefaultChain() ), 1 )
+        self.assertEquals( len( tool.listChainOverrides() ), 0 )
         self.assertEquals( len( tool.getChainFor( dummy ) ), 1 )
         self.assertEquals( len( tool.getCatalogVariablesFor( dummy ) ), 0 )
-        self.assertEquals( tool.getDefaultChainFor( dummy )
-                         , tool.getChainFor( dummy ) )
+        self.assertEquals( tool.getDefaultChain(), tool.getChainFor( dummy ) )
 
     def test_content_own_chain( self ):
 
@@ -263,6 +277,8 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         dummy = DummyContent( 'dummy' )
 
         self.assertEquals( len( tool.getDefaultChainFor( dummy ) ), 1 )
+        self.assertEquals( len( tool.getDefaultChain() ), 1 )
+        self.assertEquals( len( tool.listChainOverrides() ), 1 )
         chain = tool.getChainFor( dummy )
         self.assertEquals( len( chain ), 2 )
         self.failUnless( 'a' in chain )
@@ -276,6 +292,7 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
     def test_setChainForPortalTypes(self):
 
         tool = self._makeWithTypes()
+        tool.setDefaultChain('b, a')
         dummy = DummyContent('dummy')
 
         tool.setChainForPortalTypes( ('Dummy Content',), ('a', 'b') )
@@ -288,6 +305,14 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         tool.setChainForPortalTypes( ('Dummy Content',), '' )
         self.assertEquals( tool.getChainFor(dummy), () )
 
+        tool.setChainForPortalTypes( ('Dummy Content',), None )
+        self.assertEquals( tool.getChainFor(dummy), ('b', 'a') )
+
+        # Using the '(Default)' keyword
+        # http://www.zope.org/Collectors/CMF/475
+        tool.setChainForPortalTypes( ('Dummy Content',), '(Default)' )
+        self.assertEquals( tool.getChainFor(dummy), () )
+
     def test_getCatalogVariablesFor( self ):
 
         tool = self._makeWithTypesAndChain()
@@ -298,18 +323,6 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
         self.failUnless( 'dummy' in vars.keys() )
         self.failUnless( 'a: dummy' in vars.values() )
 
-    def test_getActionsFor( self ):
-
-        import warnings
-
-        # Collector #360: Test AtttributeError in deprecated API :(
-        tool = self._makeWithTypesAndChain()
-        dummy = DummyContent( 'dummy' )
-
-        self._trap_warning_output()
-        actions = tool.getActionsFor( dummy )
-        self.assertEqual( len( actions ), 0 )
-
     def test_getInfoFor( self ):
 
         tool = self._makeWithTypesAndChain()
@@ -347,6 +360,8 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
 
     def test_notifyBefore( self ):
 
+        provideHandler(notifyBeforeHandler)
+
         tool = self._makeWithTypesAndChain()
 
         ob = DummyContent( 'dummy' )
@@ -357,8 +372,14 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
             self.assertEqual( len( notified ), 1 )
             self.assertEqual( notified[0], ( ob, 'action' ) )
 
+            notified = wf.notified( 'before-evt' )
+            self.assertEqual( len( notified ), 1 )
+            self.assertEqual( notified[0], ( ob, 'action' ) )
+
     def test_notifySuccess( self ):
 
+        provideHandler(notifySuccessHandler)
+
         tool = self._makeWithTypesAndChain()
 
         ob = DummyContent( 'dummy' )
@@ -369,8 +390,14 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
             self.assertEqual( len( notified ), 1 )
             self.assertEqual( notified[0], ( ob, 'action', None ) )
 
+            notified = wf.notified( 'success-evt' )
+            self.assertEqual( len( notified ), 1 )
+            self.assertEqual( notified[0], ( ob, 'action', None ) )
+
     def test_notifyException( self ):
 
+        provideHandler(notifyExceptionHandler)
+
         tool = self._makeWithTypesAndChain()
 
         ob = DummyContent( 'dummy' )
@@ -381,6 +408,10 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
             self.assertEqual( len( notified ), 1 )
             self.assertEqual( notified[0], ( ob, 'action', 'exception' ) )
 
+            notified = wf.notified( 'exception-evt' )
+            self.assertEqual( len( notified ), 1 )
+            self.assertEqual( notified[0], ( ob, 'action', 'exception' ) )
+
     def xxx_test_updateRoleMappings( self ):
         """
             Build a tree of objects, invoke tool.updateRoleMappings,
@@ -390,9 +421,9 @@ class WorkflowToolTests(TestCase, WarningInterceptor):
 
 
 def test_suite():
-    return TestSuite((
-        makeSuite(WorkflowToolTests),
+    return unittest.TestSuite((
+        unittest.makeSuite(WorkflowToolTests),
         ))
 
 if __name__ == '__main__':
-    main(defaultTest='test_suite')
+    unittest.main(defaultTest='test_suite')
