@@ -12,23 +12,24 @@
 ##############################################################################
 """ A simple submit/review/publish workflow.
 
-$Id: DefaultWorkflow.py 40194 2005-11-17 14:30:45Z yuppie $
+$Id: DefaultWorkflow.py 77113 2007-06-26 20:36:26Z yuppie $
 """
 
+from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from AccessControl import ClassSecurityInfo
 from DateTime import DateTime
 from Globals import InitializeClass
+from zope.interface import implements
 
+from Products.CMFCore.interfaces import IWorkflowDefinition
 from Products.CMFCore.interfaces.portal_workflow \
-        import WorkflowDefinition as IWorkflowDefinition
+        import WorkflowDefinition as z2IWorkflowDefinition
 from Products.CMFCore.utils import _checkPermission
 from Products.CMFCore.utils import _modifyPermissionMappings
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.utils import SimpleItemWithProperties
-from Products.CMFCore.WorkflowTool import addWorkflowClass
 
 from exceptions import AccessControl_Unauthorized
 from permissions import ModifyPortalContent
@@ -37,16 +38,17 @@ from permissions import ReviewPortalContent
 from permissions import View
 
 
-class DefaultWorkflowDefinition (SimpleItemWithProperties):
+class DefaultWorkflowDefinition(SimpleItemWithProperties):
+
     """ Default workflow definition.
     """
 
-    __implements__ = IWorkflowDefinition
+    implements(IWorkflowDefinition)
+    __implements__ = z2IWorkflowDefinition
 
     meta_type = 'CMF Default Workflow'
     id = 'default_workflow'
     title = 'Simple Review / Publish Policy'
-    _isAWorkflow = 1
 
     security = ClassSecurityInfo()
 
@@ -154,17 +156,19 @@ class DefaultWorkflowDefinition (SimpleItemWithProperties):
 
         actions = []
         catalog = getToolByName(self, 'portal_catalog', None)
-        if catalog is not None:
-            pending = len(catalog.searchResults(
-                review_state='pending'))
-            if pending > 0:
-                actions.append(
-                    {'name': 'Pending review (%d)' % pending,
-                     'url': info.portal_url +
-                     '/search?review_state=pending',
-                     'permissions': (ReviewPortalContent, ),
-                     'category': 'global'}
-                    )
+        if catalog is None:
+            return actions
+
+        pending = len(catalog.searchResults(review_state='pending'))
+        if pending > 0:
+            actions.append(
+                {'name': 'Pending review (%d)' % pending,
+                 'url': info.portal_url +
+                 '/search?review_state=pending',
+                 'permissions': (ReviewPortalContent, ),
+                 'category': 'global'}
+                )
+
         return actions
 
     security.declarePrivate('isActionSupported')
@@ -324,5 +328,3 @@ class DefaultWorkflowDefinition (SimpleItemWithProperties):
         return _modifyPermissionMappings(ob, new_map)
 
 InitializeClass(DefaultWorkflowDefinition)
-
-addWorkflowClass(DefaultWorkflowDefinition)
