@@ -12,7 +12,7 @@
 ##############################################################################
 """ Basic portal discussion access tool.
 
-$Id: DiscussionTool.py 41676 2006-02-18 20:57:23Z jens $
+$Id: DiscussionTool.py 81923 2007-11-18 22:51:13Z jens $
 """
 
 from AccessControl import ClassSecurityInfo
@@ -20,15 +20,16 @@ from Acquisition import aq_base
 from Globals import DTMLFile
 from Globals import InitializeClass
 from OFS.SimpleItem import SimpleItem
+from zope.interface import implements
 
-from Products.CMFCore.ActionInformation import ActionInformation
-from Products.CMFCore.ActionProviderBase import ActionProviderBase
-from Products.CMFCore.Expression import Expression
+from Products.CMFCore.interfaces import IDiscussionResponse
+from Products.CMFCore.interfaces import IDiscussionTool
 from Products.CMFCore.interfaces.Discussions \
-        import DiscussionResponse as IDiscussionResponse
+        import DiscussionResponse as z2IDiscussionResponse
 from Products.CMFCore.interfaces.portal_discussion \
-        import portal_discussion as IDiscussionTool
-from Products.CMFCore.utils import getToolByName
+        import portal_discussion as z2IDiscussionTool
+from Products.CMFCore.utils import _checkPermission
+from Products.CMFCore.utils import registerToolInterface
 from Products.CMFCore.utils import UniqueObject
 
 from DiscussionItem import DiscussionItemContainer
@@ -36,38 +37,28 @@ from exceptions import AccessControl_Unauthorized
 from exceptions import DiscussionNotAllowed
 from permissions import ManagePortal
 from permissions import ModifyPortalContent
-from permissions import ReplyToItem
 from utils import _dtmldir
 
+_marker = []
+
+
+class DiscussionTool(UniqueObject, SimpleItem):
 
-class DiscussionTool( UniqueObject, SimpleItem, ActionProviderBase ):
     """ Links content to discussions.
     """
 
-    __implements__ = (IDiscussionTool, ActionProviderBase.__implements__)
+    implements(IDiscussionTool)
+    __implements__ = (z2IDiscussionTool, )
 
     id = 'portal_discussion'
     meta_type = 'Default Discussion Tool'
-    _actions = (ActionInformation(id='reply'
-                                , title='Reply'
-                                , action=Expression(
-                text='string:${object_url}/discussion_reply_form')
-                                , condition=Expression(
-                text='python: object is not None and ' +
-                'portal.portal_discussion.isDiscussionAllowedFor(object)')
-                                , permissions=(ReplyToItem,)
-                                , category='object'
-                                , visible=1
-                                 )
-               ,
-               )
 
     security = ClassSecurityInfo()
 
-    manage_options = (ActionProviderBase.manage_options +
-                     ({ 'label' : 'Overview', 'action' : 'manage_overview' }
-                     ,
-                     ) + SimpleItem.manage_options)
+    manage_options = ( ({'label': 'Overview',
+                         'action': 'manage_overview'},)
+                     + SimpleItem.manage_options
+                     )
 
     #
     #   ZMI methods
@@ -83,13 +74,17 @@ class DiscussionTool( UniqueObject, SimpleItem, ActionProviderBase ):
     def overrideDiscussionFor(self, content, allowDiscussion):
         """ Override discussability for the given object or clear the setting.
         """
-        mtool = getToolByName( self, 'portal_membership' )
-        if not mtool.checkPermission(ModifyPortalContent, content):
+        if not _checkPermission(ModifyPortalContent, content):
             raise AccessControl_Unauthorized
 
         if allowDiscussion is None or allowDiscussion == 'None':
-            if hasattr( aq_base(content), 'allow_discussion'):
-                del content.allow_discussion
+            disc_flag = getattr(aq_base(content), 'allow_discussion', _marker)
+            if disc_flag is not _marker:
+                try:
+                    del content.allow_discussion
+                except AttributeError:
+                    # https://bugs.launchpad.net/zope-cmf/+bug/162532
+                    pass
         else:
             content.allow_discussion = bool(allowDiscussion)
 
@@ -100,7 +95,8 @@ class DiscussionTool( UniqueObject, SimpleItem, ActionProviderBase ):
         if not self.isDiscussionAllowedFor( content ):
             raise DiscussionNotAllowed
 
-        if not IDiscussionResponse.isImplementedBy(content) and \
+        if not IDiscussionResponse.providedBy(content) and \
+                not z2IDiscussionResponse.isImplementedBy(content) and \
                 getattr( aq_base(content), 'talkback', None ) is None:
             # Discussion Items use the DiscussionItemContainer object of the
             # related content item, so only create one for other content items
@@ -114,7 +110,7 @@ class DiscussionTool( UniqueObject, SimpleItem, ActionProviderBase ):
         """
         if hasattr( aq_base(content), 'allow_discussion' ):
             return bool(content.allow_discussion)
-        typeInfo = getToolByName(self, 'portal_types').getTypeInfo( content )
+        typeInfo = content.getTypeInfo()
         if typeInfo:
             return bool( typeInfo.allowDiscussion() )
         return False
@@ -133,3 +129,4 @@ class DiscussionTool( UniqueObject, SimpleItem, ActionProviderBase ):
         return content.talkback
 
 InitializeClass( DiscussionTool )
+registerToolInterface('portal_discussion', IDiscussionTool)
