@@ -14,59 +14,29 @@
 Zope's built-in File object, but modifies the behaviour slightly to
 make it more Portal-friendly.
 
-$Id: File.py 70021 2006-09-07 10:16:08Z jens $
+$Id: File.py 77186 2007-06-28 19:06:19Z yuppie $
 """
 
-from Globals import InitializeClass
-from AccessControl import ClassSecurityInfo
-
-from Products.CMFCore.PortalContent import PortalContent
-
-from DublinCore import DefaultDublinCoreImpl
-from permissions import View
-from permissions import ModifyPortalContent
-
-from zope.interface import implements
-from Products.GenericSetup.interfaces import IDAVAware
-
-factory_type_information = (
-  { 'id'             : 'File'
-  , 'meta_type'      : 'Portal File'
-  , 'description'    : """\
-File objects can contain arbitrary downloadable files.
-"""
-  , 'icon'           : 'file_icon.gif'
-  , 'product'        : 'CMFDefault'
-  , 'factory'        : 'addFile'
-  , 'immediate_view' : 'metadata_edit_form'
-  , 'aliases'        : {'(Default)':'index_html',
-                        'view':'file_view'}
-  , 'actions'        : ( { 'id'            : 'view'
-                         , 'name'          : 'View'
-                         , 'action': 'string:${object_url}/file_view'
-                         , 'permissions'   : (View,)
-                         }
-                       , { 'id'            : 'download'
-                         , 'name'          : 'Download'
-                         , 'action': 'string:${object_url}'
-                         , 'permissions'   : (View,)
-                         }
-                       , { 'id'            : 'edit'
-                         , 'name'          : 'Edit'
-                         , 'action': 'string:${object_url}/file_edit_form'
-                         , 'permissions'   : (ModifyPortalContent,)
-                         }
-                       , { 'id'            : 'metadata'
-                         , 'name'          : 'Metadata'
-                         , 'action': 'string:${object_url}/metadata_edit_form'
-                         , 'permissions'   : (ModifyPortalContent,)
-                         }
-                       )
-  }
-,
-)
-
 import OFS.Image
+from AccessControl import ClassSecurityInfo
+from Globals import InitializeClass
+from OFS.Cache import Cacheable
+from zope.component.factory import Factory
+from zope.interface import implements
+
+from Products.CMFCore.PortalContent import PortalContent
+from Products.CMFCore.utils import _checkConditionalGET
+from Products.CMFCore.utils import _OldCacheHeaders
+from Products.CMFCore.utils import _setCacheHeaders
+from Products.CMFCore.utils import _ViewEmulator
+from Products.GenericSetup.interfaces import IDAVAware
+
+from DublinCore import DefaultDublinCoreImpl
+from interfaces import IFile
+from interfaces import IMutableFile
+from permissions import ModifyPortalContent
+from permissions import View
+
 
 def addFile( self
            , id
@@ -97,7 +67,7 @@ def addFile( self
                , description, contributors, effective_date, expiration_date
                , format, language, rights
                )
-    
+
     # Add the File instance to self
     self._setObject(id, fobj)
 
@@ -108,20 +78,22 @@ def addFile( self
 
 
 class File(PortalContent, OFS.Image.File, DefaultDublinCoreImpl):
-    """
-        A Portal-managed File
+
+    """A Portal-managed File.
     """
 
-    implements(IDAVAware)
+    implements(IMutableFile, IFile, IDAVAware)
     __implements__ = ( PortalContent.__implements__
                      , DefaultDublinCoreImpl.__implements__
                      )
-    
-    meta_type='Portal File'
+
     effective_date = expiration_date = None
-    _isDiscussable = 1
     icon = PortalContent.icon
 
+    manage_options = ( PortalContent.manage_options
+                     + Cacheable.manage_options
+                     )
+
     security = ClassSecurityInfo()
 
     def __init__( self
@@ -155,11 +127,6 @@ class File(PortalContent, OFS.Image.File, DefaultDublinCoreImpl):
                                , contributors, effective_date, expiration_date
                                , format, language, rights )
 
-    # use OFS.Image.File's index_html; PortalContent's will cause some
-    # circular behaviour w/ 'None' being returned as the default view
-    security.declareProtected(View, 'index_html')
-    index_html = OFS.Image.File.index_html
-
     # For old instances where bases had OFS.Image.File first,
     # the id was actually stored in __name__.
     # getId() will do the correct thing here, as id() is callable
@@ -174,24 +141,6 @@ class File(PortalContent, OFS.Image.File, DefaultDublinCoreImpl):
         """
         return "%s %s" % (self.title, self.description)
 
-    security.declarePrivate('manage_afterAdd')
-    def manage_afterAdd(self, item, container):
-        """Both of my parents have an afterAdd method"""
-        OFS.Image.File.manage_afterAdd(self, item, container)
-        PortalContent.manage_afterAdd(self, item, container)
-
-    security.declarePrivate('manage_afterClone')
-    def manage_afterClone(self, item):
-        """Both of my parents have an afterClone method"""
-        OFS.Image.File.manage_afterClone(self, item)
-        PortalContent.manage_afterClone(self, item)
-
-    security.declarePrivate('manage_beforeDelete')
-    def manage_beforeDelete(self, item, container):
-        """Both of my parents have a beforeDelete method"""
-        PortalContent.manage_beforeDelete(self, item, container)
-        OFS.Image.File.manage_beforeDelete(self, item, container)
-
     security.declarePrivate('_isNotEmpty')
     def _isNotEmpty(self, file):
         """ Do various checks on 'file' to try to determine non emptiness. """
@@ -225,13 +174,52 @@ class File(PortalContent, OFS.Image.File, DefaultDublinCoreImpl):
         self._edit( precondition, file )
         self.reindexObject()
 
+    security.declareProtected(View, 'index_html')
+    def index_html(self, REQUEST, RESPONSE):
+        """
+        The default view of the contents of a File or Image.
+
+        Returns the contents of the file or image.  Also, sets the
+        Content-Type HTTP header to the objects content type.
+        """
+        view = _ViewEmulator().__of__(self)
+
+        # If we have a conditional get, set status 304 and return
+        # no content 
+        if _checkConditionalGET(view, extra_context={}):
+            return ''
+
+        RESPONSE.setHeader('Content-Type', self.content_type)
+
+        # old-style If-Modified-Since header handling.
+        if self._setOldCacheHeaders():
+            # Make sure the CachingPolicyManager gets a go as well
+            _setCacheHeaders(view, extra_context={})
+            return ''
+
+        rendered = OFS.Image.File.index_html(self, REQUEST, RESPONSE)
+
+        # There are 2 Cache Managers which can be in play....
+        # need to decide which to use to determine where the cache headers
+        # are decided on.
+        if self.ZCacheable_getManager() is not None:
+            self.ZCacheable_set(None)
+        else:
+            _setCacheHeaders(view, extra_context={})
+
+        return rendered
+
+    def _setOldCacheHeaders(self):
+        # return False to disable this simple caching behaviour
+        return _OldCacheHeaders(self) 
+
     security.declareProtected(View, 'download')
     def download(self, REQUEST, RESPONSE):
         """Download this item.
-        
+
         Calls OFS.Image.File.index_html to perform the actual transfer after
         first setting Content-Disposition to suggest a filename.
-        
+
         This method is deprecated, use the URL of this object itself. Because
         the default view of a File object is to download, rather than view,
         this method is obsolete. Also note that certain browsers do not deal
@@ -241,7 +229,7 @@ class File(PortalContent, OFS.Image.File, DefaultDublinCoreImpl):
 
         RESPONSE.setHeader('Content-Disposition',
                            'attachment; filename=%s' % self.getId())
-        return OFS.Image.File.index_html(self, REQUEST, RESPONSE)
+        return self.index_html(self, REQUEST, RESPONSE)
 
     security.declareProtected(View, 'Format')
     def Format(self):
@@ -259,6 +247,6 @@ class File(PortalContent, OFS.Image.File, DefaultDublinCoreImpl):
         OFS.Image.File.PUT( self, REQUEST, RESPONSE )
         self.reindexObject()
 
-
 InitializeClass(File)
 
+FileFactory = Factory(File)
