@@ -13,54 +13,29 @@
 """ This module implements a portal-managed Image class. It is based on
 Zope's built-in Image object.
 
-$Id: Image.py 70021 2006-09-07 10:16:08Z jens $
+$Id: Image.py 77345 2007-07-03 13:46:57Z yuppie $
 """
 
-from Globals import InitializeClass
-from AccessControl import ClassSecurityInfo
-
-from Products.CMFCore.PortalContent import PortalContent
-
-from DublinCore import DefaultDublinCoreImpl
-from permissions import View
-from permissions import ModifyPortalContent
-
-from zope.interface import implements
-from Products.GenericSetup.interfaces import IDAVAware
-
-factory_type_information = (
-  { 'id'             : 'Image'
-  , 'meta_type'      : 'Portal Image'
-  , 'description'    : """\
-Image objects can be embedded in Portal documents.
-"""
-  , 'icon'           : 'image_icon.gif'
-  , 'product'        : 'CMFDefault'
-  , 'factory'        : 'addImage'
-  , 'immediate_view' : 'metadata_edit_form'
-  , 'aliases'        : {'(Default)':'index_html',
-                        'view':'image_view'}
-  , 'actions'        : ( { 'id'            : 'view'
-                         , 'name'          : 'View'
-                         , 'action': 'string:${object_url}/image_view'
-                         , 'permissions'   : (View,)
-                         }
-                       , { 'id'            : 'edit'
-                         , 'name'          : 'Edit'
-                         , 'action': 'string:${object_url}/image_edit_form'
-                         , 'permissions'   : (ModifyPortalContent,)
-                         }
-                       , { 'id'            : 'metadata'
-                         , 'name'          : 'Metadata'
-                         , 'action': 'string:${object_url}/metadata_edit_form'
-                         , 'permissions'   : (ModifyPortalContent,)
-                         }
-                       )
-  }
-,
-)
-
 import OFS.Image
+from AccessControl import ClassSecurityInfo
+from Globals import InitializeClass
+from OFS.Cache import Cacheable
+from zope.component.factory import Factory
+from zope.interface import implements
+
+from Products.CMFCore.PortalContent import PortalContent
+from Products.CMFCore.utils import _checkConditionalGET
+from Products.CMFCore.utils import _OldCacheHeaders
+from Products.CMFCore.utils import _setCacheHeaders
+from Products.CMFCore.utils import _ViewEmulator
+from Products.GenericSetup.interfaces import IDAVAware
+
+from DublinCore import DefaultDublinCoreImpl
+from interfaces import IImage
+from interfaces import IMutableImage
+from permissions import ModifyPortalContent
+from permissions import View
+
 
 def addImage( self
             , id
@@ -91,7 +66,7 @@ def addImage( self
                 , description, contributors, effective_date, expiration_date
                 , format, language, rights
                 )
-    
+
     # Add the Image instance to self
     self._setObject(id, iobj)
 
@@ -101,20 +76,22 @@ def addImage( self
 
 
 class Image(PortalContent, OFS.Image.Image, DefaultDublinCoreImpl):
-    """
-        A Portal-managed Image
+
+    """A Portal-managed Image.
     """
 
-    implements(IDAVAware)
+    implements(IMutableImage, IImage, IDAVAware)
     __implements__ = ( PortalContent.__implements__
                      , DefaultDublinCoreImpl.__implements__
                      )
-    
-    meta_type='Portal Image'
+
     effective_date = expiration_date = None
-    _isDiscussable = 1
     icon = PortalContent.icon
 
+    manage_options = ( PortalContent.manage_options
+                     + Cacheable.manage_options
+                     )
+
     security = ClassSecurityInfo()
 
     def __init__( self
@@ -160,24 +137,6 @@ class Image(PortalContent, OFS.Image.Image, DefaultDublinCoreImpl):
         """
         return "%s %s" % (self.title, self.description)
 
-    security.declarePrivate('manage_afterAdd')
-    def manage_afterAdd(self, item, container):
-        """Both of my parents have an afterAdd method"""
-        OFS.Image.Image.manage_afterAdd(self, item, container)
-        PortalContent.manage_afterAdd(self, item, container)
-
-    security.declarePrivate('manage_afterClone')
-    def manage_afterClone(self, item):
-        """Both of my parents have an afterClone method"""
-        OFS.Image.Image.manage_afterClone(self, item)
-        PortalContent.manage_afterClone(self, item)
-
-    security.declarePrivate('manage_beforeDelete')
-    def manage_beforeDelete(self, item, container):
-        """Both of my parents have a beforeDelete method"""
-        PortalContent.manage_beforeDelete(self, item, container)
-        OFS.Image.Image.manage_beforeDelete(self, item, container)
-
     security.declarePrivate('_isNotEmpty')
     def _isNotEmpty(self, file):
         """ Do various checks on 'file' to try to determine non emptiness. """
@@ -217,9 +176,33 @@ class Image(PortalContent, OFS.Image.Image, DefaultDublinCoreImpl):
         Display the image, with or without standard_html_[header|footer],
         as appropriate.
         """
-        #if REQUEST['PATH_INFO'][-10:] == 'index_html':
-        #    return self.view(self, REQUEST)
-        return OFS.Image.Image.index_html(self, REQUEST, RESPONSE)
+        view = _ViewEmulator().__of__(self)
+
+        # If we have a conditional get, set status 304 and return
+        # no content
+        if _checkConditionalGET(view, extra_context={}):
+            return ''
+
+        # old-style If-Modified-Since header handling.
+        if self._setOldCacheHeaders():
+            # Make sure the CachingPolicyManager gets a go as well
+            _setCacheHeaders(view, extra_context={})
+            return ''
+
+        rendered = OFS.Image.Image.index_html(self, REQUEST, RESPONSE)
+
+        if self.ZCacheable_getManager() is None:
+            # not none cache manager already taken care of
+            _setCacheHeaders(view, extra_context={})
+        else:
+            self.ZCacheable_set(None)
+
+        return rendered
+
+    security.declarePrivate('_setOldCacheHeaders')
+    def _setOldCacheHeaders(self):
+        # return False to disable this simple caching behaviour
+        return _OldCacheHeaders(self)
 
     security.declareProtected(View, 'Format')
     def Format(self):
@@ -239,4 +222,4 @@ class Image(PortalContent, OFS.Image.Image, DefaultDublinCoreImpl):
 
 InitializeClass(Image)
 
-
+ImageFactory = Factory(Image)
