@@ -12,12 +12,20 @@
 ##############################################################################
 """ CMFDefault.interfaces package.
 
-$Id: __init__.py 38590 2005-09-24 15:24:32Z yuppie $
+$Id: __init__.py 71020 2006-11-01 15:42:13Z yuppie $
 """
 
+from zope.publisher.interfaces.browser import IDefaultBrowserLayer
 from _content import *
 from _tools import *
 
+
+class ICMFDefaultSkin(IDefaultBrowserLayer):
+
+    """CMF default skin.
+    """
+
+
 # BBB: will be removed in CMF 2.2
 #      create zope2 interfaces
 from Interface.bridge import createZope3Bridge
