@@ -1,11 +1,13 @@
 ##parameters=member_id, password, member_email, send_password=False, **kw
 ##title=Add a member
 ##
+from Products.CMFCore.utils import getUtilityByInterfaceName
 from Products.CMFCore.utils import getToolByName
 from Products.CMFDefault.permissions import ManageUsers
+from Products.CMFDefault.utils import Message as _
 
 mtool = getToolByName(script, 'portal_membership')
-ptool = getToolByName(script, 'portal_properties')
+ptool = getUtilityByInterfaceName('Products.CMFCore.interfaces.IPropertiesTool')
 rtool = getToolByName(script, 'portal_registration')
 
 try:
@@ -17,8 +19,8 @@ except ValueError, errmsg:
     return context.setStatus(False, errmsg)
 else:
     if ptool.getProperty('validate_email') or send_password:
-        rtool.registeredNotify(member_id)
+        rtool.registeredNotify(member_id, REQUEST=context.REQUEST)
     if mtool.checkPermission(ManageUsers, mtool):
-        return context.setStatus(True, 'Member registered.')
+        return context.setStatus(True, _(u'Member registered.'))
     else:
-        return context.setStatus(False, 'Success!')
+        return context.setStatus(False, _(u'Success!'), is_newmember=True)
