@@ -1,19 +1,3 @@
-##############################################################################
-#
-# CMFDynamicViewFTI
-# Copyright (c) 2005 Plone Foundation. All Rights Reserved.
-#
-# This software is subject to the provisions of the Zope Public License,
-# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
-# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
-# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE.
-#
-# Authors:  Martin Aspeli
-#           Christian Heimes
-#
-##############################################################################
 """Mixin class for selectable views
 
 This module contains a mixin-class to support selecting default layout
@@ -21,16 +5,15 @@ templates and/or default pages (in the style of default_page/index_html).
 The implementation extends TemplateMixin from Archetypes, and implements
 the ISelectableBrowserDefault interface from CMFPlone.
 """
-__author__  = 'Martin Aspeli, Christian Heimes, Sasha Vincic'
-__docformat__ = 'plaintext'
-
 
 from zope.interface import implements
 import zope.component
+
+from zope.app.publisher.interfaces.browser import IBrowserMenu
+
 from ExtensionClass import Base
 from AccessControl import ClassSecurityInfo
 from Globals import InitializeClass
-from Acquisition import aq_parent
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Products.CMFCore.utils import getToolByName
@@ -234,7 +217,11 @@ class BrowserDefaultMixin(Base):
                                                     name=mid)
 
             if view is not None:
-                result.append((mid, mid))
+                menu = zope.component.getUtility(
+                    IBrowserMenu, 'plone_displayviews')
+                item = menu.getMenuItemByAction(self, self.REQUEST, mid)
+                title = item and item.title or mid
+                result.append((mid, title))
             else:
                 method = getattr(self, mid, None)
                 if method is not None:
