@@ -1,21 +1,5 @@
-##############################################################################
-#
-# CMFDynamicViewFTI
-# Copyright (c) 2005 Plone Foundation. All Rights Reserved.
-#
-# This software is subject to the provisions of the Zope Public License,
-# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
-# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
-# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE.
-#
-# Authors:  Martin Aspeli
-#           Christian Heimes
-#
-##############################################################################
-"""
-"""
+# -*- coding: utf-8 -*-
+# $Id: fti.py 48191 2007-08-29 16:08:43Z glenfant $
 
 from zope.interface import implements
 
@@ -30,7 +14,6 @@ from Products.CMFCore.TypesTool import TypesTool
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ManagePortal
 from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _wwwdir
 from Products.CMFCore.utils import getToolByName
 
 from Products.CMFDynamicViewFTI.interface import IDynamicViewTypeInformation
@@ -246,14 +229,14 @@ class DynamicViewTypeInformation(FactoryTypeInformation):
 InitializeClass(DynamicViewTypeInformation)
 
 
-def manage_addFactoryDynamivViewTIForm(self, REQUEST):
-    """ Get the add form for factory-based type infos.
-    """
-    addTIForm = DTMLFile('addTypeInfo', _dtmldir).__of__(self)
-    ttool = getToolByName(self, 'portal_types')
-    return addTIForm( self, REQUEST,
-                      add_meta_type=DynamicViewTypeInformation.meta_type,
-                      types=ttool.listDefaultTypeInformation() )
+#def manage_addFactoryDynamivViewTIForm(self, REQUEST):
+#    """ Get the add form for factory-based type infos.
+#    """
+#    addTIForm = DTMLFile('addTypeInfo', _dtmldir).__of__(self)
+#    ttool = getToolByName(self, 'portal_types')
+#    return addTIForm( self, REQUEST,
+#                      add_meta_type=DynamicViewTypeInformation.meta_type,
+#                      types=ttool.listDefaultTypeInformation() )
 
 
 # BBB: the following lines are required to register the new FTI in CMF 1.5 and may
