@@ -1,31 +1,6 @@
-##############################################################################
-#
-# CMFDynamicViewFTI
-# Copyright (c) 2005 Plone Foundation. All Rights Reserved.
-#
-# This software is subject to the provisions of the Zope Public License,
-# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
-# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
-# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE.
-#
-# Authors:  Martin Aspeli
-#           Christian Heimes
-#
-##############################################################################
-"""
-"""
-
-__author__ = 'Christian Heimes <tiran@cheimes.de>'
-__docformat__ = 'restructuredtext'
-
 from Products.CMFDynamicViewFTI.tests import CMFDVFTITestCase
 
 import zope.component 
-from zope.publisher.interfaces.browser import IBrowserRequest
-from zope.app.publisher.interfaces.browser import IBrowserView        
-import zope.app.publisher.browser
 import zope.publisher.browser
 
 from Products.CMFCore.utils import getToolByName
@@ -33,9 +8,7 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFDynamicViewFTI.interfaces import ISelectableBrowserDefault
 from Products.CMFDynamicViewFTI.interfaces import IBrowserDefault
 from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin
-from Products.CMFDynamicViewFTI.fti import DynamicViewTypeInformation
 
-from Interface.Verify import verifyObject
 from Interface.Verify import verifyClass
 
 class DummyFolder(BrowserDefaultMixin):
@@ -46,7 +19,7 @@ class DummyFolder(BrowserDefaultMixin):
 class IDummy(zope.interface.Interface):
     """ marker interface for a zope 3 view """
 
-class BrowserView(zope.app.publisher.browser.BrowserView):
+class BrowserView(zope.publisher.browser.BrowserView):
 
     def __init__(self, context, request):
         self.context = context
@@ -70,10 +43,12 @@ class TestAvailableLayouts(CMFDVFTITestCase.CMFDVFTITestCase):
         self.dfolder = DummyFolder()
         self.dfolder.fti = self.types['DynFolder']
 
-        zope.component.provideAdapter(
-        BrowserView,
-        (IDummy, IBrowserRequest), IBrowserView,
-        name='zope3_view')              
+        from Products.Five import zcml
+        import plone.app.contentmenu
+        import Products.CMFDynamicViewFTI.tests
+        zcml.load_config('configure.zcml', plone.app.contentmenu)
+        zcml.load_config('browserdefault.zcml', 
+                         Products.CMFDynamicViewFTI.tests)
         
     def test_Zope3View(self):
         dfolder = self.dfolder
@@ -89,6 +64,17 @@ class TestAvailableLayouts(CMFDVFTITestCase.CMFDVFTITestCase):
         view_ids = [ view_id for view_id, foo in view_methods ]
         self.failIf(dfolder.layout not in view_ids)
         
+    def test_Zope3ViewTitle(self):
+        dfolder = self.dfolder
+        dfolder.layout = 'zope3_view'
+        dfolder.REQUEST = zope.publisher.browser.TestRequest()
+        zope.interface.directlyProvides(dfolder, IDummy)
+        view_methods = dfolder.getAvailableLayouts()
+        
+        for id, title in view_methods:
+            if id == dfolder.layout:
+                self.assertEqual(title, 'Zope3 Test View')
+        
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
