@@ -30,10 +30,7 @@ class ControllerState(AccessControl.Role.RoleManager):
     # controller.
     next_action = None
 
-
-    # A dict of variables including such things as portal_status_message.  Again,
-    # each key corresponding to a message should have an i18n friendly value,
-    # e.g. something like (id, default string)
+    # A dict of variables.
     kwargs = {}
 
     # a dict of ids of validators already executed
@@ -170,13 +167,13 @@ class ControllerState(AccessControl.Role.RoleManager):
         # self.context = context
 
     def getKwargs(self):
-        """Get any extra arguments (e.g. portal_status_message) that should be
-        passed along to the next template/script"""
+        """Get any extra arguments that should be passed along to the
+        next template/script"""
         return self.kwargs
 
     def setKwargs(self, kwargs):
-        """Set any extra arguments (e.g. portal_status_message) that should be
-        passed along to the next template/script"""
+        """Set any extra arguments that should be passed along to the
+        next template/script"""
         self.kwargs = kwargs
 
     def getNextAction(self):
@@ -245,7 +242,7 @@ class ControllerState(AccessControl.Role.RoleManager):
     def __str__(self):
         return 'id = %s\nstatus = %s\nbutton=%s\nerrors=%s\ncontext=%s\nkwargs=%s\nnext_action=%s\n' % \
             (self.id, str(self.getStatus()), str(self.getButton()),
-             str(self.getErrors()), str(self.getContext()),
+             str(self.getErrors()), repr(self.getContext()),
              str(self.kwargs), str(self.next_action))
 
 Globals.InitializeClass(ControllerState)
