@@ -1,5 +1,8 @@
 from __future__ import nested_scopes
 import os
+from zope.interface import implements
+
+
 from AccessControl import ClassSecurityInfo
 import Globals
 from OFS.ObjectManager import bad_id
@@ -7,10 +10,13 @@ from StructuredText.StructuredText import HTML
 from ZPublisher.Publish import call_object, missing_name, dont_publish_class
 from ZPublisher.mapply import mapply
 from Products.CMFFormController import GLOBALS as fc_globals
+from Products.CMFCore.utils import registerToolInterface
 from Products.CMFCore.utils import getToolByName, UniqueObject, SimpleItemWithProperties
 from Products.CMFCore.permissions import ManagePortal
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
+
 from Products.CMFFormController.ControllerState import ControllerState
+from Products.CMFFormController.interfaces import IFormControllerTool
 from FormAction import FormActionType, FormActionKey, FormAction, FormActionContainer
 from FormValidator import FormValidatorKey, FormValidator, FormValidatorContainer
 from ValidationError import ValidationError
@@ -31,6 +37,8 @@ class FormController(UniqueObject, SimpleItemWithProperties):
     title = 'Manages form validation and post-validation actions'
     meta_type= 'Form Controller Tool'
 
+    implements(IFormControllerTool)
+
     manage_options = ( ({'label':'Overview', 'action':'manage_overview'},
                         {'label':'Documentation', 'action':'manage_docs'},
                         {'label': 'Validation', 'action': 'manage_formValidatorsForm'},
