@@ -16,9 +16,19 @@
 ## along with this program; see the file COPYING. If not, write to the
 ## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 """
-CMFPlacefulWorflow.interfaces package
+CMFPlacefulWorkflow.interfaces package
 """
-__version__ = "$Revision: 36863 $"
+__version__ = "$Revision: 39673 $"
 # $Source: /cvsroot/ingeniweb/PloneSubscription/SubscriptionTool.py,v $
-# $Id: __init__.py 36863 2007-02-05 21:30:44Z encolpe $
+# $Id: __init__.py 39673 2007-03-24 00:12:36Z encolpe $
 __docformat__ = 'restructuredtext'
+
+from Interface.bridge import createZope3Bridge
+
+from portal_placeful_workflow import IPlacefulWorkflowTool, IWorkflowPolicyDefinition
+
+# Zope 2 interfaces definition
+import PlacefulWorkflow
+import WorkflowPolicyDefinition
+createZope3Bridge(IPlacefulWorkflowTool, PlacefulWorkflow, 'IPlacefulWorkflowTool')
+createZope3Bridge(IWorkflowPolicyDefinition, WorkflowPolicyDefinition, 'IWorkflowPolicyDefinition')
