@@ -18,10 +18,17 @@
 """
 Import patches
 """
-__version__ = "$Revision: 36863 $"
+__version__ = "$Revision: 41400 $"
 # $Source: /cvsroot/ingeniweb/CMFPlacefulWorkflow/patches/__init__.py,v $
-# $Id: __init__.py 36863 2007-02-05 21:30:44Z encolpe $
+# $Id: __init__.py 41400 2007-05-01 15:00:58Z encolpe $
 __docformat__ = 'restructuredtext'
 
-# Make getChainFor method look for placeful workflow configuration
-import workflowtoolPatch
+
+## Patch disabled in CMFPlone with version 3.0
+## Make getChainFor method look for placeful workflow configuration
+try:
+    from Products.CMFPlone.migrations import v3_0
+except ImportError:
+    from Products.CMFPlacefulWorkflow.global_symbols import Log, LOG_NOTICE
+    Log(LOG_NOTICE, "Apply getChainFor monkey patch on WorkflowTool")
+    import workflowtoolPatch
