@@ -10,9 +10,11 @@ class CalendarTool(PloneBaseTool, BaseTool):
     meta_type = ToolNames.CalendarTool
     security = ClassSecurityInfo()
     toolicon = 'skins/plone_images/event_icon.gif'
-    
+
     __implements__ = (PloneBaseTool.__implements__, BaseTool.__implements__, )
 
+    firstweekday = 0 # 0 is Monday
+
     security.declarePublic('getDayNumbers')
     def getDayNumbers(self):
         """ Returns a list of daynumbers with the correct start day first.
@@ -26,7 +28,7 @@ class CalendarTool(PloneBaseTool, BaseTool):
 
         >>> fwday = (calendar.firstweekday()+1) % 7
 
-        >>> ctool = self.portal.portal_calendar
+        >>> ctool = CalendarTool()
 
         >>> ctool.getDayNumbers()[0] == fwday
         True
