@@ -1,20 +1,23 @@
-from Globals import InitializeClass, DTMLFile, DevelopmentMode
+import logging
+import traceback
+import sys
+
+import transaction
+from zope.interface import implements
+
 from AccessControl import ClassSecurityInfo
+from Globals import InitializeClass, DTMLFile, DevelopmentMode
 from OFS.SimpleItem import SimpleItem
 from ZODB.POSException import ConflictError
 
 from Products.CMFCore.utils import UniqueObject, getToolByName
+from Products.CMFCore.utils import registerToolInterface
 from Products.CMFCore.permissions import ManagePortal, View
+from Products.CMFPlone.interfaces import IMigrationTool
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 from Products.CMFPlone.utils import versionTupleFromString
-from Products.CMFPlone.utils import log
-from Products.CMFPlone.utils import log_deprecated
-from Products.CMFPlone.utils import postonly
-import transaction
-
-import logging
-import traceback
-import sys
+from Products.CMFPlone.utils import log, log_deprecated
+from AccessControl.requestmethod import postonly
 
 _upgradePaths = {}
 _widgetRegistry = {}
@@ -22,6 +25,8 @@ _widgetRegistry = {}
 class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
     """Handles migrations between Plone releases"""
 
+    implements(IMigrationTool)
+
     id = 'portal_migration'
     meta_type = 'Plone Migration Tool'
     toolicon = 'skins/plone_images/site_icon.gif'
@@ -32,9 +37,7 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
     _needUpdateRole = 0
 
     manage_options = (
-        { 'label' : 'Overview', 'action' : 'manage_overview' },
-        { 'label' : 'Migrate', 'action' : 'manage_migrate' },
-        { 'label' : 'Setup', 'action' : 'manage_setup' },
+        { 'label' : 'Upgrade', 'action' : 'manage_migrate' },
         )
 
     security = ClassSecurityInfo()
@@ -42,12 +45,10 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
     security.declareProtected(ManagePortal, 'manage_overview')
     security.declareProtected(ManagePortal, 'manage_results')
     security.declareProtected(ManagePortal, 'manage_migrate')
-    security.declareProtected(ManagePortal, 'manage_setup')
 
     manage_migrate = DTMLFile('www/migrationRun', globals())
     manage_overview = DTMLFile('www/migrationTool', globals())
     manage_results = DTMLFile('www/migrationResults', globals())
-    manage_setup = DTMLFile('www/migrationSetup', globals())
 
     # Add a visual note
     def om_icons(self):
@@ -79,15 +80,6 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
             self.setInstanceVersion(self.getFileSystemVersion())
         return self._version.lower()
 
-    security.declarePublic('isPloneOne')
-    def isPloneOne(self):
-        """ is this still a plone 1 instance? Needed for require login"""
-        log_deprecated("isPloneOne is deprecated and will be removed in "
-                       "Plone 3.0.")
-        ver = self.getInstanceVersion().strip()
-        if ver.startswith('1'):
-            return 1
-
     security.declareProtected(ManagePortal, 'setInstanceVersion')
     def setInstanceVersion(self, version):
         """ The version this instance of plone is on """
@@ -95,8 +87,19 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
 
     security.declareProtected(ManagePortal, 'knownVersions')
     def knownVersions(self):
-        """ All known version ids, except current one """
-        return _upgradePaths.keys()
+        """All known version ids, except current one and unsupported
+           migration paths.
+        """
+        versions = [k for k in _upgradePaths if _upgradePaths[k][1] != False]
+        return versions
+
+    security.declareProtected(ManagePortal, 'unsupportedVersion')
+    def unsupportedVersion(self):
+        """Is the current instance version known to be a no longer supported
+           version for migrations.
+        """
+        versions = [k for k in _upgradePaths if _upgradePaths[k][1] is False]
+        return self._version in versions
 
     security.declareProtected(ManagePortal, 'getFileSystemVersion')
     def getFileSystemVersion(self):
@@ -131,7 +134,6 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
         vars['Plone Instance'] = self.getInstanceVersion()
         vars['Plone File System'] = self.getFileSystemVersion()
         vars['CMF'] = cp.Products.CMFCore.version
-        vars['Five'] = cp.Products.Five.version
         vars['Debug mode'] = DevelopmentMode and 'Yes' or 'No'
         try:
             from PIL.Image import VERSION
@@ -185,106 +187,6 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
             VERSION = None
         return VERSION
 
-    ##############################################################
-    # the setup widget registry
-    # this is a whole bunch of wrappers
-    # Really an unprotected sub object
-    # declaration could do this...
-
-    def _getWidget(self, widget):
-        """ We cant instantiate widgets at run time
-        but can send all get calls through here... """
-        log_deprecated("_getWidget is deprecated and will be removed in "
-                       "Plone 3.0.")
-        _widget = _widgetRegistry[widget]
-        obj = getToolByName(self, 'portal_url').getPortalObject()
-        return _widget(obj)
-
-    security.declareProtected(ManagePortal, 'listWidgets')
-    def listWidgets(self):
-        """ List all the widgets """
-        log_deprecated("listWidgets is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return _widgetRegistry.keys()
-
-    security.declareProtected(ManagePortal, 'getDescription')
-    def getDescription(self, widget):
-        """ List all the widgets """
-        log_deprecated("getDescription is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).description
-
-    security.declareProtected(ManagePortal, 'listAvailable')
-    def listAvailable(self, widget):
-        """  List all the Available things """
-        log_deprecated("listAvailable is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).available()
-
-    security.declareProtected(ManagePortal, 'listInstalled')
-    def listInstalled(self, widget):
-        """  List all the installed things """
-        log_deprecated("listInstalled is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).installed()
-
-    security.declareProtected(ManagePortal, 'listNotInstalled')
-    def listNotInstalled(self, widget):
-        """ List all the not installed things """
-        log_deprecated("listNotInstalled is deprecated and will be removed in "
-                       "Plone 3.0.")
-        avail = self.listAvailable(widget)
-        install = self.listInstalled(widget)
-        return [ item for item in avail if item not in install ]
-
-    security.declareProtected(ManagePortal, 'activeWidget')
-    def activeWidget(self, widget):
-        """ Show the state """
-        log_deprecated("activeWidget is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).active()
-
-    security.declareProtected(ManagePortal, 'setupWidget')
-    def setupWidget(self, widget):
-        """ Show the state """
-        log_deprecated("setupWidget is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).setup()
-
-    security.declareProtected(ManagePortal, 'alterItems')
-    def alterItems(self, widget=None, items=[]):
-        """ Figure out which items to install and which to uninstall """
-        log_deprecated("alterItems is deprecated and will be removed in "
-                       "Plone 3.0.")
-        installed = self.listInstalled(widget)
-
-        toAdd = [ item for item in items if item not in installed ]
-        toDel = [ install for install in installed if install not in items ]
-
-        out = []
-        if toAdd: out += self.installItems(widget, toAdd)
-        if toDel: out += self.uninstallItems(widget, toDel)
-        try:
-            return self.manage_results(self, out=out)
-        except NameError:
-            pass
-
-    security.declareProtected(ManagePortal, 'installItems')
-    def installItems(self, widget, items):
-        """ Install the items """
-        log_deprecated("installItems is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).addItems(items)
-
-    security.declareProtected(ManagePortal, 'uninstallItems')
-    def uninstallItems(self, widget, items):
-        """ Uninstall the items """
-        log_deprecated("unInstallItems is deprecated and will be removed in "
-                       "Plone 3.0.")
-        return self._getWidget(widget).delItems(items)
-
-    ##############################################################
-
     security.declareProtected(ManagePortal, 'upgrade')
     def upgrade(self, REQUEST=None, dry_run=None, swallow_errors=1):
         """ perform the upgrade """
@@ -366,7 +268,8 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
             except:
                 out.append(("Exception was thrown while cataloging",
                             logging.ERROR))
-                out += traceback.format_tb(sys.exc_traceback)
+                for line in traceback.format_tb(sys.exc_traceback):
+                    out.append((line, logging.ERROR))
                 if not swallow_errors:
                     for msg, sev in out: log(msg, severity=sev)
                     raise
@@ -380,7 +283,8 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
             except:
                 out.append((("Exception was thrown while updating "
                              "role mappings"), logging.ERROR))
-                out += traceback.format_tb(sys.exc_traceback)
+                for line in traceback.format_tb(sys.exc_traceback):
+                    out.append((line, logging.ERROR))
                 if not swallow_errors:
                     for msg, sev in out: log(msg, severity=sev)
                     raise
@@ -408,9 +312,12 @@ class MigrationTool(PloneBaseTool, UniqueObject, SimpleItem):
     def _upgrade(self, version):
         version = version.lower()
         if not _upgradePaths.has_key(version):
-            return None, ("Migration completed at version %s" % version,)
+            return None, ("Migration completed at version %s." % version,)
 
         newversion, function = _upgradePaths[version]
+        # This means a now unsupported migration path has been triggered
+        if function is False:
+            return None, ("Migration stopped at version %s." % version,)
         res = function(self.aq_parent)
         return newversion, res
 
@@ -418,10 +325,5 @@ def registerUpgradePath(oldversion, newversion, function):
     """ Basic register func """
     _upgradePaths[oldversion.lower()] = [newversion.lower(), function]
 
-def registerSetupWidget(widget):
-    """ Basic register things """
-    log_deprecated("registerSetupWidget is deprecated and will be removed in "
-                   "Plone 3.0.")
-    _widgetRegistry[widget.type] = widget
-
 InitializeClass(MigrationTool)
+registerToolInterface('portal_migration', IMigrationTool)
