@@ -24,21 +24,12 @@ from Products.CMFCore.permissions import AccessContentsInformation, \
                     ManageProperties, ModifyPortalContent, View
 from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
 
-from Products.CMFPlone import PloneMessageFactory as _
-
 from zope.interface import implements
 from zope.app.container.contained import notifyContainerModified
 
 # ATM it's safer to define our own
 from interfaces.OrderedContainer import IOrderedContainer
-
-# This import can change in Zope 2.7
-try:
-    from OFS.IOrderSupport import IOrderedContainer as IZopeOrderedContainer
-    hasZopeOrderedSupport = 1
-except ImportError:
-    hasZopeOrderedSupport = 0
-
+from OFS.IOrderSupport import IOrderedContainer as IZopeOrderedContainer
 
 class ReplaceableWrapper:
     """A wrapper around an object to make it replaceable."""
@@ -50,49 +41,6 @@ class ReplaceableWrapper:
             return REPLACEABLE
         return getattr(self.__ob, name)
 
-factory_type_information = {
-    'id': 'Folder',
-    'meta_type': 'Plone Folder',
-    'description': (_(u"Plone folders can define custom 'view' actions, or will "
-                    "behave like directory listings without one defined.")),
-    'icon': 'folder_icon.gif',
-    'product': 'CMFPlone',
-    'factory': 'addPloneFolder',
-    'filter_content_types': 0,
-    'immediate_view': 'folder_listing',
-    'actions': (
-        {
-            'id': 'view',
-            'name': _(u'View'),
-            'action': 'string:${folder_url}/',
-            'permissions': (View,),
-            'category': 'folder',
-        },
-        {
-            'id': 'local_roles',
-            'name': _(u'Local Roles'),
-            'action': 'string:${folder_url}/folder_localrole_form',
-            'permissions': (ManageProperties,),
-            'category': 'folder',
-        },
-        {
-            'id': 'edit',
-            'name': _(u'Edit'),
-            'action': 'string:${folder_url}/folder_edit_form',
-            'permissions': (ModifyPortalContent,),
-            'category': 'folder',
-        },
-        {
-            'id': 'folderlisting',
-            'name': _(u'Folder Listing'),
-            'action': 'string:${folder_url}/folder_listing',
-            'permissions': (View,),
-            'category': 'folder',
-            'visible': 0,
-        },
-    )
-}
-
 # Portions of this class was copy/pasted from the OFS.Folder.OrderedFolder
 # from Zope2.7.  This class is licensed under the ZPL 2.0 as stated here:
 # http://www.zope.org/Resources/ZPL
@@ -103,12 +51,7 @@ factory_type_information = {
 class OrderedContainer(Folder):
     """Folder with subobject ordering support."""
 
-    if hasZopeOrderedSupport:
-        # Got the IOrderedContainer interface from Zope 2.7 too,
-        # make sure this implementation fullfills both interfaces
-        __implements__ = (IOrderedContainer, IZopeOrderedContainer)
-    else:
-        __implements__ = (IOrderedContainer,)
+    __implements__ = (IOrderedContainer, IZopeOrderedContainer)
 
     security = ClassSecurityInfo()
 
@@ -187,7 +130,7 @@ class OrderedContainer(Folder):
     def getCMFObjectsSubsetIds(self, objs):
         """Get the ids of only cmf objects (used for moveObjectsByDelta)."""
         ttool = getToolByName(self, 'portal_types')
-        cmf_meta_types = ttool.listContentTypes(by_metatype=1)
+        cmf_meta_types = [ti.Metatype() for ti in ttool.listTypeInfo()]
         return [obj['id'] for obj in objs if obj['meta_type'] in cmf_meta_types]
 
     security.declareProtected(ModifyPortalContent, 'getObjectPosition')
@@ -333,8 +276,7 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
         self._setObject(id, ob)
         if REQUEST is not None:
             # TODO HARDCODED FIXME!
-            return self.folder_contents(self, REQUEST,
-                                        portal_status_message=_(u'Folder added.'))
+            return self.folder_contents(self, REQUEST)
 
     manage_addFolder = manage_addPloneFolder
     manage_renameObject = PortalFolderBase.manage_renameObject
@@ -358,9 +300,9 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
         return getToolByName(self, 'plone_utils').browserDefault(self)
 
     security.declarePublic('contentValues')
-    def contentValues(self, spec=None, filter=None, sort_on=None, reverse=0):
+    def contentValues(self, filter=None, sort_on=None, reverse=0):
         """Able to sort on field."""
-        values = PortalFolderBase.contentValues(self, spec=spec, filter=filter)
+        values = PortalFolderBase.contentValues(self, filter=filter)
         if sort_on is not None:
             values.sort(lambda x, y,
                         sort_on=sort_on: safe_cmp(getattr(x,sort_on),
@@ -371,12 +313,12 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
         return values
 
     security.declareProtected(ListFolderContents, 'listFolderContents')
-    def listFolderContents(self, spec=None, contentFilter=None,
+    def listFolderContents(self, contentFilter=None,
                            suppressHiddenFiles=0):
         """Optionally you can suppress "hidden" files, or files that
         begin with .
         """
-        contents = PortalFolderBase.listFolderContents(self, spec=spec,
+        contents = PortalFolderBase.listFolderContents(self,
                                                   contentFilter=contentFilter)
         if suppressHiddenFiles:
             contents = [obj for obj in contents if obj.getId()[:1]!='.']
@@ -384,13 +326,13 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
 
     security.declareProtected(AccessContentsInformation,
                               'folderlistingFolderContents')
-    def folderlistingFolderContents(self, spec=None, contentFilter=None,
+    def folderlistingFolderContents(self, contentFilter=None,
                                     suppressHiddenFiles=0):
         """Calls listFolderContents in protected only by ACI so that
         folder_listing can work without the List folder contents permission,
         as in CMFDefault.
         """
-        return self.listFolderContents(spec, contentFilter, suppressHiddenFiles)
+        return self.listFolderContents(contentFilter, suppressHiddenFiles)
 
     # Override CMFCore's invokeFactory to return the id returned by the
     # factory in case the factory modifies the id
