@@ -2,15 +2,19 @@ import re
 import sys
 from types import UnicodeType, StringType
 import urlparse
-
-from Products.CMFPlone.utils import log
-from Products.CMFPlone.utils import log_exc
 import transaction
-from Products.CMFPlone import utils
 
+from zope.deprecation import deprecate
+from zope.interface import implements
+
+from AccessControl import ClassSecurityInfo, Unauthorized
 from Acquisition import aq_base, aq_inner, aq_parent
-
 from ComputedAttribute import ComputedAttribute
+from DateTime import DateTime
+from Globals import InitializeClass
+from OFS.SimpleItem import SimpleItem
+from OFS.ObjectManager import bad_id
+from ZODB.POSException import ConflictError
 
 from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import getToolByName
@@ -21,42 +25,33 @@ from Products.CMFCore.interfaces.DublinCore import DublinCore, MutableDublinCore
 from Products.CMFCore.interfaces.Discussions import Discussable
 from Products.CMFCore.WorkflowCore import WorkflowException
 from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
+from Products.CMFPlone.interfaces import IPloneTool
 from Products.CMFPlone.interfaces.Translatable import ITranslatable
 from Products.CMFPlone.interfaces import INonStructuralFolder
+from Products.CMFPlone.PloneBaseTool import PloneBaseTool
+from Products.CMFPlone.PloneFolder import ReplaceableWrapper
 from Products.CMFPlone import ToolNames
+from Products.CMFPlone import utils
+from Products.CMFPlone.utils import log
+from Products.CMFPlone.utils import log_exc
 from Products.CMFPlone.utils import transaction_note
 from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import safe_hasattr
-from Products.CMFPlone.utils import postonly
 from Products.CMFPlone.interfaces import IBrowserDefault
-
-from OFS.SimpleItem import SimpleItem
-from OFS.ObjectManager import bad_id
-from Globals import InitializeClass
-from AccessControl import ClassSecurityInfo, Unauthorized
-from ZODB.POSException import ConflictError
-from Products.CMFPlone.PloneBaseTool import PloneBaseTool
-from DateTime import DateTime
-DateTime.SyntaxError
-from Products.CMFPlone.PloneFolder import ReplaceableWrapper
-
 from Products.statusmessages.interfaces import IStatusMessage
+from AccessControl.requestmethod import postonly
+from plone.app.linkintegrity.exceptions import LinkIntegrityNotificationException
 
 AllowSendto = 'Allow sendto'
-permissions.setDefaultRoles(AllowSendto,
-                                   ('Anonymous', 'Manager',))
+permissions.setDefaultRoles(AllowSendto, ('Anonymous', 'Manager',))
 
 _marker = utils._marker
 _icons = {}
 
 CEILING_DATE = DefaultDublinCoreImpl._DefaultDublinCoreImpl__CEILING_DATE
 FLOOR_DATE = DefaultDublinCoreImpl._DefaultDublinCoreImpl__FLOOR_DATE
-
-from Products.SecureMailHost.SecureMailHost import EMAIL_RE
-from Products.SecureMailHost.SecureMailHost import EMAIL_CUTOFF_RE
 BAD_CHARS = re.compile(r'[^a-zA-Z0-9-_~,.$\(\)# ]').findall
 
-
 # XXX Remove this when we don't depend on python2.1 any longer,
 # use email.Utils.getaddresses instead
 from rfc822 import AddressList
@@ -96,16 +91,18 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     # Prefix for forms fields!?
     field_prefix = 'field_'
 
+    implements(IPloneTool)
+
     __implements__ = (PloneBaseTool.__implements__,
                       SimpleItem.__implements__, )
 
     security.declareProtected(ManageUsers, 'setMemberProperties')
     def setMemberProperties(self, member, **properties):
-        membership = getToolByName(self, 'portal_membership')
+        pas = getToolByName(self, 'acl_users')
         if safe_hasattr(member, 'getId'):
             member = member.getId()
-        user = membership.getMemberById(member)
-        user.setMemberProperties(properties)
+        user = pas.getUserById(member)
+        user.setProperties(**properties)
 
     security.declarePublic('getSiteEncoding')
     def getSiteEncoding(self):
@@ -161,7 +158,8 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         """Sends a link of a page to someone."""
         host = self.getMailHost()
         template = getattr(self, 'sendto_template')
-        encoding = self.getSiteEncoding()
+        portal = getToolByName(self, 'portal_url').getPortalObject()
+        encoding = portal.getProperty('email_charset')
         if 'envelope_from' in kwargs:
             envelope_from = kwargs['envelope_from']
         else:
@@ -380,8 +378,8 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         >>> ptool = self.portal.plone_utils
 
-        >>> ptool.getReviewStateTitleFor(self.folder)
-        'Public Draft'
+        >>> ptool.getReviewStateTitleFor(self.folder).lower()
+        'public draft'
         """
         wf_tool = getToolByName(self, 'portal_workflow')
         wfs = ()
@@ -414,27 +412,23 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
                 thread = [discussionContainer]
         return thread
 
-    # Convenience method since skinstool requires loads of acrobatics.
-    # We use this for the reconfig form
     security.declareProtected(ManagePortal, 'setDefaultSkin')
+    @deprecate("The setDefaultSkin method of the Plone tool has been "
+               "deprecated and will be removed in Plone 3.5.")
     def setDefaultSkin(self, default_skin):
         """Sets the default skin."""
         st = getToolByName(self, 'portal_skins')
         st.default_skin = default_skin
 
-    # Set the skin on the page to the specified value
-    # Can be called from a page template, but it must be called before
-    # anything anything on the skin path is resolved (e.g. main_template).
-    # TODO Note: This method will eventually be replaced by the setCurrentSkin
-    # method that is slated for CMF 1.4
     security.declarePublic('setCurrentSkin')
+    @deprecate("The setCurrentSkin method of the Plone tool has been "
+               "deprecated and will be removed in Plone 3.5.")
     def setCurrentSkin(self, skin_name):
         """Sets the current skin."""
         portal = getToolByName(self, 'portal_url').getPortalObject()
         portal.changeSkin(skin_name)
 
-    security.declareProtected(ManagePortal,
-                              'changeOwnershipOf')
+    security.declareProtected(ManagePortal, 'changeOwnershipOf')
     def changeOwnershipOf(self, object, userid, recursive=0, REQUEST=None):
         """Changes the ownership of an object."""
         membership = getToolByName(self, 'portal_membership')
@@ -548,28 +542,6 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
             request = self.REQUEST
         return utils.createNavTree(context, request)
 
-    security.declarePublic('createTopLevelTabs')
-    def createTopLevelTabs(self, actions=None, context=None, request=None,
-                           category='portal_tabs'):
-        """Returns a structure for the top level tabs.
-        """
-
-        if context is None:
-            context = self
-
-        if request is None and hasattr(context, 'REQUEST'):
-            request = context.REQUEST
-        
-        # XXX This method needs to eventually go away
-
-        utils.log_deprecated("plone_utils.createTopLevelTabs is deprecated and "
-                             "will be removed in plone 3.5, please use the "
-                             "topLevelTabs method of the INavigationTabs view "
-                             "instead.")
-
-        return utils.createTopLevelTabs(context, request, actions=actions,
-                                        category=category)
-
     security.declarePublic('createBreadCrumbs')
     def createBreadCrumbs(self, context, request=None):
         """Returns a structure for the portal breadcumbs.
@@ -652,11 +624,6 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         Only considers explicitly contained objects, either set as index_html,
         with the default_page property, or using IBrowserDefault.
         """
-        #XXX: Does this deserve deprecation?
-        # utils.log_deprecated("plone_utils.isDefaultPage is deprecated and "
-        #                      "will be removed in plone 3.5, please use the "
-        #                      "isDefaultPage method of the IDefaultPage view "
-        #                      "on the container.")
         if request is None:
             request = self.REQUEST
         return utils.isDefaultPage(obj, request, context=self)
@@ -679,11 +646,6 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         and if found, its id is returned. If no default page is set, None is
         returned. If a non-folderish item is passed in, return None always.
         """
-        #XXX: Does this deserve deprecation?
-        # utils.log_deprecated("plone_utils.getDefaultPage is deprecated and "
-        #                      "will be removed in plone 3.5, please use the "
-        #                      "getDefaultPage method of the IDefaultPage view "
-        #                      "on the container.")
         if request is None:
             request = self.REQUEST
         return utils.getDefaultPage(obj, request, context=self)
@@ -698,7 +660,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         >>> ptool = self.portal.plone_utils
 
-        >>> ptool.addPortalMessage(u'A random warning message', 'warn')
+        >>> ptool.addPortalMessage(u'A random warning message', 'warning')
 
         If no type is given it defaults to 'info'
         >>> ptool.addPortalMessage(u'A random info message')
@@ -710,8 +672,8 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
                        the message will be rendered, as it is used to select
                        the CSS class for the message. Predefined types are:
                        'info' - for informational messages
-                       'warn' - for warning messages
-                       'stop' - for messages about restricted access or errors.
+                       'warning' - for warning messages
+                       'error' - for messages about restricted access or errors.
 
         Portal messages are by default rendered by the global_statusmessage.pt
         page template.
@@ -950,10 +912,15 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         mt = getToolByName(self, 'portal_membership')
         if not mt.checkPermission(ModifyPortalContent, obj):
             raise Unauthorized
-        # Set local role status
-        gruf = getToolByName(self, 'portal_url').getPortalObject().acl_users
-        # We perform our own security check
-        gruf._acquireLocalRoles(obj, status)
+
+        # Set local role status...
+        # set the variable (or unset it if it's defined)
+        if not status:
+            obj.__ac_local_roles_block__ = 1
+        else:
+            if getattr(obj, '__ac_local_roles_block__', None):
+                obj.__ac_local_roles_block__ = None
+
         # Reindex the whole stuff.
         obj.reindexObjectSecurity()
     acquireLocalRoles = postonly(acquireLocalRoles)
@@ -963,10 +930,10 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         """Returns local role acquisition blocking status.
 
         True if normal, false if blocked.
-        GRUF IS REQUIRED FOR THIS TO WORK.
         """
-        gruf = getToolByName(self, 'portal_url').getPortalObject().acl_users
-        return gruf.isLocalRoleAcquired(obj)
+        if getattr(obj, '__ac_local_roles_block__', None):
+            return False
+        return True
 
     security.declarePublic('getOwnerName')
     def getOwnerName(self, obj):
@@ -981,7 +948,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         mt = getToolByName(self, 'portal_membership')
         if not mt.checkPermission(View, obj):
             raise Unauthorized
-        return obj.getOwner().getUserName()
+        return obj.getOwner().getId()
 
     security.declarePublic('normalizeString')
     def normalizeString(self, text, relaxed=False):
@@ -1025,7 +992,6 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         >>> ptool.normalizeString(" a string    ")
         'a-string'
-
         >>> ptool.normalizeString(">here's another!")
         'heres-another'
 
@@ -1230,4 +1196,118 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         else:
             return None
 
+    # This is public because we don't know what permissions the user
+    # has on the objects to be deleted.  The restrictedTraverse and
+    # manage_delObjects calls should handle permission checks for us.
+    security.declarePublic('deleteObjectsByPaths')
+    def deleteObjectsByPaths(self, paths, handle_errors=True, REQUEST=None):
+        failure = {}
+        success = []
+        # use the portal for traversal in case we have relative paths
+        portal = getToolByName(self, 'portal_url').getPortalObject()
+        traverse = portal.restrictedTraverse
+        for path in paths:
+            # Skip and note any errors
+            if handle_errors:
+                sp = transaction.savepoint(optimistic=True)
+            try:
+                obj = traverse(path)
+                obj_parent = aq_parent(aq_inner(obj))
+                obj_parent.manage_delObjects([obj.getId()])
+                success.append('%s (%s)' % (obj.title_or_id(), path))
+            except ConflictError:
+                raise
+            except LinkIntegrityNotificationException:
+                raise
+            except Exception, e:
+                if handle_errors:
+                    sp.rollback()
+                    failure[path]= e
+                else:
+                    raise
+        transaction_note('Deleted %s' % (', '.join(success)))
+        return success, failure
+    deleteObjectsByPaths = postonly(deleteObjectsByPaths)
+
+    security.declarePublic('transitionObjectsByPaths')
+    def transitionObjectsByPaths(self, workflow_action, paths, comment='',
+                                 expiration_date=None, effective_date=None,
+                                 include_children=False, handle_errors=True,
+                                 REQUEST=None):
+        failure = {}
+        # use the portal for traversal in case we have relative paths
+        portal = getToolByName(self, 'portal_url').getPortalObject()
+        traverse = portal.restrictedTraverse
+        for path in paths:
+            if handle_errors:
+                sp = transaction.savepoint(optimistic=True)
+            try:
+                o = traverse(path, None)
+                if o is not None:
+                    o.content_status_modify(workflow_action,
+                                            comment,
+                                            effective_date=effective_date,
+                                            expiration_date=expiration_date)
+            except ConflictError:
+                raise
+            except Exception, e:
+                if handle_errors:
+                    # skip this object but continue with sub-objects.
+                    sp.rollback()
+                    failure[path]= e
+                else:
+                    raise
+            if getattr(o, 'isPrincipiaFolderish', None) and include_children:
+                subobject_paths = ["%s/%s" % (path, id) for id in o.objectIds()]
+                self.transitionObjectsByPaths(workflow_action, subobject_paths,
+                                              comment, expiration_date,
+                                              effective_date, include_children,
+                                              handle_errors)
+        return failure
+    transitionObjectsByPaths = postonly(transitionObjectsByPaths)
+
+    security.declarePublic('renameObjectsByPaths')
+    def renameObjectsByPaths(self, paths, new_ids, new_titles,
+                             handle_errors=True, REQUEST=None):
+        failure = {}
+        success = {}
+        # use the portal for traversal in case we have relative paths
+        portal = getToolByName(self, 'portal_url').getPortalObject()
+        traverse = portal.restrictedTraverse
+        for i, path in enumerate(paths):
+            new_id = new_ids[i]
+            new_title = new_titles[i]
+            if handle_errors:
+                sp = transaction.savepoint(optimistic=True)
+            try:
+                obj = traverse(path, None)
+                obid = obj.getId()
+                title = obj.Title()
+                change_title = new_title and title != new_title
+                changed = False
+                if change_title:
+                    obj.setTitle(new_title)
+                    changed = True
+                if new_id and obid != new_id:
+                    parent = aq_parent(aq_inner(obj))
+                    parent.manage_renameObjects((obid,), (new_id,))
+                    changed = True
+                elif change_title:
+                    # the rename will have already triggered a reindex
+                    obj.reindexObject()
+                if changed:
+                    success[path]=(new_id,new_title)
+            except ConflictError:
+                raise
+            except Exception, e:
+                if handle_errors:
+                    # skip this object but continue with sub-objects.
+                    sp.rollback()
+                    failure[path]= e
+                else:
+                    raise
+        transaction_note('Renamed %s' % str(success.keys))
+        return success, failure
+    renameObjectsByPaths = postonly(renameObjectsByPaths)
+
 InitializeClass(PloneTool)
