@@ -28,6 +28,7 @@
 ## NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 ## SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+from utils import classImplements
 from Products.ZCTextIndex.ISplitter import ISplitter
 from Products.ZCTextIndex.PipelineFactory import element_factory
 
@@ -35,7 +36,7 @@ import re
 enc = 'utf-8'
 
 class Splitter:
-    
+
     __implements__ = ISplitter
 
     rx_L = re.compile(r"\w+", re.LOCALE)
@@ -75,6 +76,9 @@ class Splitter:
                 words = self.rxGlob_U.findall(s)
                 result += [w.encode(enc) for w in words]
         return result
+
+classImplements(Splitter, Splitter.__implements__)
+
 try:
     element_factory.registerFactory('Word Splitter',
         'Unicode Whitespace splitter', Splitter)
