@@ -1,8 +1,11 @@
+from Products.CMFCore.interfaces import IConfigurableWorkflowTool
+
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.WorkflowTool import WorkflowTool as BaseTool
 from Products.CMFPlone import ToolNames
+from Products.CMFPlone.utils import base_hasattr
 from ZODB.POSException import ConflictError
-from Acquisition import aq_base
+from Acquisition import aq_base, aq_parent, aq_inner
 
 from Globals import InitializeClass
 from AccessControl import getSecurityManager, ClassSecurityInfo
@@ -10,6 +13,11 @@ from Products.CMFCore.permissions import ManagePortal
 from Products.DCWorkflow.Transitions import TRIGGER_USER_ACTION
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 
+try:
+    from Products.CMFPlacefulWorkflow.PlacefulWorkflowTool import WorkflowPolicyConfig_id
+except:
+    WorkflowPolicyConfig_id = '.wf_policy_config'
+
 class WorkflowTool(PloneBaseTool, BaseTool):
 
     meta_type = ToolNames.WorkflowTool
@@ -244,6 +252,88 @@ class WorkflowTool(PloneBaseTool, BaseTool):
                 # Return the default chain.
                 return self._default_chain
 
+    security.declarePrivate('getChainFor')
+    def getChainFor(self, ob):
+        """ Get the chain that applies to the given object.
+
+        Goal: find a workflow chain in a policy
+
+        Steps:
+        1. ask the object if it contains a policy
+        2. if it does, ask him for a chain
+        3. if there's no chain for the type the we loop on the parent
+        4. if the parent is the portal object or None we stop and we ask to portal_workflow
+
+        Hint:
+        If ob was a string, ask directly portal_worlfow\n\n
+        """
+
+        cbt = self._chains_by_type
+        chain = None
+
+        if type(ob) == type(''):
+            # We are not in an object, then we can only get default from portal_workflow
+            portal_type = ob
+            if cbt is not None:
+                chain = cbt.get(portal_type, None)
+                # Note that if chain is not in cbt or has a value of None, we use a default chain.
+            if chain is None:
+                chain = self.getDefaultChainFor(ob)
+                if chain is None:
+                    # CMFCore default
+                    return ()
+
+        elif hasattr(aq_base(ob), '_getPortalTypeName'):
+            portal_type = ob._getPortalTypeName()
+        else:
+            portal_type = None
+
+        if portal_type is None or ob is None:
+            return ()
+
+        # Take some extra care when ob is a string
+        is_policy_container = False
+        objectids = []
+        try:
+            objectids = ob.objectIds()
+        except AttributeError, TypeError:
+            pass
+        if WorkflowPolicyConfig_id in objectids:
+            is_policy_container = True
+
+        # Inspired by implementation in CPSWorkflowTool.py of CPSCore 3.9.0
+        # Workflow needs to be determined by true containment not context
+        # so we loop over the actual containers
+        chain = None
+        wfpolicyconfig = None
+        current_ob = aq_inner(ob)
+        # start_here is used to check 'In policy': We check it only in the first folder
+        start_here = True
+        portal = aq_base(getToolByName(self, 'portal_url').getPortalObject())
+        while chain is None and current_ob is not None:
+            if base_hasattr(current_ob, WorkflowPolicyConfig_id):
+                wfpolicyconfig = getattr(current_ob, WorkflowPolicyConfig_id)
+                chain = wfpolicyconfig.getPlacefulChainFor(portal_type, start_here=start_here)
+                if chain is not None:
+                    return chain
+
+            elif aq_base(current_ob) is portal:
+                break
+            start_here = False
+            current_ob = aq_inner(aq_parent(current_ob))
+
+        # Note that if chain is not in cbt or has a value of None, we use a default chain.
+        if cbt is not None:
+            chain = cbt.get(portal_type, None)
+            # Note that if chain is not in cbt or has a value of
+            # None, we use a default chain.
+        if chain is None:
+            chain = self.getDefaultChainFor(ob)
+            if chain is None:
+                # CMFCore default
+                return ()
+
+        return chain
 
     security.declareProtected(ManagePortal, 'listWorkflows')
     def listWorkflows(self):
@@ -251,47 +341,6 @@ class WorkflowTool(PloneBaseTool, BaseTool):
         """
         return self.objectIds()
 
-#    security.declarePrivate('listActions')
-#    def listActions(self, info):
-#
-#        """ Returns a list of actions to be displayed to the user.
-#
-#        o Invoked by the portal_actions tool.
-#
-#        o Allows workflows to include actions to be displayed in the
-#          actions box.
-#
-#        o Object actions are supplied by workflows that apply to the object.
-#
-#        o Global actions are supplied by all workflows.
-#        """
-#        show_globals = False
-#        chain = self.getChainFor(info.content)
-#        did = {}
-#        actions = []
-#        for wf_id in chain:
-#            did[wf_id] = 1
-#            wf = self.getWorkflowById(wf_id)
-#            if wf is not None:
-#                a = wf.listObjectActions(info)
-#                if a is not None:
-#                    actions.extend(a)
-#                if show_globals:
-#                    a = wf.listGlobalActions(info)
-#                    if a is not None:
-#                        actions.extend(a)
-#
-#        if show_globals:
-#            wf_ids = self.getWorkflowIds()
-#            for wf_id in wf_ids:
-#                if not did.has_key(wf_id):
-#                    wf = self.getWorkflowById(wf_id)
-#                    if wf is not None:
-#                        a = wf.listGlobalActions(info)
-#                        if a is not None:
-#                            actions.extend(a)
-#        return actions
-
     security.declarePublic('getTitleForStateOnType')
     def getTitleForStateOnType(self, state_name, p_type):
         """Returns the workflow state title for a given state name,
