@@ -2,24 +2,17 @@ import sys
 import os
 import Globals
 
-from Products.GenericSetup import BASE
-from Products.GenericSetup import profile_registry
-
-import bbb
-
 cmfplone_globals = globals()
 this_module = sys.modules[ __name__ ]
 _marker = []
 
-# Stores the available 'Customization Policies'
-custom_policies = {}
-
 ADD_CONTENT_PERMISSION = 'Add portal content'
 
 misc_ = {'plone_icon': Globals.ImageFile(
                        os.path.join('skins', 'plone_images', 'logoIcon.gif'),
                        cmfplone_globals)}
 
+
 def initialize(context):
 
     # Stuff has been moved from module level to this method for a
@@ -31,24 +24,22 @@ def initialize(context):
     from AccessControl import ModuleSecurityInfo
     from AccessControl import allow_module, allow_class
 
-    # zLOG is deprecated in Zope > 2.7.0, use logger instead
+    # allow logging
     ModuleSecurityInfo('logging').declarePublic('getLogger')
     from logging import Logger
     allow_class(Logger)
 
-    # BBB: Deprecated do not use, will be removed in Plone 3.0
-    ModuleSecurityInfo('zLOG').declarePublic('LOG')
-    ModuleSecurityInfo('zLOG').declarePublic('INFO')
-    ModuleSecurityInfo('zLOG').declarePublic('WARNING')
+    # Register kss extension to allow it used from fs skins
+    from Products.CMFCore.DirectoryView import registerFileExtension
+    from Products.CMFCore.FSFile import FSFile
+    registerFileExtension('kss', FSFile)
 
+    # various small utils functions
     # added for unescaping view names in urls when finding selected action
     ModuleSecurityInfo('urllib').declarePublic('unquote')
     
     allow_module('Products.CMFPlone.utils')
 
-    # This is now deprecated, use utils instead.
-    allow_module('Products.CMFPlone.PloneUtilities')
-
     # For form validation bits
     from Products.CMFPlone.utils import IndexIterator
     allow_class(IndexIterator)
@@ -103,14 +94,17 @@ def initialize(context):
     # Make ZCatalog's mergeResults importable TTW
     ModuleSecurityInfo('Products.ZCatalog.Catalog').declarePublic('mergeResults')
 
-    # Backward compatibility only, please import from utils directly
-    from Products.CMFPlone.utils import transaction_note, base_hasattr
-    this_module.transaction_note = transaction_note
-    this_module.base_hasattr = base_hasattr
-
     # Make the navtree constructs available TTW
     allow_module('Products.CMFPlone.browser.navtree')
 
+    # Allow access to the exception in the folder_delete script
+    from OFS.ObjectManager import BeforeDeleteException
+    allow_module('OFS.ObjectManager')
+    allow_class(BeforeDeleteException)
+
+    # Make cgi.escape available TTW
+    ModuleSecurityInfo('cgi').declarePublic('escape')
+
     # Setup migrations
     import migrations
     migrations.executeMigrations()
@@ -131,7 +125,10 @@ def initialize(context):
     DirectoryView.registerDirectory('skins', cmfplone_globals)
 
     # Plone content
-    import PloneContent, PloneFolder, LargePloneFolder
+
+    # LargePloneFolder is deprectated and will be removed in Plone 3.5.
+    # Usage of PloneFolder is discouraged.
+    import PloneFolder, LargePloneFolder
     import Portal
 
     contentClasses      = ( PloneFolder.PloneFolder,
@@ -181,15 +178,10 @@ def initialize(context):
               TranslationServiceTool.TranslationServiceTool,
             )
 
-    from Products.CMFCore.utils import initializeBasesPhase1
-    from Products.CMFCore.utils import initializeBasesPhase2
     from Products.CMFCore.utils import ContentInit
     from Products.CMFPlone.utils import ToolInit
 
-    # Register tools, content, and customization policies
-    z_bases = initializeBasesPhase1(contentClasses, this_module)
-    initializeBasesPhase2(z_bases, context)
-
+    # Register tools and content
     ToolInit('Plone Tool'
              , tools=tools
              , icon='tool.gif'
@@ -201,34 +193,24 @@ def initialize(context):
                 , extra_constructors=contentConstructors
                 ).initialize( context )
 
-    profile_registry.registerProfile('plone',
-                                     'Plone Site',
-                                     'Profile for a default Plone.',
-                                     'profiles/default',
-                                     'CMFPlone',
-                                     BASE)
-
     import factory
     context.registerClass(Portal.PloneSite,
                           constructors=(factory.addPloneSiteForm,
                                         factory.addPloneSite),
                           icon='skins/plone_images/logoIcon.gif')
 
-    import CustomizationPolicy
-    CustomizationPolicy.register(context, cmfplone_globals)
+# Import "PloneMessageFactory as _" to create messages in the plone domain
+from zope.i18nmessageid import MessageFactory
+PloneMessageFactory = MessageFactory('plone')
 
-    ModuleSecurityInfo('Products.CMFPlone').declarePrivate('transaction')
+# Import PloneLocalesMessageFactory to create messages in the plonelocales domain
+from zope.i18nmessageid import MessageFactory
+PloneLocalesMessageFactory = MessageFactory('plonelocales')
 
-# Import "PloneMessageFactory as _" to create message ids in the plone domain
-# Zope 3.1-style messagefactory module
-# BBB: Zope 2.8 / Zope X3.0
-try:
-    from zope.i18nmessageid import MessageFactory
-except ImportError:
-    from messagefactory_ import PloneMessageFactory
-else:
-    PloneMessageFactory = MessageFactory('plone')
-
-# Provide backward compatibility for products relying on this import location
-# BBB: Remove in Plone 3.0
-import transaction
+# A module alias for the stupidly named plone.py - now called 'ploneview.py'
+# 
+# If you get weird import errors like "Cannot import module 'utils'" (when 
+# trying to import Products.CMFPlone.utils, comment out the next two lines -
+# they may be masking the error.
+from browser import ploneview
+sys.modules['Products.CMFPlone.browser.plone'] = ploneview
