@@ -1,15 +1,17 @@
+from Acquisition import aq_inner
+import zope.deprecation
 from zope.interface import implements
 
+from Products.Five import BrowserView
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone import utils
 from Products.CMFPlone.browser.interfaces import INewsPortlet
 
 
-class NewsPortlet(utils.BrowserView):
+class NewsPortlet(BrowserView):
     implements(INewsPortlet)
 
     def published_news_items(self):
-        context = utils.context(self)
+        context = aq_inner(self.context)
         portal_catalog = getToolByName(context, 'portal_catalog')
 
         return self.request.get('news', 
@@ -18,7 +20,7 @@ class NewsPortlet(utils.BrowserView):
                                                              sort_order='reverse',
                                                              review_state='published'))
     def all_news_link(self):
-        context = utils.context(self)
+        context = aq_inner(self.context)
         utool = getToolByName(context, 'portal_url')
         portal_url = utool()
         portal = utool.getPortalObject()
@@ -27,3 +29,9 @@ class NewsPortlet(utils.BrowserView):
             return '%s/news' % portal_url
         else:
             return '%s/news_listing' % portal_url
+
+zope.deprecation.deprecated(
+  ('NewsPortlet', ),
+   "Plone's portlets are based on plone.app.portlets now. The old portlets "
+   "will be removed in Plone 3.5."
+  )
