@@ -1,16 +1,18 @@
-from Products.CMFPlone.browser.interfaces import IRecentPortlet
-from Products.CMFCore.utils import getToolByName
-
+from Acquisition import aq_inner
+import zope.deprecation
 from zope.interface import implements
-from Products.CMFPlone import utils
+
+from Products.Five import BrowserView
+from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.browser.interfaces import IRecentPortlet
 
 
-class RecentPortlet(utils.BrowserView):
+class RecentPortlet(BrowserView):
     implements(IRecentPortlet)
 
     def results(self):
         """ """
-        context = utils.context(self)
+        context = aq_inner(self.context)
         putils = getToolByName(context, 'plone_utils')
         portal_catalog = getToolByName(context, 'portal_catalog')
         typesToShow = putils.getUserFriendlyTypes()
@@ -20,3 +22,9 @@ class RecentPortlet(utils.BrowserView):
                                          portal_type=typesToShow,
                                          sort_order='reverse',
                                          sort_limit=5)[:5])
+
+zope.deprecation.deprecated(
+  ('RecentPortlet', ),
+   "Plone's portlets are based on plone.app.portlets now. The old portlets "
+   "will be removed in Plone 3.5."
+  )
