@@ -1,15 +1,31 @@
+from Products.MimetypesRegistry.setuphandlers import fixUpSMIGlobs
+from Products.CMFPlone.migrations.v3_0.alphas import enableZope3Site
+from Products.CMFPlone.migrations.v3_0.alphas import registerToolsAsUtilities
+
+
 def final_two11(portal):
     """2.1-final -> 2.1.1
     """
-    from Products.MimetypesRegistry.Extensions.Install import fixUpSMIGlobs
     out = []
-    fixUpSMIGlobs(portal)
+    
+    # Make the portal a Zope3 site
+    enableZope3Site(portal, out)
+
+    # register some tools as utilities
+    registerToolsAsUtilities(portal, out)
+
+    try:
+        fixUpSMIGlobs(portal, out)
+    except TypeError:
+        fixUpSMIGlobs(out)
+
 
     # Update path index for new EPI version
     reindexPathIndex(portal, out)
 
     return out
 
+
 def reindexPathIndex(portal, out):
     """Rebuilds the path index."""
     from Products.ZCatalog.ZCatalog import ZCatalog
