@@ -1,4 +1,5 @@
-from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.migrations.v3_0.alphas import enableZope3Site
+from Products.CMFPlone.migrations.v3_0.alphas import registerToolsAsUtilities
 
 
 def two51_two52(portal):
@@ -6,6 +7,12 @@ def two51_two52(portal):
     """
     out = []
 
+    # Make the portal a Zope3 site
+    enableZope3Site(portal, out)
+
+    # register some tools as utilities
+    registerToolsAsUtilities(portal, out)
+
     # Make sure the cookie auth redirects to the correct location
     setLoginFormInCookieAuth(portal, out)
 
