@@ -4,6 +4,9 @@
 	License: http://creativecommons.org/licenses/LGPL/2.1/
 */
 
+// WARNING!!!! This file was customized from the original version!
+// Changes are marked with XXX. Also consult the checkin log.
+
 // the following functions allow querying of the DOM using CSS selectors
 var cssQuery = function() {
 var version = "2.0.2";
@@ -44,6 +47,9 @@ try {
 				$arguments = $arguments.slice(0, -1);
 				$cacheSelector += "(" + $arguments + ")";
 			}
+			// XXX - fschulze - shortcut for pure id selectors
+			if ($token==" " && $filter=="*" && $selector[j]=="#")
+				continue;
 			// process a token/filter pair use cached results if possible
 			$$from = ($useCache && cache[$cacheSelector]) ?
 				cache[$cacheSelector] : select($$from, $token, $filter, $arguments);
@@ -120,9 +126,21 @@ selectors[" "] = function($results, $from, $tagName, $namespace) {
 
 // ID selector
 selectors["#"] = function($results, $from, $id) {
-	// loop through current selection and check ID
 	var $element, j;
-	for (j = 0; ($element = $from[j]); j++) if ($element.id == $id) $results.push($element);
+	// XXX - fschulze - Try to make this as fast as possible
+	// first see whether we have a chance to optimize this
+	if ($from.length==1 && $from[0]==document) {
+		var $node = document.getElementById($id);
+		if ($node)
+			$results.push($node);
+	} else {
+		// loop through current selection and check ID
+		for (j = 0; ($element = $from[j]); j++)
+			if ($element.id == $id) {
+				$results.push($element);
+				break;
+			}
+	}
 };
 
 // class selector
@@ -234,7 +252,11 @@ var getElementsByTagName = function($element, $tagName) {
 var compareTagName = function($element, $tagName, $namespace) {
 	if ($tagName == "*") return thisElement($element);
 	if (!compareNamespace($element, $namespace)) return false;
-	if (!isXML($element)) $tagName = $tagName.toUpperCase();
+	// XXX - fschulze - this fixes problems with content inserted from an
+	// XMLHTTPRequest. The content is originally XML and then inserted into
+	// the HTML document, this causes some elements to have lowercase tagNames
+	if (!isXML($element))
+	    return $element.tagName.toUpperCase() == $tagName.toUpperCase();
 	return $element.tagName == $tagName;
 };
 
