@@ -4,7 +4,7 @@ if (!window.beforeunload) (function() {
         var self = this;
 
         this.message = window.form_modified_message ||
-            "Your form has not been saved. All changes you have made will be lost.";
+            "Discard changes? If you click OK, any changes you have made will be lost.";
 
         this.forms = [];
         this.chkId = [];
@@ -13,6 +13,22 @@ if (!window.beforeunload) (function() {
         this.submitting = false;
 
         this.execute = function(event) {
+            // First clean out dead references to make sure we only work on
+            // forms that are actually in the dom. This is needed in
+            // combination with KSS and/or other dynamic replacements.
+            var domforms = document.getElementsByTagName('form'); 
+            var forms_in_dom = [];
+            for(var i=0; i<self.forms.length; i++){
+                for(var j=0; j<domforms.length; j++){
+                    if(self.forms[i]==domforms[j]){
+                        forms_in_dom.push(domforms[j]);
+                    }
+                }
+            }
+            self.forms = forms_in_dom;
+             
+            
+            // Now do the protection work
             if (self.submitting) return;
             if (!event) event = window.event;
 
@@ -45,6 +61,11 @@ if (!window.beforeunload) (function() {
     Class.onsubmit = function() {
         var tool = window.onbeforeunload && window.onbeforeunload.tool;
         tool.submitting = true;
+        // Also set this on the unlocking tool!
+        // This way the tool knows we are in submitting,
+        // and can prevent unlocking.
+        var lockingtool = window.onunload && window.onunload.tool;
+        lockingtool.submitting = true;
     }
     Class.addForm = function(form) {
         for (var i = 0; i < this.forms.length; i++) {
