@@ -1,7 +1,7 @@
 function inputSubmitOnClick(event) {
     if (!event) var event = window.event; // IE compatibility
 
-    if (hasClassName(this, 'submitting')) {
+    if (hasClassName(this, 'submitting') && !hasClassName(this, 'allowMultiSubmit')) {
         return confirm(window.form_resubmit_message);
     } else {
         addClassName(this, 'submitting');
