@@ -53,10 +53,10 @@ function getSearchTermsFromURI(uri) {
             result = referrerSearch;
         }
     }
-    var qfinder = new RegExp("searchterm=([^&]*)", "gi");
+    var qfinder = new RegExp("(searchterm|SearchableText)=([^&]*)", "gi");
     var qq = qfinder.exec(query);
-    if (qq && qq[1]) {
-        var terms = qq[1].replace(/\+/g,' ').split(/\s+/);
+    if (qq && qq[2]) {
+        var terms = qq[2].replace(/\+/g,' ').split(' ');
         for (var i=0; i < terms.length; i++) {
             if (terms[i] != '') {
                 result.push(terms[i]);
@@ -71,7 +71,7 @@ function highlightSearchTermsFromURI() {
     // terminate if we hit a non-compliant DOM implementation
     if (!W3CDOM){return false};
 
-    // search-term-highlighter function --  Geir Bækholt
+    // search-term-highlighter function --  Geir Baekholt
     var terms = getSearchTermsFromURI(window.location.search);
     // make sure we start the right place so we don't higlight menuitems or breadcrumb
     var contentarea = getContentArea();
@@ -79,3 +79,4 @@ function highlightSearchTermsFromURI() {
 }
 
 registerPloneFunction(highlightSearchTermsFromURI);
+
