@@ -2,6 +2,12 @@
  * they point outside the site, or are special protocols
  * To disable this effect for links on a one-by-one-basis,
  * give them a class of 'link-plain'
+ *
+ * NOTE: This script is no longer hooked up, since we use CSS to do this now.
+ *       (see public.css for the implementation)
+ *       It's not removed from existing sites that use it, but new sites will
+ *       not have it enabled. The CSS approach works in all modern browsers,
+ *       but not Internet Explorer 6. It works fine in IE7, however.
  */
 
 function scanforlinks() {
@@ -11,8 +17,21 @@ function scanforlinks() {
     // first make external links open in a new window, afterwards do the
     // normal plone link wrapping in only the content area
 
-    if ((typeof external_links_in_content_only != 'undefined') &&
-        (external_links_in_content_only == false)) {
+    if (typeof external_links_open_new_window == 'string') {
+        if (external_links_open_new_window.toLowerCase() == 'true') {
+             external_links_open_new_window = Boolean(true)
+         } else {
+             external_links_open_new_window = Boolean(false)
+         }
+    }
+
+    var this_site = window.location.protocol
+                    + '//'
+                    + window.location.host;
+    var links;
+
+    if ((typeof external_links_open_new_window != 'undefined') &&
+        (external_links_open_new_window == true)) {
         links = document.getElementsByTagName('a');
         for (i=0; i < links.length; i++) {
             if ( (links[i].getAttribute('href'))
@@ -21,9 +40,7 @@ function scanforlinks() {
 
                 // check if the link href is a relative link, or an absolute link to
                 // the current host.
-                if (linkval.toLowerCase().indexOf(window.location.protocol
-                                                  + '//'
-                                                  + window.location.host)==0) {
+                if (linkval.toLowerCase().indexOf(this_site)==0) {
                     // absolute link internal to our host - do nothing
                 } else if (linkval.indexOf('http:') != 0) {
                     // not a http-link. Possibly an internal relative link, but also
@@ -33,16 +50,22 @@ function scanforlinks() {
                 } else {
                     // we are in here if the link points to somewhere else than our
                     // site.
+                    // set external_links_open_new_window in Site setup / Theme
+                    // to true if you want external links to be opened in a new
+                    // window.
                     links[i].setAttribute('target', '_blank');
                 }
             }
         }
     }
 
-    contentarea = getContentArea();
+    var contentarea = getContentArea();
     if (!contentarea)
         return false;
 
+    var protocols = ['mailto', 'ftp', 'news', 'irc', 'h323', 'sip',
+                     'callto', 'https', 'feed', 'webcal'];
+
     links = contentarea.getElementsByTagName('a');
     for (i=0; i < links.length; i++) {
         if ( (links[i].getAttribute('href'))
@@ -51,16 +74,12 @@ function scanforlinks() {
 
             // check if the link href is a relative link, or an absolute link to
             // the current host.
-            if (linkval.toLowerCase().indexOf(window.location.protocol
-                                              + '//'
-                                              + window.location.host)==0) {
+            if (linkval.toLowerCase().indexOf(this_site)==0) {
                 // absolute link internal to our host - do nothing
             } else if (linkval.indexOf('http:') != 0) {
                 // not a http-link. Possibly an internal relative link, but also
                 // possibly a mailto or other protocol add tests for relevant
                 // protocols as you like.
-                protocols = ['mailto', 'ftp', 'news', 'irc', 'h323', 'sip',
-                             'callto', 'https', 'feed', 'webcal'];
                 // h323, sip and callto are internet telephony VoIP protocols
                 for (p=0; p < protocols.length; p++) {
                     if (linkval.indexOf(protocols[p]+':') == 0) {
@@ -78,13 +97,6 @@ function scanforlinks() {
                     // images in them
                     wrapNode(links[i], 'span', 'link-external');
                 }
-                // set open_links_in_external_window in plone_javascript_variables.js.pt
-                // to true if you want external links to be opened in a new
-                // window.
-                if ((typeof external_links_open_new_window != 'undefined') &&
-                    (external_links_open_new_window == true)) {
-                    links[i].setAttribute('target', '_blank');
-                }
             }
         }
     }
