@@ -11,14 +11,14 @@
 from Products.CMFPlone import PloneMessageFactory as _
 
 REQUEST=context.REQUEST
-msg = _(u'No changes done.')
+msg = _(u'No changes made.')
 
 if addname:
     success = context.portal_groups.addGroup(addname,(),(),REQUEST=context.REQUEST)
     if not success:
-        msg = _(u'Could not add group ${name}, perhaps a member or group with '
+        msg = _(u'Could not add group ${name}, perhaps a user or group with '
                 u'this name already exists.', mapping={u'name' : addname})
-        context.plone_utils.addPortalMessage(msg)
+        context.plone_utils.addPortalMessage(msg, 'error')
         return context.prefs_group_details()
     group=context.portal_groups.getGroupById(addname)
     msg = _(u'Group ${name} has been added.',
