@@ -7,14 +7,6 @@
 ##bind subpath=traverse_subpath
 ##parameters=
 
-INTERFACE = 'Products.CMFPlone.interfaces.BrowserDefault.ISelectableBrowserDefault'
-
-from Products.CMFCore.utils import getToolByName
-itool = getToolByName(context, 'portal_interface')
-
-if not itool.objectImplements(context, INTERFACE):
-    return None
-
 if not context.canSetLayout():
     return None
 
