@@ -7,17 +7,20 @@
 ##bind subpath=traverse_subpath
 ##parameters=
 from AccessControl import Unauthorized
+from Products.CMFPlone.utils import base_hasattr
 # It's silly but because this is often called on the parent folder, we must
 # ensure we have permission.
 try:
     if not context.isPrincipiaFolderish:
         return False
 except Unauthorized:
-        return False
+    return False
 
-if 'index_html' in context.objectIds():
+# Use the BTreeFolder API if possible
+if base_hasattr(context, 'has_key'):
+    # BTreeFolder's has_key returns numeric values
+    return context.has_key('index_html') and True or False
+elif 'index_html' in context.objectIds():
     return True
 else:
     return False
-    
-    
\ No newline at end of file
