@@ -7,11 +7,11 @@
 ##title=Mail a user's password
 ##parameters=
 
-from Products.CMFPlone import PloneMessageFactory as _
+from Products.CMFPlone import PloneMessageFactory as pmf
 REQUEST=context.REQUEST
 try:
     response = context.portal_registration.mailPassword(REQUEST['userid'], REQUEST)
 except ValueError, e:
-    context.plone_utils.addPortalMessage(str(e))
+    context.plone_utils.addPortalMessage(pmf(str(e)))
     response = context.mail_password_form()
 return response
