@@ -8,6 +8,7 @@
 ##title=Show the rename form for an object
 ##
 
+from Products.CMFPlone.utils import safe_unicode
 from Products.CMFPlone.utils import transaction_note
 from Products.CMFCore.utils import getToolByName
 from OFS.CopySupport import CopyError
@@ -15,11 +16,12 @@ from AccessControl import Unauthorized
 from Products.PythonScripts.standard import url_quote_plus
 
 REQUEST = context.REQUEST
+title = safe_unicode(context.title_or_id())
 
 mtool = getToolByName(context, 'portal_membership')
 if not mtool.checkPermission('Copy or Move', context):
     raise Unauthorized, _(u'Permission denied to rename ${title}.',
-                          mapping={u'title': context.title_or_id()})
+                          mapping={u'title': title})
 
 pathName = url_quote_plus('paths:list')
 safePath = '/'.join(context.getPhysicalPath())
