@@ -1,4 +1,4 @@
-## Script (Python) "utranslate"
+## Script (Python) "utranslate (alias for translate)"
 ##bind container=container
 ##bind context=context
 ##bind namespace=
@@ -6,16 +6,16 @@
 ##bind subpath=traverse_subpath
 ##parameters=msgid, mapping={}, default=None, domain='plone', target_language=None, escape_for_js=False
 
-from Products.CMFCore.utils import getToolByName
-
 # handle the possible "nothing" condition in folder_contents.pt ln 21 gracefully
 if msgid == None:
     return None
 
+from Products.CMFCore.utils import getToolByName
+
 # get tool
 tool = getToolByName(context, 'translation_service')
 
-# this returns type unicode
+# this returns type unicode 
 value = tool.utranslate(domain,
                         msgid,
                         mapping,
@@ -29,5 +29,8 @@ if not value and default is None:
     for k, v in mapping.items():
         value = value.replace('${%s}' % k, v)
 
+if escape_for_js:
+    value = value.replace("'", "\\'")
+
 return value
 
