@@ -2,11 +2,12 @@
 # Helper objects for the Plone test suite
 #
 
-# $Id: dummy.py 10711 2006-08-31 05:01:52Z alecm $
+# $Id: dummy.py 18241 2007-12-02 09:23:35Z alecm $
 
 import os
 
-from zope.interface import implements
+from zope.interface import Interface, implements
+from zope.interface import Interface
 
 from Products.CMFPlone.interfaces import INonStructuralFolder
 
@@ -46,19 +47,6 @@ class Item(SimpleItem):
         if title is not None:
             self.title = title
 
-
-class DeletedItem(Item):
-    '''Item than can be asked whether it has been deleted'''
-
-    manage_before_delete_called = 0
-
-    def manage_beforeDelete(self, item, container):
-        self.manage_before_delete_called = 1
-
-    def before_delete_called(self):
-        return self.manage_before_delete_called
-
-
 class SizedItem(Item):
     '''Item maintaining a size'''
 
@@ -70,6 +58,7 @@ class SizedItem(Item):
     def get_size(self):
         return self.size
 
+
 class FieldStorage(object):
     def __init__(self, file, filename='testfile', headers=None):
         self.file = file
@@ -78,6 +67,7 @@ class FieldStorage(object):
         self.headers = headers
         self.filename = filename
 
+
 class File(FileUpload):
     '''Dummy upload object
        Used to fake uploaded files.
@@ -186,3 +176,20 @@ class ImageComputedProps(Item):
         return getattr(self, '_longdesc', '')
 
     longdesc = ComputedAttribute(get_longdesc, 1)
+
+
+class IDummyUtility(Interface):
+    pass
+
+
+class DummyUtility(SimpleItem):
+    implements(IDummyUtility)
+
+
+class ICantBeDeleted(Interface):
+    """A marker indicating that an object can't be deleted"""
+
+
+def disallow_delete_handler(obj, event):
+    obj.delete_attempted = True
+    raise Exception, "You can't delete this!"
