@@ -2,10 +2,6 @@
 # Test methods used to make browser-default-mixin enabled display menu work
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.utils import _createObjectByType
 
@@ -53,18 +49,9 @@ class TestBrowserDefaultScripts(PloneTestCase.PloneTestCase):
         self.folder.setLayout('atct_album_view')
         self.assertEqual(self.folder.getViewTemplateId(), 'atct_album_view')
 
-    def testGetViewTemplateIdNonBrowserDefault(self):
-        _createObjectByType('CMF Folder', self.folder, 'cmffolder')
-        _createObjectByType('CMF Document', self.folder, 'cmfdocument')
-        self.assertEqual(self.folder.cmffolder.getViewTemplateId(), 'folder_listing')
-        self.assertEqual(self.folder.cmfdocument.getViewTemplateId(), 'document_view')
-
 
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestBrowserDefaultScripts))
     return suite
-
-if __name__ == '__main__':
-    framework()
