@@ -2,9 +2,8 @@
 # CatalogTool tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
+import unittest
+import zope.interface
 
 from Products.CMFPlone.tests import PloneTestCase
 
@@ -26,7 +25,8 @@ default_user  = PloneTestCase.default_user
 user2  = 'u2'
 group2 = 'g2'
 
-base_content = ['Members', 'events', 'news', 'previous',
+base_content = ['Members', 'aggregator', 'aggregator',
+                'events', 'news', 'previous',
                 default_user, 'front-page', 'doc']
 
 
@@ -389,9 +389,9 @@ class TestCatalogSearching(PloneTestCase.PloneTestCase):
         # After adding a group with access rights and containing user2,
         # a search must find the document.
         groupname = self.addUser2ToGroup()
-        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
+        self.setRequestMethod('POST')
         self.folder.folder_localrole_edit('add', [groupname], 'Owner')
-        self.app.REQUEST.set('REQUEST_METHOD', 'GET')
+        self.setRequestMethod('GET')
         self.login(user2)
         self.assertEqual(self.catalog(SearchableText='aaa')[0].id, 'aaa')
 
@@ -399,9 +399,9 @@ class TestCatalogSearching(PloneTestCase.PloneTestCase):
         # After adding a group with access rights and containing user2,
         # a search must find the document in subfolders.
         groupname = self.addUser2ToGroup()
-        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
+        self.setRequestMethod('POST')
         self.folder.folder_localrole_edit('add', [groupname], 'Owner')
-        self.app.REQUEST.set('REQUEST_METHOD', 'GET')
+        self.setRequestMethod('GET')
         self.login(user2)
         # Local Role works in subfolder
         self.assertEqual(self.catalog(SearchableText='bbb')[0].id, 'bbb')
@@ -411,11 +411,11 @@ class TestCatalogSearching(PloneTestCase.PloneTestCase):
         # a search should not find documents in subfolders which have
         # disabled local role acquisition.
         groupname = self.addUser2ToGroup()
-        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
+        self.setRequestMethod('POST')
         self.folder.folder_localrole_edit('add', [groupname], 'Owner')
         # Acquisition off for folder2
         self.folder.folder2.folder_localrole_set(use_acquisition=0)
-        self.app.REQUEST.set('REQUEST_METHOD', 'GET')
+        self.setRequestMethod('GET')
         # Everything in subfolder should be invisible
         self.login(user2)
         self.failIf(self.catalog(SearchableText='bar'))
@@ -462,7 +462,8 @@ class TestCatalogSorting(PloneTestCase.PloneTestCase):
 
     def testSortableTitleOutput(self):
         doc = self.folder.doc
-        wrapped = ExtensibleIndexableObjectWrapper(vars, doc, self.portal)
+        wrapped = ExtensibleIndexableObjectWrapper(doc, self.portal)
+        wrapped.update(vars={})
 
         self.assertEqual(wrapped.sortable_title, u'00000012 document 00000025')
 
@@ -471,7 +472,8 @@ class TestCatalogSorting(PloneTestCase.PloneTestCase):
         title = 'La Pe\xc3\xb1a'
         doc = self.folder.doc
         doc.setTitle(title)
-        wrapped = ExtensibleIndexableObjectWrapper(vars, doc, self.portal)
+        wrapped = ExtensibleIndexableObjectWrapper(doc, self.portal)
+        wrapped.update(vars={})
         self.assertEqual(wrapped.sortable_title, u'la pe\xf1a'.encode('utf-8'))
 
 
@@ -510,6 +512,7 @@ class TestFolderCataloging(PloneTestCase.PloneTestCase):
         # The bug in fact talks about folder_rename
         title = 'Test Folder - Snooze!'
         foo_path = '/'.join(self.folder.foo.getPhysicalPath())
+        self.setRequestMethod('POST')
         self.folder.folder_rename(paths=[foo_path], new_ids=['foo'], new_titles=[title])
         results = self.catalog(Title='Snooze')
         self.failUnless(results)
@@ -522,6 +525,7 @@ class TestFolderCataloging(PloneTestCase.PloneTestCase):
         title = 'Test Folder - Snooze!'
         transaction.savepoint(optimistic=True) # make rename work
         foo_path = '/'.join(self.folder.foo.getPhysicalPath())
+        self.setRequestMethod('POST')
         self.folder.folder_rename(paths=[foo_path], new_ids=['bar'], new_titles=[title])
         results = self.catalog(Title='Snooze')
         self.failUnless(results)
@@ -768,9 +772,9 @@ class TestCatalogUnindexing(PloneTestCase.PloneTestCase):
         doc_path = '/'.join(self.folder.doc.getPhysicalPath())
         self.app.REQUEST.set('paths', [doc_path])
         # folder_delete requires a non-GET request
-        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
+        self.setRequestMethod('POST')
         self.folder.folder_delete()
-        self.app.REQUEST.set('REQUEST_METHOD', 'GET')
+        self.setRequestMethod('GET')
         self.failIf(self.catalog(getId='doc'))
 
     def testPublishedIsUnindexedWhenDeletingParentFolder(self):
@@ -907,7 +911,8 @@ class TestExtensibleIndexableObjectWrapper(PloneTestCase.PloneTestCase):
     def testWrapper(self):
         doc = self.doc
         vars = {'var' : 'a var'}
-        wrapped = ExtensibleIndexableObjectWrapper(vars, doc, self.portal)
+        wrapped = ExtensibleIndexableObjectWrapper(doc, self.portal)
+        wrapped.update(vars)
         self.failUnlessEqual(wrapped.var, 'a var')
         self.failUnlessEqual(wrapped.getId(), 'doc')
         self.failUnlessEqual(wrapped.Title(), 'document')
@@ -934,10 +939,37 @@ class TestExtensibleIndexableObjectWrapper(PloneTestCase.PloneTestCase):
         from Products.CMFCore.tests.base.dummy import DummyContent
 
         obj = DummyContent()
-        w = ExtensibleIndexableObjectWrapper({}, obj, self.portal)
+        w = ExtensibleIndexableObjectWrapper(obj, self.portal)
+        w.update(vars={})
         self.failUnless(IContentish.providedBy(w))
         self.failUnless(IIndexableObjectWrapper.providedBy(w))
 
+    def test_getIcon(self):
+        doc = self.doc
+        iconname = doc.getIcon(relative_to_portal=1)
+        wrapped = ExtensibleIndexableObjectWrapper(doc, self.portal)
+        self.failUnlessEqual(wrapped.getIcon, iconname)
+
+
+class TestObjectProvidedIndexExtender(unittest.TestCase):
+    def _index(self, object):
+        from Products.CMFPlone.CatalogTool import object_provides
+        return object_provides(object, None)
+    
+    def testNoInterfaces(self):
+        class Dummy(object):
+            pass
+        self.assertEqual(self._index(Dummy()), ['zope.interface.Interface'])
+        
+    def testSimpleInterface(self):
+        class IDummy(zope.interface.Interface):
+            pass
+        class Dummy(object):
+            zope.interface.implements(IDummy)
+        self.assertEqual(self._index(Dummy()), [
+            'Products.CMFPlone.tests.testCatalogTool.IDummy',
+            'zope.interface.Interface'])
+
 
 def test_suite():
     from unittest import TestSuite, makeSuite
@@ -952,7 +984,5 @@ def test_suite():
     suite.addTest(makeSuite(TestCatalogExpirationFiltering))
     suite.addTest(makeSuite(TestExtensibleIndexableObjectWrapper))
     suite.addTest(makeSuite(TestCatalogSorting))
+    suite.addTest(makeSuite(TestObjectProvidedIndexExtender))
     return suite
-
-if __name__ == '__main__':
-    framework()
