@@ -2,16 +2,11 @@
 # Tests the content type scripts
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from AccessControl import Unauthorized
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
 
 AddPortalTopics = 'Add portal topics'
-from Products.CMFPlone import LargePloneFolder
 import transaction
 from OFS.CopySupport import CopyError
 
@@ -126,17 +121,6 @@ class TestContentTypeScripts(PloneTestCase.PloneTestCase):
         self.assertEqual(self.folder.folder.Title(), 'Foo')
         self.assertEqual(self.folder.folder.Description(), 'Bar')
 
-    def testLargePloneFolderCreate(self):
-        LargePloneFolder.addLargePloneFolder(self.folder, id='lpf', title='Foo', description='Bar')
-        self.assertEqual(self.folder.lpf.Title(), 'Foo')
-        self.assertEqual(self.folder.lpf.Description(), 'Bar')
-
-    def testLargePloneFolderEdit(self):
-        LargePloneFolder.addLargePloneFolder(self.folder, id='lpf')
-        self.folder.lpf.folder_edit('Foo', 'Bar')
-        self.assertEqual(self.folder.lpf.Title(), 'Foo')
-        self.assertEqual(self.folder.lpf.Description(), 'Bar')
-
     def testLinkCreate(self):
         self.folder.invokeFactory('Link', id='link', remote_url='http://foo.com', title='Foo')
         self.assertEqual(self.folder.link.Title(), 'Foo')
@@ -201,7 +185,7 @@ class TestContentTypeScripts(PloneTestCase.PloneTestCase):
 
     def testObjectDelete(self):
         self.folder.invokeFactory('Document', id='doc')
-        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
+        self.setRequestMethod('POST')
         self.folder.doc.object_delete()
         self.failIf('doc' in self.folder.objectIds())
 
@@ -463,6 +447,3 @@ def test_suite():
     suite.addTest(makeSuite(TestImageProps))
     suite.addTest(makeSuite(TestWorkflowHistory))
     return suite
-
-if __name__ == '__main__':
-    framework()
