@@ -2,10 +2,6 @@
 # DateIndex range tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
 from DateTime import DateTime
@@ -55,6 +51,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestDateIndexRanges))
     return suite
-
-if __name__ == '__main__':
-    framework()
