@@ -2,11 +2,6 @@
 # Tests for displayContentsTab script
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 
 from Products.CMFCore.permissions import ListFolderContents
@@ -16,9 +11,12 @@ from Products.CMFCore.permissions import ReviewPortalContent
 from AccessControl.Permissions import copy_or_move
 from AccessControl.Permissions import delete_objects
 
-from Products.CMFPlone import transaction
+import transaction
 
 
+# XXX: This is done in the PloneView now, and perhaps these tests should be
+# moved there.  We will leave the script around for a while, so we still test
+# there for now.
 class TestDisplayContentsTab(PloneTestCase.PloneTestCase):
     '''For the contents tab to display a user must have the ListFolderContents,
        and one of the (Modify portal contents, Copy or move, Add portal contents,
@@ -35,7 +33,9 @@ class TestDisplayContentsTab(PloneTestCase.PloneTestCase):
         folder_path = '/'.join(self.folder.foo.folder1.getPhysicalPath())
         transaction.savepoint(optimistic=True) # make rename work
         # Make the folder the default page
+        self.setRequestMethod('POST')
         self.folder.folder_rename(paths=[folder_path], new_ids=['index_html'], new_titles=['Default Folderish Document'])
+        self.setRequestMethod('GET')
 
     def getModificationPermissions(self):
         return [ModifyPortalContent,
@@ -110,6 +110,8 @@ class TestDisplayContentsTab(PloneTestCase.PloneTestCase):
         def_page = self.folder.foo.index_html
         self.failUnless(def_page.displayContentsTab())
         self.folder.foo.manage_permission(ListFolderContents, ['Manager'], acquire=0)
+        # Clear the memoized results, as it would happen for a new request
+        del self.app.REQUEST.__annotations__
         self.failIf(def_page.displayContentsTab())
 
 
@@ -118,6 +120,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestDisplayContentsTab))
     return suite
-
-if __name__ == '__main__':
-    framework()
