@@ -2,10 +2,6 @@
 # Test the getObjSize script
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
 
@@ -88,6 +84,3 @@ def test_suite():
     suite.addTest(makeSuite(TestGetObjSize))
     suite.addTest(makeSuite(TestGetObjSizedItem))
     return suite
-
-if __name__ == '__main__':
-    framework()
