@@ -2,10 +2,6 @@
 # logged_in.cpy tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
 from Products.CMFCore.permissions import SetOwnProperties
@@ -21,9 +17,10 @@ class TestLogin(PloneTestCase.PloneTestCase):
         self.login('member')
 
     def testLoggedInCreatesMemberArea(self):
-        self.assertEqual(self.membership.getHomeFolder(), None) 
-        self.portal.logged_in()
-        self.failIfEqual(self.membership.getHomeFolder(), None) 
+        if self.membership.memberareaCreationFlag == 'True':
+            self.assertEqual(self.membership.getHomeFolder(), None) 
+            self.portal.logged_in()
+            self.failIfEqual(self.membership.getHomeFolder(), None)
 
     def testLoggedInSetsLoginTime(self):
         now = DateTime()
@@ -68,6 +65,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestLogin))
     return suite
-
-if __name__ == '__main__':
-    framework()
