@@ -2,10 +2,6 @@
 # MemberDataTool tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
 
@@ -69,6 +65,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestMemberDataTool))
     return suite
-
-if __name__ == '__main__':
-    framework()
