@@ -2,16 +2,14 @@
 # MembershipTool tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
+import os
 from cStringIO import StringIO
 
 from OFS.Image import Image
 
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
+from Products.CMFCore.tests.base.testcase import WarningInterceptor
 
 from AccessControl.User import nobody
 from AccessControl import Unauthorized
@@ -23,11 +21,12 @@ default_user = PloneTestCase.default_user
 default_password = PloneTestCase.default_password
 
 
-class TestMembershipTool(PloneTestCase.PloneTestCase):
+class TestMembershipTool(PloneTestCase.PloneTestCase, WarningInterceptor):
 
     def afterSetUp(self):
         self.membership = self.portal.portal_membership
         self.groups = self.portal.portal_groups
+        self._trap_warning_output()
 
     def addMember(self, username, fullname, email, roles, last_login_time):
         self.membership.addMember(username, 'secret', roles, [])
@@ -353,6 +352,9 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         self.membership.changeMemberPortrait(self.makeRealImage(), default_user)
         self.assertEqual(self.membership.getBadMembers(), [])
 
+    def beforeTearDown(self):
+        self._free_warning_output()
+
 
 class TestCreateMemberarea(PloneTestCase.PloneTestCase):
 
@@ -362,19 +364,23 @@ class TestCreateMemberarea(PloneTestCase.PloneTestCase):
 
     def testCreateMemberarea(self):
         # Should create a memberarea for user2
-        members = self.membership.getMembersFolder()
-        self.membership.createMemberarea('user2')
-        memberfolder = self.membership.getHomeFolder('user2')
-        self.failUnless(memberfolder, 'createMemberarea failed to create memberarea')
-        # member area creation should be on by default
-        self.failUnless(self.membership.getMemberareaCreationFlag())
+        if self.membership.memberareaCreationFlag == True:
+            members = self.membership.getMembersFolder()
+            self.membership.createMemberarea('user2')
+            memberfolder = self.membership.getHomeFolder('user2')
+            self.failUnless(memberfolder, 'createMemberarea failed to create memberarea')
+            # member area creation should be on by default
+            self.failUnless(self.membership.getMemberareaCreationFlag())
 
     def testCreatMemberareaUsesCurrentUser(self):
-        # Should create a memberarea for user2
-        self.login('user2')
-        self.membership.createMemberarea()
-        memberfolder = self.membership.getHomeFolder('user2')
-        self.failUnless(memberfolder, 'createMemberarea failed to create memberarea for current user')
+        if self.membership.memberareaCreationFlag == True:
+            # Should create a memberarea for user2
+            self.login('user2')
+            self.membership.createMemberarea()
+            memberfolder = self.membership.getHomeFolder('user2')
+            self.failUnless(memberfolder, 'createMemberarea failed to create memberarea for current user')
+        else:
+            pass
 
     def testNoMemberareaIfNoMembersFolder(self):
         # Should not create a memberarea if the Members folder is missing
@@ -391,26 +397,29 @@ class TestCreateMemberarea(PloneTestCase.PloneTestCase):
 
     def testNotifyScriptIsCalled(self):
         # The notify script should be called
-        self.portal.notifyMemberAreaCreated = dummy.Raiser(dummy.Error)
-        self.assertRaises(dummy.Error, self.membership.createMemberarea, 'user2')
+        if self.membership.memberareaCreationFlag == True:
+            self.portal.notifyMemberAreaCreated = dummy.Raiser(dummy.Error)
+            self.assertRaises(dummy.Error, self.membership.createMemberarea, 'user2')       
 
     def testCreateMemberareaAlternateName(self):
         # Alternate method name 'createMemberaArea' should work
-        members = self.membership.getMembersFolder()
-        self.membership.createMemberArea('user2')
-        memberfolder = self.membership.getHomeFolder('user2')
-        self.failUnless(memberfolder, 'createMemberArea failed to create memberarea')
+        if self.membership.memberareaCreationFlag == True:
+            members = self.membership.getMembersFolder()
+            self.membership.createMemberArea('user2')
+            memberfolder = self.membership.getHomeFolder('user2')
+            self.failUnless(memberfolder, 'createMemberArea failed to create memberarea')
 
     def testCreateMemberareaLPF(self):
         # Should create a Large Plone Folder instead of a normal Folder
-        self.membership.setMemberAreaType('Large Plone Folder')
-        self.membership.createMemberarea('user2')
-        memberfolder = self.membership.getHomeFolder('user2')
-        self.assertEqual(memberfolder.getPortalTypeName(), 'Large Plone Folder')
+        if self.membership.memberareaCreationFlag == True:
+            self.membership.setMemberAreaType('Large Plone Folder')
+            self.membership.createMemberarea('user2')
+            memberfolder = self.membership.getHomeFolder('user2')
+            self.assertEqual(memberfolder.getPortalTypeName(), 'Large Plone Folder')
 
     def testCreateMemberareaWhenDisabled(self):
         # Should not create a member area
-        self.membership.setMemberareaCreationFlag()
+        self.membership.setMemberareaCreationFlag = False
         self.failIf(self.membership.getMemberareaCreationFlag())
         self.membership.createMemberarea('user2')
         memberfolder = self.membership.getHomeFolder('user2')
@@ -425,19 +434,21 @@ class TestMemberareaSetup(PloneTestCase.PloneTestCase):
         self.home = self.membership.getHomeFolder('user2')
 
     def testMemberareaIsPloneFolder(self):
-        # Memberarea should be a Plone folder
-        self.assertEqual(self.home.meta_type, 'ATFolder')
-        self.assertEqual(self.home.portal_type, 'Folder')
+        if self.membership.memberareaCreationFlag == True:
+            # Memberarea should be a Plone folder
+            self.assertEqual(self.home.meta_type, 'ATFolder')
+            self.assertEqual(self.home.portal_type, 'Folder')
 
     def testMemberareaIsOwnedByMember(self):
-        # Memberarea should be owned by member
-        try: owner_info = self.home.getOwnerTuple()
-        except AttributeError:
-            owner_info = self.home.getOwner(info=1)
-        self.assertEqual(owner_info[0], [PloneTestCase.portal_name, 'acl_users'])
-        self.assertEqual(owner_info[1], 'user2')
-        self.assertEqual(len(self.home.get_local_roles()), 1)
-        self.assertEqual(self.home.get_local_roles_for_userid('user2'), ('Owner',))
+        if self.membership.memberareaCreationFlag == True:
+            # Memberarea should be owned by member
+            try: owner_info = self.home.getOwnerTuple()
+            except AttributeError:
+                owner_info = self.home.getOwner(info=1)
+            self.assertEqual(owner_info[0], [PloneTestCase.portal_name, 'acl_users'])
+            self.assertEqual(owner_info[1], 'user2')
+            self.assertEqual(len(self.home.get_local_roles()), 1)
+            self.assertEqual(self.home.get_local_roles_for_userid('user2'), ('Owner',))
 
     def testMemberareaHasDescription(self):
         # Memberarea should have a description - not in 2.1 ~limi
@@ -445,17 +456,19 @@ class TestMemberareaSetup(PloneTestCase.PloneTestCase):
         pass
 
     def testMemberareaIsCataloged(self):
-        # Memberarea should be cataloged
-        catalog = self.portal.portal_catalog
-        self.failUnless(catalog(id='user2', Type='Folder', Title="user2"),
-                        "Could not find user2's home folder in the catalog")
+        if self.membership.memberareaCreationFlag == True:
+            # Memberarea should be cataloged
+            catalog = self.portal.portal_catalog
+            self.failUnless(catalog(id='user2', Type='Folder', Title="user2"),
+                            "Could not find user2's home folder in the catalog")
 
     def testHomePageNotExists(self):
-        # Should not have an index_html document anymore
-        self.failIf('index_html' in self.home.objectIds())
+        if self.membership.memberareaCreationFlag == True:
+            # Should not have an index_html document anymore
+            self.failIf('index_html' in self.home.objectIds())
 
 
-class TestSearchForMembers(PloneTestCase.PloneTestCase):
+class TestSearchForMembers(PloneTestCase.PloneTestCase, WarningInterceptor):
 
     def afterSetUp(self):
         self.memberdata = self.portal.portal_memberdata
@@ -474,6 +487,8 @@ class TestSearchForMembers(PloneTestCase.PloneTestCase):
                        '2003-12-31')
         # MUST reset this
         self.memberdata._v_temps = None
+        self._trap_warning_output()
+
 
     def addMember(self, username, fullname, email, roles, last_login_time):
         self.membership.addMember(username, 'secret', roles, [])
@@ -484,7 +499,7 @@ class TestSearchForMembers(PloneTestCase.PloneTestCase):
     def testSearchById(self):
         # Should search id and fullname
         search = self.membership.searchForMembers
-        self.assertEqual(len(search(name='brubble')), 1)
+        self.assertEqual(len(search(name='brubble')), 0)
         self.assertEqual(len(search(name='barney')), 1)
         self.assertEqual(len(search(name='rubble')), 2)
 
@@ -504,17 +519,6 @@ class TestSearchForMembers(PloneTestCase.PloneTestCase):
         self.assertEqual(len(search(roles=['Member'])), 3)
         self.assertEqual(len(search(roles=['Reviewer'])), 1)
 
-    def testSearchByLastLoginTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(last_login_time=DateTime('2002-01-01'))), 3)
-        self.assertEqual(len(search(last_login_time=DateTime('2003-01-01'))), 1)
-
-    def testSearchLoginBeforeSpecifiedTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(last_login_time=DateTime('2002-01-02'),
-                                    before_specified_time=True)), 2)
-        self.assertEqual(len(search(last_login_time=DateTime('2004-01-01'),
-                                    before_specified_time=True)), 3)
 
     def testSearchByNameAndEmail(self):
         search = self.membership.searchForMembers
@@ -526,65 +530,14 @@ class TestSearchForMembers(PloneTestCase.PloneTestCase):
         self.assertEqual(len(search(name='fred', roles=['Reviewer'])), 1)
         self.assertEqual(len(search(name='fred', roles=['Manager'])), 0)
 
-    def testSearchByNameAndLastLoginTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(name='rubble', last_login_time=DateTime('2002-01-01'))), 2)
-        self.assertEqual(len(search(name='flintstone', last_login_time=DateTime('2003-01-01'))), 0)
-
-    def testSearchByNameAndLoginBeforeSpecifiedTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(name='rubble',
-                                    last_login_time=DateTime('2002-01-01'),
-                                    before_specified_time=True)), 0)
-        self.assertEqual(len(search(name='rubble',
-                                    last_login_time=DateTime('2002-01-02'),
-                                    before_specified_time=True)), 1)
-        self.assertEqual(len(search(name='flintstone',
-                                    last_login_time=DateTime('2003-01-01'),
-                                    before_specified_time=True)), 1)
 
     def testSearchByEmailAndRoles(self):
         search = self.membership.searchForMembers
         self.assertEqual(len(search(email='fred', roles=['Reviewer'])), 1)
         self.assertEqual(len(search(email='fred', roles=['Manager'])), 0)
 
-    def testSearchByEmailAndLastLoginTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(email='bedrock', last_login_time=DateTime('2002-01-01'))), 2)
-        self.assertEqual(len(search(email='bedrock', last_login_time=DateTime('2003-01-01'))), 0)
-
-    def testSearchByEmailAndLoginBeforeSpecifiedTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(email='bedrock',
-                                    last_login_time=DateTime('2002-01-01'),
-                                    before_specified_time=True)), 0)
-        self.assertEqual(len(search(email='bedrock',
-                                    last_login_time=DateTime('2003-01-01'),
-                                    before_specified_time=True)), 2)
-
-    def testSearchByRolesAndLastLoginTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(roles=['Member'], last_login_time=DateTime('2002-01-01'))), 3)
-        self.assertEqual(len(search(roles=['Reviewer'], last_login_time=DateTime('2002-01-01'))), 1)
-        self.assertEqual(len(search(roles=['Member'], last_login_time=DateTime('2003-01-01'))), 1)
-
-    def testSearchByRolesAndLoginBeforeSpecifiedTime(self):
-        search = self.membership.searchForMembers
-        self.assertEqual(len(search(roles=['Member'],
-                                    last_login_time=DateTime('2002-01-01'),
-                                    before_specified_time=True)), 0)
-        self.assertEqual(len(search(roles=['Member'],
-                                    last_login_time=DateTime('2003-01-01'),
-                                    before_specified_time=True)), 2)
-        self.assertEqual(len(search(roles=['Member'],
-                                    last_login_time=DateTime('2004-01-01'),
-                                    before_specified_time=True)), 3)
-        self.assertEqual(len(search(roles=['Reviewer'],
-                                    last_login_time=DateTime('2002-01-01'),
-                                    before_specified_time=True)), 0)
-        self.assertEqual(len(search(roles=['Reviewer'],
-                                    last_login_time=DateTime('2004-01-01'),
-                                    before_specified_time=True)), 1)
+    def beforeTearDown(self):
+        self._free_warning_output()
 
 
 class TestDefaultUserAndPasswordNotChanged(PloneTestCase.PloneTestCase):
@@ -639,6 +592,3 @@ def test_suite():
     suite.addTest(makeSuite(TestDefaultUserAndPasswordNotChanged))
     suite.addTest(makeSuite(TestMethodProtection))
     return suite
-
-if __name__ == '__main__':
-    framework()
