@@ -2,17 +2,14 @@
 # MigrationTool tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
-
+from Products.CMFPlone.interfaces import IMigrationTool
+from Products.CMFCore.utils import getToolByName
 
 class TestMigrationTool(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
-        self.migration = self.portal.portal_migration
+        self.migration = getToolByName(self, "portal_migration")
 
     def testMigrationFinished(self):
         self.assertEqual(self.migration.getInstanceVersion(),
@@ -31,13 +28,20 @@ class TestMigrationTool(PloneTestCase.PloneTestCase):
         self.failIf(self.migration.needRecatalog(),
                     'Migration needs recataloging')
 
-    def testForceMigration(self):
-        self.setRoles(['Manager'])
-        # Make sure we don't embarrass ourselves again...
+    def testForceMigrationFromUnsupportedVersion(self):
         version = '2.0.5'
         while version is not None:
             version, msg = self.migration._upgrade(version)
-        expect = 'Migration completed at version %s' % \
+        expect = 'Migration stopped at version 2.0.5.'
+        self.assertEqual(msg[0], expect)
+
+    def testForceMigration(self):
+        self.setRoles(['Manager'])
+        # Make sure we don't embarrass ourselves again...
+        version = '2.1'
+        while version is not None:
+            version, msg = self.migration._upgrade(version)
+        expect = 'Migration completed at version %s.' % \
                  self.migration.getFileSystemVersion()
         self.assertEqual(msg[0], expect)
 
@@ -47,6 +51,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestMigrationTool))
     return suite
-
-if __name__ == '__main__':
-    framework()
