@@ -2,20 +2,23 @@
 # Tests the PloneTool
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
-from Products.CMFPlone.tests import dummy
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.browser.navtree import *
 
-from Products.CMFPlone.browser.interfaces import INavigationRoot
+from plone.app.layout.navigation.interfaces import INavigationRoot
+
+from plone.app.layout.navigation.navtree import NavtreeStrategyBase
+from plone.app.layout.navigation.navtree import buildFolderTree
+from plone.app.layout.navigation.root import getNavigationRoot
+
+from Products.CMFPlone.browser.navtree import NavtreeQueryBuilder
+from Products.CMFPlone.browser.navtree import SitemapQueryBuilder
+from Products.CMFPlone.browser.navtree import SitemapNavtreeStrategy
+from Products.CMFPlone.browser.navtree import DefaultNavtreeStrategy
 
-import transaction
 from zope.interface import directlyProvides
+from zope.interface import implements
 
 default_user = PloneTestCase.default_user
 
@@ -450,6 +453,15 @@ class TestFolderTree(PloneTestCase.PloneTestCase):
         self.assertEqual(tree[5]['children'][0]['children'][0]['item'].getPath(), rootPath + '/folder2/folder21/doc211')
         self.assertEqual(tree[5]['children'][0]['children'][1]['item'].getPath(), rootPath + '/folder2/folder21/doc212')
 
+    def testCurrentParent(self):
+        self.loginAsPortalOwner()
+        self.portal.invokeFactory('Document', 'doc')
+        context = self.portal.doc1
+        tree = buildFolderTree(self.portal, obj=context)['children']
+        for t in tree:
+            if t['item'].getId == 'doc':
+                self.assertEqual(t['currentParent'], False)
+
 class TestNavigationRoot(PloneTestCase.PloneTestCase):
 
     def testGetNavigationRootPropertyNotSet(self):
@@ -494,6 +506,3 @@ def test_suite():
     suite.addTest(makeSuite(TestFolderTree))
     suite.addTest(makeSuite(TestNavigationRoot))
     return suite
-
-if __name__ == '__main__':
-    framework()
