@@ -2,22 +2,12 @@
 # Test methods used to make ...
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-try:
-    from zope.app.publication.browser import setDefaultSkin
-    ZOPE28 = False
-except ImportError:
-    ZOPE28 = True
-
+from zope.publisher.browser import setDefaultSkin
 from zope.interface import directlyProvides
 
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
 
-from Products.CMFPlone.utils import _createObjectByType
-
 from Products.CMFPlone.browser.navigation import CatalogNavigationTree
 from Products.CMFPlone.browser.navigation import CatalogSiteMap
 from Products.CMFPlone.browser.navigation import CatalogNavigationTabs
@@ -37,9 +27,8 @@ class TestBaseNavTree(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
         self.request = self.app.REQUEST
-        if not ZOPE28:
-            # Apply a default layer for view lookups to work in Zope 2.9+
-            setDefaultSkin(self.request)
+        # Apply a default layer for view lookups to work in Zope 2.9+
+        setDefaultSkin(self.request)
         self.populateSite()
         
     def populateSite(self):
@@ -305,6 +294,9 @@ class TestBaseNavTree(PloneTestCase.PloneTestCase):
     def testCustomQuery(self):
         # Try a custom query script for the navtree that returns only published
         # objects
+        self.portal._delObject('Members')
+        self.portal._delObject('news')
+        self.portal._delObject('events')
         workflow = self.portal.portal_workflow
         factory = self.portal.manage_addProduct['PythonScripts']
         factory.manage_addPythonScript('getCustomNavQuery')
@@ -327,6 +319,9 @@ class TestBaseNavTree(PloneTestCase.PloneTestCase):
 
     def testStateFiltering(self):
         # Test Navtree workflow state filtering
+        self.portal._delObject('Members')
+        self.portal._delObject('news')
+        self.portal._delObject('events')
         workflow = self.portal.portal_workflow
         ntp=self.portal.portal_properties.navtree_properties
         ntp.manage_changeProperties(wf_states_to_show=['published'])
@@ -359,9 +354,8 @@ class TestBaseSiteMap(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
         self.request = self.app.REQUEST
-        if not ZOPE28:
-            # Apply a default layer for view lookups to work in Zope 2.9+
-            setDefaultSkin(self.request)
+        # Apply a default layer for view lookups to work in Zope 2.9+
+        setDefaultSkin(self.request)
         self.populateSite()
         
     def populateSite(self):
@@ -487,8 +481,7 @@ class TestBasePortalTabs(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
         self.request = self.app.REQUEST
-        if not ZOPE28:
-            setDefaultSkin(self.request)
+        setDefaultSkin(self.request)
         self.populateSite()
 
     def populateSite(self):
@@ -503,9 +496,15 @@ class TestBasePortalTabs(PloneTestCase.PloneTestCase):
     def testCreateTopLevelTabs(self):
         # See if we can create one at all
         view = self.view_class(self.portal, self.request)
+        
+        #Everything shows up by default
         tabs = view.topLevelTabs()
         self.failUnless(tabs)
+        self.assertEqual(len(tabs), 8)
+        
         #Only the folders show up (Members, news, events, folder1, folder2)
+        self.portal.portal_properties.site_properties.disable_nonfolderish_sections = True
+        tabs = view.topLevelTabs()
         self.assertEqual(len(tabs), 5)
 
     def testTabsRespectFolderOrder(self):
@@ -525,6 +524,9 @@ class TestBasePortalTabs(PloneTestCase.PloneTestCase):
     def testCustomQuery(self):
         # Try a custom query script for the tabs that returns only published
         # objects
+        self.portal._delObject('Members')
+        self.portal._delObject('news')
+        self.portal._delObject('events')
         workflow = self.portal.portal_workflow
         factory = self.portal.manage_addProduct['PythonScripts']
         factory.manage_addPythonScript('getCustomNavQuery')
@@ -546,6 +548,9 @@ class TestBasePortalTabs(PloneTestCase.PloneTestCase):
 
     def testStateFiltering(self):
         # Test tabs workflow state filtering
+        self.portal._delObject('Members')
+        self.portal._delObject('news')
+        self.portal._delObject('events')
         workflow = self.portal.portal_workflow
         ntp=self.portal.portal_properties.navtree_properties
         ntp.manage_changeProperties(wf_states_to_show=['published'])
@@ -619,13 +624,13 @@ class TestBasePortalTabs(PloneTestCase.PloneTestCase):
         self.failIf('folder2' in tab_names)
 
     def testTabsExcludeNonFolderishItems(self):
-        # Make sure that items witht he exclude_from_nav property are purged
+        self.portal.portal_properties.site_properties.disable_nonfolderish_sections = True
         view = self.view_class(self.portal, self.request)
         tabs = view.topLevelTabs()
         orig_len = len(tabs)
         self.setRoles(['Manager','Member'])
         self.portal.invokeFactory('Document','foo')
-        self.portal.foo.reindexObject()
+        
         view = self.view_class(self.portal, self.request)
         tabs = view.topLevelTabs()
         self.failUnless(tabs)
@@ -643,6 +648,7 @@ class TestBasePortalTabs(PloneTestCase.PloneTestCase):
         
         rootPath = '/'.join(self.portal.getPhysicalPath()) + '/folder1'
         self.portal.portal_properties.navtree_properties.root = '/folder1'
+        self.portal.portal_properties.site_properties.disable_nonfolderish_sections = True
         
         view = self.view_class(self.portal, self.request)
         tabs = view.topLevelTabs()
@@ -664,8 +670,7 @@ class TestBaseBreadCrumbs(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
         self.request = self.app.REQUEST
-        if not ZOPE28:
-            setDefaultSkin(self.request)
+        setDefaultSkin(self.request)
         self.populateSite()
 
     def populateSite(self):
@@ -729,6 +734,3 @@ def test_suite():
     suite.addTest(makeSuite(TestCatalogBreadCrumbs))
     suite.addTest(makeSuite(TestPhysicalBreadCrumbs))
     return suite
-
-if __name__ == '__main__':
-    framework()
