@@ -2,17 +2,11 @@
 # PloneFolder tests
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
-from Products.CMFPlone.utils import _createObjectByType
-from Products.CMFPlone import transaction
 
-from OFS.IOrderSupport import IOrderedContainer
+from Products.CMFPlone.utils import _createObjectByType
+import transaction
 
 from AccessControl import Unauthorized
 from Products.CMFCore.permissions import DeleteObjects
@@ -36,41 +30,36 @@ class TestPloneFolder(PloneTestCase.PloneTestCase):
         self.assertRaises(NotFound, self.folder.getObjectPosition, 'foobar')
 
     def testSortOrder(self):
-        self.assertEqual(self.folder.objectIds(), 
+        self.assertEqual(self.folder.objectIds(),
             ['sub1', 'sub2', 'sub3'])
 
     def testEditFolderKeepsPosition(self):
-        # Cover http://plone.org/collector/2796
+        # Cover http://dev.plone.org/plone/ticket/2796
         self.folder.sub2.folder_edit('Foo', 'Description')
         self.assertEqual(self.folder.sub2.Title(), 'Foo')
         # Order should remain the same
-        self.assertEqual(self.folder.objectIds(), 
+        self.assertEqual(self.folder.objectIds(),
             ['sub1', 'sub2', 'sub3'])
 
     def testRenameFolderKeepsPosition(self):
-        # Cover http://plone.org/collector/2796
+        # Cover http://dev.plone.org/plone/ticket/2796
         transaction.savepoint(optimistic=True) # make rename work
         self.folder.sub2.folder_edit('Foo', 'Description', id='foo')
         self.assertEqual(self.folder.foo.Title(), 'Foo')
         # Order should remain the same
-        self.assertEqual(self.folder.objectIds(), 
+        self.assertEqual(self.folder.objectIds(),
             ['sub1', 'foo', 'sub3'])
 
     def testCanViewManagementScreen(self):
         # Make sure the ZMI management screen works
         self.folder.manage_main()
 
-    def testLargePloneFolderIsNotOrdered(self):
-        _createObjectByType('Large Plone Folder', self.folder, 'lpf')
-        lpf = self.folder.lpf
-        self.failIf(IOrderedContainer.isImplementedBy(lpf))
-
 
 class TestCheckIdAvailable(PloneTestCase.PloneTestCase):
     # PortalFolder.checkIdAvailable() did not properly catch
-    # zExceptions.BadRequest. 
+    # zExceptions.BadRequest.
     # Fixed in CMFCore.PortalFolder, not Plone.
-    
+
     def afterSetUp(self):
         _createObjectByType('Large Plone Folder', self.folder, 'lpf')
         self.lpf = self.folder.lpf
@@ -123,7 +112,7 @@ class TestCheckIdAvailable(PloneTestCase.PloneTestCase):
 
 
 class TestFolderListing(PloneTestCase.PloneTestCase):
-    # Tests for http://plone.org/collector/3512
+    # Tests for http://dev.plone.org/plone/ticket/3512
 
     def afterSetUp(self):
         self.workflow = self.portal.portal_workflow
@@ -194,11 +183,16 @@ class TestFolderListing(PloneTestCase.PloneTestCase):
         self.assertEqual(len(contents), 1)
         self.assertEqual(contents[0].getId, 'sub1doc1')
 
-        self.failUnless(self.folder.sub1.folder_contents())
+        self.failUnless(self.folder.sub1.old_folder_contents())
+        view = self.folder.sub1.restrictedTraverse("folder_contents")
+        self.failUnless(view())
 
         self.folder.sub1.manage_permission('List folder contents', ['Manager'], acquire=0)
 
-        self.assertRaises(Unauthorized, self.folder.sub1.folder_contents)
+        self.assertRaises(Unauthorized, self.folder.sub1.old_folder_contents)
+        def func():
+            return self.folder.sub1.restrictedTraverse("folder_contents")
+        self.assertRaises(Unauthorized, func)
 
 
 class TestManageDelObjects(PloneTestCase.PloneTestCase):
@@ -246,8 +240,7 @@ class TestManageDelObjectsInPortal(PloneTestCase.PloneTestCase):
         # Should be able to delete sub1 as the portal does not implement
         # additional permission checks.
         self.sub1.manage_permission(DeleteObjects, ['Manager'], acquire=0)
-        self.portal.manage_delObjects('sub1')
-        self.failIf('sub1' in self.portal.objectIds())
+        self.assertRaises(Unauthorized, self.portal.manage_delObjects, 'sub1')
 
 
 def test_suite():
@@ -259,6 +252,3 @@ def test_suite():
     suite.addTest(makeSuite(TestManageDelObjects))
     suite.addTest(makeSuite(TestManageDelObjectsInPortal))
     return suite
-
-if __name__ == '__main__':
-    framework()
