@@ -2,10 +2,6 @@
 # Tests for renderBase.py
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
 
@@ -46,6 +42,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestRenderBase))
     return suite
-
-if __name__ == '__main__':
-    framework()
