@@ -3,10 +3,6 @@
 # for access by restricted code (aka PythonScripts)
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
@@ -48,27 +44,6 @@ class TestSecurityDeclarations(RestrictedPythonTest):
     # environment. Therefore the tests are not truly independent.
     # Be careful when adding new tests to this class.
 
-    def testImport_LOG(self):
-        self.check('from zLOG import LOG')
-
-    def testAccess_LOG(self):
-        self.check('import zLOG;'
-                   'print zLOG.LOG')
-
-    def testImport_INFO(self):
-        self.check('from zLOG import INFO')
-
-    def testAccess_INFO(self):
-        self.check('import zLOG;'
-                   'print zLOG.INFO')
-
-    def testImport_WARNING(self):
-        self.check('from zLOG import WARNING')
-
-    def testAccess_WARNING(self):
-        self.check('import zLOG;'
-                   'print zLOG.WARNING')
-
     def testImport_log(self):
         self.check('from Products.CMFPlone.utils import log')
 
@@ -153,13 +128,6 @@ class TestSecurityDeclarations(RestrictedPythonTest):
         self.check('from Products.CMFPlone import Batch;'
                    'print Batch([], 0).nexturls')
 
-    def testImport_listPolicies(self):
-        self.check('from Products.CMFPlone.Portal import listPolicies')
-
-    def testAccess_listPolicies(self):
-        self.check('import Products.CMFPlone.Portal;'
-                   'print Products.CMFPlone.Portal.listPolicies')
-
     # utils
 
     def testImport_transaction_note(self):
@@ -190,22 +158,6 @@ class TestSecurityDeclarations(RestrictedPythonTest):
         self.check('import Products.CMFPlone.utils;'
                    'print Products.CMFPlone.utils.safe_callable')
 
-    # B/w compatibility
-
-    def testImport_transaction_note_bbb(self):
-        self.check('from Products.CMFPlone import transaction_note')
-
-    def testAccess_transaction_note_bbb(self):
-        self.check('import Products.CMFPlone;'
-                   'print Products.CMFPlone.transaction_note')
-
-    def testImport_base_hasattr_bbb(self):
-        self.check('from Products.CMFPlone import base_hasattr')
-
-    def testAccess_base_hasattr_bbb(self):
-        self.check('import Products.CMFPlone;'
-                   'print Products.CMFPlone.base_hasattr')
-
     # Exceptions
 
     def testImport_Unauthorized(self):
@@ -536,8 +488,6 @@ class TestNavtreeSecurity(PloneTestCase.PloneTestCase, RestrictedPythonTest):
     def testBuildFolderTree(self):
         self.check('from Products.CMFPlone.browser.navtree import buildFolderTree')
 
-
-
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
@@ -547,6 +497,3 @@ def test_suite():
     suite.addTest(makeSuite(TestSkinSecurity))
     suite.addTest(makeSuite(TestNavtreeSecurity))
     return suite
-
-if __name__ == '__main__':
-    framework()
