@@ -2,10 +2,6 @@
 # Skeleton PloneTestCase
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
 
@@ -24,6 +20,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestSomething))
     return suite
-
-if __name__ == '__main__':
-    framework()
