@@ -2,10 +2,6 @@
 # Tests the workflow tool
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
 portal_name = PloneTestCase.portal_name
@@ -42,6 +38,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestURLTool))
     return suite
-
-if __name__ == '__main__':
-    framework()
