@@ -1,6 +1,3 @@
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
 
 from Products.CMFPlone.tests import PloneTestCase
 
@@ -420,6 +417,3 @@ def test_suite():
     suite.addTest(makeSuite(TestPUTObjects))
     suite.addTest(makeSuite(TestDAVOperations))
     return suite
-
-if __name__ == '__main__':
-    framework()
