@@ -2,14 +2,27 @@
 # Tests the workflow tool
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-
 from Products.CMFPlone.tests import PloneTestCase
 
 default_user = PloneTestCase.default_user
 
+# XXX - Ugh...Rather than use and update ambiguous numbers,
+# we maintain a mapping of the various workflows to stats
+# though there are some obvious downsides to this, it's better than just
+# asserting that there are X published states in all workflows, etc.
+workflow_dict = {
+      'folder_workflow':('private','published','visible',)
+    , 'intranet_folder_workflow':('internal','private',)
+    , 'intranet_workflow':('internal','internally_published','pending',
+                           'private','external',)
+    , 'one_state_workflow':('published',)
+    , 'plone_workflow':('pending','private','published','visible',)
+    , 'simple_publication_workflow':('private','published','pending',)
+}
+# then we join all states into one master list
+all_states = []
+for states in workflow_dict.values():
+    all_states += list(states)
 
 class TestWorkflowTool(PloneTestCase.PloneTestCase):
 
@@ -42,7 +55,7 @@ class TestWorkflowTool(PloneTestCase.PloneTestCase):
         state_id = self.workflow.getInfoFor(self.doc, 'review_state', '')
         state_title = self.workflow.getTitleForStateOnType(state_id, self.doc.portal_type)
         self.assertEqual(state_id, 'visible')
-        self.assertEqual(state_title, 'Public Draft')
+        self.assertEqual(state_title.lower(), 'public draft')
 
     def testGetTitleForStateOnTypeFallsBackOnStateId(self):
         state_id = 'nonsense'
@@ -75,27 +88,24 @@ class TestWorkflowTool(PloneTestCase.PloneTestCase):
 
     def testListWFStatesByTitle(self):
         states = self.workflow.listWFStatesByTitle()
-        self.assertEqual(len(states), 7)
+        self.assertEqual(len(states), len(all_states))
         pub_states = [s for s in states if s[1]=='published']
         priv_states = [s for s in states if s[1]=='private']
         pend_states = [s for s in states if s[1]=='pending']
         vis_states = [s for s in states if s[1]=='visible']
-        self.assertEqual(len(pub_states), 2)
-        self.assertEqual(len(priv_states), 2)
-        self.assertEqual(len(pend_states), 1)
-        self.assertEqual(len(vis_states), 2)
+        external_states = [s for s in states if s[1]=='external']
+        internal_states = [s for s in states if s[1]=='internal']
+        internal_pub_states = [s for s in states
+                                 if s[1]=='internally_published']
 
-    def testListWFStatesByTitleFiltersSimilar(self):
-        states = self.workflow.listWFStatesByTitle(filter_similar=True)
-        self.assertEqual(len(states), 4)
-        pub_states = [s for s in states if s[1]=='published']
-        priv_states = [s for s in states if s[1]=='private']
-        pend_states = [s for s in states if s[1]=='pending']
-        vis_states = [s for s in states if s[1]=='visible']
-        self.assertEqual(len(pub_states), 1)
-        self.assertEqual(len(priv_states), 1)
-        self.assertEqual(len(pend_states), 1)
-        self.assertEqual(len(vis_states), 1)
+        self.assertEqual(len(pub_states), all_states.count('published'))
+        self.assertEqual(len(priv_states), all_states.count('private'))
+        self.assertEqual(len(pend_states), all_states.count('pending'))
+        self.assertEqual(len(vis_states), all_states.count('visible'))
+        self.assertEqual(len(external_states), all_states.count('external'))
+        self.assertEqual(len(internal_states), all_states.count('internal'))
+        self.assertEqual(len(internal_pub_states),
+                         all_states.count('internally_published'))
 
 
 def test_suite():
@@ -103,6 +113,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestWorkflowTool))
     return suite
-
-if __name__ == '__main__':
-    framework()
