@@ -2,13 +2,17 @@ import re
 from types import ClassType
 from os.path import join, abspath, split
 from cStringIO import StringIO
-
 from PIL import Image
 
+from plone.i18n.normalizer.interfaces import IIDNormalizer
+from plone.i18n.normalizer.interfaces import IFileNameNormalizer
+from plone.i18n.normalizer.interfaces import IUserPreferredFileNameNormalizer
+
 import zope.interface
 from zope.interface import implementedBy
 from zope.component import getMultiAdapter
-from zope.component.interfaces import ComponentLookupError
+from zope.component import queryMultiAdapter
+from zope.component import queryUtility
 
 import OFS
 import Globals
@@ -18,7 +22,6 @@ from Products.Five import BrowserView as BaseView
 from Products.Five.bridge import fromZ2Interface
 from Products.CMFCore.utils import ToolInit as CMFCoreToolInit
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.UnicodeNormalizer import normalizeUnicode
 from Products.CMFPlone.interfaces.Translatable import ITranslatable
 import transaction
 
@@ -34,13 +37,6 @@ from log import log
 from log import log_exc
 from log import log_deprecated
 
-# Define and compile static regexes
-IGNORE_REGEX = re.compile(r"[']")
-FILENAME_REGEX = re.compile(r"^(.+)\.(\w{,4})$")
-NON_WORD_REGEX = re.compile(r"[\W\-]+")
-DANGEROUS_CHARS_REGEX = re.compile(r"[?&/:\\#]+")
-EXTRA_DASHES_REGEX = re.compile(r"(^\-+)|(\-+$)")
-
 # Settings for member image resize quality
 PIL_SCALING_ALGO = Image.ANTIALIAS
 PIL_QUALITY = 88
@@ -68,10 +64,6 @@ def createBreadCrumbs(context, request):
     view = getMultiAdapter((context, request), name='breadcrumbs_view')
     return view.breadcrumbs()
 
-def createTopLevelTabs(context, request, actions=None, category='portal_tabs'):
-    view = getMultiAdapter((context, request), name='portal_tabs_view')
-    return view.topLevelTabs(actions=actions, category=category)
-
 def createNavTree(context, request, sitemap=False):
     view = getMultiAdapter((context, request), name='navtree_builder_view')
     return view.navigationTree()
@@ -86,11 +78,10 @@ def _getDefaultPageView(obj, request):
        the default skin.  Explicitly marking the request appears to cause
        connection errors, so we just instantiate the view manually.
     """
-    try:
-        view = getMultiAdapter((obj, request), name='default_page')
-    except ComponentLookupError:
+    view = queryMultiAdapter((obj, request), name='default_page')
+    if view is None:
         # XXX: import here to avoid a circular dependency
-        from browser.navigation import DefaultPage
+        from plone.app.layout.navigation.defaultpage import DefaultPage
         view = DefaultPage(obj, request)
     return view
 
@@ -149,8 +140,8 @@ def lookupTranslationId(obj, page, ids):
 
 def pretty_title_or_id(context, obj, empty_value=_marker):
     """Return the best possible title or id of an item, regardless
-    of whether obj is a catalog brain or an object, but returning an
-    empty title marker if the id is not set (i.e. it's auto-generated).
+       of whether obj is a catalog brain or an object, but returning an
+       empty title marker if the id is not set (i.e. it's auto-generated).
     """
     #if safe_hasattr(obj, 'aq_explicit'):
     #    obj = obj.aq_explicit
@@ -232,56 +223,80 @@ def normalizeString(text, context=None, encoding=None, relaxed=False):
             encoding = getSiteEncoding(context)
         text = unicode(text, encoding)
 
-    text = text.strip()
     if not relaxed:
-        text = text.lower()
-    text = normalizeUnicode(text)
+        return queryUtility(IIDNormalizer).normalize(text)
 
-    base = text
-    ext  = ""
+    # BBB To be removed in Plone 3.5
+    log_deprecated("The relaxed mode of normalizeString is deprecated and will "
+                   "be removed in Plone 3.5. Please use either the url or file "
+                   "name normalizer from the plone.i18n package instead.")
 
-    m = FILENAME_REGEX.match(text)
-    if m is not None:
-        base = m.groups()[0]
-        ext  = m.groups()[1]
+    request = getattr(context, 'REQUEST', None)
+    # If we have a request, get the preferred user normalizer
+    if request is not None:
+        return IUserPreferredFileNameNormalizer(request).normalize(text)
 
-    base = IGNORE_REGEX.sub("", base)
+    return queryUtility(IFileNameNormalizer).normalize(text)
 
-    if not relaxed:
-        base = NON_WORD_REGEX.sub("-", base)
-    else:
-        base = DANGEROUS_CHARS_REGEX.sub("-", base)
+class IndexIterator(object):
+    """BBB: This iterator was us ed for tabindex use, but for accessibility 
+       reasons, we have deprecated it, and it now returns None always. Should 
+       be removed in Plone 3.5.
+       
+       Below are the different use cases we used to have, all return None now:
 
-    base = EXTRA_DASHES_REGEX.sub("", base)
+        >>> i = IndexIterator(pos=10, mainSlot=True)
+        >>> i.next() is None
+        True
 
-    if ext != "":
-        base = base + "." + ext
-    return base
+       The default start value gets "None"
 
-class IndexIterator:
-    """An iterator used to generate tabindexes. Note that tabindexes are not as
-    good for accessibility as once thought, and are largely disabled with this
-    iterator. Only the first iteration of an iterator instantiated with 
-    mainSlot=True will get an index, subsequent iterations will get None (thus
-    removing the tabindex attribute).
+        >>> i = IndexIterator(mainSlot=True)
+        >>> i.next() is None
+        True
+
+       Subsequent iterations will get None (thus removing the tabindex
+       attribute):
+
+        >>> i.next() is None
+        True
+
+       Outside the mainSlot all iterations will get None:
+
+        >>> i = IndexIterator(pos=10, mainSlot=False)
+        >>> i.next() is None
+        True
+
+        >>> i.next() is None
+        True
+
+        >>> i = IndexIterator(mainSlot=False)
+        >>> i.next() is None
+        True
     """
     __allow_access_to_unprotected_subobjects__ = 1
 
-    def __init__(self, upper=100000, pos=0, mainSlot=True):
+    def __init__(self, upper=100000, pos=1, mainSlot=True):
         self.upper=upper
         self.pos=pos
         self.mainSlot=mainSlot
 
-        if not mainSlot:
-            self.disabled = True
-        else:
-            self.disabled = False
-
     def next(self):
-        if self.disabled:
-            return None
-        self.disabled = True
-        return self.pos
+        return None
+
+class RealIndexIterator(object):
+    """The 'real' version of the IndexIterator class, that's actually 
+    used to generate unique indexes. 
+    """ 
+    __allow_access_to_unprotected_subobjects__ = 1 
+
+    def __init__(self, pos=0): 
+        self.pos=pos
+
+    def next(self): 
+        result=self.pos 
+        self.pos=self.pos+1 
+        return result 
 
 class ToolInit(CMFCoreToolInit):
 
@@ -380,7 +395,23 @@ release_levels = ('alpha', 'beta', 'candidate', 'final')
 rl_abbr = {'a':'alpha', 'b':'beta', 'rc':'candidate'}
 
 def versionTupleFromString(v_str):
-    """Returns version tuple from passed in version string"""
+    """Returns version tuple from passed in version string
+
+        >>> versionTupleFromString('1.2.3')
+        (1, 2, 3, 'final', 0)
+
+        >>> versionTupleFromString('2.1-final1 (SVN)')
+        (2, 1, 0, 'final', 1)
+
+        >>> versionTupleFromString('3-beta')
+        (3, 0, 0, 'beta', 0)
+
+        >>> versionTupleFromString('2.0a3')
+        (2, 0, 0, 'alpha', 3)
+
+        >>> versionTupleFromString('foo') is None
+        True
+        """
     regex_str = "(^\d+)[.]?(\d*)[.]?(\d*)[- ]?(alpha|beta|candidate|final|a|b|rc)?(\d*)"
     v_regex = re.compile(regex_str)
     match = v_regex.match(v_str)
@@ -558,7 +589,6 @@ def webdav_enabled(obj, container):
 # a dependency.
 
 from App.Dialogs import MessageDialog
-from OFS.CopySupport import CopyContainer
 from OFS.CopySupport import CopyError
 from OFS.CopySupport import eNotSupported
 from cgi import escape
@@ -574,23 +604,23 @@ def _unrestricted_rename(container, id, new_id):
         * no verify object check from PortalFolder so it's allowed to rename
           even unallowed portal types inside a folder
     """
-    try: container._checkId(new_id)
-    except: raise CopyError, MessageDialog(
-                  title='Invalid Id',
-                  message=sys.exc_info()[1],
-                  action ='manage_main')
+    try:
+        container._checkId(new_id)
+    except:
+        raise CopyError, MessageDialog(
+              title='Invalid Id',
+              message=sys.exc_info()[1],
+              action ='manage_main')
     ob=container._getOb(id)
-    #!#if ob.wl_isLocked():
-    #!#    raise ResourceLockedError, 'Object "%s" is locked via WebDAV' % ob.getId()
     if not ob.cb_isMoveable():
         raise CopyError, eNotSupported % escape(id)
-    #!#container._verifyObjectPaste(ob)
-    #!#CopyContainer._verifyObjectPaste(container, ob)
-    try:    ob._notifyOfCopyTo(container, op=1)
-    except: raise CopyError, MessageDialog(
-                  title='Rename Error',
-                  message=sys.exc_info()[1],
-                  action ='manage_main')
+    try:
+        ob._notifyOfCopyTo(container, op=1)
+    except:
+        raise CopyError, MessageDialog(
+              title='Rename Error',
+              message=sys.exc_info()[1],
+              action ='manage_main')
     container._delObject(id)
     ob = aq_base(ob)
     ob._setId(new_id)
@@ -601,8 +631,6 @@ def _unrestricted_rename(container, id, new_id):
     ob = container._getOb(new_id)
     ob._postCopy(container, op=1)
 
-    #!#if REQUEST is not None:
-    #!#    return container.manage_main(container, REQUEST, update_menu=1)
     return None
 
 
@@ -756,20 +784,72 @@ def scale_image(image_file, max_size=None, default_format=None):
     # Return the file data and the new mimetype
     return new_file, mimetype
 
-# postonly decorator is only available in Zope 2.8.9, 2.9.7, 2.10.3 and 2.11,
-# or in Hotfix_20070320.
-try:
-    from AccessControl.requestmethod import postonly
-except ImportError:
+def isLinked(obj):
+    """ check if the given content object is linked from another one
+        WARNING: don't use this function in your code!!
+            it is a helper for the link integrity code and will potentially
+            abort the ongoing transaction, giving you unexpected results...
+    """
+    # first check to see if link integrity handling has been enabled at all
+    # and if so, if the removal of the object was already confirmed, i.e.
+    # while replaying the request;  unfortunately this makes it necessary
+    # to import from plone.app.linkintegrity here, hence the try block...
     try:
-        from Products.Hotfix_20070320 import postonly
-    except ImportError:
-        def postonly(callable):
-            return callable
+        from plone.app.linkintegrity.interfaces import ILinkIntegrityInfo
+        info = ILinkIntegrityInfo(obj.REQUEST)
+    except (ImportError, TypeError):
+        # if p.a.li isn't installed the following check can be cut short...
+        return False
+    if not info.integrityCheckingEnabled():
+        return False
+    if info.isConfirmedItem(obj):
+        return True
+    # otherwise, when not replaying the request already, it is tried to
+    # delete the object, making it possible to find out if it was referenced,
+    # i.e. in case a link integrity exception was raised
+    linked = False
+    parent = obj.aq_inner.aq_parent
+    try:
+        parent.manage_delObjects(obj.getId())
+    except OFS.ObjectManager.BeforeDeleteException, e:
+        linked = True
+    except: # ignore other exceptions, not useful to us at this point
+        pass
+    # since this function is called first thing in `delete_confirmation.cpy`
+    # and therefore nothing can possibly have changed yet at this point, we
+    # might as well "begin" a new transaction instead of using a savepoint,
+    # which creates a funny exception when using zeo (see #6666)
+    transaction.begin()
+    return linked
 
-# Keep these here to not fully change the old API
+# BBB Plone 3.5: Cyclic import errors are bad, deprecate these import locations.
 # Put these at the end to avoid an ImportError for safe_unicode
 from i18nl10n import utranslate
 from i18nl10n import ulocalized_time
-from i18nl10n import getGlobalTranslationService
+
+import zope.deprecation
+zope.deprecation.deprecated(
+    ('getGlobalTranslationService'),
+    "This reference to getGlobalTranslationService will be removed in Plone 3.5"
+    ". Please import it from Products.PageTemplates.GlobalTranslationService.")
+zope.deprecation.deprecated(
+    ('utranslate'),
+    "This reference to the utranslate method has been deprecated will be "
+    "removed in Plone 3.5. Please use the translate method of the "
+    "GlobalTranslationService instead.")
+zope.deprecation.deprecated(
+    ('ulocalized_time'),
+    "This reference to the ulocalized_time method has been deprecated will be "
+    "removed in Plone 3.5. Please import it from Products.CMFPlone.i18nl10n.")
+zope.deprecation.deprecated(
+    ('BrowserView'),
+    "Products.CMFPlone.utils.BrowserView will be removed in Plone 3.5. "
+    "Please use Products.Five.BrowserView instead.")
+zope.deprecation.deprecated(
+    ('context'),
+    "This method is only useful for classes derived from the deprectaed "
+    "Products.CMFPlone.utils.BrowserView class. Please use "
+    "Products.Five.BrowserView as base class and aq_inner(self.context) "
+    "to get the current context.")
+
 
