@@ -12,7 +12,7 @@
 ##############################################################################
 """ CMFTopic product:  unit test utilities.
 
-$Id: common.py 38418 2005-09-09 08:40:13Z yuppie $
+$Id: common.py 77369 2007-07-03 16:17:37Z yuppie $
 """
 
 from unittest import TestCase
@@ -30,11 +30,7 @@ class CriterionTestCase(TestCase):
         verifyClass( ICriterion, self._getTargetClass() )
 
     def test_z3interfaces(self):
-        try:
-            from zope.interface.verify import verifyClass
-            from Products.CMFTopic.interfaces import ICriterion
-        except ImportError:
-            # BBB: for Zope 2.7
-            return
+        from zope.interface.verify import verifyClass
+        from Products.CMFTopic.interfaces import ICriterion
 
-        verifyClass( ICriterion, self._getTargetClass() )
+        verifyClass(ICriterion, self._getTargetClass())
