@@ -12,45 +12,25 @@
 ##############################################################################
 """Unique id generation and handling.
 
-$Id: __init__.py 69357 2006-08-05 16:43:48Z shh $
+$Id: __init__.py 68513 2006-06-07 16:45:25Z yuppie $
 """
 
-from sys import modules
-
 from Products.CMFCore import utils
-from Products.CMFCore.interfaces import ISiteRoot
-from Products.GenericSetup import EXTENSION
-from Products.GenericSetup import profile_registry
 
 import UniqueIdAnnotationTool
 import UniqueIdGeneratorTool
 import UniqueIdHandlerTool
 
+
 tools = (
     UniqueIdAnnotationTool.UniqueIdAnnotationTool,
     UniqueIdGeneratorTool.UniqueIdGeneratorTool,
     UniqueIdHandlerTool.UniqueIdHandlerTool,
 )
 
-this_module = modules[ __name__ ]
-
-z_tool_bases = utils.initializeBasesPhase1(tools, this_module)
-
-my_globals=globals()
-
 def initialize(context):
 
-    utils.initializeBasesPhase2(z_tool_bases, context)
-
     utils.ToolInit( 'CMF Unique Id Tool'
                   , tools=tools
                   , icon='tool.gif'
                   ).initialize(context)
-
-    profile_registry.registerProfile('default',
-                                     'CMFUid',
-                                     'Adds UID support.',
-                                     'profiles/default',
-                                     'CMFUid',
-                                     EXTENSION,
-                                     for_=ISiteRoot)
