@@ -12,7 +12,7 @@
 ##############################################################################
 """ Web-configurable workflow UI.
 
-$Id: WorkflowUIMixin.py 73952 2007-03-31 13:45:25Z alecm $
+$Id: WorkflowUIMixin.py 77182 2007-06-28 17:25:27Z yuppie $
 """
 
 import os
@@ -20,6 +20,7 @@ import os
 from Globals import DTMLFile
 from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
+from AccessControl.requestmethod import postonly
 from Acquisition import aq_get
 
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
@@ -27,7 +28,6 @@ from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from permissions import ManagePortal
 from Guard import Guard
 from utils import _dtmldir
-from Products.CMFCore.utils import postonly
 
 try:
     #
@@ -54,10 +54,13 @@ class WorkflowUIMixin:
     manage_groups = PageTemplateFile('workflow_groups.pt', _dtmldir)
 
     security.declareProtected(ManagePortal, 'setProperties')
-    def setProperties(self, title, manager_bypass=0, props=None, REQUEST=None):
+    @postonly
+    def setProperties(self, title, manager_bypass=0, props=None, 
+                      REQUEST=None, description=''):
         """Sets basic properties.
         """
         self.title = str(title)
+        self.description = str(description)
         self.manager_bypass = manager_bypass and 1 or 0
         g = Guard()
         if g.changeFromProperties(props or REQUEST):
@@ -67,7 +70,6 @@ class WorkflowUIMixin:
         if REQUEST is not None:
             return self.manage_properties(
                 REQUEST, manage_tabs_message='Properties changed.')
-    setProperties = postonly(setProperties)
 
     _permissions_form = DTMLFile('workflow_permissions', _dtmldir)
 
@@ -81,6 +83,7 @@ class WorkflowUIMixin:
                                       )
 
     security.declareProtected(ManagePortal, 'addManagedPermission')
+    @postonly
     def addManagedPermission(self, p, REQUEST=None):
         """Adds to the list of permissions to manage.
         """
@@ -92,9 +95,9 @@ class WorkflowUIMixin:
         if REQUEST is not None:
             return self.manage_permissions(
                 REQUEST, manage_tabs_message='Permission added.')
-    addManagedPermission = postonly(addManagedPermission)
 
     security.declareProtected(ManagePortal, 'delManagedPermissions')
+    @postonly
     def delManagedPermissions(self, ps, REQUEST=None):
         """Removes from the list of permissions to manage.
         """
@@ -106,7 +109,6 @@ class WorkflowUIMixin:
         if REQUEST is not None:
             return self.manage_permissions(
                 REQUEST, manage_tabs_message='Permission(s) removed.')
-    delManagedPermissions = postonly(delManagedPermissions)
 
     security.declareProtected(ManagePortal, 'getPossiblePermissions')
     def getPossiblePermissions(self):
@@ -136,6 +138,7 @@ class WorkflowUIMixin:
             return [g['id'] for g in groups]
 
     security.declareProtected(ManagePortal, 'addGroup')
+    @postonly
     def addGroup(self, group, RESPONSE=None, REQUEST=None):
         """Adds a group by name.
         """
@@ -146,9 +149,9 @@ class WorkflowUIMixin:
             RESPONSE.redirect(
                 "%s/manage_groups?manage_tabs_message=Added+group."
                 % self.absolute_url())
-    addGroup = postonly(addGroup)
 
     security.declareProtected(ManagePortal, 'delGroups')
+    @postonly
     def delGroups(self, groups, RESPONSE=None, REQUEST=None):
         """Removes groups by name.
         """
@@ -157,7 +160,6 @@ class WorkflowUIMixin:
             RESPONSE.redirect(
                 "%s/manage_groups?manage_tabs_message=Groups+removed."
                 % self.absolute_url())
-    delGroups = postonly(delGroups)
 
     security.declareProtected(ManagePortal, 'getAvailableRoles')
     def getAvailableRoles(self):
@@ -185,6 +187,7 @@ class WorkflowUIMixin:
         return self.valid_roles()
 
     security.declareProtected(ManagePortal, 'setRoles')
+    @postonly
     def setRoles(self, roles, RESPONSE=None, REQUEST=None):
         """Changes the list of roles mapped to groups by this workflow.
         """
@@ -197,7 +200,6 @@ class WorkflowUIMixin:
             RESPONSE.redirect(
                 "%s/manage_groups?manage_tabs_message=Roles+changed."
                 % self.absolute_url())
-    setRoles = postonly(setRoles)
 
     security.declareProtected(ManagePortal, 'getGuard')
     def getGuard(self):
