@@ -12,24 +12,27 @@
 ##############################################################################
 """ Unit tests for DCWorkflow module.
 
-$Id: test_DCWorkflow.py 40346 2005-11-23 17:15:03Z yuppie $
+$Id: test_DCWorkflow.py 78745 2007-08-10 20:19:46Z mj $
 """
 
-from unittest import TestCase, TestSuite, makeSuite, main
+import unittest
 import Testing
-try:
-    import Zope2
-except ImportError: # BBB: for Zope 2.7
-    import Zope as Zope2
-Zope2.startup()
 
+from zope.component import adapter
+from zope.component import provideHandler
+
+from Products.CMFCore.testing import TraversingEventZCMLLayer
 from Products.CMFCore.tests.base.dummy import DummyContent
 from Products.CMFCore.tests.base.dummy import DummySite
 from Products.CMFCore.tests.base.dummy import DummyTool
 from Products.CMFCore.WorkflowTool import WorkflowTool
+from Products.DCWorkflow.interfaces import IAfterTransitionEvent
+from Products.DCWorkflow.interfaces import IBeforeTransitionEvent
 
 
-class DCWorkflowDefinitionTests(TestCase):
+class DCWorkflowDefinitionTests(unittest.TestCase):
+
+    layer = TraversingEventZCMLLayer
 
     def setUp(self):
         self.site = DummySite('site')
@@ -46,12 +49,8 @@ class DCWorkflowDefinitionTests(TestCase):
         verifyClass(IWorkflowDefinition, DCWorkflowDefinition)
 
     def test_z3interfaces(self):
-        try:
-            from zope.interface.verify import verifyClass
-            from Products.CMFCore.interfaces import IWorkflowDefinition
-        except ImportError:
-            # BBB: for Zope 2.7
-            return
+        from zope.interface.verify import verifyClass
+        from Products.CMFCore.interfaces import IWorkflowDefinition
         from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
 
         verifyClass(IWorkflowDefinition, DCWorkflowDefinition)
@@ -100,6 +99,65 @@ class DCWorkflowDefinitionTests(TestCase):
 
         # XXX more
 
+    def test_events(self):
+
+        events = []
+
+        @adapter(IBeforeTransitionEvent)
+        def _handleBefore(event):
+            events.append(event)
+        provideHandler(_handleBefore)
+
+        @adapter(IAfterTransitionEvent)
+        def _handleAfter(event):
+            events.append(event)
+        provideHandler(_handleAfter)
+
+        wftool = self.site.portal_workflow
+        wf = self._getDummyWorkflow()
+
+        dummy = self.site._setObject( 'dummy', DummyContent() )
+        wftool.notifyCreated(dummy)
+        wf.doActionFor(dummy, 'publish', comment='foo', test='bar')
+
+        self.assertEquals(4, len(events))
+
+        evt = events[0]
+        self.failUnless(IBeforeTransitionEvent.providedBy(evt))
+        self.assertEquals(dummy, evt.object)
+        self.assertEquals('private', evt.old_state.id)
+        self.assertEquals('private', evt.new_state.id)
+        self.assertEquals(None, evt.transition)
+        self.assertEquals({}, evt.status)
+        self.assertEquals(None, evt.kwargs)
+
+        evt = events[1]
+        self.failUnless(IAfterTransitionEvent.providedBy(evt))
+        self.assertEquals(dummy, evt.object)
+        self.assertEquals('private', evt.old_state.id)
+        self.assertEquals('private', evt.new_state.id)
+        self.assertEquals(None, evt.transition)
+        self.assertEquals({'state': 'private', 'comments': ''}, evt.status)
+        self.assertEquals(None, evt.kwargs)
+
+        evt = events[2]
+        self.failUnless(IBeforeTransitionEvent.providedBy(evt))
+        self.assertEquals(dummy, evt.object)
+        self.assertEquals('private', evt.old_state.id)
+        self.assertEquals('published', evt.new_state.id)
+        self.assertEquals('publish', evt.transition.id)
+        self.assertEquals({'state': 'private', 'comments': ''}, evt.status)
+        self.assertEquals({'test' : 'bar', 'comment' : 'foo'}, evt.kwargs)
+
+        evt = events[3]
+        self.failUnless(IAfterTransitionEvent.providedBy(evt))
+        self.assertEquals(dummy, evt.object)
+        self.assertEquals('private', evt.old_state.id)
+        self.assertEquals('published', evt.new_state.id)
+        self.assertEquals('publish', evt.transition.id)
+        self.assertEquals({'state': 'published', 'comments': 'foo'}, evt.status)
+        self.assertEquals({'test' : 'bar', 'comment' : 'foo'}, evt.kwargs)
+
     def test_checkTransitionGuard(self):
 
         wftool = self.site.portal_workflow
@@ -132,9 +190,10 @@ class DCWorkflowDefinitionTests(TestCase):
 
 
 def test_suite():
-    return TestSuite((
-        makeSuite(DCWorkflowDefinitionTests),
+    return unittest.TestSuite((
+        unittest.makeSuite(DCWorkflowDefinitionTests),
         ))
 
 if __name__ == '__main__':
-    main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
