@@ -12,29 +12,24 @@
 ##############################################################################
 """DCWorkflow export / import unit tests.
 
-$Id: test_exportimport.py 69757 2006-08-24 05:00:14Z alecm $
+$Id: test_exportimport.py 80705 2007-10-08 07:41:41Z rossp $
 """
 
 import unittest
 import Testing
 
-import Products
 from Products.PythonScripts.PythonScript import PythonScript
 from Products.ExternalMethod.ExternalMethod import ExternalMethod
-from Products.Five import zcml
 
-import Products.GenericSetup.PythonScripts
 from Products.CMFCore.exportimport.tests.test_workflow \
         import _BINDINGS_TOOL_EXPORT
-from Products.CMFCore.exportimport.tests.test_workflow import _DUMMY_ZCML
 from Products.CMFCore.exportimport.tests.test_workflow \
         import _EMPTY_TOOL_EXPORT
 from Products.CMFCore.exportimport.tests.test_workflow \
         import _WorkflowSetup as WorkflowSetupBase
-from Products.CMFCore.exportimport.tests.test_workflow import DummyWorkflow
-from Products.CMFCore.exportimport.tests.test_workflow \
-        import DummyWorkflowTool
+from Products.CMFCore.testing import DummyWorkflow
 from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
+from Products.DCWorkflow.testing import ExportImportZCMLLayer
 from Products.DCWorkflow.Transitions import TRIGGER_USER_ACTION
 from Products.DCWorkflow.Transitions import TRIGGER_AUTOMATIC
 from Products.GenericSetup.tests.common import DummyExportContext
@@ -76,20 +71,6 @@ class _GuardChecker:
 
 class _WorkflowSetup(WorkflowSetupBase):
 
-    def setUp(self):
-        WorkflowSetupBase.setUp(self)
-        zcml.load_config('permissions.zcml', Products.Five)
-        zcml.load_config('configure.zcml', Products.DCWorkflow)
-        zcml.load_config('configure.zcml', Products.GenericSetup.PythonScripts)
-        try:
-            import zope.traversing
-        except ImportError:
-            # BBB: Zope < 2.10
-            pass
-        else:
-            # Traversal adapters are needed for TALES
-            zcml.load_config('configure.zcml', zope.traversing)
-
     def _initDCWorkflow( self, workflow_id ):
 
         wf_tool = self.root.site.portal_workflow
@@ -210,6 +191,8 @@ class _WorkflowSetup(WorkflowSetupBase):
 
 class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
+    layer = ExportImportZCMLLayer
+
     def _getTargetClass( self ):
         from Products.DCWorkflow.exportimport \
                 import WorkflowDefinitionConfigurator
@@ -229,6 +212,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         self.assertEqual( info[ 'id' ], WF_ID )
         self.assertEqual( info[ 'meta_type' ], DCWorkflowDefinition.meta_type )
         self.assertEqual( info[ 'title' ], dcworkflow.title )
+        self.assertEqual( info['description'], dcworkflow.description )
 
         self.assertEqual( info[ 'state_variable' ], dcworkflow.state_var )
 
@@ -482,11 +466,13 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID = 'empty'
         WF_TITLE = 'Empty DCWorkflow'
+        WF_DESCRIPTION = 'This is a empty workflow'
         WF_INITIAL_STATE = 'initial'
 
         site = self._initSite()
         dcworkflow = self._initDCWorkflow( WF_ID )
         dcworkflow.title = WF_TITLE
+        dcworkflow.description = WF_DESCRIPTION
         dcworkflow.initial_state = WF_INITIAL_STATE
 
         configurator = self._makeOne(dcworkflow).__of__(site)
@@ -494,6 +480,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         self._compareDOM( configurator.generateWorkflowXML()
                         , _EMPTY_WORKFLOW_EXPORT % ( WF_ID
                                                    , WF_TITLE
+                                                   , WF_DESCRIPTION
                                                    , WF_INITIAL_STATE
                                                    ) )
 
@@ -501,11 +488,13 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal Workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
         dcworkflow = self._initDCWorkflow( WF_ID )
         dcworkflow.title = WF_TITLE
+        dcworkflow.description = WF_DESCRIPTION
         dcworkflow.initial_state = WF_INITIAL_STATE
         dcworkflow.permissions = _WF_PERMISSIONS
         self._initVariables( dcworkflow )
@@ -520,6 +509,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
                         , _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -528,14 +518,17 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID_1 = 'dc1'
         WF_TITLE_1 = 'Normal DCWorkflow #1'
+        WF_DESCRIPTION_1 = 'Normal Number 1'
         WF_ID_2 = 'dc2'
         WF_TITLE_2 = 'Normal DCWorkflow #2'
+        WF_DESCRIPTION_2 = 'Normal Numer 2'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
 
         dcworkflow_1 = self._initDCWorkflow( WF_ID_1 )
         dcworkflow_1.title = WF_TITLE_1
+        dcworkflow_1.description = WF_DESCRIPTION_1
         dcworkflow_1.initial_state = WF_INITIAL_STATE
         dcworkflow_1.permissions = _WF_PERMISSIONS
         self._initVariables( dcworkflow_1 )
@@ -546,6 +539,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         dcworkflow_2 = self._initDCWorkflow( WF_ID_2 )
         dcworkflow_2.title = WF_TITLE_2
+        dcworkflow_2.description = WF_DESCRIPTION_2
         dcworkflow_2.initial_state = WF_INITIAL_STATE
         dcworkflow_2.permissions = _WF_PERMISSIONS
         self._initVariables( dcworkflow_2 )
@@ -560,6 +554,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
                         , _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID_1
                             , 'title' : WF_TITLE_1
+                            , 'description' : WF_DESCRIPTION_1
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID_1.replace(' ', '_')
                             } )
@@ -570,6 +565,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
                         , _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID_2
                             , 'title' : WF_TITLE_2
+                            , 'description' : WF_DESCRIPTION_2
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID_2.replace(' ', '_')
                             } )
@@ -578,6 +574,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID = 'empty'
         WF_TITLE = 'Empty DCWorkflow'
+        WF_DESCRIPTION = 'This is an empty workflow'
         WF_INITIAL_STATE = 'initial'
 
         site = self._initSite()
@@ -594,12 +591,15 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML( _EMPTY_WORKFLOW_EXPORT
                                          % ( WF_ID
                                            , WF_TITLE
+                                           , WF_DESCRIPTION
                                            , WF_INITIAL_STATE
                                            ) )
 
+        self.assertEqual(description, WF_DESCRIPTION)
         self.assertEqual( len( states ), 0 )
         self.assertEqual( len( transitions ), 0 )
         self.assertEqual( len( variables ), 0 )
@@ -611,6 +611,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'This is a normal DCWorkflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -627,16 +628,19 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
 
         self.assertEqual( workflow_id, WF_ID )
         self.assertEqual( title, WF_TITLE )
+        self.assertEqual( description, WF_DESCRIPTION )
         self.assertEqual( state_variable, 'state' )
         self.assertEqual( initial_state, WF_INITIAL_STATE )
 
@@ -644,6 +648,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -660,10 +665,12 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -707,6 +714,7 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -723,10 +731,12 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description 
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -770,10 +780,9 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
     def test_parseWorkflowXML_normal_variables( self ):
 
-        from Products.DCWorkflow.exportimport import TRIGGER_TYPES
-
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -790,10 +799,12 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -847,10 +858,9 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
     def test_parseWorkflowXML_normal_worklists( self ):
 
-        from Products.DCWorkflow.exportimport import TRIGGER_TYPES
-
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -867,10 +877,12 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -908,10 +920,9 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
     def test_parseWorkflowXML_normal_permissions( self ):
 
-        from Products.DCWorkflow.exportimport import TRIGGER_TYPES
-
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -928,10 +939,12 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description' : WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -944,10 +957,9 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
 
     def test_parseWorkflowXML_normal_scripts( self ):
 
-        from Products.DCWorkflow.exportimport import TRIGGER_TYPES
-
         WF_ID = 'normal'
         WF_TITLE = 'Normal DCWorkflow'
+        WF_DESCRIPTION = 'Normal workflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -964,10 +976,12 @@ class WorkflowDefinitionConfiguratorTests( _WorkflowSetup, _GuardChecker ):
         , worklists
         , permissions
         , scripts
+        , description
         ) = configurator.parseWorkflowXML(
                           _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID
                             , 'title' : WF_TITLE
+                            , 'description': WF_DESCRIPTION
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID.replace(' ', '_')
                             } )
@@ -1265,6 +1279,7 @@ _EMPTY_WORKFLOW_EXPORT = """\
 <dc-workflow
     workflow_id="%s"
     title="%s"
+    description="%s"
     state_variable="state"
     initial_state="%s">
 </dc-workflow>
@@ -1520,6 +1535,7 @@ _NORMAL_WORKFLOW_EXPORT = """\
 <dc-workflow
     workflow_id="%(workflow_id)s"
     title="%(title)s"
+    description="%(description)s"
     state_variable="state"
     initial_state="%(initial_state)s">
  <permission>Open content for modifications</permission>
@@ -1758,9 +1774,10 @@ _NORMAL_WORKFLOW_EXPORT = """\
 </dc-workflow>
 """
 
-class Test_exportWorkflow( _WorkflowSetup
-                         , _GuardChecker
-                         ):
+
+class Test_exportWorkflow(_WorkflowSetup, _GuardChecker):
+
+    layer = ExportImportZCMLLayer
 
     def test_empty( self ):
         from Products.CMFCore.exportimport.workflow import exportWorkflowTool
@@ -1780,8 +1797,10 @@ class Test_exportWorkflow( _WorkflowSetup
 
         WF_ID_NON = 'non_dcworkflow'
         WF_TITLE_NON = 'Non-DCWorkflow'
+        WF_DESCRIPTION_NON = 'Not a DCWorkflow'
         WF_ID_DC = 'dcworkflow'
         WF_TITLE_DC = 'DCWorkflow'
+        WF_DESCRIPTION_DC = 'I am a DCWorkflow'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
@@ -1789,10 +1808,12 @@ class Test_exportWorkflow( _WorkflowSetup
         wf_tool = site.portal_workflow
         nondcworkflow = DummyWorkflow( WF_TITLE_NON )
         nondcworkflow.title = WF_TITLE_NON
+        nondcworkflow.description = WF_DESCRIPTION_NON
         wf_tool._setObject( WF_ID_NON, nondcworkflow )
 
         dcworkflow = self._initDCWorkflow( WF_ID_DC )
         dcworkflow.title = WF_TITLE_DC
+        dcworkflow.description = WF_DESCRIPTION_DC
         dcworkflow.initial_state = WF_INITIAL_STATE
         dcworkflow.permissions = _WF_PERMISSIONS
         self._initVariables( dcworkflow )
@@ -1818,6 +1839,7 @@ class Test_exportWorkflow( _WorkflowSetup
                         , _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID_DC
                             , 'title' : WF_TITLE_DC
+                            , 'description' : WF_DESCRIPTION_DC
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID_DC.replace(' ', '_')
                             } )
@@ -1834,12 +1856,14 @@ class Test_exportWorkflow( _WorkflowSetup
 
         WF_ID_DC = 'name with spaces'
         WF_TITLE_DC = 'DCWorkflow with spaces'
+        WF_DESCRIPTION_DC = 'Workflow w/spaces'
         WF_INITIAL_STATE = 'closed'
 
         site = self._initSite()
 
         dcworkflow = self._initDCWorkflow( WF_ID_DC )
         dcworkflow.title = WF_TITLE_DC
+        dcworkflow.description = WF_DESCRIPTION_DC
         dcworkflow.initial_state = WF_INITIAL_STATE
         dcworkflow.permissions = _WF_PERMISSIONS
         self._initVariables( dcworkflow )
@@ -1866,6 +1890,7 @@ class Test_exportWorkflow( _WorkflowSetup
                         , _NORMAL_WORKFLOW_EXPORT
                           % { 'workflow_id' : WF_ID_DC
                             , 'title' : WF_TITLE_DC
+                            , 'description' : WF_DESCRIPTION_DC
                             , 'initial_state' : WF_INITIAL_STATE
                             , 'workflow_filename' : WF_ID_DC.replace(' ', '_')
                             } )
@@ -1878,22 +1903,24 @@ class Test_exportWorkflow( _WorkflowSetup
         self.assertEqual( text, _AFTER_CLOSE_SCRIPT)
         self.assertEqual( content_type, 'text/plain' )
 
-class Test_importWorkflow( _WorkflowSetup
-                         , _GuardChecker
-                         ):
 
-    def _importNormalWorkflow( self, wf_id, wf_title, wf_initial_state ):
+class Test_importWorkflow(_WorkflowSetup, _GuardChecker):
+
+    layer = ExportImportZCMLLayer
+
+    def _importNormalWorkflow( self, wf_id, wf_title, 
+                               wf_description, wf_initial_state ):
         from Products.CMFCore.exportimport.workflow import importWorkflowTool
 
         site, context = self._prepareImportNormalWorkflow(
-            wf_id, wf_title, wf_initial_state)
+            wf_id, wf_title, wf_description, wf_initial_state)
 
         importWorkflowTool(context)
 
         return site.portal_workflow
 
-    def _prepareImportNormalWorkflow(self, wf_id, wf_title, wf_initial_state,
-                                     site=None, purge=True):
+    def _prepareImportNormalWorkflow(self, wf_id, wf_title, wf_description, 
+                                     wf_initial_state, site=None, purge=True):
         if site is None:
             site = self._initSite()
         workflow_filename = wf_id.replace(' ', '_')
@@ -1909,6 +1936,7 @@ class Test_importWorkflow( _WorkflowSetup
                       ] = ( _NORMAL_WORKFLOW_EXPORT
                             % { 'workflow_id' : wf_id
                               , 'title' : wf_title
+                              , 'description' : wf_description
                               , 'initial_state' : wf_initial_state
                               , 'workflow_filename' : workflow_filename
                               }
@@ -2083,16 +2111,18 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_purge'
         WF_TITLE = 'DC Workflow testing purge'
+        WF_DESCRIPTION = 'Test Purge'
         WF_INITIAL_STATE = 'closed'
 
         # Import a first time
         site, context = self._prepareImportNormalWorkflow(
-            WF_ID, WF_TITLE, WF_INITIAL_STATE)
+            WF_ID, WF_TITLE, WF_DESCRIPTION, WF_INITIAL_STATE)
         importWorkflowTool(context)
 
         # Now reimport without purge
         site, context = self._prepareImportNormalWorkflow(
-            WF_ID, WF_TITLE, WF_INITIAL_STATE, site=site, purge=False)
+            WF_ID, WF_TITLE, WF_DESCRIPTION, WF_INITIAL_STATE, 
+            site=site, purge=False)
         importWorkflowTool(context)
         workflow = site.portal_workflow.objectValues()[1]
 
@@ -2119,9 +2149,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_tool'
         WF_TITLE = 'DC Workflow testing tool'
+        WF_DESCRIPTION = 'Testing Tool'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE,
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         self.assertEqual( len( tool.objectIds() ), 2 )
         self.assertEqual( tool.objectIds()[ 1 ], WF_ID )
@@ -2130,9 +2162,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_attrs'
         WF_TITLE = 'DC Workflow testing attrs'
+        WF_DESCRIPTION = 'Testing Attributes'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE,
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
         self.assertEqual( workflow.meta_type, DCWorkflowDefinition.meta_type )
@@ -2144,9 +2178,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_permissions'
         WF_TITLE = 'DC Workflow testing permissions'
+        WF_DESCRIPTION = 'Testing Permissions'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE,
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
 
@@ -2160,9 +2196,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_variables'
         WF_TITLE = 'DC Workflow testing variables'
+        WF_DESCRIPTION = 'Testing Variables'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE,
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
 
@@ -2192,9 +2230,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_states'
         WF_TITLE = 'DC Workflow testing states'
+        WF_DESCRIPTION = 'Testing States'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE,
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
 
@@ -2249,9 +2289,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_transitions'
         WF_TITLE = 'DC Workflow testing transitions'
+        WF_DESCRIPTION = 'Testing Transitions'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE,
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
 
@@ -2291,9 +2333,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_worklists'
         WF_TITLE = 'DC Workflow testing worklists'
+        WF_DESCRIPTION = 'Testing Worklists'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, 
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
 
@@ -2357,9 +2401,11 @@ class Test_importWorkflow( _WorkflowSetup
 
         WF_ID = 'dcworkflow_scripts'
         WF_TITLE = 'DC Workflow testing scripts'
+        WF_DESCRIPTION = 'Testing Scripts'
         WF_INITIAL_STATE = 'closed'
 
-        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, WF_INITIAL_STATE )
+        tool = self._importNormalWorkflow( WF_ID, WF_TITLE, 
+                                           WF_DESCRIPTION, WF_INITIAL_STATE )
 
         workflow = tool.objectValues()[ 1 ]
 
@@ -2377,6 +2423,52 @@ class Test_importWorkflow( _WorkflowSetup
             if script.meta_type == PythonScript.meta_type:
                 self.assertEqual( script.manage_FTPget(), expected[ 1 ] )
 
+    def test_scripts_with_invalid_meta_type(self):
+        """
+        A script with an invalid meta_type should raise an error.
+
+        Otherwise the previous script will be added for that script.
+        """
+        from Products.DCWorkflow import exportimport
+
+        tool = self._importNormalWorkflow(
+            'dcworkflow_scripts', 'DC Workflow testing scripts',
+            'Testing Scripts', 'closed')
+        workflow = tool.objectValues()[1]
+        scripts = workflow.scripts
+
+        s_infos = [
+            dict(script_id='invalid', meta_type='invalid',
+                 filename='')]
+        self.assertRaises(ValueError, 
+                          exportimport._initDCWorkflowScripts,
+                          workflow, s_infos, None)
+
+    def test_scripts_by_meta_type(self):
+        """
+        Constructors for meta_types other than those hard coded should
+        be looked up.
+        """
+        from Products.DCWorkflow import exportimport
+
+        tool = self._importNormalWorkflow(
+            'dcworkflow_scripts', 'DC Workflow testing scripts',
+            'Testing Scripts', 'closed')
+        workflow = tool.objectValues()[1]
+        scripts = workflow.scripts
+
+        scripts.all_meta_types = scripts.all_meta_types() + [
+            dict(instance=PythonScript, name='Foo Script')]
+
+        s_infos = [
+            dict(script_id='doc', meta_type='DTML Document',
+                 filename=''),
+            dict(script_id='bar', meta_type='Foo Script',
+                 filename='')]
+        exportimport._initDCWorkflowScripts(workflow, s_infos, None)
+        
+        self.assertEqual(scripts['doc'].meta_type, 'DTML Document')
+        self.assertEqual(scripts['bar'].meta_type, 'Script (Python)')
 
 def test_suite():
     return unittest.TestSuite((
@@ -2386,4 +2478,5 @@ def test_suite():
         ))
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+    from Products.CMFCore.testing import run
+    run(test_suite())
