@@ -12,14 +12,17 @@
 ##############################################################################
 """ Classes:  ImportStepRegistry, ExportStepRegistry
 
-$Id: registry.py 67831 2006-05-02 12:33:03Z regebro $
+$Id: registry.py 79508 2007-09-06 22:54:10Z wichert $
 """
-
+import os
 from xml.sax import parseString
+from xml.sax.handler import ContentHandler
 
 from AccessControl import ClassSecurityInfo
 from Acquisition import Implicit
 from Globals import InitializeClass
+from App.FactoryDispatcher import ProductDispatcher
+import App.Product
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from zope.interface import implements
 
@@ -29,7 +32,7 @@ from interfaces import IExportStepRegistry
 from interfaces import IToolsetRegistry
 from interfaces import IProfileRegistry
 from permissions import ManagePortal
-from utils import HandlerBase
+from metadata import ProfileMetadata
 from utils import _xmldir
 from utils import _getDottedName
 from utils import _resolveDottedName
@@ -108,7 +111,10 @@ class ImportStepRegistry( Implicit ):
         if info is None:
             return default
 
-        return info.copy()
+        result = info.copy()
+        result['invalid'] =  _resolveDottedName( result[ 'handler' ] ) is None
+
+        return result
 
     security.declareProtected( ManagePortal, 'listStepMetadata' )
     def listStepMetadata( self ):
@@ -168,7 +174,8 @@ class ImportStepRegistry( Implicit ):
           - Attempting to register an older one after a newer one results
             in a KeyError.
 
-        o 'handler' should implement IImportPlugin.
+        o 'handler' is the dottoed name of a handler which should implement
+           IImportPlugin.
 
         o 'dependencies' is a tuple of step ids which have to run before
           this step in order to be able to run at all. Registration of
@@ -189,16 +196,23 @@ class ImportStepRegistry( Implicit ):
             raise KeyError( 'Existing registration for step %s, version %s'
                           % ( id, already[ 'version' ] ) )
 
+        if not isinstance(handler, str):
+            handler = _getDottedName( handler )
+
         if title is None or description is None:
 
-            t, d = _extractDocstring( handler, id, '' )
+            method = _resolveDottedName(handler)
+            if method is None:
+                t,d = id, ''
+            else:
+                t, d = _extractDocstring( method, id, '' )
 
             title = title or t
             description = description or d
 
         info = { 'id'           : id
                , 'version'      : version
-               , 'handler'      : _getDottedName( handler )
+               , 'handler'      : handler
                , 'dependencies' : dependencies
                , 'title'        : title
                , 'description'  : description
@@ -323,7 +337,10 @@ class ExportStepRegistry( Implicit ):
         if info is None:
             return default
 
-        return info.copy()
+        result = info.copy()
+        result['invalid'] =  _resolveDottedName( result[ 'handler' ] ) is None
+
+        return result
 
     security.declareProtected( ManagePortal, 'listStepMetadata' )
     def listStepMetadata( self ):
@@ -367,7 +384,8 @@ class ExportStepRegistry( Implicit ):
 
         o 'id' is the unique identifier for this step
 
-        o 'step' should implement IExportPlugin.
+        o 'handler' is the dottoed name of a handler which should implement
+           IImportPlugin.
 
         o 'title' is a one-line UI description for this step.
           If None, the first line of the documentation string of the step
@@ -377,15 +395,22 @@ class ExportStepRegistry( Implicit ):
           If None, the remaining line of the documentation string of
           the step is used, or default to ''.
         """
+        if not isinstance(handler, str):
+            handler = _getDottedName( handler )
+
         if title is None or description is None:
 
-            t, d = _extractDocstring( handler, id, '' )
+            method = _resolveDottedName(handler)
+            if method is None:
+                t,d = id, ''
+            else:
+                t, d = _extractDocstring( method, id, '' )
 
             title = title or t
             description = description or d
 
         info = { 'id'           : id
-               , 'handler'      : _getDottedName( handler )
+               , 'handler'      : handler
                , 'title'        : title
                , 'description'  : description
                }
@@ -537,6 +562,7 @@ class ToolsetRegistry( Implicit ):
 
 InitializeClass( ToolsetRegistry )
 
+
 class ProfileRegistry( Implicit ):
 
     """ Track registered profiles.
@@ -550,7 +576,7 @@ class ProfileRegistry( Implicit ):
 
         self.clear()
 
-    security.declareProtected( ManagePortal, '' )
+    security.declareProtected( ManagePortal, 'getProfileInfo' )
     def getProfileInfo( self, profile_id, for_=None ):
 
         """ See IProfileRegistry.
@@ -610,6 +636,32 @@ class ProfileRegistry( Implicit ):
                , 'for': for_
                }
 
+        metadata = ProfileMetadata( path )()
+
+        version = metadata.get( 'version', None )
+        if version is None and product is not None:
+            prod_name = product.split('.')[-1]
+            prod_module = getattr(App.Product.Products, prod_name, None)
+            if prod_module is not None:
+                prod_path = prod_module.__path__[0]
+
+                # Retrieve version number from any suitable version.txt
+                for fname in ('version.txt', 'VERSION.txt', 'VERSION.TXT'):
+                    try:
+                        fpath = os.path.join( prod_path, fname )
+                        fhandle = open( fpath, 'r' )
+                        version = fhandle.read().strip()
+                        fhandle.close()
+                        break
+                    except IOError:
+                        continue
+
+            if version is not None:
+                metadata[ 'version' ] = version
+
+        # metadata.xml description trumps ZCML description... awkward
+        info.update( metadata )
+
         self._profile_info[ profile_id ] = info
 
     security.declarePrivate( 'clear' )
@@ -622,7 +674,31 @@ InitializeClass( ProfileRegistry )
 
 _profile_registry = ProfileRegistry()
 
-class _ImportStepRegistryParser( HandlerBase ):
+
+#
+#   XML parser
+#
+
+class _HandlerBase(ContentHandler):
+
+    _MARKER = object()
+
+    def _extract(self, attrs, key):
+        result = attrs.get(key, self._MARKER)
+
+        if result is self._MARKER:
+            return None
+
+        return self._encode(result)
+
+    def _encode(self, content):
+        if self._encoding is None:
+            return content
+
+        return content.encode(self._encoding)
+
+
+class _ImportStepRegistryParser(_HandlerBase):
 
     security = ClassSecurityInfo()
     security.declareObjectPrivate()
@@ -692,7 +768,8 @@ class _ImportStepRegistryParser( HandlerBase ):
 
 InitializeClass( _ImportStepRegistryParser )
 
-class _ExportStepRegistryParser( HandlerBase ):
+
+class _ExportStepRegistryParser(_HandlerBase):
 
     security = ClassSecurityInfo()
     security.declareObjectPrivate()
@@ -750,7 +827,7 @@ class _ExportStepRegistryParser( HandlerBase ):
 InitializeClass( _ExportStepRegistryParser )
 
 
-class _ToolsetParser( HandlerBase ):
+class _ToolsetParser(_HandlerBase):
 
     security = ClassSecurityInfo()
     security.declareObjectPrivate()
@@ -783,5 +860,4 @@ class _ToolsetParser( HandlerBase ):
         else:
             raise ValueError, 'Unknown element %s' % name
 
-
 InitializeClass( _ToolsetParser )
