@@ -12,11 +12,13 @@
 ##############################################################################
 """ Classes:  SetupTool
 
-$Id: tool.py 71275 2006-11-22 18:00:34Z alecm $
+$Id: tool.py 82137 2007-12-05 09:34:56Z wichert $
 """
 
 import os
 import time
+import logging
+from warnings import warn
 from cgi import escape
 
 from AccessControl import ClassSecurityInfo
@@ -25,9 +27,11 @@ from Globals import InitializeClass
 from OFS.Folder import Folder
 from OFS.Image import File
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
+from ZODB.POSException import ConflictError
 from zope.interface import implements
 from zope.interface import implementedBy
 
+from interfaces import BASE
 from interfaces import EXTENSION
 from interfaces import ISetupTool
 from interfaces import SKIPPED_FILES
@@ -43,6 +47,11 @@ from registry import ExportStepRegistry
 from registry import ToolsetRegistry
 from registry import _profile_registry
 
+from upgrade import listUpgradeSteps
+from upgrade import listProfilesWithUpgrades
+from upgrade import _upgrade_registry
+
+from utils import _getDottedName
 from utils import _resolveDottedName
 from utils import _wwwdir
 
@@ -97,19 +106,22 @@ def importToolset(context):
         tool_class = _resolveDottedName(info['class'])
 
         existing = getattr(aq_base(site), tool_id, None)
-        try:
-            new_tool = tool_class()
-        except TypeError:
-            new_tool = tool_class(tool_id)
-        else:
-            try:
-                new_tool._setId(tool_id)
-            except: # XXX:  ImmutableId raises result of calling MessageDialog
-                pass
-
+        # Don't even initialize the tool again, if it already exists.
         if existing is None:
-            site._setObject(tool_id, new_tool)
+            try:
+                new_tool = tool_class()
+            except TypeError:
+                new_tool = tool_class(tool_id)
+            else:
+                try:
+                    new_tool._setId(tool_id)
+                except (ConflictError, KeyboardInterrupt):
+                    raise
+                except:
+                    # XXX: ImmutableId raises result of calling MessageDialog
+                    pass
 
+            site._setObject(tool_id, new_tool)
         else:
             unwrapped = aq_base(existing)
             if not isinstance(unwrapped, tool_class):
@@ -141,8 +153,12 @@ class SetupTool(Folder):
 
     meta_type = 'Generic Setup Tool'
 
+    _baseline_context_id = ''
+    # BBB _import_context_id is a vestige of a stateful import context
     _import_context_id = ''
 
+    _profile_upgrade_versions = {}
+
     security = ClassSecurityInfo()
 
     def __init__(self, id):
@@ -150,7 +166,7 @@ class SetupTool(Folder):
         self._import_registry = ImportStepRegistry()
         self._export_registry = ExportStepRegistry()
         self._export_registry.registerStep('step_registries',
-                                           exportStepRegistries,
+                                           _getDottedName(exportStepRegistries),
                                            'Export import / export steps.',
                                           )
         self._toolset_registry = ToolsetRegistry()
@@ -163,25 +179,58 @@ class SetupTool(Folder):
 
         """ See ISetupTool.
         """
-        return 'ascii'
+        return 'utf-8'
 
     security.declareProtected(ManagePortal, 'getImportContextID')
     def getImportContextID(self):
 
         """ See ISetupTool.
         """
+        warn('getImportContextId, and the very concept of a stateful '
+             'active import context, is deprecated.  You can find the '
+             'base profile that was applied using getBaselineContextID.',
+             DeprecationWarning, stacklevel=2)
         return self._import_context_id
 
-    security.declareProtected(ManagePortal, 'setImportContext')
-    def setImportContext(self, context_id, encoding=None):
+    security.declareProtected(ManagePortal, 'getBaselineContextID')
+    def getBaselineContextID(self):
 
         """ See ISetupTool.
         """
-        self._import_context_id = context_id
-        context = self._getImportContext(context_id)
+        return self._baseline_context_id
 
+    security.declareProtected(ManagePortal, 'setImportContext')
+    def setImportContext(self, context_id, encoding=None):
+        """ See ISetupTool.
+        """
+        warn('setImportContext is deprecated.  Use setBaselineContext to '
+             'specify the baseline context, and/or runImportStepFromProfile '
+             'to run the steps from a specific import context.',
+             DeprecationWarning, stacklevel=2)
+        self._import_context_id = context_id
+
+        context_type = BASE  # snapshots are always baseline contexts
+        if context_id.startswith('profile-'):
+            profile_info = _profile_registry.getProfileInfo(context_id[8:])
+            context_type = profile_info['type']
+
+        if context_type == BASE:
+            self.setBaselineContext(context_id, encoding)
+
+    security.declareProtected(ManagePortal, 'setBaselineContext')
+    def setBaselineContext(self, context_id, encoding=None):
+        """ See ISetupTool.
+        """
+        self._baseline_context_id = context_id
+        self.applyContextById(context_id, encoding)
+
+
+    security.declareProtected(ManagePortal, 'applyContextById')
+    def applyContextById(self, context_id, encoding=None):
+        context = self._getImportContext(context_id)
         self.applyContext(context, encoding)
 
+
     security.declareProtected(ManagePortal, 'applyContext')
     def applyContext(self, context, encoding=None):
         self._updateImportStepsRegistry(context, encoding)
@@ -208,16 +257,20 @@ class SetupTool(Folder):
         """
         return self._toolset_registry
 
-    security.declareProtected(ManagePortal, 'runImportStep')
-    def runImportStep(self, step_id, run_dependencies=True, purge_old=None):
-
+    security.declareProtected(ManagePortal, 'runImportStepFromProfile')
+    def runImportStepFromProfile(self, profile_id, step_id,
+                                 run_dependencies=True, purge_old=None):
         """ See ISetupTool.
         """
-        context = self._getImportContext(self._import_context_id, purge_old)
+        old_context = self._import_context_id
+        context = self._getImportContext(profile_id, purge_old)
+
+        self.applyContext(context)
 
         info = self._import_registry.getStepMetadata(step_id)
 
         if info is None:
+            self._import_context_id = old_context
             raise ValueError, 'No such import step: %s' % step_id
 
         dependencies = info.get('dependencies', ())
@@ -238,18 +291,54 @@ class SetupTool(Folder):
         messages[step_id] = '\n'.join(message_list)
         steps.append(step_id)
 
+        self._import_context_id = old_context
+
         return { 'steps' : steps, 'messages' : messages }
 
+    security.declareProtected(ManagePortal, 'runImportStep')
+    def runImportStep(self, step_id, run_dependencies=True, purge_old=None):
+
+        """ See ISetupTool.
+        """
+        warn('The runImportStep method is deprecated.  Please use '
+             'runImportStepFromProfile instead.',
+             DeprecationWarning, stacklevel=2)
+        return self.runImportStepFromProfile(self._import_context_id,
+                                             step_id,
+                                             run_dependencies,
+                                             purge_old,
+                                             )
+
+    security.declareProtected(ManagePortal, 'runAllImportStepsFromProfile')
+    def runAllImportStepsFromProfile(self, profile_id, purge_old=None):
+
+        """ See ISetupTool.
+        """
+        __traceback_info__ = profile_id
+
+        old_context = self._import_context_id
+        context = self._getImportContext(profile_id, purge_old)
+
+        result = self._runImportStepsFromContext(context, purge_old=purge_old)
+        prefix = 'import-all-%s' % profile_id.replace(':', '_')
+        name = self._mangleTimestampName(prefix, 'log')
+        self._createReport(name, result['steps'], result['messages'])
+
+        self._import_context_id = old_context
+
+        return result
+
     security.declareProtected(ManagePortal, 'runAllImportSteps')
     def runAllImportSteps(self, purge_old=None):
 
         """ See ISetupTool.
         """
-        __traceback_info__ = self._import_context_id
-
-        context = self._getImportContext(self._import_context_id, purge_old)
-
-        return self._runImportStepsFromContext(context, purge_old=purge_old)
+        warn('The runAllImportSteps method is deprecated.  Please use '
+             'runAllImportStepsFromProfile instead.',
+             DeprecationWarning, stacklevel=2)
+        context_id = self._import_context_id
+        return self.runAllImportStepsFromProfile(self._import_context_id,
+                                                 purge_old)
 
     security.declareProtected(ManagePortal, 'runExportStep')
     def runExportStep(self, step_id):
@@ -279,7 +368,9 @@ class SetupTool(Folder):
             handler = self._export_registry.getStep(step_id)
 
             if handler is None:
-                raise ValueError('Invalid export step: %s' % step_id)
+                logger = logging.getLogger('GenericSetup')
+                logger.error('Step %s has an invalid handler' % step_id)
+                continue
 
             messages[step_id] = handler(context)
 
@@ -361,7 +452,7 @@ class SetupTool(Folder):
     #   ZMI
     #
     manage_options = (Folder.manage_options[:1]
-                    + ({'label' : 'Properties',
+                    + ({'label' : 'Profiles',
                         'action' : 'manage_tool'
                        },
                        {'label' : 'Import',
@@ -370,6 +461,9 @@ class SetupTool(Folder):
                        {'label' : 'Export',
                         'action' : 'manage_exportSteps'
                        },
+                       {'label' : 'Upgrades',
+                        'action' : 'manage_upgrades'
+                        },
                        {'label' : 'Snapshots',
                         'action' : 'manage_snapshots'
                        },
@@ -387,7 +481,7 @@ class SetupTool(Folder):
     def manage_updateToolProperties(self, context_id, RESPONSE):
         """ Update the tool's settings.
         """
-        self.setImportContext(context_id)
+        self.setBaselineContext(context_id)
 
         RESPONSE.redirect('%s/manage_tool?manage_tabs_message=%s'
                          % (self.absolute_url(), 'Properties+updated.'))
@@ -396,12 +490,7 @@ class SetupTool(Folder):
     manage_importSteps = PageTemplateFile('sutImportSteps', _wwwdir)
 
     security.declareProtected(ManagePortal, 'manage_importSelectedSteps')
-    def manage_importSelectedSteps(self,
-                                   ids,
-                                   run_dependencies,
-                                   RESPONSE,
-                                   create_report=True,
-                                  ):
+    def manage_importSelectedSteps(self, ids, run_dependencies, context_id=None):
         """ Import the steps selected by the user.
         """
         messages = {}
@@ -409,38 +498,63 @@ class SetupTool(Folder):
             summary = 'No steps selected.'
 
         else:
+            if context_id is None:
+                context_id = self.getBaselineContextID()
             steps_run = []
             for step_id in ids:
-                result = self.runImportStep(step_id, run_dependencies)
+                result = self.runImportStepFromProfile(context_id,
+                                                       step_id,
+                                                       run_dependencies)
                 steps_run.extend(result['steps'])
                 messages.update(result['messages'])
 
             summary = 'Steps run: %s' % ', '.join(steps_run)
 
-            if create_report:
-                name = self._mangleTimestampName('import-selected', 'log')
-                self._createReport(name, result['steps'], result['messages'])
+            name = self._mangleTimestampName('import-selected', 'log')
+            self._createReport(name, result['steps'], result['messages'])
 
         return self.manage_importSteps(manage_tabs_message=summary,
                                        messages=messages)
 
     security.declareProtected(ManagePortal, 'manage_importSelectedSteps')
-    def manage_importAllSteps(self, RESPONSE, create_report=True):
+    def manage_importAllSteps(self, context_id=None):
 
         """ Import all steps.
         """
-        result = self.runAllImportSteps()
-        steps_run = 'Steps run: %s' % ', '.join(result['steps'])
+        if context_id is None:
+            context_id = self.getBaselineContextID()
+        result = self.runAllImportStepsFromProfile(context_id, purge_old=None)
 
-        if create_report:
-            name = self._mangleTimestampName('import-all', 'log')
-            self._createReport(name, result['steps'], result['messages'])
+        steps_run = 'Steps run: %s' % ', '.join(result['steps'])
 
         return self.manage_importSteps(manage_tabs_message=steps_run,
                                        messages=result['messages'])
 
+    security.declareProtected(ManagePortal, 'manage_importExtensions')
+    def manage_importExtensions(self, RESPONSE, profile_ids=()):
+
+        """ Import all steps for the selected extension profiles.
+        """
+        detail = {}
+        if len(profile_ids) == 0:
+            message = 'Please select one or more extension profiles.'
+            RESPONSE.redirect('%s/manage_tool?manage_tabs_message=%s'
+                                  % (self.absolute_url(), message))
+        else:
+            message = 'Imported profiles: %s' % ', '.join(profile_ids)
+        
+            for profile_id in profile_ids:
+
+                result = self.runAllImportStepsFromProfile(profile_id)
+
+                for k, v in result['messages'].items():
+                    detail['%s:%s' % (profile_id, k)] = v
+
+            return self.manage_importSteps(manage_tabs_message=message,
+                                        messages=detail)
+
     security.declareProtected(ManagePortal, 'manage_importTarball')
-    def manage_importTarball(self, tarball, RESPONSE, create_report=True):
+    def manage_importTarball(self, tarball):
         """ Import steps from the uploaded tarball.
         """
         if getattr(tarball, 'read', None) is not None:
@@ -455,9 +569,8 @@ class SetupTool(Folder):
                                                  purge_old=True)
         steps_run = 'Steps run: %s' % ', '.join(result['steps'])
 
-        if create_report:
-            name = self._mangleTimestampName('import-all', 'log')
-            self._createReport(name, result['steps'], result['messages'])
+        name = self._mangleTimestampName('import-all', 'log')
+        self._createReport(name, result['steps'], result['messages'])
 
         return self.manage_importSteps(manage_tabs_message=steps_run,
                                        messages=result['messages'])
@@ -491,6 +604,12 @@ class SetupTool(Folder):
                            'attachment; filename=%s' % result['filename'])
         return result['tarball']
 
+    security.declareProtected(ManagePortal, 'manage_upgrades')
+    manage_upgrades = PageTemplateFile('setup_upgrades', _wwwdir)
+
+    security.declareProtected(ManagePortal, 'upgradeStepMacro')
+    upgradeStepMacro = PageTemplateFile('upgradeStep', _wwwdir)
+
     security.declareProtected(ManagePortal, 'manage_snapshots')
     manage_snapshots = PageTemplateFile('sutSnapshots', _wwwdir)
 
@@ -524,6 +643,7 @@ class SetupTool(Folder):
     def listProfileInfo(self):
 
         """ Return a list of mappings describing registered profiles.
+        Base profile is listed first, extensions are sorted.
 
         o Keys include:
 
@@ -537,23 +657,62 @@ class SetupTool(Folder):
 
           'product' -- name of the registering product
         """
-        return _profile_registry.listProfileInfo()
+        base = []
+        ext = []
+        for info in _profile_registry.listProfileInfo():
+            if info.get('type', BASE) == BASE:
+                base.append(info)
+            else:
+                ext.append(info)
+        ext.sort(lambda x, y: cmp(x['id'], y['id']))
+        return base + ext
 
     security.declareProtected(ManagePortal, 'listContextInfos')
     def listContextInfos(self):
 
         """ List registered profiles and snapshots.
         """
+        def readableType(x):
+            if x is BASE:
+                return 'base'
+            elif x is EXTENSION:
+                return 'extension'
+            return 'unknown'
 
-        s_infos = [{ 'id': 'snapshot-%s' % info['id'],
-                      'title': info['title'] }
+        s_infos = [{'id': 'snapshot-%s' % info['id'],
+                     'title': info['title'],
+                     'type': 'snapshot',
+                   }
                     for info in self.listSnapshotInfo()]
-        p_infos = [{ 'id': 'profile-%s' % info['id'],
-                      'title': info['title'] }
-                    for info in self.listProfileInfo()]
+        p_infos = [{'id': 'profile-%s' % info['id'],
+                    'title': info['title'],
+                    'type': readableType(info['type']),
+                   }
+                   for info in self.listProfileInfo()]
 
         return tuple(s_infos + p_infos)
 
+    security.declareProtected(ManagePortal, 'getProfileImportDate')
+    def getProfileImportDate(self, profile_id):
+        """ See ISetupTool.
+        """
+        prefix = ('import-all-%s-' % profile_id).replace(':', '_')
+        candidates = [x for x in self.objectIds('File')
+                        if x.startswith(prefix)]
+        if len(candidates) == 0:
+            return None
+        candidates.sort()
+        last = candidates[-1]
+        stamp = last[len(prefix):-4]
+        assert(len(stamp) == 14)
+        return '%s-%s-%sT%s:%s:%sZ' % (stamp[0:4],
+                                       stamp[4:6],
+                                       stamp[6:8],
+                                       stamp[8:10],
+                                       stamp[10:12],
+                                       stamp[12:14],
+                                      )
+
     security.declareProtected(ManagePortal, 'manage_createSnapshot')
     def manage_createSnapshot(self, RESPONSE, snapshot_id=None):
 
@@ -568,6 +727,7 @@ class SetupTool(Folder):
 
         RESPONSE.redirect('%s/manage_snapshots?manage_tabs_message=%s'
                          % (self.absolute_url(), 'Snapshot+created.'))
+        return ""
 
     security.declareProtected(ManagePortal, 'manage_showDiff')
     manage_showDiff = PageTemplateFile('sutCompare', _wwwdir)
@@ -609,6 +769,94 @@ class SetupTool(Folder):
                                           ignore_blanks,
                                          )
 
+    #
+    # Upgrades management
+    #
+    security.declareProtected(ManagePortal, 'getLastVersionForProfile')
+    def getLastVersionForProfile(self, profile_id):
+        """Return the last upgraded version for the specified profile.
+        """
+        version = self._profile_upgrade_versions.get(profile_id, 'unknown')
+        return version
+
+    security.declareProtected(ManagePortal, 'setLastVersionForProfile')
+    def setLastVersionForProfile(self, profile_id, version):
+        """Set the last upgraded version for the specified profile.
+        """
+        if isinstance(version, basestring):
+            version = tuple(version.split('.'))
+        prof_versions = self._profile_upgrade_versions.copy()
+        prof_versions[profile_id] = version
+        self._profile_upgrade_versions = prof_versions
+
+    security.declareProtected(ManagePortal, 'getVersionForProfile')
+    def getVersionForProfile(self, profile_id):
+        """Return the registered filesystem version for the specified
+        profile.
+        """
+        info = _profile_registry.getProfileInfo(profile_id)
+        return info.get('version', 'unknown')
+
+    security.declareProtected(ManagePortal, 'listProfilesWithUpgrades')
+    def listProfilesWithUpgrades(self):
+        return listProfilesWithUpgrades()
+
+    security.declarePrivate('_massageUpgradeInfo')
+    def _massageUpgradeInfo(self, info):
+        """Add a couple of data points to the upgrade info dictionary.
+        """
+        info = info.copy()
+        info['haspath'] = info['source'] and info['dest']
+        info['ssource'] = '.'.join(info['source'] or ('all',))
+        info['sdest'] = '.'.join(info['dest'] or ('all',))
+        return info
+
+    security.declareProtected(ManagePortal, 'listUpgrades')
+    def listUpgrades(self, profile_id, show_old=False):
+        """Get the list of available upgrades.
+        """
+        if show_old:
+            source = None
+        else:
+            source = self.getLastVersionForProfile(profile_id)
+        upgrades = listUpgradeSteps(self, profile_id, source)
+        res = []
+        for info in upgrades:
+            if type(info) == list:
+                subset = []
+                for subinfo in info:
+                    subset.append(self._massageUpgradeInfo(subinfo))
+                res.append(subset)
+            else:
+                res.append(self._massageUpgradeInfo(info))
+        return res
+
+    security.declareProtected(ManagePortal, 'manage_doUpgrades')
+    def manage_doUpgrades(self, request=None):
+        """Perform all selected upgrade steps.
+        """
+        if request is None:
+            request = self.REQUEST
+        logger = logging.getLogger('GenericSetup')
+        steps_to_run = request.form.get('upgrades', [])
+        profile_id = request.get('profile_id', '')
+        for step_id in steps_to_run:
+            step = _upgrade_registry.getUpgradeStep(profile_id, step_id)
+            if step is not None:
+                step.doStep(self)
+                msg = "Ran upgrade step %s for profile %s" % (step.title,
+                                                              profile_id)
+                logger.log(logging.INFO, msg)
+
+        # XXX should be a bit smarter about deciding when to up the
+        #     profile version
+        profile_info = _profile_registry.getProfileInfo(profile_id)
+        version = profile_info.get('version', None)
+        if version is not None:
+            self.setLastVersionForProfile(profile_id, version)
+
+        url = self.absolute_url()
+        request.RESPONSE.redirect("%s/manage_upgrades?saved=%s" % (url, profile_id))
 
     #
     #   Helper methods
@@ -653,11 +901,13 @@ class SetupTool(Folder):
                 should_purge = (info.get('type') != EXTENSION)
             return DirectoryImportContext(self, path, should_purge, encoding)
 
-        # else snapshot
-        context_id = context_id[len('snapshot-'):]
-        if should_purge is None:
-            should_purge = True
-        return SnapshotImportContext(self, context_id, should_purge, encoding)
+        elif context_id.startswith('snapshot-'):
+            context_id = context_id[len('snapshot-'):]
+            if should_purge is None:
+                should_purge = True
+            return SnapshotImportContext(self, context_id, should_purge, encoding)
+        else:
+            raise KeyError, 'Unknown context "%s"' % context_id
 
     security.declarePrivate('_updateImportStepsRegistry')
     def _updateImportStepsRegistry(self, context, encoding):
@@ -676,8 +926,7 @@ class SetupTool(Folder):
 
             id = step_info['id']
             version = step_info['version']
-            handler = _resolveDottedName(step_info['handler'])
-
+            handler = step_info['handler']
             dependencies = tuple(step_info.get('dependencies', ()))
             title = step_info.get('title', id)
             description = ''.join(step_info.get('description', []))
@@ -706,8 +955,7 @@ class SetupTool(Folder):
         for step_info in info_list:
 
             id = step_info['id']
-            handler = _resolveDottedName(step_info['handler'])
-
+            handler = step_info['handler']
             title = step_info.get('title', id)
             description = ''.join(step_info.get('description', []))
 
@@ -723,12 +971,19 @@ class SetupTool(Folder):
         """ Run a single import step, using a pre-built context.
         """
         __traceback_info__ = step_id
+        marker = object()
 
         handler = self._import_registry.getStep(step_id)
 
-        if handler is None:
+        if handler is marker:
             raise ValueError('Invalid import step: %s' % step_id)
 
+        if handler is None:
+            msg = 'Step %s has an invalid import handler' % step_id
+            logger = logging.getLogger('GenericSetup')
+            logger.error(msg)
+            return 'ERROR: ' + msg
+
         return handler(context)
 
     security.declarePrivate('_doRunExportSteps')
@@ -738,15 +993,22 @@ class SetupTool(Folder):
         """
         context = TarballExportContext(self)
         messages = {}
+        marker = object()
 
         for step_id in steps:
 
-            handler = self._export_registry.getStep(step_id)
+            handler = self._export_registry.getStep(step_id, marker)
 
-            if handler is None:
+            if handler is marker:
                 raise ValueError('Invalid export step: %s' % step_id)
 
-            messages[step_id] = handler(context)
+            if handler is None:
+                msg = 'Step %s has an invalid import handler' % step_id
+                logger = logging.getLogger('GenericSetup')
+                logger.error(msg)
+                messages[step_id] = msg
+            else:
+                messages[step_id] = handler(context)
 
         return { 'steps' : steps
                , 'messages' : messages
@@ -807,6 +1069,10 @@ class SetupTool(Folder):
         if isinstance(report, unicode):
             report = report.encode('latin-1')
 
+        # BBB: ObjectManager won't allow unicode IDS
+        if isinstance(name, unicode):
+            name = name.encode('UTF-8')
+
         file = File(id=name,
                     title='',
                     file=report,
