@@ -16,7 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 """
-$Id: test_marshall.py 5634 2006-01-24 17:14:16Z dreamcatcher $
+$Id: test_marshall.py 7825 2007-03-29 10:19:26Z nouri $
 """
 
 import os, sys
@@ -32,7 +32,6 @@ from Products.Marshall.tests.base import BaseTest
 # Install our product
 ZopeTestCase.installProduct('Marshall')
 ZopeTestCase.installProduct('Archetypes')
-ZopeTestCase.installProduct('ArchExample')
 ZopeTestCase.installProduct('ATContentTypes')
 
 from Products.CMFCore.utils import getToolByName
@@ -69,7 +68,8 @@ class MarshallerTest(BaseTest):
         marshaller.demarshall(self.obj, content)
         ctype, length, got = marshaller.marshall(self.obj, filename=self.input)
         normalize = self.input.endswith('xml')
-        self.assertEqualsDiff(got, content, normalize=normalize)
+        
+        self.assertEqualsDiff(content, got, normalize=normalize)
 
 class ATXMLReferenceMarshallTest(BaseTest):
 
@@ -509,7 +509,7 @@ class DocumentationTest(ZopeTestCase.Functional, BaseTest):
         self.loginPortalOwner()
         self.qi = self.portal.portal_quickinstaller
         self.qi.installProduct('Marshall')
-        self.qi.installProduct('ArchExample')
+        self.qi.installProduct('ATContentTypes')
 
 def test_suite():
     import unittest
@@ -518,8 +518,10 @@ def test_suite():
     suite.addTest(FunctionalDocFileSuite('doc/README.txt',
                                          package='Products.Marshall',
                                          test_class=DocumentationTest))
-    suite.addTest(unittest.makeSuite(ATXMLReferenceMarshallTest))
-    suite.addTest(unittest.makeSuite(BlobMarshallTest))
+
+    ## XXX: reenable Blob and Image tests
+    #suite.addTest(unittest.makeSuite(ATXMLReferenceMarshallTest))
+    #suite.addTest(unittest.makeSuite(BlobMarshallTest))
     dirs = glob.glob(os.path.join(PACKAGE_HOME, 'input', '*'))
     comps = [i['name'] for i in getRegisteredComponents()]
     for d in dirs:
