@@ -1,5 +1,6 @@
 """some common utilities
 """
+import logging
 from time import time
 from types import UnicodeType, StringType
 
@@ -9,9 +10,10 @@ class MimeTypeException(Exception):
     pass
 
 # logging function
-from zLOG import LOG, INFO
-def log(msg, severity=INFO, id='MimetypesRegistry'):
-    LOG(id, severity, msg)
+logger = logging.getLogger('MimetypesRegistry')
+
+def log(msg, severity=logging.INFO, id='MimetypesRegistry'):
+    logger.log(severity, msg)
 
 # directory where template for the ZMI are located
 import os.path
