@@ -1,6 +1,3 @@
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
 
 from Testing import ZopeTestCase
 from Products.Archetypes.tests.atsitetestcase import ATSiteTestCase
@@ -47,6 +44,3 @@ def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestGuessMagic))
     return suite
-
-if __name__ == '__main__':
-    framework()
