@@ -1,8 +1,6 @@
-"""
-$Id: Negotiator.py 21785 2006-04-04 20:34:35Z hannosch $
-"""
-
+import logging
 import types
+from utils import log
 
 _langPrefsRegistry = {}
 
@@ -173,12 +171,14 @@ def setCookieLanguage(request, lang, REQUEST=None):
     else:
         return lang
 
-
+# BBB: This handler will be removed in PTS 1.5. It is not registered anymore
+# in 1.4 as it interferes with forms that include a field called language.
 class RequestGetAccept:
     filters = (str_lower, lang_normalize, str_strip)
 
     def __init__(self, request):
-        pass
+        log('DeprecationWarning: The RequestGetAccept handler is deprecated '
+            'and will be removed in PTS 1.5.', logging.WARNING)
 
     def getAccepted(self, request, kind='language'):
         # get
@@ -209,7 +209,6 @@ class RequestGetAccept:
 # in the chain is queried
 registerLangPrefsMethod({'klass':BrowserAccept,   'priority':10 }, 'language')
 registerLangPrefsMethod({'klass':CookieAccept,   'priority':40 }, 'language')
-registerLangPrefsMethod({'klass':RequestGetAccept,'priority':50 }, 'language')
 
 registerLangPrefsMethod({'klass':BrowserAccept,'priority':10 }, 'content-type')
 
@@ -223,21 +222,9 @@ class Negotiator:
 
     def negotiate(self, choices, request, kind='content-type'):
         choices = tuple(choices)
-        cache_name = '_pts_negotiator_cache_%s' % kind
-        try:
-            cache = request.other[cache_name]
-        except KeyError:
-            # Store cache in request object
-            cache = {}
-            request.set(cache_name, cache)
-        try:
-            return cache[choices]
-        except KeyError:
-            cache[choices] = self._negotiate(choices, request, kind)
-        return cache[choices]
+        return self._negotiate(choices, request, kind)
 
     def _negotiate(self, choices, request, kind):
-
         userchoices = getLangPrefs(request, kind)
         # Prioritize on the user preferred choices. Return the first user
         # preferred choice that the object has available.
