@@ -1,20 +1,26 @@
-"""Placeless Translation Service for providing I18n to file-based code.
-
-$Id: PlacelessTranslationService.py 29774 2006-09-02 21:06:59Z alecm $
-"""
-
 import sys, os, re, fnmatch
-from types import StringType, UnicodeType
+import logging
+from stat import ST_MTIME
+
+from zope.component import getGlobalSiteManager
+from zope.component import queryUtility
+from zope.deprecation import deprecate
+from zope.i18n.translationdomain import TranslationDomain
+from zope.i18n.interfaces import ITranslationDomain
+from zope.interface import implements
+from zope.publisher.interfaces.browser import IBrowserRequest
 
 import Globals
 from ExtensionClass import Base
+from Acquisition import aq_acquire
 from Acquisition import ImplicitAcquisitionWrapper
 from AccessControl import ClassSecurityInfo
 from AccessControl.Permissions import view, view_management_screens
 from Globals import InitializeClass
 from OFS.Folder import Folder
-from ZPublisher.HTTPRequest import HTTPRequest
 
+from Products.PlacelessTranslationService.lazycatalog import \
+    LazyGettextMessageCatalog
 from GettextMessageCatalog import BrokenMessageCatalog
 from GettextMessageCatalog import GettextMessageCatalog
 from GettextMessageCatalog import translationRegistry
@@ -22,12 +28,11 @@ from GettextMessageCatalog import rtlRegistry
 from GettextMessageCatalog import getMessage
 from Negotiator import negotiator
 from Domain import Domain
-import logging
-from utils import log, Registry
+from interfaces import IPlacelessTranslationService
+from memoize import memoize
+from msgfmt import Msgfmt
 from msgfmt import PoSyntaxError
-
-from Tracker import global_tracker
-from GettextMessageCatalog import ptFile
+from utils import log, Registry
 
 PTS_IS_RTL = '_pts_is_rtl'
 
@@ -39,13 +44,6 @@ NAME_RE = r"[a-zA-Z][-a-zA-Z0-9_]*"
 _interp_regex = re.compile(r'(?<!\$)(\$(?:%(n)s|{%(n)s}))' %({'n': NAME_RE}))
 _get_var_regex = re.compile(r'%(n)s' %({'n': NAME_RE}))
 
-
-# The configure.zcml file should specify a list of fallback languages for the
-# site.  If a particular catalog for a negotiated language is not available,
-# then the zcml specified order should be tried.  If that fails, then as a
-# last resort the languages in the following list are tried.  If these fail
-# too, then the msgid is returned.
-#
 # Note that these fallbacks are used only to find a catalog.  If a particular
 # message in a catalog is not translated, tough luck, you get the msgid.
 LANGUAGE_FALLBACKS = list(os.environ.get('LANGUAGE_FALLBACKS', 'en').split(' '))
@@ -55,11 +53,10 @@ registerCatalog = catalogRegistry.register
 fbcatalogRegistry = Registry()
 registerFBCatalog = fbcatalogRegistry.register
 
-
 class PTSWrapper(Base):
     """
     Wrap the persistent PTS since persistent
-    objects cant be passed around threads
+    objects can't be passed around threads.
     """
 
     security = ClassSecurityInfo()
@@ -80,35 +77,33 @@ class PTSWrapper(Base):
     def translate(self, domain, msgid, mapping=None, context=None,
                   target_language=None, default=None):
         """
-        translate a message using the default encoding
-        get the real service and call its translate method
-        return default if service couldnt be retrieved
+        Translate a message using Unicode.
         """
-
-        # this is useful for GettextMessageCatalog see the end of
-        # GettextMessageCatalog.py for details
-        __pts_caller_backcount__ = 1
-
         service = self.load(context)
-        if not service: return default
+        if not service:
+            return default
         return service.translate(domain, msgid, mapping, context, target_language, default)
 
     security.declareProtected(view, 'utranslate')
+    @deprecate("The utranslate method of the PTS is deprecated and will be "
+               "removed in the next PTS release. Use the translate method "
+               "instead.")
     def utranslate(self, domain, msgid, mapping=None, context=None,
                   target_language=None, default=None):
         """
-        Translate a message using unicode. See translate().
+        Translate a message using Unicode..
         """
         service = self.load(context)
-        if not service: return default
+        if not service:
+            return default
         return service.utranslate(domain, msgid, mapping, context, target_language, default)
 
-    security.declareProtected(view, 'getLanguageName')
+    security.declarePublic(view, 'getLanguageName')
     def getLanguageName(self, code, context):
         service = self.load(context)
         return service.getLanguageName(code)
 
-    security.declareProtected(view, 'getLanguages')
+    security.declarePublic(view, 'getLanguages')
     def getLanguages(self, context, domain=None):
         service = self.load(context)
         return service.getLanguages(domain)
@@ -119,10 +114,14 @@ class PTSWrapper(Base):
         return service.negotiate_language(context.REQUEST,domain)
 
     security.declarePublic('isRTL')
+    @deprecate("The isRTL method of the PTS is deprecated and will be removed "
+               "in the next PTS release. Use the information found in the "
+               "Zope3 locale instead.")
     def isRTL(self, context, domain):
         service = self.load(context)
         # Default to LtR
-        if service is None: return False
+        if service is None:
+            return False
         return service.isRTL(context.REQUEST,domain)
 
     def __repr__(self):
@@ -137,6 +136,7 @@ class PlacelessTranslationService(Folder):
     """
     The Placeless Translation Service
     """
+    implements(IPlacelessTranslationService)
 
     meta_type = title = 'Placeless Translation Service'
     icon = 'misc_/PlacelessTranslationService/PlacelessTranslationService.png'
@@ -146,15 +146,9 @@ class PlacelessTranslationService(Folder):
     # -3 for alpha, -2 for beta, -1 for release candidate
     # use an internal of > 99 to recreate the PTS at every startup
     # (development mode)
-    _class_version = (1, 3, 2, 0)
+    _class_version = (1, 4, 8, 0)
     all_meta_types = ()
 
-    manage_options = Folder.manage_options + (
-        {'label': 'Tracker', 'action': 'manage_trackerForm'},)
-
-    manage_trackerForm = ptFile(
-        'manage_trackerForm', globals(), 'www', 'manage_trackerForm')
-
     security = ClassSecurityInfo()
 
     def __init__(self, default_domain='global', fallbacks=None):
@@ -320,6 +314,54 @@ class PlacelessTranslationService(Folder):
 
         log('Initialized:', detail = repr(names) + (' from %s\n' % basepath))
 
+    def _updateMoFile(self, name, msgpath, lang, domain):
+        """
+        Creates or updates a mo file in the locales folder. Returns True if a
+        new file was created.
+        """
+        pofile = os.path.normpath(os.path.join(msgpath, name))
+        mofile = os.path.normpath(os.path.join(msgpath, domain+'.mo'))
+        create = False
+        update = False
+
+        try:
+            po_mtime = os.stat(pofile)[ST_MTIME]
+        except (IOError, OSError):
+            po_mtime = 0
+
+        if os.path.exists(mofile):
+            # Update mo file?
+            try:
+                mo_mtime = os.stat(mofile)[ST_MTIME]
+            except (IOError, OSError):
+                mo_mtime = 0
+
+            if po_mtime > mo_mtime:
+                # Update mo file
+                update = True
+            else:
+                # Mo file is current
+                return
+        else:
+            # Create mo file
+            create = True
+
+        if create or update:
+            try:
+                mo = Msgfmt(pofile, domain).getAsFile()
+                fd = open(mofile, 'wb')
+                fd.write(mo.read())
+                fd.close()
+
+            except (IOError, OSError, PoSyntaxError):
+                log('Error while compiling %s' % pofile, logging.WARNING)
+                return
+
+            if create:
+                return True
+
+        return None
+
     def _load_locales_dir(self, basepath):
         """
         Loads an locales directory (Zope3 format)
@@ -347,32 +389,26 @@ class PlacelessTranslationService(Folder):
             for name in names:
                 domain = name[:-3]
                 found.append('%s:%s' % (lang, domain))
-                self._load_catalog_file(name, msgpath, lang, domain)
+                result = self._updateMoFile(name, msgpath, lang, domain)
+                if result:
+                    # Newly created file, the Z3 domain might not exist
+                    mofile = os.path.join(msgpath, domain + '.mo')
+                    if queryUtility(ITranslationDomain, name=domain) is None:
+                        ts_domain = TranslationDomain(domain)
+                        sm = getGlobalSiteManager()
+                        sm.registerUtility(ts_domain, ITranslationDomain, name=domain)
+
+                    util = queryUtility(ITranslationDomain, name=domain)
+                    if util is not None:
+                        # Add message catalog
+                        cat = LazyGettextMessageCatalog(lang, domain, mofile)
+                        util.addCatalog(cat)
 
         if not found:
             log('nothing found', logging.DEBUG)
             return
         log('Initialized:', detail = repr(found) + (' from %s\n' % basepath))
 
-    def _getContext(self, context):
-        # ZPT passes the object as context.  That's wrong according to spec.
-        context = getattr(context, 'REQUEST', context)
-        if not isinstance(context, HTTPRequest):
-            # try to recover
-            log('Using get_request patch.', severity=logging.INFO)
-            # XXX: import the get_request method
-            # this will fail the first time we need it if the patch
-            # wasn't applied before
-            try:
-                from Globals import get_request
-            except ImportError:
-                from PatchStringIO import applyRequestPatch
-                applyRequestPatch()
-            else:
-                context = get_request()
-
-        return context
-
     security.declareProtected(view_management_screens, 'manage_renameObject')
     def manage_renameObject(self, id, new_id, REQUEST=None):
         """
@@ -409,19 +445,10 @@ class PlacelessTranslationService(Folder):
         self._registerMessageCatalog(catalog)
 
     security.declarePrivate('getCatalogsForTranslation')
-    def getCatalogsForTranslation(self, context, domain, target_language=None):
-        # ZPT passes the object as context.  That's wrong according to spec.
-        context = self._getContext(context)
-
+    @memoize
+    def getCatalogsForTranslation(self, request, domain, target_language=None):
         if target_language is None:
-            target_language = self.negotiate_language(context, domain)
-
-        # cache catalog names to speed up because this method is called
-        # for every msgid
-        cache_name = '_pts_catalog_names_%s_%s' % (domain, target_language or 'none')
-        cached_catalog_names = context.get(cache_name, None)
-        if cached_catalog_names:
-            return [translationRegistry[name] for name in cached_catalog_names]
+            target_language = self.negotiate_language(request, domain)
 
         # get the catalogs for translations
         catalog_names = catalogRegistry.get((target_language, domain), ()) or \
@@ -447,16 +474,12 @@ class PlacelessTranslationService(Folder):
                 catalog_names.insert(pos, catalog_name)
                 pos+=1
 
-        # set catalog names cache. Do *not* store a persistent object
-        # in the request. It may cause reference circles and cause memory leaks
-        context.set(cache_name, catalog_names)
-
         # test for right to left language
-        if not context.has_key(PTS_IS_RTL):
-            context.set(PTS_IS_RTL, False)
+        if not request.has_key(PTS_IS_RTL):
+            request.set(PTS_IS_RTL, False)
         for name in catalog_names:
             if rtlRegistry.get(name):
-                context.set(PTS_IS_RTL, True)
+                request.set(PTS_IS_RTL, True)
                 break
 
         return [translationRegistry[name] for name in catalog_names]
@@ -495,38 +518,44 @@ class PlacelessTranslationService(Folder):
         return l
 
     security.declareProtected(view, 'isRTL')
+    @deprecate("The isRTL method of the PTS is deprecated and will be removed "
+               "in the next PTS release. Use the information found in the "
+               "Zope3 locale instead.")
     def isRTL(self, context, domain):
         """get RTL settings
         """
-        context = self._getContext(context)
-        pts_is_rtl = context.get(PTS_IS_RTL, None)
+        request = getattr(context, 'REQUEST', context)
+        pts_is_rtl = request.get(PTS_IS_RTL, None)
         if pts_is_rtl is None:
             # call getCatalogsForTranslation to initialize the negotiator
-            self.getCatalogsForTranslation(context, domain)
-        return context.get(PTS_IS_RTL, False)
+            self.getCatalogsForTranslation(request, domain)
+        return request.get(PTS_IS_RTL, False)
 
     security.declareProtected(view, 'utranslate')
+    @deprecate("The utranslate method of the PTS is deprecated and will be "
+               "removed in the next PTS release. Use the translate method "
+               "instead.")
     def utranslate(self, domain, msgid, mapping=None, context=None,
                   target_language=None, default=None):
         """
-        translate() using unicode
+        translate() using Unicode.
         """
         return self.translate(domain, msgid, mapping, context,
-                  target_language, default, as_unicode=True)
+                  target_language, default)
 
     security.declareProtected(view, 'translate')
     def translate(self, domain, msgid, mapping=None, context=None,
-                  target_language=None, default=None, as_unicode=False):
+                  target_language=None, default=None):
         """
-        translate a message using the default encoding
+        Translate a message using Unicode.
         """
-        global global_tracker
         if not msgid:
             # refuse to translate an empty msgid
             return default
 
         # ZPT passes the object as context.  That's wrong according to spec.
-        context = self._getContext(context)
+        if not IBrowserRequest.providedBy(context):
+            context = aq_acquire(context, 'REQUEST')
         text = msgid
 
         catalogs = self.getCatalogsForTranslation(context, domain, target_language)
@@ -536,32 +565,25 @@ class PlacelessTranslationService(Folder):
             except KeyError:
                 # it's not in this catalog, try the next one
                 continue
-            # found! negotiate output encodings now
-            if not as_unicode:
-                # ask HTTPResponse to encode it for us
-                text = context.RESPONSE._encode_unicode(text)
+            # found!
             break
         else:
             # Did the fallback fail? Sigh, use the default if it is not None.
             if default is not None:
                 text = default
-            if target_language is None:
-                target_language = self.negotiate_language(context, domain)
-            global_tracker.recordFailure(domain, msgid, target_language)
 
         # Now we need to do the interpolation
         return self.interpolate(text, mapping)
 
     security.declarePrivate('negotiate_language')
-    def negotiate_language(self, context, domain):
-        if context is None:
-            raise TypeError, 'No destination language'
+    @memoize
+    def negotiate_language(self, request, domain):
         langs = [m[0] for m in catalogRegistry.keys() if m[1] == domain] + \
                 [m[0] for m in fbcatalogRegistry.keys() if m[1] == domain]
         for fallback in self._fallbacks:
             if fallback not in langs:
                 langs.append(fallback)
-        return negotiator.negotiate(langs, context, 'language')
+        return negotiator.negotiate(langs, request, 'language')
 
     security.declareProtected(view, 'getDomain')
     def getDomain(self, domain):
@@ -615,23 +637,9 @@ class PlacelessTranslationService(Folder):
         except AttributeError:
             manage_main = ImplicitAcquisitionWrapper(Folder.manage_main, self)
             r = manage_main(self, self, REQUEST, *a, **kw)
-        if type(r) is UnicodeType:
+        if isinstance(r, unicode):
             r = r.encode('utf-8')
         REQUEST.RESPONSE.setHeader('Content-type', 'text/html; charset=utf-8')
         return r
 
-    security.declareProtected(view_management_screens, 'manage_tracker')
-    def manage_tracker(self, REQUEST=None):
-        """Defers all to the global_tracker
-        """
-        global global_tracker
-        return global_tracker.manage_tracker(self, REQUEST)
-
-    security.declareProtected(view, 'getTracker')
-    def getTracker(self):
-        """The domain tracker of that PTS (used only for ZMI template)
-        """
-        global global_tracker
-        return global_tracker
-
 InitializeClass(PlacelessTranslationService)
