@@ -17,12 +17,14 @@
 
 from sets import Set
 from StringIO import StringIO
-from Acquisition import aq_base, aq_inner, aq_parent
 
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.Expression import Expression
-from Products.PluginRegistry.PluginRegistry import PluginRegistry
 
+from zope.component.interfaces import ComponentLookupError
+
+from Products.PluggableAuthService.interfaces.authservice \
+        import IPluggableAuthService
 from Products.PluggableAuthService.interfaces.plugins import IPropertiesPlugin
 from Products.PluggableAuthService.interfaces.plugins import IGroupsPlugin
 from Products.PluggableAuthService.interfaces.plugins \
@@ -31,8 +33,6 @@ from Products.PluggableAuthService.interfaces.plugins \
      import ICredentialsResetPlugin
 from Products.PluggableAuthService.interfaces.plugins \
      import IChallengePlugin
-from Products.PluggableAuthService.PluggableAuthService \
-     import PluggableAuthService
 from Products.PluggableAuthService.Extensions.upgrade \
      import replace_acl_users
 
@@ -46,38 +46,37 @@ from Products.PlonePAS.tools.groups import GroupsTool
 from Products.PlonePAS.tools.groupdata import GroupDataTool
 from Products.PlonePAS.tools.membership import MembershipTool
 from Products.PlonePAS.tools.memberdata import MemberDataTool
-from Products.PlonePAS.tools.plonetool import PloneTool
 
 from Products.PlonePAS.MigrationCheck import canAutoMigrate
+from plone.session.plugins.session import manage_addSessionPlugin
 
-CAN_LDAP = 0
 try:
     import Products.LDAPMultiPlugins
-    CAN_LDAP = 1
+    CAN_LDAP = True
 except ImportError:
-    pass
+    CAN_LDAP = False
 
-def activatePluginInterfaces(portal, plugin, out):
+
+def activatePluginInterfaces(portal, plugin, out, disable=[]):
     pas = portal.acl_users
     plugin_obj = pas[plugin]
 
-    interfaces = plugin_obj.listInterfaces()
-
     activatable = []
 
-    try:
-        for info in plugin_obj.plugins.listPluginTypeInfo():
-            interface = info['interface']
-            interface_name = info['id']
-            if plugin_obj.testImplements(interface):
+    for info in plugin_obj.plugins.listPluginTypeInfo():
+        interface = info['interface']
+        interface_name = info['id']
+        if plugin_obj.testImplements(interface):
+            if interface_name in disable:
+                disable.append(interface_name)
+                print >> out, " - Disabling: " + info['title']
+            else:
                 activatable.append(interface_name)
                 print >> out, " - Activating: " + info['title']
-    except AttributeError:
-        print >> out, "It looks like you have a non-PAS acl_users folder. "
-        print >> out, "Please remove it before installing PlonePAS."
     plugin_obj.manage_activateInterfaces(activatable)
     print >> out, plugin + " activated."
 
+
 def installProducts(portal, out):
     print >> out, "\nInstalling other products"
     qi = getToolByName(portal, 'portal_quickinstaller')
@@ -85,11 +84,13 @@ def installProducts(portal, out):
     print >> out, " - PasswordResetTool"
     qi.installProduct('PasswordResetTool')
 
+
 def setupRoles(portal):
     rmanager = portal.acl_users.role_manager
     rmanager.addRole('Member', title="Portal Member")
     rmanager.addRole('Reviewer', title="Content Reviewer")
 
+
 def registerPluginType(pas, plugin_type, plugin_info):
     # Make sure there's no dupes in _plugin_types, otherwise your PAS
     # will *CRAWL*
@@ -106,6 +107,7 @@ def registerPluginType(pas, plugin_type, plugin_info):
     # It's safe to assign over a existing key here.
     pas.plugins._plugin_type_info[plugin_type] =  plugin_info
 
+
 def registerPluginTypes(pas):
 
     PluginInfo = {
@@ -152,6 +154,7 @@ def registerPluginTypes(pas):
 
     registerPluginType(pas, ILocalRolesPlugin, PluginInfo)
 
+
 def setupPlugins(portal, out):
     uf = portal.acl_users
     print >> out, "\nPlugin setup"
@@ -165,7 +168,7 @@ def setupPlugins(portal, out):
     if not found:
         plone_pas.manage_addUserManager('source_users')
         print >> out, "Added User Manager."
-        activatePluginInterfaces(portal, 'source_users', out)
+    activatePluginInterfaces(portal, 'source_users', out)
 
     found = uf.objectIds(['Group Aware Role Manager'])
     if not found:
@@ -197,6 +200,19 @@ def setupPlugins(portal, out):
         print >> out, "Added Mutable Property Manager."
         activatePluginInterfaces(portal, "mutable_properties", out)
 
+    found = uf.objectIds(['Automatic Group Plugin'])
+    if not found:
+        plone_pas.manage_addAutoGroup('auto_group', "Automatic Group Provider",
+                "AuthenticatedUsers", "Authenticated Users (Virtual Group)")
+        print >> out, "Added Automatic Group."
+        activatePluginInterfaces(portal, "auto_group", out)
+
+    found = uf.objectIds(['Plone Session Plugin'])
+    if not found:
+        manage_addSessionPlugin(plone_pas, 'session')
+        print >> out, "Added Plone Session Plugin."
+        activatePluginInterfaces(portal, "session", out)
+
 
 def setupAuthPlugins(portal, pas, plone_pas, out,
                      deactivate_basic_reset=True,
@@ -228,7 +244,12 @@ def setupAuthPlugins(portal, pas, plone_pas, out,
         plone_pas.manage_addExtendedCookieAuthHelper('credentials_cookie_auth',
                                                      cookie_name=cookie_name)
     print >> out, "Added Extended Cookie Auth Helper."
-    activatePluginInterfaces(portal, 'credentials_cookie_auth', out)
+    if deactivate_basic_reset:
+        disable=['ICredentialsResetPlugin', 'ICredentialsUpdatePlugin']
+    else:
+        disable=[]
+    activatePluginInterfaces(portal, 'credentials_cookie_auth', out,
+            disable=disable)
 
     credentials_cookie_auth = uf._getOb('credentials_cookie_auth')
     if 'login_form' in credentials_cookie_auth.objectIds():
@@ -245,7 +266,6 @@ def setupAuthPlugins(portal, pas, plone_pas, out,
     assert not ccs, "Extra cookie crumblers found."
     print >> out, "Removed old Cookie Crumbler"
 
-
     found = uf.objectIds(['HTTP Basic Auth Helper'])
     if not found:
         pas.addHTTPBasicAuthHelper('credentials_basic_auth',
@@ -254,10 +274,10 @@ def setupAuthPlugins(portal, pas, plone_pas, out,
     activatePluginInterfaces(portal, 'credentials_basic_auth', out)
 
     if deactivate_basic_reset:
-        pas.plugins.deactivatePlugin(ICredentialsResetPlugin,
+        uf.plugins.deactivatePlugin(ICredentialsResetPlugin,
                                      'credentials_basic_auth')
     if deactivate_cookie_challenge:
-        pas.plugins.deactivatePlugin(IChallengePlugin,
+        uf.plugins.deactivatePlugin(IChallengePlugin,
                                      'credentials_cookie_auth')
 
 
@@ -269,6 +289,7 @@ def configurePlonePAS(portal, out):
     setupPlugins(portal, out)
 #    setupRoles( portal )
 
+
 def grabUserData(portal, out):
     """Return a list of (id, password, roles, domains, properties)
     tuples for the users of the system.
@@ -278,11 +299,15 @@ def grabUserData(portal, out):
     print >> out, "\nExtract Member information..."
 
     userdata = ()
-    mdtool = getToolByName(portal, 'portal_memberdata')
-    mtool = getToolByName(portal, 'portal_membership')
+    try:
+        mdtool = getToolByName(portal, "portal_memberdata")
+        mtool = getToolByName(portal, "portal_membership")
+    except ComponentLookupError:
+        return userdata
 
     props = mdtool.propertyIds()
     members = mtool.listMembers()
+    userids=set()
     for member in members:
         id = member.getId()
         print >> out, " : %s" % id
@@ -297,17 +322,24 @@ def grabUserData(portal, out):
         if portrait is not None:
             portrait=portrait.aq_base
         userdata += ((id, password, roles, domains, properties, portrait),)
+        userids.add(id)
+
+    for (id,data) in mdtool._members.items():
+        if id not in userids:
+            userdata+= ((id, None, None, None, data.__dict__, None),)
+            userids.add(id)
 
     print >> out, "...extract done"
     return userdata
 
+
 def restoreUserData(portal, out, userdata):
     print >> out, "\nRestoring Member information..."
 
     # re-add users
     # Password may be encypted or not: addUser will figure it out.
-    mtool = getToolByName(portal, 'portal_membership')
-    mdtool = getToolByName(portal, 'portal_memberdata')
+    mdtool = getToolByName(portal, "portal_memberdata")
+    mtool = getToolByName(portal, "portal_membership")
     emerg = portal.acl_users._emergency_user.getId()
     for u in userdata:
         if u[0] == emerg:
@@ -332,6 +364,7 @@ def restoreUserData(portal, out, userdata):
 
     print >> out, "...restore done"
 
+
 def grabGroupData(portal, out):
     """Return a list of (id, roles, groups, properties) tuples for the
     users of the system and a mapping of group ids to a list of group
@@ -371,6 +404,7 @@ def grabGroupData(portal, out):
     print >> out, "...extract done"
     return groupdata, groupmemberships
 
+
 def restoreGroupData(portal, out, groupdata, groupmemberships):
     print >> out, "\nRestoring Group information..."
 
@@ -400,26 +434,30 @@ def setupTools(portal, out):
     migrateGroupDataTool(portal, out)
     modActions(portal, out)
 
+
 def migratePloneTool(portal, out):
     print >> out, "Plone Tool (plone_utils)"
-    print >> out, " ...nothing to migrate"
-    print >> out, " - Removing Default"
-    portal.manage_delObjects(['plone_utils'])
-    print >> out, " - Installing PAS Aware"
-    portal._setObject(PloneTool.id, PloneTool())
+    pt = portal.plone_utils
+    if pt.meta_type == 'PlonePAS Utilities Tool':
+        from Products.CMFPlone.PloneTool import PloneTool
+        print >> out, " - Removing obsolete PlonePAS version of the Plone Tool"
+        portal.manage_delObjects(['plone_utils'])
+        print >> out, " - Installing standard tool"
+        portal._setObject(PloneTool.id, PloneTool())
     print >> out, " ...done"
 
+
 def migrateMembershipTool(portal, out):
     print >> out, "Membership Tool (portal_membership)"
 
-    mt = getToolByName(portal, 'portal_membership')
+    mt = getToolByName(portal, "portal_membership")
     print >> out, " ...copying settings"
     memberareaCreationFlag = mt.getMemberareaCreationFlag()
     role_map = getattr(mt, 'role_map', None)
     membersfolder_id = mt.membersfolder_id
 
     print >> out, " ...copying actions"
-    actions = mt._actions
+    actions = getattr(mt, '_actions', None)
 
     print >> out, " - Removing Default"
     portal.manage_delObjects(['portal_membership'])
@@ -437,14 +475,18 @@ def migrateMembershipTool(portal, out):
     if membersfolder_id:
         mt.membersfolder_id = membersfolder_id
 
-    print >> out, " ...restoring actions"
-    mt._actions = actions
+    if actions is not None:
+        print >> out, " ...restoring actions"
+        mt._actions = actions
 
     print >> out, " ...done"
 
+
 def migrateGroupsTool(portal, out):
     print >> out, "Groups Tool (portal_groups)"
-    gt = getToolByName(portal, 'portal_groups', None)
+    # We only want the physical object in the portal, getToolByName could give
+    # us a registered utility as well
+    gt = getattr(portal, 'portal_groups', None)
 
     HAS_GT = gt is not None
 
@@ -457,7 +499,7 @@ def migrateGroupsTool(portal, out):
         groupWorkspaceContainerType =  gt.getGroupWorkspaceContainerType()
 
         print >> out, " ...copying actions"
-        actions = gt._actions
+        actions = getattr(gt, '_actions', None)
 
         print >> out, " - Removing Default"
         portal.manage_delObjects(['portal_groups'])
@@ -474,23 +516,27 @@ def migrateGroupsTool(portal, out):
         gt.setGroupWorkspaceType(groupWorkspaceType)
         gt.setGroupWorkspaceContainerType(groupWorkspaceContainerType)
 
-        print >> out, " ...restoring actions"
-        gt._actions = actions
+        if actions is not None:
+            print >> out, " ...restoring actions"
+            gt._actions = actions
 
     print >> out, " ...done"
 
+
 def migrateGroupDataTool(portal, out):
     # this could be somewhat combined with migrateMemberDataTool, but
     # I don't think it's worth it
 
     print >> out, "GroupData Tool (portal_groupdata)"
-    gt = getToolByName(portal, 'portal_groupdata', None)
+    # We only want the physical object in the portal, getToolByName could give
+    # us a registered utility as well
+    gt = getattr(portal, 'portal_groupdata', None)
 
     HAS_GT = gt is not None
 
     if HAS_GT:
         print >> out, " ...copying actions"
-        actions = gt._actions
+        actions = getattr(gt, '_actions', None)
 
         print >> out, " ...extracting data"
         properties = gt._properties
@@ -505,20 +551,22 @@ def migrateGroupDataTool(portal, out):
     gt = getToolByName(portal, 'portal_groupdata')
 
     if HAS_GT:
-        print >> out, " ...restoring actions"
-        gt._actions = actions
+        if actions is not None:
+            print >> out, " ...restoring actions"
+            gt._actions = actions
 
         print >> out, " ...restoring data"
-        for prop in properties:
-            updateProp(gt, prop)
+        
+        updateProperties(gt, properties)
 
     print >> out, " ...done"
 
+
 def migrateMemberDataTool(portal, out):
     print >> out, "MemberData Tool (portal_memberdata)"
 
     print >> out, " ...copying actions"
-    actions = portal.portal_memberdata._actions
+    actions = getattr(portal.portal_memberdata, '_actions', None)
 
     print >> out, "  ...extracting data"
     mdtool = portal.portal_memberdata
@@ -527,19 +575,20 @@ def migrateMemberDataTool(portal, out):
         elt['value'] = mdtool.getProperty(elt['id'])
 
     mdtool = None
-    print >> out, " - Removing Default"
+    print >> out, " - Removing existing portal_memberdata tool"
     portal.manage_delObjects(['portal_memberdata'])
 
-    print >> out, " - Installing PAS Aware"
+    print >> out, " - Installing PAS Aware tool"
     portal._setObject(MemberDataTool.id, MemberDataTool())
 
-    print >> out, " ...restoring actions"
-    portal.portal_memberdata._actions = actions
+    if actions is not None:
+        print >> out, " ...restoring actions"
+        portal.portal_memberdata._actions = actions
 
     print >> out, " ...restoring data"
     mdtool = portal.portal_memberdata
-    for prop in properties:
-        updateProp(mdtool, prop)
+    
+    updateProperties(mdtool, properties)
 
     print >> out, " ...done"
 
@@ -554,6 +603,16 @@ def modActions(portal, out):
             action.condition = Expression("python:member.canPasswordSet()")
     cp._actions=_actions
 
+
+def updateProperties(tool, properties):
+    propsWithNoDeps = [prop for prop in properties if prop['type'] not in ('selection', 'multiple selection')]
+    propsWithDeps = [prop for prop in properties if prop['type'] in ('selection', 'multiple selection')]
+    for prop in propsWithNoDeps:
+        updateProp(tool, prop)
+    for prop in propsWithDeps:
+        updateProp(tool, prop)
+
+
 def updateProp(prop_manager, prop_dict):
     """Provided a PropertyManager and a property dict of {id, value,
     type}, set or update that property as applicable.
@@ -569,8 +628,9 @@ def updateProp(prop_manager, prop_dict):
         prop_manager._updateProperty(id, value)
     else:
         prop_manager._setProperty(id, value, type)
-        if type in ('selection', 'multiple selection'):
-            prop_manager._updateProperty(id, prop_dict['value'])
+    if type in ('selection', 'multiple selection'):
+        prop_manager._updateProperty(id, prop_dict['value'])
+
 
 def grabLDAPFolders(portal, out):
     """Get hold of any existing LDAPUserFolders so that we can put
@@ -596,6 +656,7 @@ def grabLDAPFolders(portal, out):
     print >> out, "...done"
     return ldap_ufs, ldap_gf
 
+
 def restoreLDAP(portal, out, ldap_ufs, ldap_gf):
     """Create appropriate plugins to replace destroyed LDAP user
     folders.
@@ -652,6 +713,7 @@ def restoreLDAP(portal, out, ldap_ufs, ldap_gf):
             # move properties up
             pas.plugins.movePluginsUp(IPropertiesPlugin, [id])
 
+
 def replaceUserFolder(portal, out):
     print >> out, "\nUser folder replacement:"
 
@@ -662,10 +724,12 @@ def replaceUserFolder(portal, out):
 
     print >> out, "...replace done"
 
+
 def addPAS(portal, out):
     print >> out, " - Adding PAS user folder"
     portal.manage_addProduct['PluggableAuthService'].addPluggableAuthService()
 
+
 def goForMigration(portal, out):
     """Checks for supported configurations.
     Other configurations might work. The migration code is pretty generic.
@@ -687,7 +751,7 @@ def migrate_root_uf(self, out):
     # Acquire parent user folder.
     parent = self.getPhysicalRoot()
     uf = getToolByName(parent, 'acl_users')
-    if uf.meta_type == PluggableAuthService.meta_type:
+    if IPluggableAuthService.providedBy(uf):
         # It's a PAS already, fixup if needed.
         pas_fixup(parent, out)
 
@@ -724,8 +788,7 @@ def pas_fixup(self, out):
          import _PLUGIN_TYPE_INFO, PluggableAuthService
 
     pas = getToolByName(self, 'acl_users')
-    if not pas.meta_type == PluggableAuthService.meta_type:
-        # Not a PAS, skip.
+    if not IPluggableAuthService.providedBy(pas):
         print >> out, 'PAS UF not found, skipping PAS fixup'
         return
 
@@ -762,9 +825,6 @@ def challenge_chooser_setup(self, out):
             print >> out, 'Needed plugins have not been found, ignoring'
             return
 
-    from Products.PluggableAuthService.interfaces.plugins import \
-         IRequestTypeSniffer, IChallengeProtocolChooser
-
     found = uf.objectIds(['Challenge Protocol Chooser Plugin'])
     if not found:
         print >> out, 'Adding Challenge Protocol Chooser Plugin.'
@@ -789,6 +849,7 @@ def challenge_chooser_setup(self, out):
         print >> out, 'Found existing Request Type Sniffer Plugin.'
         activatePluginInterfaces(self, found[0], out)
 
+
 def install(self):
     out = StringIO()
     portal = getToolByName(self, 'portal_url').getPortalObject()
@@ -796,7 +857,7 @@ def install(self):
     uf = getToolByName(self, 'acl_users')
 
     EXISTING_UF = 'acl_users' in portal.objectIds()
-    EXISTING_PAS = uf.meta_type == PluggableAuthService.meta_type
+    EXISTING_PAS = IPluggableAuthService.providedBy(uf)
 
     if EXISTING_PAS:
         # Fix possible missing PAS plugins registration.
@@ -805,11 +866,11 @@ def install(self):
         # Register PAS Plugin Types
         registerPluginTypes(uf)
 
-
     ldap_ufs, ldap_gf = None, None
     userdata=groupdata=memberships=()
 
     if not EXISTING_UF:
+        userdata = grabUserData(portal, out)
         addPAS(portal, out)
     elif not EXISTING_PAS:
         # We've got a existing user folder, but it's not a PAS
@@ -845,6 +906,7 @@ def install(self):
         restoreUserData(portal, out, userdata)
         restoreGroupData(portal, out, groupdata, memberships)
 
+    # XXX Why do we need to do this?
     migrate_root_uf(self, out)
 
     print >> out, "\nSuccessfully installed %s." % config.PROJECTNAME
@@ -853,7 +915,7 @@ def install(self):
 
 # Future refactor notes:
 #  we cannot tell automatically between LDAP and AD uses of LDAPUserFolder
-#    - except maybe sAMAAccountName
+#    - except maybe sAMAccountName
 #    - so some sort of UI is necessary
 #  should have some sort of facility for allowing easy extension of migration of UFs
 #    - register grab and restore methods, or something
