@@ -1,9 +1,8 @@
-from AccessControl.Role import RoleManager
+from logging import DEBUG
+from zope.interface import implements
+
 from AccessControl import ClassSecurityInfo
-from Acquisition import Implicit
-from Acquisition import aq_parent
 from Acquisition import aq_base
-from Globals import Persistent
 from Globals import InitializeClass
 from Globals import PersistentMapping
 try:
@@ -11,12 +10,12 @@ try:
 except ImportError:
     from persistent.list import PersistentList
 from OFS.Folder import Folder
-from OFS.SimpleItem import Item
 
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
 from Products.CMFCore.ActionProviderBase import ActionProviderBase
 from Products.CMFCore.permissions import ManagePortal, View
+from Products.CMFCore.utils import registerToolInterface
 from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import getToolByName
 
@@ -25,6 +24,7 @@ from Products.PortalTransforms import transforms
 from Products.PortalTransforms.interfaces import iengine
 from Products.PortalTransforms.interfaces import idatastream
 from Products.PortalTransforms.interfaces import itransform
+from Products.PortalTransforms.interfaces import IPortalTransformsTool
 from Products.PortalTransforms.data import datastream
 from Products.PortalTransforms.chain import TransformsChain
 from Products.PortalTransforms.chain import chain
@@ -32,20 +32,16 @@ from Products.PortalTransforms.cache import Cache
 from Products.PortalTransforms.Transform import Transform
 from Products.PortalTransforms.utils import log
 from Products.PortalTransforms.utils import TransformException
-from Products.PortalTransforms.utils import BadRequest
 from Products.PortalTransforms.utils import _www
 
-__revision__ = '$Id: TransformEngine.py 7305 2006-12-29 22:08:43Z tomster $'
-
-from logging import DEBUG
-
 class TransformTool(UniqueObject, ActionProviderBase, Folder):
 
-    id        = 'portal_transforms'
+    id = 'portal_transforms'
     meta_type = id.title().replace('_', ' ')
     isPrincipiaFolderish = 1 # Show up in the ZMI
 
     __implements__ = iengine
+    implements(IPortalTransformsTool)
 
     meta_types = all_meta_types = (
         { 'name'   : 'Transform',
@@ -513,3 +509,4 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
         return available_types
 
 InitializeClass(TransformTool)
+registerToolInterface('portal_transforms', IPortalTransformsTool)
