@@ -1,7 +1,6 @@
 import os.path
 __version__ = open(os.path.join(__path__[0], 'version.txt')).read().strip()
 
-from Products.PortalTransforms.utils import skins_dir
 from Products.PortalTransforms.TransformEngine import TransformTool
 
 GLOBALS = globals()
@@ -26,9 +25,6 @@ from Products.MimetypesRegistry import MimeTypeItem
 sys.modules['Products.PortalTransforms.zope.MimeTypeItem'] = MimeTypeItem
 
 def initialize(context):
-    from Products.CMFCore.DirectoryView import registerDirectory
-    #registerDirectory(skins_dir, GLOBALS)
-
     from Products.CMFCore import utils
     utils.ToolInit("%s Tool" % PKG_NAME, 
                    tools=tools,
