@@ -120,8 +120,10 @@ VALID_TAGS = { 'a'          : 1
              , 'pre'        : 1
              , 'span'       : 1
              , 'strong'     : 1
+             , 'strike'     : 1
              , 'table'      : 1
              , 'tbody'      : 1
+             , 'thead'      : 1
              , 'td'         : 1
              , 'th'         : 1
              , 'title'      : 1
