@@ -1,6 +1,3 @@
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
 
 from Testing import ZopeTestCase
 from Products.Archetypes.tests.atsitetestcase import ATSiteTestCase
@@ -20,12 +17,15 @@ class TestGraph(ATSiteTestCase):
         out = self.engine.convertTo('text/plain', data, filename=FILE_PATH)
         assert(out.getData())
 
+    def testIdentity(self):
+        orig = 'Some text'
+        converted = self.engine.convertTo(
+            'text/plain', 'Some text', mimetype='text/plain')
+        self.assertEquals(orig, str(converted))
+
 
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestGraph))
     return suite
-
-if __name__ == '__main__':
-    framework()
