@@ -1,24 +1,21 @@
 #
 # CSSRegistry Tests
 #
-
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
-from textwrap import dedent
+from zope.component import getUtility, getMultiAdapter
+from zope.contentprovider.interfaces import IContentProvider
 
 from App.Common import rfc1123_date
 from DateTime import DateTime
 from zExceptions import NotFound
 from AccessControl import Unauthorized
-from Interface.Verify import verifyObject
+from zope.interface.verify import verifyObject
 
 from Products.CMFCore.utils import getToolByName
 
 from Products.PloneTestCase.PloneTestCase import PLONE21, portal_owner, default_password
 
 from Products.ResourceRegistries.config import CSSTOOLNAME
-from Products.ResourceRegistries.interfaces.ResourceRegistries import ICSSRegistry as z2ICSSRegistry
+from Products.ResourceRegistries.interfaces import ICSSRegistry
 from Products.ResourceRegistries.tests.RegistryTestCase import RegistryTestCase
 from Products.ResourceRegistries.tests.RegistryTestCase import FunctionalRegistryTestCase
 
@@ -27,8 +24,8 @@ class TestImplementation(RegistryTestCase):
 
     def test_interfaces(self):
         tool = getattr(self.portal, CSSTOOLNAME)
-        self.failUnless(z2ICSSRegistry.isImplementedBy(tool))
-        self.failUnless(verifyObject(z2ICSSRegistry, tool))
+        self.failUnless(ICSSRegistry.providedBy(tool))
+        self.failUnless(verifyObject(ICSSRegistry, tool))
 
 class TestTool(RegistryTestCase):
 
@@ -49,7 +46,7 @@ class TestSkin(RegistryTestCase):
         self.failUnless('ResourceRegistries' in skins)
 
     def testSkinExists(self):
-        self.failUnless(getattr(self.portal, 'renderAllTheStylesheets'))
+        self.failUnless(getattr(self.portal, 'test_rr_1.css'))
 
 
 class testZMIMethods(RegistryTestCase):
@@ -215,6 +212,10 @@ class TestStylesheetCooking(RegistryTestCase):
         self.assertEqual(len(self.tool.getResources()), 3)
         self.assertEqual(len(self.tool.cookedresources), 1)
         self.assertEqual(len(self.tool.concatenatedresources.keys()), 4)
+        self.tool.setAutoGroupingMode(True)
+        self.assertEqual(len(self.tool.getResources()), 3)
+        self.assertEqual(len(self.tool.cookedresources), 1)
+        self.assertEqual(len(self.tool.concatenatedresources.keys()), 4)
 
     def testStylesheetCookingValues(self):
         self.tool.registerStylesheet('ham')
@@ -244,6 +245,15 @@ class TestStylesheetCooking(RegistryTestCase):
         self.failUnless('spam spam' in self.tool.concatenatedresources[magic_ids[1]])
         self.failUnless('spam spam spam' in self.tool.concatenatedresources[magic_ids[1]])
 
+        self.tool.setAutoGroupingMode(True)
+        self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 2)
+        magic_ids = [item.getId() for item in self.tool.getEvaluatedResources(self.folder)]
+        self.failUnless('ham' in self.tool.concatenatedresources[magic_ids[0]])
+        self.failUnless('eggs' in self.tool.concatenatedresources[magic_ids[0]])
+        self.failUnless('spam' in self.tool.concatenatedresources[magic_ids[1]])
+        self.failUnless('spam spam' in self.tool.concatenatedresources[magic_ids[1]])
+        self.failUnless('spam spam spam' in self.tool.concatenatedresources[magic_ids[1]])
+
     def testConcatenatedStylesheetsHaveNoMedia(self):
         self.tool.registerStylesheet('ham')
         self.tool.registerStylesheet('spam', media='print')
@@ -254,16 +264,22 @@ class TestStylesheetCooking(RegistryTestCase):
         self.tool.registerStylesheet('ham')
         self.tool.registerStylesheet('spam', expression='python:1')
         self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 2)
+        self.tool.setAutoGroupingMode(True)
+        self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 2)
 
     def testGetEvaluatedStylesheetsWithFailingExpression(self):
         self.tool.registerStylesheet('ham')
         self.tool.registerStylesheet('spam', expression='python:0')
         self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 1)
+        self.tool.setAutoGroupingMode(True)
+        self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 1)
 
     def testGetEvaluatedStylesheetsWithContextualExpression(self):
         self.folder.invokeFactory('Document', 'eggs')
         self.tool.registerStylesheet('spam', expression='python:"eggs" in object.objectIds()')
         self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 1)
+        self.tool.setAutoGroupingMode(True)
+        self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 1)
 
     def testCollapsingStylesheetsLookup(self):
         self.tool.registerStylesheet('ham')
@@ -271,6 +287,9 @@ class TestStylesheetCooking(RegistryTestCase):
         self.tool.registerStylesheet('spam spam', expression='string:ham')
         evaluated = self.tool.getEvaluatedResources(self.folder)
         self.assertEqual(len(evaluated), 2)
+        self.tool.setAutoGroupingMode(True)
+        evaluated = self.tool.getEvaluatedResources(self.folder)
+        self.assertEqual(len(evaluated), 2)
 
     def testRenderingIsInTheRightOrder(self):
         self.tool.registerStylesheet('ham', expression='string:ham')
@@ -293,13 +312,22 @@ class TestStylesheetCooking(RegistryTestCase):
         self.failUnless(results[0] == 'ham')
         self.failUnless(results[1] == 'spam')
         self.failUnless(results[2] == 'eggs')
+        self.tool.setAutoGroupingMode(True)
+        evaluated = self.tool.getEvaluatedResources(self.folder)
+        results = self.tool.concatenatedresources[evaluated[0].getId()]
+        self.failUnless(results[0] == 'ham')
+        self.failUnless(results[1] == 'spam')
+        self.failUnless(results[2] == 'eggs')
 
     def testRenderingStylesheetLinks(self):
         self.tool.registerStylesheet('ham', rendering='link')
         self.tool.registerStylesheet('ham 2 b merged', rendering='link')
         self.tool.registerStylesheet('spam', expression='string:ham', rendering='link')
         self.tool.registerStylesheet('test_rr_1.css', rendering='inline')
-        all = getattr(self.portal, 'renderAllTheStylesheets')()
+        view = self.portal.restrictedTraverse('@@plone')
+        viewletmanager = getMultiAdapter((self.portal, self.portal.REQUEST, view), IContentProvider, name = u'plone.resourceregistries.styles')
+        viewletmanager.update()
+        all = viewletmanager.render()
         evaluated = self.tool.getEvaluatedResources(self.folder)
         magic_ids = [item.getId() for item in evaluated]
         self.failUnless('background-color' in all)
@@ -310,7 +338,10 @@ class TestStylesheetCooking(RegistryTestCase):
     def testReenderingConcatenatesInline(self):
         self.tool.registerStylesheet('test_rr_1.css', rendering='inline')
         self.tool.registerStylesheet('test_rr_2.css', rendering='inline')
-        all = getattr(self.portal, 'renderAllTheStylesheets')()
+        view = self.portal.restrictedTraverse('@@plone')
+        viewletmanager = getMultiAdapter((self.portal, self.portal.REQUEST, view), IContentProvider, name = u'plone.resourceregistries.styles')
+        viewletmanager.update()
+        all = viewletmanager.render()
         self.failUnless('background-color' in all)
         self.failUnless('blue' in all)
 
@@ -324,6 +355,8 @@ class TestStylesheetCooking(RegistryTestCase):
         self.tool.registerStylesheet('spam', rendering='link')
         self.tool.registerStylesheet('egg', rendering='inline')
         self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 3)
+        self.tool.setAutoGroupingMode(True)
+        self.assertEqual(len(self.tool.getEvaluatedResources(self.folder)), 2)
 
     def testRenderingWorksInMainTemplate(self):
         renderedpage = getattr(self.portal, 'index_html')()
@@ -562,10 +595,16 @@ class TestZODBTraversal(RegistryTestCase):
                                    file='body { background-color : purple }')
         self.tool.registerStylesheet('context.css', rendering='inline')
         self.setRoles(['Member'])
-        content = getattr(self.portal.folder1, 'renderAllTheStylesheets')()
+        view = self.portal.restrictedTraverse('@@plone')
+        viewletmanager = getMultiAdapter((self.portal.folder1, self.portal.folder1.REQUEST, view), IContentProvider, name = u'plone.resourceregistries.styles')
+        viewletmanager.update()
+        content = viewletmanager.render()
         self.failUnless('pink' in content)
         self.failIf('purple' in content)
-        content = getattr(self.portal.folder2, 'renderAllTheStylesheets')()
+        view = self.portal.restrictedTraverse('@@plone')
+        viewletmanager = getMultiAdapter((self.portal.folder2, self.portal.folder2.REQUEST, view), IContentProvider, name = u'plone.resourceregistries.styles')
+        viewletmanager.update()
+        content = viewletmanager.render()
         self.failUnless('purple' in content)
         self.failIf('pink' in content)
 
@@ -595,7 +634,7 @@ class TestMergingDisabled(RegistryTestCase):
     def testNumberOfResources(self):
         self.assertEqual(len(self.tool.getResources()), 3)
         self.assertEqual(len(self.tool.cookedresources), 2)
-        self.assertEqual(len(self.tool.concatenatedresources), 4)
+        self.assertEqual(len(self.tool.concatenatedresources), 5)
         styles = self.tool.getEvaluatedResources(self.portal)
         self.assertEqual(len(styles), 2)
 
@@ -603,19 +642,23 @@ class TestMergingDisabled(RegistryTestCase):
         self.tool.moveResourceToBottom('test_rr_2.css')
         self.assertEqual(len(self.tool.getResources()), 3)
         self.assertEqual(len(self.tool.cookedresources), 2)
-        self.assertEqual(len(self.tool.concatenatedresources), 4)
+        self.assertEqual(len(self.tool.concatenatedresources), 5)
         styles = self.tool.getEvaluatedResources(self.portal)
         self.assertEqual(len(styles), 2)
-        magicId = None
+        magicIds = []
         for style in styles:
             id = style.getId()
-            if id.startswith(self.tool.filename_base):
-                magicId = id
-        self.failUnless(magicId)
-        content = str(self.portal.restrictedTraverse('portal_css/%s' % magicId))
+            if '-cachekey' in id:
+                magicIds.append(id)
+        self.failUnless(magicIds[-1].startswith('test_rr_2'))
+        content = str(self.portal.restrictedTraverse('portal_css/%s' % magicIds[-2]))
         self.failUnless('red' in content)
         self.failUnless('green' in content)
         self.failIf('blue' in content)
+        content = str(self.portal.restrictedTraverse('portal_css/%s' % magicIds[-1]))
+        self.failIf('red' in content)
+        self.failIf('green' in content)
+        self.failUnless('blue' in content)
         content = str(self.portal.restrictedTraverse('portal_css/test_rr_2.css'))
         self.failUnless('blue' in content)
 
@@ -623,13 +666,13 @@ class TestMergingDisabled(RegistryTestCase):
         self.tool.moveResourceToTop('test_rr_2.css')
         self.assertEqual(len(self.tool.getResources()), 3)
         self.assertEqual(len(self.tool.cookedresources), 2)
-        self.assertEqual(len(self.tool.concatenatedresources), 4)
+        self.assertEqual(len(self.tool.concatenatedresources), 5)
         styles = self.tool.getEvaluatedResources(self.portal)
         self.assertEqual(len(styles), 2)
         magicId = None
         for style in styles:
             id = style.getId()
-            if id.startswith(self.tool.filename_base):
+            if '-cachekey' in id:
                 magicId = id
         self.failUnless(magicId)
         content = str(self.portal.restrictedTraverse('portal_css/%s' % magicId))
@@ -644,7 +687,7 @@ class TestMergingDisabled(RegistryTestCase):
         self.tool.moveResourceDown('test_rr_2.css')
         self.assertEqual(len(self.tool.getResources()), 3)
         self.assertEqual(len(self.tool.cookedresources), 3)
-        self.assertEqual(len(self.tool.concatenatedresources), 5)
+        self.assertEqual(len(self.tool.concatenatedresources), 6)
         styles = self.tool.getEvaluatedResources(self.portal)
         self.assertEqual(len(styles), 3)
         content = str(self.portal.restrictedTraverse('portal_css/test_rr_2.css'))
@@ -674,21 +717,21 @@ class TestMergingDisabled(RegistryTestCase):
         #Now have [[green,red],blue,[purple,pink]]
         self.assertEqual(len(self.tool.getResources()), 5)
         self.assertEqual(len(self.tool.cookedresources), 3)
-        self.assertEqual(len(self.tool.concatenatedresources), 7)
+        self.assertEqual(len(self.tool.concatenatedresources), 8)
         styles = self.tool.getEvaluatedResources(self.portal)
         self.assertEqual(len(styles), 3)
         magicIds = []
         for style in styles:
             id = style.getId()
-            if id.startswith(self.tool.filename_base):
+            if '-cachekey' in id:
                 magicIds.append(id)
-        self.assertEqual(len(magicIds), 2)
+        self.assertEqual(len(magicIds), 3)
         content = str(self.portal.restrictedTraverse('portal_css/%s' % magicIds[0]))
         self.failUnless('red' in content)
         self.failUnless('green' in content)
         self.failIf('pink' in content)
         self.failIf('purple' in content)
-        content = str(self.portal.restrictedTraverse('portal_css/%s' % magicIds[1]))
+        content = str(self.portal.restrictedTraverse('portal_css/%s' % magicIds[2]))
         self.failUnless('pink' in content)
         self.failUnless('purple' in content)
         self.failIf('red' in content)
@@ -808,8 +851,9 @@ class TestResourcePermissions(FunctionalRegistryTestCase):
     def testRemovedFromResources(self):
         styles = self.tool.getEvaluatedResources(self.portal)
         ids = [item.getId() for item in styles]
+        self.assertEqual(len(self.tool.concatenatedresources), 4)
         self.failIf('testroot.css' in ids)
-        self.failUnless('test_rr_1.css' in self.tool.concatenatedresources[ids[0]])
+        self.failUnless('test_rr_1.css' in self.tool.concatenatedresources[ids[1]])
 
     def testRemovedFromMergedResources(self):
         self.tool.unregisterResource('testroot.css')
@@ -818,7 +862,7 @@ class TestResourcePermissions(FunctionalRegistryTestCase):
         magicId = None
         for style in styles:
             id = style.getId()
-            if id.startswith(self.tool.filename_base):
+            if '-cachekey' in id:
                 magicId = id
         self.failUnless(magicId)
         content = str(self.portal.restrictedTraverse('portal_css/%s' % magicId))
@@ -952,12 +996,18 @@ class TestSkinAwareness(FunctionalRegistryTestCase):
         self.setRoles(['Member'])
         
     def testRenderIncludesSkinInPath(self):
-        self.portal.changeSkin('PinkSkin')
-        content = getattr(self.portal, 'renderAllTheStylesheets')()
+        self.portal.changeSkin('PinkSkin', REQUEST=self.portal.REQUEST)
+        view = self.portal.restrictedTraverse('@@plone')
+        viewletmanager = getMultiAdapter((self.portal, self.portal.REQUEST, view), IContentProvider, name = u'plone.resourceregistries.styles')
+        viewletmanager.update()
+        content = viewletmanager.render()
         self.failUnless('/PinkSkin/' in content)
         self.failIf('/PurpleSkin/' in content)
-        self.portal.changeSkin('PurpleSkin')
-        content = getattr(self.portal, 'renderAllTheStylesheets')()
+        self.portal.changeSkin('PurpleSkin', REQUEST=self.portal.REQUEST)
+        view = self.portal.restrictedTraverse('@@plone')
+        viewletmanager = getMultiAdapter((self.portal, self.portal.REQUEST, view), IContentProvider, name = u'plone.resourceregistries.styles')
+        viewletmanager.update()
+        content = viewletmanager.render()
         self.failUnless('/PurpleSkin/' in content)
         self.failIf('/PinkSkin/' in content)
 
@@ -1094,6 +1144,3 @@ def test_suite():
     suite.addTest(makeSuite(TestCachingHeaders))
 
     return suite
-
-if __name__ == '__main__':
-    framework()
