@@ -22,15 +22,12 @@ from OFS.Cache import Cacheable
 from Products.CMFCore.Expression import Expression
 from Products.CMFCore.Expression import createExprContext
 from Products.CMFCore.utils import UniqueObject, getToolByName
-from Products.CMFCore.ActionProviderBase import ActionProviderBase
 
-from Products.ResourceRegistries import config
 from Products.ResourceRegistries import permissions
-from Products.ResourceRegistries.interfaces.ResourceRegistries import IResourceRegistry as z2IResourceRegistry
 from Products.ResourceRegistries.interfaces import IResourceRegistry
 
 import Acquisition
-from thread import get_ident
+
 
 # version agnostic import of z3_Resource
 try:
@@ -58,6 +55,16 @@ def getDummyFileForContent(name, ctype):
     output.headers = {'content-type': ctype}
     return File(name, name, output)
 
+def getCharsetFromContentType(contenttype, default='utf-8'):
+    contenttype = contenttype.lower()
+    if 'charset=' in contenttype:
+        i = contenttype.index('charset=')
+        charset = contenttype[i+8:]
+        charset = charset.split(';')[0]
+        return charset
+    else:
+        return default
+
 class Resource(Persistent):
     security = ClassSecurityInfo()
 
@@ -93,7 +100,7 @@ class Resource(Persistent):
 
     security.declarePublic('getEnabled')
     def getEnabled(self):
-        return self._data['enabled']
+        return bool(self._data['enabled'])
 
     security.declareProtected(permissions.ManagePortal, 'setEnabled')
     def setEnabled(self, enabled):
@@ -129,7 +136,7 @@ class Skin(Acquisition.Implicit):
     def __before_publishing_traverse__(self, object, REQUEST):
         """ Pre-traversal hook. Specify the skin. 
         """
-        self.changeSkin(self._skin)
+        self.changeSkin(self._skin, REQUEST)
 
     def __bobo_traverse__(self, REQUEST, name):
         """Traversal hook."""
@@ -157,17 +164,18 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
 
     security = ClassSecurityInfo()
     implements(IResourceRegistry)
-    __implements__ = (SimpleItem.__implements__, z2IResourceRegistry)
+    __implements__ = SimpleItem.__implements__
     manage_options = SimpleItem.manage_options
 
     attributes_to_compare = ('getExpression', 'getCookable', 'getCacheable')
     filename_base = 'ploneResources'
     filename_appendix = '.res'
-    merged_output_prefix = ''
+    merged_output_prefix = u''
     cache_duration = 3600
     resource_class = Resource
 
-    debugmode = False # backward compatibility for old instances
+    debugmode = False
+    autogroupingmode = False
 
     #
     # Private Methods
@@ -179,6 +187,7 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         self.cookedresources = ()
         self.concatenatedresources = {}
         self.debugmode = False
+        self.autogroupingmode = False
 
     def __getitem__(self, item):
         """Return a resource from the registry."""
@@ -230,8 +239,9 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
             site_props = portal_props.site_properties
             charset = site_props.getProperty('default_charset', 'utf-8')
             output = output.encode(charset)
-            contenttype += ';charset=' + charset
-
+            if 'charset=' not in contenttype:
+                contenttype += ';charset=' + charset
+        
         out = StringIO(output)
         out.headers = {'content-type': contenttype}
         # At this point we are ready to provide some content
@@ -293,13 +303,14 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                 raise ValueError, 'Duplicate id %s' %(id)
 
     security.declarePrivate('storeResource')
-    def storeResource(self, resource):
+    def storeResource(self, resource, skipCooking=False):
         """Store a resource."""
         self.validateId(resource.getId(), self.getResources())
         resources = list(self.resources)
         resources.append(resource)
         self.resources = tuple(resources)
-        self.cookResources()
+        if not skipCooking:
+            self.cookResources()
 
     security.declarePrivate('clearResources')
     def clearResources(self):
@@ -331,11 +342,24 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                 return False
         return True
 
+    security.declarePrivate('sortResources')
+    def sortResourceKey(self, resource):
+        """Returns a sort key for the resource."""
+        return [getattr(resource, attr)() for attr in
+                self.attributes_to_compare]
+
     security.declarePrivate('generateId')
-    def generateId(self):
+    def generateId(self, res_id, prev_id=None):
         """Generate a random id."""
-        return '%s%04d%s' % (self.filename_base, random.randint(0, 9999),
-                             self.filename_appendix)
+        id_parts = res_id.split('.')
+        if (len(id_parts) > 1):
+            base = '.'.join(id_parts[:-1])
+            appendix = ".%s" % id_parts[-1]
+        else:
+            base = id_parts[0]
+            appendix = self.filename_appendix
+        base = base.replace('++', '').replace('/', '')
+        return '%s-cachekey%04d%s' % (base, random.randint(0, 9999), appendix)
 
     security.declarePrivate('finalizeResourceMerging')
     def finalizeResourceMerging(self, resource, previtem):
@@ -365,6 +389,17 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
             results = [x for x in resources]
         else:
             results = []
+            if self.getAutoGroupingMode():
+                # Sort resources according to their sortkey first, so resources
+                # with compatible keys will be merged.
+                def _sort_position(r):
+                    key = self.sortResourceKey(r[0])
+                    key.append(r[1])
+                    return key
+                # We need to respect the resource position inside the sort groups
+                positioned_resources = [(r, resources.index(r)) for r in resources]
+                positioned_resources.sort(key=_sort_position)
+                resources = [r[0] for r in positioned_resources]
             for resource in resources:
                 if results:
                     previtem = results[-1]
@@ -376,22 +411,22 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                         if self.concatenatedresources.has_key(prev_id):
                             self.concatenatedresources[prev_id].append(res_id)
                         else:
-                            magic_id = self.generateId()
+                            magic_id = self.generateId(res_id, prev_id)
                             self.concatenatedresources[magic_id] = [prev_id, res_id]
                             previtem._setId(magic_id)
                     else:
-                        if resource.getCookable():
-                            magic_id = self.generateId()
+                        if resource.getCookable() or resource.getCacheable():
+                            magic_id = self.generateId(resource.getId())
                             self.concatenatedresources[magic_id] = [resource.getId()]
                             resource._setId(magic_id)
                         results.append(resource)
                 else:
-                    if resource.getCookable():
-                        magic_id = self.generateId()
+                    if resource.getCookable() or resource.getCacheable():
+                        magic_id = self.generateId(resource.getId())
                         self.concatenatedresources[magic_id] = [resource.getId()]
                         resource._setId(magic_id)
                     results.append(resource)
-    
+
         resources = self.getResources()
         for resource in resources:
             self.concatenatedresources[resource.getId()] = [resource.getId()]
@@ -404,7 +439,7 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         """
         try:
             if expression and context is not None:
-                portal = getToolByName(self, 'portal_url').getPortalObject()
+                portal = getToolByName(context, 'portal_url').getPortalObject()
 
                 # Find folder (code courtesy of CMFCore.ActionsTool)
                 if context is None or not hasattr(context, 'aq_base'):
@@ -447,18 +482,19 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         resources = self.getResourcesDict()
         if ids is not None:
             ids = ids[:]
-        output = ""
+        output = u""
         if len(ids) > 1:
             output = output + self.merged_output_prefix
 
-        portal = None
-        u_tool = getToolByName(self, 'portal_url', None)
-        if u_tool:
-            portal = u_tool.getPortalObject()
+        portal = getToolByName(context, 'portal_url').getPortalObject()
 
         if context == self and portal is not None:
             context = portal
 
+        portal_props = getToolByName(self, 'portal_properties')
+        site_props = portal_props.site_properties
+        default_charset = site_props.getProperty('default_charset', 'utf-8')
+
         for id in ids:
             try:
                 if portal is not None:
@@ -467,16 +503,16 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                     #Can't do anything other than attempt a getattr
                     obj = getattr(context, id)
             except (AttributeError, KeyError):
-                output += "\n/* XXX ERROR -- could not find '%s'*/\n" % id
-                content = ''
+                output += u"\n/* XXX ERROR -- could not find '%s'*/\n" % id
+                content = u''
                 obj = None
             except Unauthorized:
                 #If we're just returning a single resource, raise an Unauthorized,
                 #otherwise we're merging resources in which case just log an error
                 if len(ids) > 1:
                     #Object probably isn't published yet
-                    output += "\n/* XXX ERROR -- access to '%s' not authorized */\n" % id
-                    content = ''
+                    output += u"\n/* XXX ERROR -- access to '%s' not authorized */\n" % id
+                    content = u''
                     obj = None
                 else:
                     raise
@@ -503,6 +539,9 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                         pass
                     # Now, get the content.
                     content = obj.GET()
+                    contenttype = self.REQUEST.RESPONSE.headers.get('content-type', '')
+                    contenttype = getCharsetFromContentType(contenttype, default_charset)
+                    content = unicode(content, contenttype)
                     # Now restore the headers and for safety, check that we
                     # have a 20x response. If not, we have a problem and
                     # some browser would hang indefinitely at this point.
@@ -512,30 +551,41 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                 elif hasattr(aq_base(obj),'meta_type') and  obj.meta_type in ['DTML Method', 'Filesystem DTML Method']:
                     content = obj(client=self.aq_parent, REQUEST=self.REQUEST,
                                   RESPONSE=self.REQUEST.RESPONSE)
-                
+                    contenttype = self.REQUEST.RESPONSE.headers.get('content-type', '')
+                    contenttype = getCharsetFromContentType(contenttype, default_charset)
+                    content = unicode(content, contenttype)
                 elif hasattr(aq_base(obj),'meta_type') and obj.meta_type == 'Filesystem File':
-                   obj._updateFromFS()
-                   content = obj._readFile(0)
+                    obj._updateFromFS()
+                    content = obj._readFile(0)
+                    contenttype = getCharsetFromContentType(obj.content_type, default_charset)
+                    content = unicode(content, contenttype)
                 elif hasattr(aq_base(obj),'meta_type') and obj.meta_type == 'ATFile':
-                    content = str(obj)
+                    f = obj.getFile()
+                    contenttype = getCharsetFromContentType(f.getContentType(), default_charset)
+                    content = unicode(str(f), contenttype)
                 # We should add more explicit type-matching checks
                 elif hasattr(aq_base(obj), 'index_html') and callable(obj.index_html):
                     content = obj.index_html(self.REQUEST,
                                              self.REQUEST.RESPONSE)
+                    if not isinstance(content, unicode):
+                        content = unicode(content, default_charset)
                 elif callable(obj):
                     content = obj(self.REQUEST, self.REQUEST.RESPONSE)
+                    if not isinstance(content, unicode):
+                        content = unicode(content, default_charset)
                 else:
                     content = str(obj)
+                    content = unicode(content, default_charset)
 
             # Add start/end notes to the resource for better
             # understanding and debugging
             if content:
-                output += '\n/* - %s - */\n' % (id,)
+                output += u'\n/* - %s - */\n' % (id,)
                 if original:
                     output += content
                 else:
                     output += self.finalizeContent(resources[id], content)
-                output += '\n'
+                output += u'\n'
         return output
 
     #
@@ -705,6 +755,17 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         self.debugmode = value
         self.cookResources()
 
+    security.declareProtected(permissions.ManagePortal, 'getAutoGroupingMode')
+    def getAutoGroupingMode(self):
+        """Is resource merging disabled?"""
+        return self.autogroupingmode
+
+    security.declareProtected(permissions.ManagePortal, 'setAutoGroupingMode')
+    def setAutoGroupingMode(self, value):
+        """Set whether resource merging should be disabled."""
+        self.autogroupingmode = bool(value)
+        self.cookResources()
+
     security.declareProtected(permissions.View, 'getEvaluatedResources')
     def getEvaluatedResources(self, context):
         """Return the filtered evaluated resources."""
@@ -714,31 +775,6 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         results = [item for item in results
                    if self.evaluateExpression(item.getExpression(), context)]
 
-        # filter out resources to which the user does not have access
-        # this is mainly cosmetic but saves raising lots of Unauthorized
-        # requests whilst resources are in their private state. 404s should stay
-        # though since they indicate an error on the part of the designer/developer
-        # or are considered legal by the Unit Tests!
-        portal = None
-        u_tool = getToolByName(self, 'portal_url', None)
-        if u_tool:
-            portal = u_tool.getPortalObject()
-
-        if portal is not None:
-            #If we don't have a portal object, just let'em through - the stylesheets will raise
-            # an Unauthorized when requested though
-            for item in results:
-                id = item.getId()
-                if not id.startswith(self.filename_base):
-                    try:
-                        obj = portal.restrictedTraverse(id)
-                    except Unauthorized:
-                        #Only include links to Unauthorized objects if we're debugging
-                        if not self.getDebugMode():
-                            results.remove(item)
-                    except (AttributeError, KeyError):
-                        pass
-
         return results
 
     security.declareProtected(permissions.View, 'getInlineResource')
