@@ -1,4 +1,3 @@
-from DateTime import DateTime
 from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
 
@@ -10,12 +9,10 @@ from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
 from Products.ResourceRegistries import config
 from Products.ResourceRegistries import permissions
-from Products.ResourceRegistries.interfaces.ResourceRegistries import ICSSRegistry as z2ICSSRegistry
 from Products.ResourceRegistries.interfaces import ICSSRegistry
 from Products.ResourceRegistries.tools.BaseRegistry import BaseRegistryTool
 from Products.ResourceRegistries.tools.BaseRegistry import Resource
 
-import re
 from packer import CSSPacker
 
 
@@ -94,7 +91,7 @@ class CSSRegistryTool(BaseRegistryTool):
     security = ClassSecurityInfo()
 
     implements(ICSSRegistry)
-    __implements__ = (BaseRegistryTool.__implements__, z2ICSSRegistry,)
+    __implements__ = BaseRegistryTool.__implements__
 
     #
     # ZMI stuff
@@ -118,7 +115,7 @@ class CSSRegistryTool(BaseRegistryTool):
                              'getCacheable', 'getRel', 'getRendering')
     filename_base = 'ploneStyles'
     filename_appendix = '.css'
-    merged_output_prefix = ''
+    merged_output_prefix = u''
     cache_duration = config.CSS_CACHE_DURATION
     resource_class = Stylesheet
 
@@ -127,7 +124,7 @@ class CSSRegistryTool(BaseRegistryTool):
     #
 
     security.declarePrivate('storeResource')
-    def storeResource(self, resource):
+    def storeResource(self, resource, skipCooking=False):
         """Store a resource."""
         self.validateId(resource.getId(), self.getResources())
         resources = list(self.getResources())
@@ -137,7 +134,8 @@ class CSSRegistryTool(BaseRegistryTool):
         else:
             resources.append(resource)
         self.resources = tuple(resources)
-        self.cookResources()
+        if not skipCooking:
+            self.cookResources()
 
     security.declarePrivate('clearStylesheets')
     def clearStylesheets(self):
@@ -206,6 +204,8 @@ class CSSRegistryTool(BaseRegistryTool):
         """
         debugmode = REQUEST.get('debugmode',False)
         self.setDebugMode(debugmode)
+        autogroupingmode = REQUEST.get('autogroupingmode', False)
+        self.setAutoGroupingMode(autogroupingmode)
         records = REQUEST.get('stylesheets')
         records.sort(lambda a, b: a.sort - b.sort)
         self.resources = ()
@@ -241,7 +241,8 @@ class CSSRegistryTool(BaseRegistryTool):
     security.declareProtected(permissions.ManagePortal, 'registerStylesheet')
     def registerStylesheet(self, id, expression='', media='', rel='stylesheet',
                            title='', rendering='import',  enabled=1,
-                           cookable=True, compression='safe', cacheable=True):
+                           cookable=True, compression='safe', cacheable=True,
+                           skipCooking=False):
         """Register a stylesheet."""
         stylesheet = Stylesheet(id,
                                 expression=expression,
@@ -253,7 +254,7 @@ class CSSRegistryTool(BaseRegistryTool):
                                 cookable=cookable,
                                 compression=compression,
                                 cacheable=cacheable)
-        self.storeResource(stylesheet)
+        self.storeResource(stylesheet, skipCooking=skipCooking)
 
     security.declareProtected(permissions.ManagePortal, 'updateStylesheet')
     def updateStylesheet(self, id, **data):
