@@ -1,4 +1,3 @@
-from DateTime import DateTime
 from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
 
@@ -10,7 +9,6 @@ from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
 from Products.ResourceRegistries import config
 from Products.ResourceRegistries import permissions
-from Products.ResourceRegistries.interfaces.ResourceRegistries import IJSRegistry as z2IJSRegistry
 from Products.ResourceRegistries.interfaces import IJSRegistry
 from Products.ResourceRegistries.tools.BaseRegistry import BaseRegistryTool
 from Products.ResourceRegistries.tools.BaseRegistry import Resource
@@ -61,7 +59,7 @@ class JSRegistryTool(BaseRegistryTool):
     security = ClassSecurityInfo()
 
     implements(IJSRegistry)
-    __implements__ = (BaseRegistryTool.__implements__, z2IJSRegistry)
+    __implements__ = BaseRegistryTool.__implements__
 
     #
     # ZMI stuff
@@ -86,7 +84,7 @@ class JSRegistryTool(BaseRegistryTool):
     filename_base = 'ploneScripts'
     filename_appendix = '.js'
     cache_duration = config.JS_CACHE_DURATION
-    merged_output_prefix = """
+    merged_output_prefix = u"""
 /* Merged Plone Javascript file
  * This file is dynamically assembled from separate parts.
  * Some of these parts have 3rd party licenses or copyright information attached
@@ -148,8 +146,10 @@ class JSRegistryTool(BaseRegistryTool):
 
         Updates the whole sequence. For editing and reordering.
         """
-        debugmode = REQUEST.get('debugmode',False)
+        debugmode = REQUEST.get('debugmode', False)
         self.setDebugMode(debugmode)
+        autogroupingmode = REQUEST.get('autogroupingmode', False)
+        self.setAutoGroupingMode(autogroupingmode)
         records = REQUEST.form.get('scripts')
         records.sort(lambda a, b: a.sort-b.sort)
         self.resources = ()
@@ -181,7 +181,8 @@ class JSRegistryTool(BaseRegistryTool):
 
     security.declareProtected(permissions.ManagePortal, 'registerScript')
     def registerScript(self, id, expression='', inline=False, enabled=True,
-                       cookable=True, compression='safe', cacheable=True):
+                       cookable=True, compression='safe', cacheable=True,
+                       skipCooking=False):
         """Register a script."""
         script = JavaScript(id,
                             expression=expression,
@@ -190,7 +191,7 @@ class JSRegistryTool(BaseRegistryTool):
                             cookable=cookable,
                             compression=compression,
                             cacheable=cacheable)
-        self.storeResource(script)
+        self.storeResource(script, skipCooking=skipCooking)
 
     security.declareProtected(permissions.ManagePortal, 'updateScript')
     def updateScript(self, id, **data):
