@@ -13,7 +13,7 @@
 #
 ##############################################################################
 """SMTP mail objects
-$Id: SecureMailHost.py 39729 2007-03-25 13:21:14Z hannosch $
+$Id: SecureMailHost.py 45282 2007-07-08 20:26:19Z optilude $
 """
 
 from config import BAD_HEADERS
@@ -27,11 +27,9 @@ from email.Utils import getaddresses
 from email.Utils import formataddr
 
 import re
-from types import StringType, TupleType, ListType
 
 from AccessControl import ClassSecurityInfo
-from AccessControl.Permissions import view_management_screens, \
-                                      use_mailhost_services
+from AccessControl.Permissions import use_mailhost_services
 from Globals import Persistent, DTMLFile, InitializeClass
 from Products.MailHost.MailHost import MailHostError, MailBase
 from Products.SecureMailHost.mail import Mail
@@ -206,6 +204,8 @@ class SecureMailBase(MailBase):
             # change the message
             msg = deepcopy(message)
         else:
+            if isinstance(message, unicode):
+                message = message.encode(charset)
             msg = email.MIMEText.MIMEText(message, subtype, charset)
 
         mfrom = encodeHeaderAddress(mfrom, charset)
@@ -253,7 +253,7 @@ class SecureMailBase(MailBase):
     def _send(self, mfrom, mto, messageText, debug=False):
         """Send the message
         """
-        if not isinstance(messageText, email.MIMEText.MIMEText):
+        if not isinstance(messageText, email.Message.Message):
             message = email.message_from_string(messageText)
         else:
             message = messageText
@@ -278,14 +278,14 @@ class SecureMailBase(MailBase):
             or mixed
         """
         # stage 1: test for type
-        if type(addr_list) not in (TupleType, ListType):
+        if not isinstance(addr_list, (list, tuple)):
             # a string is supposed to be a valid list of email addresses
             # or None
             return addr_list
         # stage 2: get a list of address strings using email.formataddr
         addresses = []
         for addr in addr_list:
-            if type(addr) is StringType:
+            if isinstance(addr, basestring):
                 addresses.append(email.Utils.formataddr(('', addr)))
             else:
                 if len(addr) != 2:
@@ -303,7 +303,7 @@ class SecureMailBase(MailBase):
         """Lower-level function to validate a single normalized email
         address, see validateEmailAddress
         """
-        if type(address) is not StringType:
+        if not isinstance(address, basestring):
             return False
 
         sub = EMAIL_CUTOFF_RE.match(address);
@@ -321,7 +321,7 @@ class SecureMailBase(MailBase):
     def validateSingleEmailAddress(self, address):
         """Validate a single email address, see also validateEmailAddresses
         """
-        if type(address) is not StringType:
+        if not isinstance(address, basestring):
             return False
 
         sub = EMAIL_CUTOFF_RE.match(address);
@@ -345,7 +345,7 @@ class SecureMailBase(MailBase):
         """Validate a list of possibly several email addresses, see
         also validateSingleEmailAddress
         """
-        if type(addresses) is not StringType:
+        if not isinstance(addresses, basestring):
             return False
 
         sub = EMAIL_CUTOFF_RE.match(addresses);
