@@ -7,14 +7,14 @@
  * Contributors see CREDITS.txt.
  *
  *****************************************************************************/
-
-// $Id: kupusaveonpart.js 25040 2006-03-27 14:49:21Z fschulze $
+// $Id: kupusaveonpart.js 35854 2006-12-18 15:37:15Z duncan $
 
 function saveOnPart() {
     /* ask the user if (s)he wants to save the document before leaving */
-    if (kupu.content_changed && 
-        confirm(_('You are leaving the editor. Do you want to save your changes?'))) {
+    if (kupu.content_changed && confirm(
+            _('You are leaving the editor. Do you want to save your changes?')
+            )) {
         kupu.config.reload_src = 0;
         kupu.saveDocument(false, true);
     };
-};
+}
