@@ -9,7 +9,7 @@
 ##############################################################################
 """Zope2 permissions for server-side Kupu interaction
 
-$Id: permissions.py 9879 2005-03-18 12:04:00Z yuppie $
+$Id: permissions.py 36159 2007-01-05 08:50:23Z duncan $
 """
 try:
     from Products.CMFCore.permissions import setDefaultRoles
@@ -21,5 +21,5 @@ QueryLibraries = "Kupu: Query libraries"
 ManageLibraries = "Kupu: Manage libraries"
 
 # Set up default roles for permissions
-setDefaultRoles(QueryLibraries, ('Manager', 'Member'))
+setDefaultRoles(QueryLibraries, ('Manager', 'Authenticated'))
 setDefaultRoles(ManageLibraries, ('Manager',))
