@@ -20,35 +20,6 @@ if 'final' in release:
 
 numversion = (int(major), int(minor), int(bugfix), relinfo)
 
-at_versions = (
-    '1.3.0-final',
-    '1.3.1-rc1',
-    '1.3.1-rc2',
-    '1.3.1-rc3',
-    '1.3.1-rc4',
-    '1.3.1-final',
-    '1.3.2-rc1',
-    '1.3.2-final',
-    '1.3.3-rc1',
-    '1.3.3-rc2',
-    '1.3.3-rc3',
-    '1.3.3-final',
-    '1.3.4-beta1',
-    '1.3.4-beta2',
-    '1.3.4-rc1',
-    '1.3.4-rc2',
-    '1.3.4-rc3',
-    '1.3.4-final',
-    '1.3.5-final',
-    '1.3.6-RC1',
-    '1.3.6-final',
-    '1.3.7-final',
-    '1.3.8-final',
-    '1.3.9-final',
-    '1.3.10-final',
-    '1.3.10-final2',
-    ###MARKERFORATRELEASESCRIPT###
-    )
 license = 'BSD (ish)'
 copyright = '''Benjamin Saller (c) 2003'''
 
@@ -58,7 +29,7 @@ author_email = "archetypes-devel@lists.sourceforge.net"
 short_desc = "Some generic validators originaly defined for Archetypes"
 long_desc = short_desc
 
-web = "http://www.sourceforge.net/projects/archetypes"
+web = "http://plone.org/products/archetypes"
 ftp = ""
 mailing_list = "archetypes-devel@lists.sourceforge.net"
 
